@@ -77,7 +77,7 @@ MediaWindowControl::~MediaWindowControl()
 void MediaWindowControl::update()
 {
     MediaItem aItem;
-    
+
     static_cast< MediaWindowImpl* >( GetParent() )->updateMediaItem( aItem );
     setState( aItem );
 }
@@ -94,11 +94,7 @@ void  MediaWindowControl::execute( const MediaItem& rItem )
 // --------------------
 
 MediaChildWindow::MediaChildWindow( Window* pParent ) :
-#ifdef GSTREAMER
     SystemChildWindow( pParent, WB_CLIPCHILDREN )
-#else
-    JavaChildWindow( pParent, WB_CLIPCHILDREN )
-#endif
 {
 }
 
@@ -114,12 +110,8 @@ void MediaChildWindow::MouseMove( const MouseEvent& rMEvt )
 {
     const MouseEvent aTransformedEvent( GetParent()->ScreenToOutputPixel( OutputToScreenPixel( rMEvt.GetPosPixel() ) ),
                                           rMEvt.GetClicks(), rMEvt.GetMode(), rMEvt.GetButtons(), rMEvt.GetModifier() );
-    
-#ifdef GSTREAMER
+
     SystemChildWindow::MouseMove( rMEvt );
-#else
-    JavaChildWindow::MouseMove( rMEvt );
-#endif
     GetParent()->MouseMove( aTransformedEvent );
 }
 
@@ -129,12 +121,8 @@ void MediaChildWindow::MouseButtonDown( const MouseEvent& rMEvt )
 {
     const MouseEvent aTransformedEvent( GetParent()->ScreenToOutputPixel( OutputToScreenPixel( rMEvt.GetPosPixel() ) ),
                                           rMEvt.GetClicks(), rMEvt.GetMode(), rMEvt.GetButtons(), rMEvt.GetModifier() );
-    
-#ifdef GSTREAMER
+
     SystemChildWindow::MouseButtonDown( rMEvt );
-#else
-    JavaChildWindow::MouseButtonDown( rMEvt );
-#endif
     GetParent()->MouseButtonDown( aTransformedEvent );
 }
 
@@ -145,11 +133,7 @@ void MediaChildWindow::MouseButtonUp( const MouseEvent& rMEvt )
     const MouseEvent aTransformedEvent( GetParent()->ScreenToOutputPixel( OutputToScreenPixel( rMEvt.GetPosPixel() ) ),
                                           rMEvt.GetClicks(), rMEvt.GetMode(), rMEvt.GetButtons(), rMEvt.GetModifier() );
 
-#ifdef GSTREAMER
     SystemChildWindow::MouseButtonUp( rMEvt );
-#else
-    JavaChildWindow::MouseButtonUp( rMEvt );
-#endif
     GetParent()->MouseButtonUp( aTransformedEvent );
 }
 
@@ -157,11 +141,7 @@ void MediaChildWindow::MouseButtonUp( const MouseEvent& rMEvt )
 
 void MediaChildWindow::KeyInput( const KeyEvent& rKEvt )
 {
-#ifdef GSTREAMER
     SystemChildWindow::KeyInput( rKEvt );
-#else
-    JavaChildWindow::KeyInput( rKEvt );
-#endif
     GetParent()->KeyInput( rKEvt );
 }
 
@@ -169,11 +149,7 @@ void MediaChildWindow::KeyInput( const KeyEvent& rKEvt )
 
 void MediaChildWindow::KeyUp( const KeyEvent& rKEvt )
 {
-#ifdef GSTREAMER
     SystemChildWindow::KeyUp( rKEvt );
-#else
-    JavaChildWindow::KeyUp( rKEvt );
-#endif
     GetParent()->KeyUp( rKEvt );
 }
 
@@ -183,12 +159,8 @@ void MediaChildWindow::Command( const CommandEvent& rCEvt )
 {
     const CommandEvent aTransformedEvent( GetParent()->ScreenToOutputPixel( OutputToScreenPixel( rCEvt.GetMousePosPixel() ) ),
                                             rCEvt.GetCommand(), rCEvt.IsMouseEvent(), rCEvt.GetData() );
-    
-#ifdef GSTREAMER
+
     SystemChildWindow::Command( rCEvt );
-#else
-    JavaChildWindow::Command( rCEvt );
-#endif
     GetParent()->Command( aTransformedEvent );
 }
 
@@ -207,9 +179,10 @@ MediaWindowImpl::MediaWindowImpl( Window* pParent, MediaWindow* pMediaWindow, bo
     mpEmptyBmpEx( NULL ),
     mpAudioBmpEx( NULL )
 {
+    maChildWindow.SetBackground( Color( COL_BLACK ) );
     maChildWindow.SetHelpId( HID_AVMEDIA_PLAYERWINDOW );
     maChildWindow.Hide();
-    
+
     if( mpMediaWindowControl )
     {
         mpMediaWindowControl->SetSizePixel( mpMediaWindowControl->getMinSizePixel() );
@@ -239,12 +212,12 @@ void MediaWindowImpl::cleanUp()
         xPlayerWindow->removeKeyListener( uno::Reference< awt::XKeyListener >( mxEventsIf, uno::UNO_QUERY ) );
         xPlayerWindow->removeMouseListener( uno::Reference< awt::XMouseListener >( mxEventsIf, uno::UNO_QUERY ) );
         xPlayerWindow->removeMouseMotionListener( uno::Reference< awt::XMouseMotionListener >( mxEventsIf, uno::UNO_QUERY ) );
-        
+
         uno::Reference< lang::XComponent > xComponent( xPlayerWindow, uno::UNO_QUERY );
-        
+
         if( xComponent.is() )
             xComponent->dispose();
-            
+
         setPlayerWindow( NULL );
     }
 
@@ -261,28 +234,15 @@ void MediaWindowImpl::onURLChanged()
         uno::Reference< media::XPlayerWindow > xPlayerWindow;
         const Point                            aPoint;
         const Size					           aSize( maChildWindow.GetSizePixel() );
-#ifndef GSTREAMER
-        const sal_IntPtr                       nWndHandle = static_cast< sal_IntPtr >( maChildWindow.getParentWindowHandleForJava() );
-#else
         const sal_Int32                        nWndHandle = 0;
-#endif
        
         aArgs[ 0 ] = uno::makeAny( nWndHandle );
         aArgs[ 1 ] = uno::makeAny( awt::Rectangle( aPoint.X(), aPoint.Y(), aSize.Width(), aSize.Height() ) );
-#ifdef GSTREAMER
-                const SystemEnvData *pSystemData = maChildWindow.GetSystemData();
-                OSL_TRACE( "MediaWindowImpl::onURLChanged xwindow id: %ld", pSystemData->aWindow );
-                aArgs[ 2 ] = uno::makeAny( pSystemData->aWindow );
-#endif
-        
+        aArgs[ 2 ] = uno::makeAny( reinterpret_cast< sal_IntPtr >( &maChildWindow ) );
+
         try
         {
-#ifdef GSTREAMER
-            if( pSystemData->aWindow != 0 )
-#else
-            if( nWndHandle != 0 )
-#endif
-                xPlayerWindow = getPlayer()->createPlayerWindow( aArgs );
+            xPlayerWindow = getPlayer()->createPlayerWindow( aArgs );
         }
         catch( uno::RuntimeException )
         {
@@ -323,7 +283,7 @@ void MediaWindowImpl::onURLChanged()
 void MediaWindowImpl::update()
 {
     uno::Reference< media::XPlayerWindow > xPlayerWindow( getPlayerWindow() );
-    
+
     if( xPlayerWindow.is() )
         xPlayerWindow->update();
 }
@@ -332,7 +292,7 @@ void MediaWindowImpl::update()
 
 void MediaWindowImpl::setPosSize( const Rectangle& rRect )
 {
-    SetPosSizePixel( rRect.Left(), rRect.Top(), rRect.GetWidth(), rRect.GetHeight() );
+    SetPosSizePixel( rRect.TopLeft(), rRect.GetSize() );
 }
 
 // ---------------------------------------------------------------------
@@ -340,25 +300,24 @@ void MediaWindowImpl::setPosSize( const Rectangle& rRect )
 void MediaWindowImpl::setPointer( const Pointer& rPointer )
 {
     uno::Reference< media::XPlayerWindow >	xPlayerWindow( getPlayerWindow() );
-    
+
     SetPointer( rPointer );
     maChildWindow.SetPointer( rPointer );
-    
+
     if( xPlayerWindow.is() )
     {
-        
         long nPointer;
-        
+
         switch( rPointer.GetStyle() )
         {
             case( POINTER_CROSS ): nPointer = awt::SystemPointer::CROSS; break;
             case( POINTER_HAND ): nPointer = awt::SystemPointer::HAND; break;
             case( POINTER_MOVE ): nPointer = awt::SystemPointer::MOVE; break;
             case( POINTER_WAIT ): nPointer = awt::SystemPointer::WAIT; break;
-            
+
             default: nPointer = awt::SystemPointer::ARROW; break;
         }
-        
+
         xPlayerWindow->setPointerType( nPointer );
     }
 }
@@ -386,20 +345,20 @@ void MediaWindowImpl::Resize()
     const sal_Int32							nOffset( mpMediaWindowControl ? AVMEDIA_CONTROLOFFSET : 0 );
     Size 									aPlayerWindowSize( aCurSize.Width() - ( nOffset << 1 ),
                                                                aCurSize.Height() - ( nOffset << 1 ) );
-    
+
     if( mpMediaWindowControl )
     {
         const sal_Int32	nControlHeight = mpMediaWindowControl->GetSizePixel().Height();
         const sal_Int32	nControlY = ::std::max( aCurSize.Height() - nControlHeight - nOffset, 0L );
-        
+
         aPlayerWindowSize.Height() = ( nControlY - ( nOffset << 1 ) );
         mpMediaWindowControl->SetPosSizePixel( Point( nOffset, nControlY ), Size( aCurSize.Width() - ( nOffset << 1 ), nControlHeight ) );
     }
-                                       
-    maChildWindow.SetPosSizePixel( Point( nOffset, nOffset ), aPlayerWindowSize );
-    
+
     if( xPlayerWindow.is() )
         xPlayerWindow->setPosSize( 0, 0, aPlayerWindowSize.Width(), aPlayerWindowSize.Height(), 0 );
+
+    maChildWindow.SetPosSizePixel( Point( nOffset, nOffset ), aPlayerWindowSize );
 }
 
 // ---------------------------------------------------------------------
@@ -438,25 +397,25 @@ void MediaWindowImpl::StateChanged( StateChangedType eType )
 void MediaWindowImpl::Paint( const Rectangle& )
 {
     BitmapEx* pLogo = NULL;
-    
+
     if( !getPlayer().is() )
     {
         if( !mpEmptyBmpEx )
             mpEmptyBmpEx = new BitmapEx( AVMEDIA_RESID( AVMEDIA_BMP_EMPTYLOGO ) );
-        
+
         pLogo = mpEmptyBmpEx;
     }
-    else if ( !getPlayerWindow().is() )
+    else if( !getPlayerWindow().is() )
     {
         if( !mpAudioBmpEx )
             mpAudioBmpEx = new BitmapEx( AVMEDIA_RESID( AVMEDIA_BMP_AUDIOLOGO ) );
-    
+
         pLogo = mpAudioBmpEx;
     }
 
     const Point     aBasePos( maChildWindow.GetPosPixel() );
-    const Rectangle aVideoRect( aBasePos, maChildWindow.GetSizePixel() ); 	
-        
+    const Rectangle aVideoRect( aBasePos, maChildWindow.GetSizePixel() );
+
     if( pLogo && !pLogo->IsEmpty() && ( aVideoRect.GetWidth() > 0 ) && ( aVideoRect.GetHeight() > 0 ) )
     {
         Size	    aLogoSize( pLogo->GetSizePixel() );
@@ -465,7 +424,7 @@ void MediaWindowImpl::Paint( const Rectangle& )
         SetLineColor( aBackgroundColor );
         SetFillColor( aBackgroundColor );
         DrawRect( aVideoRect );
-        
+
         if( ( aLogoSize.Width() > aVideoRect.GetWidth() || aLogoSize.Height() > aVideoRect.GetHeight() ) &&
             ( aLogoSize.Height() > 0 ) )
         {
@@ -483,12 +442,10 @@ void MediaWindowImpl::Paint( const Rectangle& )
             }
         }
 
-        DrawBitmapEx( Point( aBasePos.X() + ( ( aVideoRect.GetWidth() - aLogoSize.Width() ) >> 1 ), 
+        DrawBitmapEx( Point( aBasePos.X() + ( ( aVideoRect.GetWidth() - aLogoSize.Width() ) >> 1 ),
                              aBasePos.Y() + ( ( aVideoRect.GetHeight() - aLogoSize.Height() ) >> 1 ) ),
                       aLogoSize, *pLogo );
     }
-
-    update();
 }
 
 // ---------------------------------------------------------------------
