@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -59,6 +59,7 @@
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star;
 
+using ::std::vector;
 
 DBG_NAME( IDEBaseWindow )
 
@@ -81,7 +82,7 @@ IDEBaseWindow::IDEBaseWindow( Window* pParent, const ScriptDocument& rDocument,
 
 
 
-__EXPORT IDEBaseWindow::~IDEBaseWindow()
+IDEBaseWindow::~IDEBaseWindow()
 {
     DBG_DTOR( IDEBaseWindow, 0 );
     if ( pShellVScrollBar )
@@ -104,7 +105,7 @@ void IDEBaseWindow::Init()
 
 
 
-void __EXPORT IDEBaseWindow::DoInit()
+void IDEBaseWindow::DoInit()
 {
 }
 
@@ -130,14 +131,14 @@ IMPL_LINK_INLINE_END( IDEBaseWindow, ScrollHdl, ScrollBar *, pCurScrollBar )
 
 
 
-void __EXPORT IDEBaseWindow::ExecuteCommand( SfxRequest& )
+void IDEBaseWindow::ExecuteCommand( SfxRequest& )
 {
     DBG_CHKTHIS( IDEBaseWindow, 0 );
 }
 
 
 
-void __EXPORT IDEBaseWindow::GetState( SfxItemSet& )
+void IDEBaseWindow::GetState( SfxItemSet& )
 {
     DBG_CHKTHIS( IDEBaseWindow, 0 );
 }
@@ -151,7 +152,7 @@ long IDEBaseWindow::Notify( NotifyEvent& rNEvt )
     {
         KeyEvent aKEvt = *rNEvt.GetKeyEvent();
         KeyCode aCode = aKEvt.GetKeyCode();
-        USHORT nCode = aCode.GetCode();
+        sal_uInt16 nCode = aCode.GetCode();
 
         switch ( nCode )
         {
@@ -175,34 +176,34 @@ long IDEBaseWindow::Notify( NotifyEvent& rNEvt )
 }
 
 
-void __EXPORT IDEBaseWindow::DoScroll( ScrollBar* )
+void IDEBaseWindow::DoScroll( ScrollBar* )
 {
     DBG_CHKTHIS( IDEBaseWindow, 0 );
 }
 
 
-void __EXPORT IDEBaseWindow::StoreData()
+void IDEBaseWindow::StoreData()
 {
 }
 
-BOOL __EXPORT IDEBaseWindow::CanClose()
+sal_Bool IDEBaseWindow::CanClose()
 {
-    return TRUE;
+    return sal_True;
 }
 
-BOOL __EXPORT IDEBaseWindow::AllowUndo()
+sal_Bool IDEBaseWindow::AllowUndo()
 {
-    return TRUE;
+    return sal_True;
 }
 
 
 
-void __EXPORT IDEBaseWindow::UpdateData()
+void IDEBaseWindow::UpdateData()
 {
 }
 
 
-String __EXPORT IDEBaseWindow::GetTitle()
+String IDEBaseWindow::GetTitle()
 {
     return String();
 }
@@ -225,39 +226,39 @@ String IDEBaseWindow::CreateQualifiedName()
     return aName;
 }
 
-void IDEBaseWindow::SetReadOnly( BOOL )
+void IDEBaseWindow::SetReadOnly( sal_Bool )
 {
 }
 
-BOOL IDEBaseWindow::IsReadOnly()
+sal_Bool IDEBaseWindow::IsReadOnly()
 {
-    return FALSE;
+    return sal_False;
 }
 
-void __EXPORT IDEBaseWindow::BasicStarted()
+void IDEBaseWindow::BasicStarted()
 {
 }
 
-void __EXPORT IDEBaseWindow::BasicStopped()
+void IDEBaseWindow::BasicStopped()
 {
 }
 
-BOOL __EXPORT IDEBaseWindow::IsModified()
+sal_Bool IDEBaseWindow::IsModified()
 {
-    return TRUE;
+    return sal_True;
 }
 
-BOOL __EXPORT IDEBaseWindow::IsPasteAllowed()
+sal_Bool IDEBaseWindow::IsPasteAllowed()
 {
-    return FALSE;
+    return sal_False;
 }
 
-Window* __EXPORT IDEBaseWindow::GetLayoutWindow()
+Window* IDEBaseWindow::GetLayoutWindow()
 {
     return this;
 }
 
-SfxUndoManager* __EXPORT IDEBaseWindow::GetUndoManager()
+::svl::IUndoManager* IDEBaseWindow::GetUndoManager()
 {
     return NULL;
 }
@@ -265,11 +266,10 @@ SfxUndoManager* __EXPORT IDEBaseWindow::GetUndoManager()
 BreakPointList::BreakPointList()
 {}
 
-BreakPointList::BreakPointList(BreakPointList const & rList):
-    BreakPL( sal::static_int_cast<USHORT>( rList.Count() ))
+BreakPointList::BreakPointList(BreakPointList const & rList)
 {
-    for (ULONG i = 0; i < rList.Count(); ++i)
-        Insert(new BreakPoint(*rList.GetObject(i)), i);
+    for (size_t i = 0; i < rList.size(); ++i)
+        maBreakPoints.push_back( new BreakPoint(*rList.at( i ) ) );
 }
 
 BreakPointList::~BreakPointList()
@@ -279,76 +279,69 @@ BreakPointList::~BreakPointList()
 
 void BreakPointList::reset()
 {
-    while (Count() > 0)
-        delete Remove(Count() - 1);
+    for ( size_t i = 0, n = maBreakPoints.size(); i < n; ++i )
+        delete maBreakPoints[ i ];
+    maBreakPoints.clear();
 }
 
 void BreakPointList::transfer(BreakPointList & rList)
 {
     reset();
-    for (ULONG i = 0; i < rList.Count(); ++i)
-        Insert(rList.GetObject(i), i);
-    rList.Clear();
+    for (size_t i = 0; i < rList.size(); ++i)
+        maBreakPoints.push_back( rList.at( i ) );
+    rList.reset();
 }
 
 void BreakPointList::InsertSorted( BreakPoint* pNewBrk )
 {
-    BreakPoint* pBrk = First();
-    while ( pBrk )
+    for ( vector< BreakPoint* >::iterator i = maBreakPoints.begin(); i < maBreakPoints.end(); ++i )
     {
-        if ( pNewBrk->nLine <= pBrk->nLine )
+        if ( pNewBrk->nLine <= (*i)->nLine )
         {
-            DBG_ASSERT( ( pBrk->nLine != pNewBrk->nLine ) || pNewBrk->bTemp, "BreakPoint existiert schon!" );
-            Insert( pNewBrk );
+            DBG_ASSERT( ( (*i)->nLine != pNewBrk->nLine ) || pNewBrk->bTemp, "BreakPoint existiert schon!" );
+            maBreakPoints.insert( i, pNewBrk );
             return;
         }
-        pBrk = Next();
     }
     // Keine Einfuegeposition gefunden => LIST_APPEND
-    Insert( pNewBrk, LIST_APPEND );
+    maBreakPoints.push_back( pNewBrk );
 }
 
 void BreakPointList::SetBreakPointsInBasic( SbModule* pModule )
 {
     pModule->ClearAllBP();
 
-    BreakPoint* pBrk = First();
-    while ( pBrk )
+    for ( size_t i = 0, n = maBreakPoints.size(); i < n; ++i )
     {
+        BreakPoint* pBrk = maBreakPoints[ i ];
         if ( pBrk->bEnabled )
-            pModule->SetBP( (USHORT)pBrk->nLine );
-        pBrk = Next();
+            pModule->SetBP( (sal_uInt16)pBrk->nLine );
     }
 }
 
-BreakPoint*	BreakPointList::FindBreakPoint( ULONG nLine )
+BreakPoint*	BreakPointList::FindBreakPoint( size_t nLine )
 {
-    BreakPoint* pBrk = First();
-    while ( pBrk )
+    for ( size_t i = 0, n = maBreakPoints.size(); i < n; ++i )
     {
+        BreakPoint* pBrk = maBreakPoints[ i ];
         if ( pBrk->nLine == nLine )
             return pBrk;
-
-        pBrk = Next();
     }
-
-    return (BreakPoint*)0;
+    return NULL;
 }
 
-
-
-void BreakPointList::AdjustBreakPoints( ULONG nLine, BOOL bInserted )
+void BreakPointList::AdjustBreakPoints( size_t nLine, bool bInserted )
 {
-    BreakPoint* pBrk = First();
-    while ( pBrk )
+    for ( size_t i = 0; i < maBreakPoints.size(); )
     {
-        BOOL bDelBrk = FALSE;
+        BreakPoint* pBrk = maBreakPoints[ i ];
+        bool bDelBrk = false;
         if ( pBrk->nLine == nLine )
         {
             if ( bInserted )
                 pBrk->nLine++;
             else
-                bDelBrk = TRUE;
+                bDelBrk = true;
         }
         else if ( pBrk->nLine > nLine )
         {
@@ -360,32 +353,71 @@ void BreakPointList::AdjustBreakPoints( ULONG nLine, BOOL bInserted )
 
         if ( bDelBrk )
         {
-            ULONG n = GetCurPos();
-            delete Remove( pBrk );
-            pBrk = Seek( n );
+            delete remove( pBrk );
         }
         else
         {
-            pBrk = Next();
+            ++i;
         }
     }
 }
 
 void BreakPointList::ResetHitCount()
 {
-    BreakPoint* pBrk = First();
-    while ( pBrk )
+    for ( size_t i = 0, n = maBreakPoints.size(); i < n; ++i )
     {
+        BreakPoint* pBrk = maBreakPoints[ i ];
         pBrk->nHitCount = 0;
-        pBrk = Next();
     }
 }
 
+size_t BreakPointList::size() const
+{
+    return maBreakPoints.size();
+}
+
+BreakPoint* BreakPointList::at( size_t i )
+{
+    if ( i < maBreakPoints.size() )
+        return maBreakPoints[ i ];
+    else
+        return NULL;
+}
+
+const BreakPoint* BreakPointList::at( size_t i ) const
+{
+    return maBreakPoints[ i ];
+}
+
+BreakPoint* BreakPointList::remove( BreakPoint* ptr )
+{
+    for ( vector< BreakPoint* >::iterator i = maBreakPoints.begin(); i < maBreakPoints.end(); ++i )
+    {
+        if ( ptr == *i )
+        {
+            maBreakPoints.erase( i );
+            return ptr;
+        }
+    }
+    return NULL;
+}
+
+void BreakPointList::push_back( BreakPoint* item )
+{
+    maBreakPoints.push_back( item );
+}
+
+void BreakPointList::clear()
+{
+    maBreakPoints.clear();
+}
+
+
 void IDEBaseWindow::Deactivating()
 {
 }
 
-USHORT __EXPORT IDEBaseWindow::GetSearchOptions()
+sal_uInt16 IDEBaseWindow::GetSearchOptions()
 {
     return 0;
 }
@@ -400,11 +432,11 @@ BasicDockingWindow::BasicDockingWindow( Window* pParent ) :
 
 
 
-BOOL __EXPORT BasicDockingWindow::Docking( const Point& rPos, Rectangle& rRect )
+sal_Bool BasicDockingWindow::Docking( const Point& rPos, Rectangle& rRect )
 {
     ModulWindowLayout* pLayout = (ModulWindowLayout*)GetParent();
     Rectangle aTmpRec( rRect );
-    BOOL bDock = IsDockingPrevented() ? FALSE : pLayout->IsToBeDocked( this, rPos, aTmpRec );
+    sal_Bool bDock = IsDockingPrevented() ? sal_False : pLayout->IsToBeDocked( this, rPos, aTmpRec );
     if ( bDock )
     {
         rRect.SetSize( aTmpRec.GetSize() );
@@ -419,13 +451,13 @@ BOOL __EXPORT BasicDockingWindow::Docking( const Point& rPos, Rectangle& rRect )
 
 
 
-void __EXPORT BasicDockingWindow::EndDocking( const Rectangle& rRect, BOOL bFloatMode )
+void BasicDockingWindow::EndDocking( const Rectangle& rRect, sal_Bool bFloatMode )
 {
     if ( bFloatMode )
         DockingWindow::EndDocking( rRect, bFloatMode );
     else
     {
-        SetFloatingMode( FALSE );
+        SetFloatingMode( sal_False );
         ModulWindowLayout* pLayout = (ModulWindowLayout*)GetParent();
         pLayout->DockaWindow( this );
     }
@@ -433,7 +465,7 @@ void __EXPORT BasicDockingWindow::EndDocking( const Rectangle& rRect, BOOL bFloa
 
 
 
-void __EXPORT BasicDockingWindow::ToggleFloatingMode()
+void BasicDockingWindow::ToggleFloatingMode()
 {
     ModulWindowLayout* pLayout = (ModulWindowLayout*)GetParent();
     if ( IsFloatingMode() )
@@ -447,7 +479,7 @@ void __EXPORT BasicDockingWindow::ToggleFloatingMode()
 
 
 
-BOOL __EXPORT BasicDockingWindow::PrepareToggleFloatingMode()
+sal_Bool BasicDockingWindow::PrepareToggleFloatingMode()
 {
     if ( IsFloatingMode() )
     {
@@ -455,12 +487,12 @@ BOOL __EXPORT BasicDockingWindow::PrepareToggleFloatingMode()
         aFloatingPosAndSize.SetPos( GetParent()->OutputToScreenPixel( GetPosPixel() ) );
         aFloatingPosAndSize.SetSize( GetSizePixel() );
     }
-    return TRUE;
+    return sal_True;
 }
 
 
 
-void __EXPORT BasicDockingWindow::StartDocking()
+void BasicDockingWindow::StartDocking()
 {
     // Position und Groesse auf dem Desktop merken...
     if ( IsFloatingMode() )
@@ -506,23 +538,23 @@ IMPL_LINK_INLINE_END( ExtendedEdit, EditAccHdl, Accelerator *, pAcc )
 
 struct TabBarDDInfo
 {
-    ULONG 	npTabBar;
-    USHORT 	nPage;
+    sal_uLong 	npTabBar;
+    sal_uInt16 	nPage;
 
     TabBarDDInfo() { npTabBar = 0; nPage = 0; }
-    TabBarDDInfo( ULONG _npTabBar, USHORT _nPage ) { npTabBar = _npTabBar; nPage = _nPage; }
+    TabBarDDInfo( sal_uLong _npTabBar, sal_uInt16 _nPage ) { npTabBar = _npTabBar; nPage = _nPage; }
 };
 
 
 BasicIDETabBar::BasicIDETabBar( Window* pParent ) :
     TabBar( pParent, WinBits( WB_3DLOOK | WB_SCROLL | WB_BORDER | WB_SIZEABLE | WB_DRAG ) )
 {
-    EnableEditMode( TRUE );
+    EnableEditMode( sal_True );
 
     SetHelpId( HID_BASICIDE_TABBAR );
 }
 
-void __EXPORT BasicIDETabBar::MouseButtonDown( const MouseEvent& rMEvt )
+void BasicIDETabBar::MouseButtonDown( const MouseEvent& rMEvt )
 {
     if ( rMEvt.IsLeft() && ( rMEvt.GetClicks() == 2 ) && !IsInEditMode() )
     {
@@ -540,7 +572,7 @@ void __EXPORT BasicIDETabBar::MouseButtonDown( const MouseEvent& rMEvt )
     }
 }
 
-void __EXPORT BasicIDETabBar::Command( const CommandEvent& rCEvt )
+void BasicIDETabBar::Command( const CommandEvent& rCEvt )
 {
     if ( ( rCEvt.GetCommand() == COMMAND_CONTEXTMENU ) && !IsInEditMode() )
     {
@@ -555,9 +587,9 @@ void __EXPORT BasicIDETabBar::Command( const CommandEvent& rCEvt )
         PopupMenu aPopup( IDEResId( RID_POPUP_TABBAR ) );
         if ( GetPageCount() == 0 )
         {
-            aPopup.EnableItem( SID_BASICIDE_DELETECURRENT, FALSE );
-            aPopup.EnableItem( SID_BASICIDE_RENAMECURRENT, FALSE );
-            aPopup.EnableItem( SID_BASICIDE_HIDECURPAGE, FALSE );
+            aPopup.EnableItem( SID_BASICIDE_DELETECURRENT, sal_False );
+            aPopup.EnableItem( SID_BASICIDE_RENAMECURRENT, sal_False );
+            aPopup.EnableItem( SID_BASICIDE_HIDECURPAGE, sal_False );
         }
 
         if ( StarBASIC::IsRunning() )
@@ -577,13 +609,13 @@ void __EXPORT BasicIDETabBar::Command( const CommandEvent& rCEvt )
             if ( ( xModLibContainer.is() && xModLibContainer->hasByName( aOULibName ) && xModLibContainer->isLibraryReadOnly( aOULibName ) ) ||
                  ( xDlgLibContainer.is() && xDlgLibContainer->hasByName( aOULibName ) && xDlgLibContainer->isLibraryReadOnly( aOULibName ) ) )
             {
-                aPopup.EnableItem( aPopup.GetItemId( 0 ), FALSE );
-                aPopup.EnableItem( SID_BASICIDE_DELETECURRENT, FALSE );
-                aPopup.EnableItem( SID_BASICIDE_RENAMECURRENT, FALSE );
+                aPopup.EnableItem( aPopup.GetItemId( 0 ), sal_False );
+                aPopup.EnableItem( SID_BASICIDE_DELETECURRENT, sal_False );
+                aPopup.EnableItem( SID_BASICIDE_RENAMECURRENT, sal_False );
                 aPopup.RemoveDisabledEntries();
             }
              if ( aDocument.isInVBAMode() )
-            {	
+            {
                 // disable to delete or remove object modules in IDE
                 BasicManager* pBasMgr = aDocument.getBasicManager();
                 if ( pBasMgr )
@@ -598,8 +630,8 @@ void __EXPORT BasicIDETabBar::Command( const CommandEvent& rCEvt )
                             SbModule* pActiveModule = (SbModule*)pBasic->FindModule( pWin->GetName() );
                             if( pActiveModule && ( pActiveModule->GetModuleType() == script::ModuleType::DOCUMENT ) )
                             {
-                                aPopup.EnableItem( SID_BASICIDE_DELETECURRENT, FALSE );
-                                aPopup.EnableItem( SID_BASICIDE_RENAMECURRENT, FALSE );
+                                aPopup.EnableItem( SID_BASICIDE_DELETECURRENT, sal_False );
+                                aPopup.EnableItem( SID_BASICIDE_RENAMECURRENT, sal_False );
                             }
                         }
                     }
@@ -617,7 +649,7 @@ void __EXPORT BasicIDETabBar::Command( const CommandEvent& rCEvt )
 
 long BasicIDETabBar::AllowRenaming()
 {
-    BOOL bValid = BasicIDE::IsValidSbxName( GetEditText() );
+    sal_Bool bValid = BasicIDE::IsValidSbxName( GetEditText() );
 
     if ( !bValid )
         ErrorBox( this, WB_OK | WB_DEF_OK, String( IDEResId( RID_STR_BADSBXNAME ) ) ).Execute();
@@ -626,7 +658,7 @@ long BasicIDETabBar::AllowRenaming()
 }
 
 
-void __EXPORT BasicIDETabBar::EndRenaming()
+void BasicIDETabBar::EndRenaming()
 {
     if ( !IsEditModeCanceled() )
     {
@@ -653,13 +685,13 @@ void BasicIDETabBar::Sort()
         TabBarSortHelper aTabBarSortHelper;
         ::std::vector<TabBarSortHelper> aModuleList;
         ::std::vector<TabBarSortHelper> aDialogList;
-        USHORT nPageCount = GetPageCount();
-        USHORT i;
+        sal_uInt16 nPageCount = GetPageCount();
+        sal_uInt16 i;
 
         // create module and dialog lists for sorting
         for ( i = 0; i < nPageCount; i++)
         {
-            USHORT nId = GetPageId( i );
+            sal_uInt16 nId = GetPageId( i );
             aTabBarSortHelper.nPageId = nId;
             aTabBarSortHelper.aPageText = GetPageText( nId );
             IDEBaseWindow* pWin = aIDEWindowTable.Get( nId );
@@ -679,8 +711,8 @@ void BasicIDETabBar::Sort()
         ::std::sort( aDialogList.begin() , aDialogList.end() );
 
 
-        USHORT nModules = sal::static_int_cast<USHORT>( aModuleList.size() );
-        USHORT nDialogs = sal::static_int_cast<USHORT>( aDialogList.size() );
+        sal_uInt16 nModules = sal::static_int_cast<sal_uInt16>( aModuleList.size() );
+        sal_uInt16 nDialogs = sal::static_int_cast<sal_uInt16>( aDialogList.size() );
 
         // move module pages to new positions
         for (i = 0; i < nModules; i++)
@@ -696,10 +728,9 @@ void BasicIDETabBar::Sort()
     }
 }
 
-void CutLines( ::rtl::OUString& rStr, sal_Int32 nStartLine, sal_Int32 nLines, BOOL bEraseTrailingEmptyLines )
+void CutLines( ::rtl::OUString& rStr, sal_Int32 nStartLine, sal_Int32 nLines, sal_Bool bEraseTrailingEmptyLines )
 {
     sal_Int32 nStartPos = 0;
-    sal_Int32 nEndPos = 0;
     sal_Int32 nLine = 0;
     while ( nLine < nStartLine )
     {
@@ -714,7 +745,8 @@ void CutLines( ::rtl::OUString& rStr, sal_Int32 nStartLine, sal_Int32 nLines, BO
 
     if ( nStartPos != -1 )
     {
-        nEndPos = nStartPos;
+        sal_Int32 nEndPos = nStartPos;
+
         for ( sal_Int32 i = 0; i < nLines; i++ )
             nEndPos = searchEOL( rStr, nEndPos+1 );
 
@@ -746,10 +778,10 @@ void CutLines( ::rtl::OUString& rStr, sal_Int32 nStartLine, sal_Int32 nLines, BO
     }
 }
 
-ULONG CalcLineCount( SvStream& rStream )
+sal_uLong CalcLineCount( SvStream& rStream )
 {
-    ULONG nLFs = 0;
-    ULONG nCRs = 0;
+    sal_uLong nLFs = 0;
+    sal_uLong nCRs = 0;
     char c;
 
     rStream.Seek( 0 );
@@ -800,7 +832,7 @@ bool LibInfoKey::operator==( const LibInfoKey& rKey ) const
     return bRet;
 }
 
-LibInfoItem::LibInfoItem( const ScriptDocument& rDocument, const String& rLibName, const String& rCurrentName, USHORT nCurrentType )
+LibInfoItem::LibInfoItem( const ScriptDocument& rDocument, const String& rLibName, const String& rCurrentName, sal_uInt16 nCurrentType )
     :m_aDocument( rDocument )
     ,m_aLibName( rLibName )
     ,m_aCurrentName( rCurrentName )
@@ -886,7 +918,7 @@ LibInfoItem* LibInfos::GetInfo( const LibInfoKey& rKey )
     return pItem;
 }
 
-SbxItem::SbxItem(USHORT nWhich_, const ScriptDocument& rDocument, const String& aLibName, const String& aName, USHORT nType )
+SbxItem::SbxItem(sal_uInt16 nWhich_, const ScriptDocument& rDocument, const String& aLibName, const String& aName, sal_uInt16 nType )
     :SfxPoolItem( nWhich_ )
     ,m_aDocument(rDocument)
     ,m_aLibName(aLibName)
@@ -895,7 +927,7 @@ SbxItem::SbxItem(USHORT nWhich_, const ScriptDocument& rDocument, const String&
 {
 }
 
-SbxItem::SbxItem(USHORT nWhich_, const ScriptDocument& rDocument, const String& aLibName, const String& aName, const String& aMethodName, USHORT nType )
+SbxItem::SbxItem(sal_uInt16 nWhich_, const ScriptDocument& rDocument, const String& aLibName, const String& aName, const String& aMethodName, sal_uInt16 nType )
     :SfxPoolItem( nWhich_ )
     ,m_aDocument(rDocument)
     ,m_aLibName(aLibName)
@@ -930,7 +962,7 @@ SfxPoolItem *SbxItem::Clone( SfxItemPool* ) const
     return new SbxItem(*this);
 }
 
-BOOL QueryDel( const String& rName, const ResId& rId, Window* pParent )
+sal_Bool QueryDel( const String& rName, const ResId& rId, Window* pParent )
 {
     String aQuery( rId );
     String aName( rName );
@@ -939,39 +971,39 @@ BOOL QueryDel( const String& rName, const ResId& rId, Window* pParent )
     aQuery.SearchAndReplace( String( RTL_CONSTASCII_USTRINGPARAM( "XX" ) ), aName );
     QueryBox aQueryBox( pParent, WB_YES_NO | WB_DEF_YES, aQuery );
     if ( aQueryBox.Execute() == RET_YES )
-        return TRUE;
-    return FALSE;
+        return sal_True;
+    return sal_False;
 }
 
-BOOL QueryDelMacro( const String& rName, Window* pParent )
+sal_Bool QueryDelMacro( const String& rName, Window* pParent )
 {
     return QueryDel( rName, IDEResId( RID_STR_QUERYDELMACRO ), pParent );
 }
 
-BOOL QueryReplaceMacro( const String& rName, Window* pParent )
+sal_Bool QueryReplaceMacro( const String& rName, Window* pParent )
 {
     return QueryDel( rName, IDEResId( RID_STR_QUERYREPLACEMACRO ), pParent );
 }
 
-BOOL QueryDelDialog( const String& rName, Window* pParent )
+sal_Bool QueryDelDialog( const String& rName, Window* pParent )
 {
     return QueryDel( rName, IDEResId( RID_STR_QUERYDELDIALOG ), pParent );
 }
 
-BOOL QueryDelLib( const String& rName, BOOL bRef, Window* pParent )
+sal_Bool QueryDelLib( const String& rName, sal_Bool bRef, Window* pParent )
 {
     return QueryDel( rName, IDEResId( bRef ? RID_STR_QUERYDELLIBREF : RID_STR_QUERYDELLIB ), pParent );
 }
 
-BOOL QueryDelModule( const String& rName, Window* pParent )
+sal_Bool QueryDelModule( const String& rName, Window* pParent )
 {
     return QueryDel( rName, IDEResId( RID_STR_QUERYDELMODULE ), pParent );
 }
 
-BOOL QueryPassword( const Reference< script::XLibraryContainer >& xLibContainer, const String& rLibName, String& rPassword, BOOL bRepeat, BOOL bNewTitle )
+sal_Bool QueryPassword( const Reference< script::XLibraryContainer >& xLibContainer, const String& rLibName, String& rPassword, sal_Bool bRepeat, sal_Bool bNewTitle )
 {
-    BOOL bOK = FALSE;
-    USHORT nRet = 0;
+    sal_Bool bOK = sal_False;
+    sal_uInt16 nRet = 0;
 
     do
     {
