@@ -7,9 +7,6 @@
  *
  * OpenOffice.org - a multi-platform office productivity suite
  *
- * $RCSfile: b2dpolygontriangulator.cxx,v $
- * $Revision: 1.7 $
- *
  * This file is part of OpenOffice.org.
  *
  * OpenOffice.org is free software: you can redistribute it and/or modify
@@ -224,7 +221,7 @@ namespace basegfx
                 // Loop while new entry is bigger, use operator<
                 while(aCurrent != maTrDeEdgeEntries.end() && (*aCurrent) < rNewEdge)
                 {
-                    aCurrent++;
+                    ++aCurrent;
                 }
 
                 // Insert before first which is smaller or equal or at end
@@ -625,7 +622,7 @@ namespace basegfx
                         // to not have an endless loop and start next. During development
                         // i constantly had breakpoints here, so i am sure enough to add an
                         // assertion here
-                        OSL_ENSURE(false, "Trapeziod decomposer in illegal state (!)");
+                        OSL_FAIL("Trapeziod decomposer in illegal state (!)");
                         maTrDeEdgeEntries.pop_front();
                         continue;
                     }
@@ -639,7 +636,7 @@ namespace basegfx
                         // line; consume the single edge to not have an endless loop and start
                         // next. During development i constantly had breakpoints here, so i am 
                         // sure enough to add an assertion here
-                        OSL_ENSURE(false, "Trapeziod decomposer in illegal state (!)");
+                        OSL_FAIL("Trapeziod decomposer in illegal state (!)");
                         maTrDeEdgeEntries.pop_front();
                         continue;
                     }
