@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -44,7 +44,6 @@
 #include "basmgr.hxx"
 #include "sbintern.hxx"
 
-
 #define LIB_SEP			0x01
 #define LIBINFO_SEP		0x02
 #define LIBINFO_ID		0x1491
@@ -61,6 +60,7 @@
 #include <com/sun/star/script/XStarBasicLibraryInfo.hpp>
 
 #include <cppuhelper/implbase1.hxx>
+#include <vector>
 
 namespace binfilter {
 
@@ -69,7 +69,10 @@ using namespace com::sun::star::uno;
 using namespace com::sun::star::lang;
 using namespace com::sun::star::script;
 using namespace cppu;
-using namespace rtl;
+using ::std::vector;
+using ::std::advance;
+
+using ::rtl::OUString;
 
 typedef WeakImplHelper1< XNameContainer > NameContainerHelper;
 typedef WeakImplHelper1< XStarBasicModuleInfo > ModuleInfoHelper;
@@ -111,8 +114,7 @@ DBG_NAME( BasicManager );
 StreamMode eStreamReadMode = STREAM_READ | STREAM_NOCREATE | STREAM_SHARE_DENYALL;
 StreamMode eStorageReadMode = STREAM_READ | STREAM_SHARE_DENYWRITE;
 
-DECLARE_LIST( BasErrorLst, BasicError* )
-
+typedef vector< BasicError* > BasErrorLst;
 
 //----------------------------------------------------------------------------
 // BasicManager impl data
@@ -200,7 +202,7 @@ void BasMgrContainerListenerImpl::insertLibraryImpl( const Reference< XLibraryCo
     {
         BasicManager* pBasMgr = static_cast< BasicManager* >( pMgr );
 #ifdef DBG_UTIL
-        StarBASIC* pLib = 
+        StarBASIC* pLib =
 #endif
         pBasMgr->CreateLibForLibContainer( aLibName, xScriptCont );
         DBG_ASSERT( pLib, "XML Import: Basic library could not be created");
@@ -366,18 +368,37 @@ class BasicErrorManager
 {
 private:
     BasErrorLst	aErrorList;
+    size_t CurrentError;
 
 public:
+                BasicErrorManager() { CurrentError = 0; }
                 ~BasicErrorManager();
 
     void		Reset();
     void		InsertError( const BasicError& rError );
 
-    BOOL		HasErrors()			{ return (BOOL)aErrorList.Count(); }
-    BasicError*	GetFirstError()		{ return aErrorList.First(); }
-    BasicError*	GetNextError()		{ return aErrorList.Next(); }
+    BOOL		HasErrors()			{ return !aErrorList.empty(); }
+    BasicError*	GetFirstError();
+    BasicError*	GetNextError();
 };
 
+BasicError* BasicErrorManager::GetFirstError()
+{
+    CurrentError = 0;
+    if ( aErrorList.empty() )
+        return NULL;
+    return aErrorList[ 0 ];
+}
+
+BasicError* BasicErrorManager::GetNextError()
+{
+    if (  aErrorList.empty()
+       || CurrentError + 1 >= aErrorList.size()
+       )
+        return NULL;
+    CurrentError++;
+    return aErrorList[ CurrentError ];
+}
 
 BasicErrorManager::~BasicErrorManager()
 {
@@ -386,18 +407,14 @@ BasicErrorManager::~BasicErrorManager()
 
 void BasicErrorManager::Reset()
 {
-    BasicError* pError = (BasicError*)aErrorList.First();
-    while ( pError )
-    {
-        delete pError;
-        pError = (BasicError*)aErrorList.Next();
-    }
-    aErrorList.Clear();
+    for ( size_t i = 0, n = aErrorList.size(); i < n; ++i )
+        delete aErrorList[ i ];
+    aErrorList.clear();
 }
 
 void BasicErrorManager::InsertError( const BasicError& rError )
 {
-    aErrorList.Insert( new BasicError( rError ), LIST_APPEND );
+    aErrorList.push_back( new BasicError( rError ) );
 }
 
 BasicError::BasicError( ULONG nId, USHORT nR, const String& rErrStr ) :
@@ -460,7 +477,7 @@ public:
     const String&	GetLibName() const					{ return aLibName; }
     void			SetLibName( const String& rName )	{ aLibName = rName; }
 
-    // Nur temporaer fuer Laden/Speichern....
+    // Only temporary, for saving/loading ...
     BOOL			DoLoad()							{ return bDoLoad; }
 
     BOOL			HasPassword() const 				{ return aPassword.Len() != 0; }
@@ -482,14 +499,105 @@ public:
         { mxScriptCont = xScriptCont; }
 };
 
-DECLARE_LIST( BasicLibsBase, BasicLibInfo* )
+typedef vector< BasicLibInfo* > BasicLibsBase;
 
-class BasicLibs : public BasicLibsBase
+class BasicLibs
 {
+private:
+    BasicLibsBase   mpList;
+    size_t          current;
+
 public:
     String	aBasicLibPath;		// soll eigentlich Member vom Manager werden, aber jetzt nicht inkompatibel!
+    BasicLibInfo*   GetObject( size_t i );
+    void            Insert( BasicLibInfo* item, size_t i );
+    void            Clear() { mpList.clear(); }
+    size_t          Count() { return mpList.size(); }
+    size_t          GetPos( BasicLibInfo* pItem );
+    size_t          GetCurPos() { return current; }
+    BasicLibInfo*   First();
+    BasicLibInfo*   Next();
+    BasicLibInfo*   Prev();
+    BasicLibInfo*   Last();
+    BasicLibInfo*   Remove( BasicLibInfo* pItem );
 };
 
+size_t BasicLibs::GetPos( BasicLibInfo* pItem )
+{
+    for ( size_t i = 0, n = mpList.size(); i < n; ++i )
+        if ( mpList[ i ] == pItem )
+            return i;
+    return size_t(-1);
+}
+
+void BasicLibs::Insert( BasicLibInfo* pItem, size_t i )
+{
+    if ( i >= mpList.size() )
+    {
+        mpList.push_back( pItem );
+        current = mpList.size() - 1;
+    }
+    else
+    {
+        BasicLibsBase::iterator it = mpList.begin();
+        advance( it, i );
+        mpList.insert( it, pItem );
+        current = i;
+    }
+}
+
+BasicLibInfo* BasicLibs::Remove( BasicLibInfo* pItem )
+{
+    size_t pos = GetPos( pItem );
+    if ( pos == size_t(-1) ) return NULL;
+
+    current = pos;
+    BasicLibsBase::iterator it = mpList.begin();
+    advance( it, pos );
+    mpList.erase( it );
+    return pItem;
+}
+
+BasicLibInfo* BasicLibs::GetObject( size_t i )
+{
+    if ( i >= mpList.size() ) return NULL;
+    return mpList[ i ];
+}
+
+BasicLibInfo* BasicLibs::First()
+{
+    current = 0;
+    if ( mpList.empty() ) return NULL;
+    return mpList[ current ];
+}
+
+BasicLibInfo* BasicLibs::Next()
+{
+    if (  mpList.empty()
+       || current+1 >= mpList.size()
+       )
+        return NULL;
+    current++;
+    return mpList[ current ];
+}
+
+BasicLibInfo* BasicLibs::Prev()
+{
+    if (  mpList.empty()
+       || current == 0
+       )
+        return NULL;
+    current--;
+    return mpList[ current ];
+}
+
+BasicLibInfo* BasicLibs::Last()
+{
+    if ( mpList.empty() ) return NULL;
+    current = mpList.size() - 1;
+    return mpList[ current ];
+}
+
 BasicLibInfo::BasicLibInfo()
 {
     bReference 			= FALSE;
@@ -520,13 +628,12 @@ void BasicLibInfo::Store( SotStorageStream& rSStream, const String& rBasMgrStora
     if ( aStorageName.Len() == 0 )
         aStorageName = aCurStorageName;
 
-    // Wieder laden?
+    // Load again?
     BOOL bDoLoad_ = xLib.Is();
     if ( bUseOldReloadInfo )
         bDoLoad_ = DoLoad();
     rSStream << bDoLoad_;
 
-    // Den Namen der Lib...
     rSStream.WriteByteString(GetLibName());
 
     // Absoluter Pfad....
@@ -581,10 +688,10 @@ BasicLibInfo* BasicLibInfo::Create( SotStorageStream& rSStream )
     rSStream >> nId;
     rSStream >> nVer;
 
-    DBG_ASSERT( nId == LIBINFO_ID, "Keine BasicLibInfo !?" );
+    DBG_ASSERT( nId == LIBINFO_ID, "Without BasicLibInfo !?" );
     if( nId == LIBINFO_ID )
     {
-        // Wieder laden?
+        // Load again?
         BOOL bDoLoad;
         rSStream >> bDoLoad;
         pInfo->bDoLoad = bDoLoad;
@@ -645,8 +752,6 @@ BasicManager::BasicManager( SotStorage& rStorage, const String& rBaseURL, StarBA
     // #91251: Storage name not longer available for documents < 5.0
     // Should be no real problem, because only relative storage names
     // (links) can be affected.
-    // DBG_ASSERT( aStorName.Len(), "No Storage Name!" );
-    // DBG_ASSERT(aStorageName.Len() != 0, "Bad storage name");
 
     // Wenn es den Manager-Stream nicht gibt, sind keine weiteren
     // Aktionen noetig.
@@ -679,7 +784,6 @@ BasicManager::BasicManager( SotStorage& rStorage, const String& rBaseURL, StarBA
                 StarBASIC* pBasic = GetLib( nBasic );
                 if ( pBasic )
                 {
-//					pBasic->SetParent( pStdLib );
                     pStdLib->Insert( pBasic );
                     pBasic->SetFlag( SBX_EXTSEARCH );
                 }
@@ -902,8 +1006,6 @@ void BasicManager::ImpMgrNotLoaded( const String& rStorageName )
 {
     // pErrInf wird nur zerstoert, wenn der Fehler von einem ErrorHandler
     // gehandelt wird!
-//	String aErrorText( BasicResId( IDS_SBERR_MGROPEN ) );
-//	aErrorText.SearchAndReplace( "XX", rStorageName );
     StringErrorInfo* pErrInf = new StringErrorInfo( ERRCODE_BASMGR_MGROPEN,	rStorageName, ERRCODE_BUTTON_OK );
     pErrorMgr->InsertError( BasicError( *pErrInf, BASERR_REASON_OPENMGRSTREAM, rStorageName ) );
 
@@ -933,7 +1035,6 @@ void BasicManager::LoadBasicManager( SotStorage& rStorage, const String& rBaseUR
 {
     DBG_CHKTHIS( BasicManager, 0 );
 
-//	StreamMode eStreamMode = STREAM_READ | STREAM_NOCREATE | STREAM_SHARE_DENYWRITE;
 
     SotStorageStreamRef xManagerStream = rStorage.OpenSotStream
         ( ManagerStreamName, eStreamReadMode );
@@ -953,7 +1054,6 @@ void BasicManager::LoadBasicManager( SotStorage& rStorage, const String& rBaseUR
     String aRealStorageName = maStorageName;  // fuer relative Pfade, kann durch BaseURL umgebogen werden.
 
     // Wenn aus Vorlagen geladen wird, gilt nur die BaseURL:
-    //String aBaseURL = INetURLObject::GetBaseURL();
     if ( rBaseURL.Len() )
     {
         INetURLObject aObj( rBaseURL );
@@ -988,11 +1088,6 @@ void BasicManager::LoadBasicManager( SotStorage& rStorage, const String& rBaseUR
             bool bWasAbsolute = FALSE;
             aObj = aObj.smartRel2Abs( pInfo->GetRelStorageName(), bWasAbsolute );
 
-            //*** TODO: Replace if still necessary
-            /* if ( SfxContentHelper::Exists( aObj.GetMainURL() ) )
-                pInfo->SetStorageName( aObj.GetMainURL() );
-            else */
-            //*** TODO-End
             if ( pLibs->aBasicLibPath.Len() )
             {
                 // Lib im Pfad suchen...
@@ -1026,7 +1121,6 @@ void BasicManager::LoadOldBasicManager( SotStorage& rStorage )
 {
     DBG_CHKTHIS( BasicManager, 0 );
 
-//	StreamMode eStreamMode = STREAM_READ | STREAM_NOCREATE | STREAM_SHARE_DENYWRITE;
 
     SotStorageStreamRef xManagerStream = rStorage.OpenSotStream
         ( String::CreateFromAscii(szOldManagerStream), eStreamReadMode );
@@ -1051,8 +1145,6 @@ void BasicManager::LoadOldBasicManager( SotStorage& rStorage )
     xManagerStream->Seek( nBasicStartOff );
     if( !ImplLoadBasic( *xManagerStream, pLibs->GetObject(0)->GetLibRef() ) )
     {
-//		String aErrorText( BasicResId( IDS_SBERR_MGROPEN ) );
-//      aErrorText.SearchAndReplace( "XX", aStorName );
         StringErrorInfo* pErrInf = new StringErrorInfo( ERRCODE_BASMGR_MGROPEN, aStorName, ERRCODE_BUTTON_OK );
         pErrorMgr->InsertError( BasicError( *pErrInf, BASERR_REASON_OPENMGRSTREAM, aStorName ) );
         // und es geht weiter...
@@ -1099,8 +1191,6 @@ void BasicManager::LoadOldBasicManager( SotStorage& rStorage )
                 AddLib( *xStorageRef, aLibName, FALSE );
             else
             {
-//				String aErrorText( BasicResId( IDS_SBERR_LIBLOAD ) );
-//				aErrorText.SearchAndReplace( "XX", aLibName );
                 StringErrorInfo* pErrInf = new StringErrorInfo( ERRCODE_BASMGR_LIBLOAD, aStorName, ERRCODE_BUTTON_OK );
                 pErrorMgr->InsertError( BasicError( *pErrInf, BASERR_REASON_STORAGENOTFOUND, aStorName ) );
             }
@@ -1171,7 +1261,6 @@ BOOL BasicManager::CopyBasicData( SotStorage* pStorFrom, const String& rSourceUR
             bOk = pStorFrom->CopyTo( BasicStreamName, pStorTo, BasicStreamName );
         if( bOk && pStorFrom->IsStream( ManagerStreamName ) )
         {
-            // bOk = pStorFrom->CopyTo( szManagerStream, pStorTo, szManagerStream );
             BasicManager aBasMgr;
             // Die aktuelle Base-URL ist die vom speichern...
             String aStorName( pStorFrom->GetName() );
@@ -1277,7 +1366,7 @@ void BasicManager::Store( SotStorage& rStorage, const String& rBaseURL, BOOL bSt
         // Store saved streams
         SotStorageStreamRef xManagerStream = rStorage.OpenSotStream(
             ManagerStreamName, STREAM_STD_READWRITE | STREAM_TRUNC );
-            //ManagerStreamName, STREAM_STD_READWRITE /* | STREAM_TRUNC */ );
+
         // STREAM_TRUNC buggy??!!! Then
         // xManagerStream->Seek( 0 );
         mpImpl->mpManagerStream->Seek( 0 );
@@ -1321,8 +1410,6 @@ void BasicManager::Store( SotStorage& rStorage, const String& rBaseURL, BOOL bSt
 
     if ( !xManagerStream.Is() || xManagerStream->GetError() )
     {
-//		String aErrorText( BasicResId( IDS_SBERR_MGRSAVE ) );
-//      aErrorText.SearchAndReplace( "XX", aStorName );
         StringErrorInfo* pErrInf = new StringErrorInfo( ERRCODE_BASMGR_MGRSAVE, aStorName, ERRCODE_BUTTON_OK );
         ((BasicManager*)this)->pErrorMgr->InsertError( BasicError( *pErrInf, BASERR_REASON_OPENMGRSTREAM, aStorName ) );
     }
@@ -1432,8 +1519,6 @@ BOOL BasicManager::ImpStoreLibary( StarBASIC* pLib, SotStorage& rStorage ) const
     DBG_ASSERT( aStorName.Len(), "No Storage Name!" );
     if ( !xBasicStorage.Is() || xBasicStorage->GetError() )
     {
-//		String aErrorText( BasicResId( IDS_SBERR_MGRSAVE ) );
-//      aErrorText.SearchAndReplace( "XX", aStorName );
         StringErrorInfo* pErrInf = new StringErrorInfo( ERRCODE_BASMGR_MGRSAVE, aStorName, ERRCODE_BUTTON_OK );
         ((BasicManager*)this)->pErrorMgr->InsertError( BasicError( *pErrInf, BASERR_REASON_OPENLIBSTORAGE, pLib->GetName() ) );
     }
@@ -1443,8 +1528,6 @@ BOOL BasicManager::ImpStoreLibary( StarBASIC* pLib, SotStorage& rStorage ) const
         SotStorageStreamRef xBasicStream = xBasicStorage->OpenSotStream( pLib->GetName(), STREAM_STD_READWRITE );
         if ( !xBasicStream.Is() || xBasicStream->GetError() )
         {
-//			String aErrorText( BasicResId( IDS_SBERR_LIBSAVE ) );
-//			aErrorText.SearchAndReplace( "XX", pLib->GetName() );
             StringErrorInfo* pErrInf = new StringErrorInfo( ERRCODE_BASMGR_LIBSAVE,	pLib->GetName(), ERRCODE_BUTTON_OK );
             ((BasicManager*)this)->pErrorMgr->InsertError( BasicError( *pErrInf, BASERR_REASON_OPENLIBSTREAM, pLib->GetName() ) );
         }
@@ -1476,7 +1559,6 @@ BOOL BasicManager::ImpStoreLibary( StarBASIC* pLib, SotStorage& rStorage ) const
             }
             // Vorsichtshalber alle Dont't Store lassen...
             pLib->SetFlag( SBX_DONTSTORE );
-//			SetFlagToAllLibs( SBX_DONTSTORE, FALSE );
             pLib->SetModified( FALSE );
             if( !xBasicStorage->Commit() )
                 bDone = FALSE;
@@ -1583,7 +1665,6 @@ BOOL BasicManager::ImpLoadLibary( BasicLibInfo* pLibInfo, SotStorage* pCurStorag
                 xBasicStream->SetKey( ByteString() );
                 CheckModules( pLibInfo->GetLib(), pLibInfo->IsReference() );
             }
-//			bBasMgrModified = TRUE;	// Warum?
             return bLoaded;
         }
     }
@@ -1632,13 +1713,6 @@ BOOL BasicManager::ImplLoadBasic( SvStream& rStrm, StarBASICRef& rOldBasic ) con
             // Fill new libray container (5.2 -> 6.0)
             copyToLibraryContainer( pNew, mpImpl->mpInfo );
 
-/*
-            if( rOldBasic->GetParent() )
-            {
-                rOldBasic->GetParent()->Insert( rOldBasic );
-                rOldBasic->SetFlag( SBX_EXTSEARCH );
-            }
-*/
             pNew->SetModified( FALSE );
             bLoaded = TRUE;
         }
@@ -1655,19 +1729,11 @@ void BasicManager::CheckModules( StarBASIC* pLib, BOOL bReference ) const
 
     BOOL bModified = pLib->IsModified();
 
-/*?*/ // 	for ( USHORT nMod = 0; nMod < pLib->GetModules()->Count(); nMod++ )
-/*?*/ // 	{
-/*?*/ // 		SbModule* pModule = (SbModule*)pLib->GetModules()->Get( nMod );
-/*?*/ // 		DBG_ASSERT( pModule, "Modul nicht erhalten!" );
-/*?*/ // 		if ( !pModule->IsCompiled() && !StarBASIC::GetErrorCode() )
-/*?*/ // 			pLib->Compile( pModule );
-/*?*/ // 	}
-
     // #67477, AB 8.12.99 On demand Compilieren bei referenzierten
     // Libraries sollte nicht zu modified fuehren
     if( !bModified && bReference )
     {
-        DBG_ERROR( "Per Reference eingebundene Basic-Library ist nicht compiliert!" );
+        OSL_FAIL( "Per Reference eingebundene Basic-Library ist nicht compiliert!" );
         pLib->SetModified( FALSE );
     }
 }
@@ -1691,7 +1757,6 @@ StarBASIC* BasicManager::AddLib( SotStorage& rStorage, const String& rLibName, B
     // Erstmal mit dem Original-Namen, da sonst ImpLoadLibary nicht geht...
     pLibInfo->SetLibName( rLibName );
     // Funktioniert so aber nicht, wenn Name doppelt
-//	USHORT nLibId = GetLibId( rLibName );
     USHORT nLibId = (USHORT) pLibs->GetPos( pLibInfo );
 
     // Vorm Laden StorageNamen setzen, da er mit pCurStorage verglichen wird.
@@ -1707,7 +1772,6 @@ StarBASIC* BasicManager::AddLib( SotStorage& rStorage, const String& rLibName, B
         {
             pLibInfo->GetLib()->SetModified( FALSE );	// Dann nicht speichern
             pLibInfo->SetRelStorageName( String() );
-//			pLibInfo->CalcRelStorageName( GetStorageName() );
             pLibInfo->IsReference() = TRUE;
         }
         else
@@ -1781,7 +1845,6 @@ BOOL BasicManager::RemoveLib( USHORT nLib, BOOL bDelBasicFromStorage )
 
             if ( !xBasicStorage.Is() || xBasicStorage->GetError() )
             {
-//				String aErrorText( BasicResId( IDS_SBERR_REMOVELIB ) );
                 StringErrorInfo* pErrInf = new StringErrorInfo( ERRCODE_BASMGR_REMOVELIB, String(), ERRCODE_BUTTON_OK );
                 pErrorMgr->InsertError( BasicError( *pErrInf, BASERR_REASON_OPENLIBSTORAGE, pLibInfo->GetLibName() ) );
             }
@@ -1807,9 +1870,6 @@ BOOL BasicManager::RemoveLib( USHORT nLib, BOOL bDelBasicFromStorage )
                     {
                         String aName_( xStorage->GetName() );
                         xStorage.Clear();
-                        //*** TODO: Replace if still necessary
-                        //SfxContentHelper::Kill( aName );
-                        //*** TODO-End
                     }
                 }
             }
@@ -1953,15 +2013,7 @@ StarBASIC* BasicManager::CreateLib
             {
                 pLib = AddLib( *xStorage, rLibName, TRUE );
 
-                //if( !pLibInfo )
-                    //pLibInfo = FindLibInfo( pLib );
-                //pLibInfo->SetStorageName( LinkTargetURL );
-                //pLibInfo->GetLib()->SetModified( FALSE );	// Dann nicht speichern
-                //pLibInfo->SetRelStorageName( String() );
-                //pLibInfo->IsReference() = TRUE;
             }
-            //else
-                //Message?
 
             DBG_ASSERT( pLib, "XML Import: Linked basic library could not be loaded");
         }
@@ -2186,7 +2238,7 @@ Any ModuleContainer_Impl::getByName( const OUString& aName )
     if( !pMod )
         throw NoSuchElementException();
     Reference< XStarBasicModuleInfo > xMod = (XStarBasicModuleInfo*)new ModuleInfo_Impl
-        ( aName, OUString::createFromAscii( "StarBasic" ), pMod->GetSource32() );
+        ( aName, OUString( RTL_CONSTASCII_USTRINGPARAM( "StarBasic" )), pMod->GetSource32() );
     Any aRetAny;
     aRetAny <<= xMod;
     return aRetAny;
