@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -37,7 +37,6 @@
 #include <tools/errinf.hxx>
 #endif
 #include <sbx.hxx>
-#include <tools/list.hxx>
 #include <tools/rc.hxx>
 #include <vcl/svapp.hxx>
 #include "sbunoobj.hxx"
@@ -51,8 +50,6 @@
 
 namespace binfilter {
 
-// #pragma SW_SEGMENT_CLASS( SBASIC, SBASIC_CODE )
-
 TYPEINIT1(StarBASIC,SbxObject)
 
 #define RTLNAME "@SBRTL"
@@ -67,7 +64,7 @@ struct SFX_VB_ErrorItem
     SbError nErrorSFX;
 };
 
-const SFX_VB_ErrorItem __FAR_DATA SFX_VB_ErrorTab[] =
+const SFX_VB_ErrorItem SFX_VB_ErrorTab[] =
 {
     { 1, SbERR_BASIC_EXCEPTION },  // #87844 Map exception to error code 1
     { 2, SbERR_SYNTAX },
@@ -330,7 +327,7 @@ SbClassModuleObject::SbClassModuleObject( SbModule* pClassModule )
     aOUSource = pClassModule->aOUSource;
     aComment = pClassModule->aComment;
     pImage = pClassModule->pImage;
-    
+
     SetClassName( pClassModule->GetName() );
 
     // Allow search only internally
@@ -364,7 +361,7 @@ SbClassModuleObject::SbClassModuleObject( SbModule* pClassModule )
         }
     }
 
-    // Copy SbIfaceMapperMethod in a second step to ensure that 
+    // Copy SbIfaceMapperMethod in a second step to ensure that
     // the corresponding base methods have already been copied
     for( i = 0 ; i < nMethodCount ; i++ )
     {
@@ -376,7 +373,7 @@ SbClassModuleObject::SbClassModuleObject( SbModule* pClassModule )
             SbMethod* pImplMethod = pIfaceMethod->getImplMethod();
             if( !pImplMethod )
             {
-                DBG_ERROR( "No ImplMethod" );
+                OSL_FAIL( "No ImplMethod" );
                 continue;
             }
 
@@ -386,10 +383,10 @@ SbClassModuleObject::SbClassModuleObject( SbModule* pClassModule )
             SbMethod* pImplMethodCopy = p ? PTR_CAST(SbMethod,p) : NULL;
             if( !pImplMethodCopy )
             {
-                DBG_ERROR( "Found no ImplMethod copy" );
+                OSL_FAIL( "Found no ImplMethod copy" );
                 continue;
             }
-            SbIfaceMapperMethod* pNewIfaceMethod = 
+            SbIfaceMapperMethod* pNewIfaceMethod =
                 new SbIfaceMapperMethod( pIfaceMethod->GetName(), pImplMethodCopy );
             pMethods->PutDirect( pNewIfaceMethod, i );
         }
@@ -408,7 +405,6 @@ SbClassModuleObject::SbClassModuleObject( SbModule* pClassModule )
             pProcedureProp->SetFlag( SBX_NO_BROADCAST );
             SbProcedureProperty* pNewProp = new SbProcedureProperty
                 ( pProcedureProp->GetName(), pProcedureProp->GetType() );
-                // ( pProcedureProp->GetName(), pProcedureProp->GetType(), this );
             pNewProp->ResetFlag( SBX_NO_BROADCAST );
             pProcedureProp->SetFlags( nFlags_ );
             pProps->PutDirect( pNewProp, i );
@@ -435,7 +431,7 @@ SbClassModuleObject::~SbClassModuleObject()
 {
     triggerTerminateEvent();
 
-    // Must be deleted by base class dtor because this data 
+    // Must be deleted by base class dtor because this data
     // is not owned by the SbClassModuleObject object
     pImage = NULL;
 }
@@ -565,7 +561,7 @@ void SbClassModuleObject::triggerTerminateEvent( void )
 
 void SbClassData::clear( void )
 {
-    mxIfaces->Clear(); 
+    mxIfaces->Clear();
 }
 
 SbClassFactory::SbClassFactory( void )
@@ -618,7 +614,7 @@ StarBASIC::StarBASIC( StarBASIC* p )
         pOLEFAC = new SbOLEFactory;
         AddFactory( pOLEFAC );
     }
-//	pRtl = new SbiStdObject( String( RTL_CONSTASCII_USTRINGPARAM(RTLNAME) ), this );
+
     // Suche ueber StarBASIC ist immer global
     SetFlag( SBX_GBLSEARCH );
 }
@@ -668,7 +664,6 @@ void* StarBASIC::operator new( size_t n )
 {
     if( n < sizeof( StarBASIC ) )
     {
-//		DBG_ASSERT( FALSE, "Warnung: inkompatibler BASIC-Stand!" );
         n = sizeof( StarBASIC );
     }
     return ::operator new( n );
@@ -746,15 +741,7 @@ SbModule* StarBASIC::FindModule( const String& rName )
 // Init-Code aller Module ausfuehren (auch in inserteten Bibliotheken)
 void StarBASIC::InitAllModules( StarBASIC* pBasicNotToInit )
 {
-    // Eigene Module initialisieren
-/*?*/ // 	for ( USHORT nMod = 0; nMod < pModules->Count(); nMod++ )
-/*?*/ // 	{
-/*?*/ // 		SbModule* pModule = (SbModule*)pModules->Get( nMod );
-/*?*/ // 		if(	!pModule->IsCompiled() )
-/*?*/ // 			pModule->Compile();
-/*?*/ // 		pModule->RunInit();
-/*?*/ // 	}
-    DBG_ERROR( "StarBASIC::InitAllModules: dead code!" );
+    OSL_FAIL( "StarBASIC::InitAllModules: dead code!" );
     // Alle Objekte ueberpruefen, ob es sich um ein Basic handelt
     // Wenn ja, auch dort initialisieren
     for ( USHORT nObj = 0; nObj < pObjs->Count(); nObj++ )
@@ -810,8 +797,6 @@ SbxVariable* StarBASIC::Find( const String& rName, SbxClassType t )
             if( rName.EqualsIgnoreCaseAscii( RTLNAME ) )
                 pRes = pRtl;
         }
-/*?*/ //		if( !pRes )
-/*?*/ //			pRes = ((SbiStdObject*) (SbxObject*) pRtl)->Find( rName, t );
         if( pRes )
             pRes->SetFlag( SBX_EXTFOUND );
     }
@@ -863,15 +848,7 @@ BOOL StarBASIC::Call( const String& rName, SbxArray* pParam )
     return bRes;
 }
 
-void StarBASIC::Stop()
-{
-/*?*/ //	SbiInstance* p = pINST;
-/*?*/ //	while( p )
-/*?*/ //	{
-/*?*/ //		p->Stop();
-/*?*/ //		p = p->pNext;
-/*?*/ //	}
-}
+void StarBASIC::Stop() { }
 
 BOOL StarBASIC::IsRunning()
 {
@@ -884,7 +861,7 @@ BOOL StarBASIC::IsRunning()
 *
 **************************************************************************/
 
-USHORT __EXPORT StarBASIC::BreakHdl()
+USHORT StarBASIC::BreakHdl()
 {
     return (USHORT) ( aBreakHdl.IsSet()
         ? aBreakHdl.Call( this ) : SbDEBUG_CONTINUE );
@@ -986,26 +963,6 @@ void StarBASIC::MakeErrorText( SbError nId, const String& /*aMsg*/ )
 
     USHORT nOldID = GetVBErrorCode( nId );
 
-    // Hilfsklasse instanzieren
-/*?*/ //	BasicResId aId( RID_BASIC_START );
-/*?*/ //	BasicStringList_Impl aMyStringList( aId, USHORT(nId & ERRCODE_RES_MASK) );
-
-/*?*/ //	if( aMyStringList.IsErrorTextAvailable() )
-/*?*/ ///*?*/ //	{
-/*?*/ //		// Merge Message mit Zusatztext
-/*?*/ //		String aMsg1 = aMyStringList.GetString();
-/*?*/ //		// Argument-Platzhalter durch %s ersetzen
-/*?*/ //		String aSrgStr( RTL_CONSTASCII_USTRINGPARAM("$(ARG1)") );
-/*?*/ //		USHORT nResult = aMsg1.Search( aSrgStr );
-/*?*/ //
-/*?*/ //		if( nResult != STRING_NOTFOUND )
-/*?*/ //		{
-/*?*/ //			aMsg1.Erase( nResult, aSrgStr.Len() );
-/*?*/ //			aMsg1.Insert( aMsg, nResult );
-/*?*/ //		}
-/*?*/ //		GetSbData()->aErrMsg = aMsg1;
-/*?*/ //	}
-/*?*/ //	else if( nOldID != 0 )
     if( nOldID != 0 )
     {
         String aStdMsg( RTL_CONSTASCII_USTRINGPARAM("error ") );
@@ -1025,11 +982,6 @@ BOOL StarBASIC::CError
     // Compiler-Fehler waehrend der Laufzeit -> Programm anhalten
     if( IsRunning() )
     {
-        // #109018 Check if running Basic is affected
-/*?*/ //		StarBASIC* pStartedBasic = pINST->GetBasic();
-/*?*/ //		if( pStartedBasic != this )
-/*?*/ //			return FALSE;
-
         Stop();
     }
 
@@ -1050,7 +1002,7 @@ BOOL StarBASIC::CError
         bRet = (BOOL) GetSbData()->aErrHdl.Call( this );
     else
         bRet = ErrorHdl();
-    GetSbData()->bCompiler = FALSE;		// nur TRUE fuer Error-Handler
+    GetSbData()->bCompiler = FALSE;		// Only TRUE for Error-Handler
     return bRet;
 }
 
@@ -1085,19 +1037,11 @@ void StarBASIC::Error( SbError n )
     Error( n, String() );
 }
 
-void StarBASIC::Error( SbError /*n*/, const String& /*rMsg*/ )
-{
-/*?*/ //	if( pINST )
-/*?*/ //		pINST->Error( n, rMsg );
-}
+void StarBASIC::Error( SbError /*n*/, const String& /*rMsg*/ ) { }
 
-void StarBASIC::FatalError( SbError /*n*/ )
-{
-/*?*/ //	if( pINST )
-/*?*/ //		pINST->FatalError( n );
-}
+void StarBASIC::FatalError( SbError /*n*/ ) { }
 
-BOOL __EXPORT StarBASIC::ErrorHdl()
+BOOL StarBASIC::ErrorHdl()
 {
     return (BOOL) ( aErrorHdl.IsSet()
         ? aErrorHdl.Call( this ) : FALSE );
@@ -1105,7 +1049,7 @@ BOOL __EXPORT StarBASIC::ErrorHdl()
 
 /**************************************************************************
 *
-*	Laden und Speichern
+*	Saving and Loading
 *
 **************************************************************************/
 
@@ -1336,7 +1280,7 @@ void BasicCollection::CollAdd( SbxArray* pPar_ )
                 }
                 nNextIndex = nAfterIndex + 1;
             }
-            else // if( nCount == 4 )
+            else
             {
                 INT32 nBeforeIndex = implGetIndex( pBefore );
                 if( nBeforeIndex == -1 )
