@@ -769,7 +769,7 @@ BOOL SbxValue::Put( const SbxValues& rVal )
                         {
                             if ( p != this )
                             {
-                                DBG_ERROR( "TheRealValue" );
+                                OSL_FAIL( "TheRealValue" );
                             }
                             HACK(nicht bei Parent-Prop - sonst CyclicRef)
                             SbxVariable *pThisVar = PTR_CAST(SbxVariable, this);
@@ -1074,8 +1074,6 @@ BOOL SbxValue::Compute( SbxOperator eOp, const SbxValue& rOp )
                     || GetType() == SbxCURRENCY
                     || GetType() == SbxULONG )
                     aL.eType = aR.eType = GetType();
-//				else if( GetType() == SbxDouble || GetType() == SbxSingle )
-//					aL.eType = aR.eType = SbxLONG64;
                 else
                     aL.eType = aR.eType = SbxLONG;
             }
@@ -1083,9 +1081,6 @@ BOOL SbxValue::Compute( SbxOperator eOp, const SbxValue& rOp )
                      || GetType() == SbxULONG64 || eOpType == SbxULONG64
                      || GetType() == SbxLONG64 || eOpType == SbxLONG64 )
                 aL.eType = aR.eType = SbxLONG64;
-//			else if( GetType() == SbxDouble || rOP.GetType() == SbxDouble
-//			         || GetType() == SbxSingle || rOP.GetType() == SbxSingle )
-//				aL.eType = aR.eType = SbxLONG64;
             else
                 aL.eType = aR.eType = SbxLONG;
 
@@ -1378,7 +1373,7 @@ BOOL SbxValue::Compare( SbxOperator eOp, const SbxValue& rOp ) const
                     SetError( SbxERR_NOTIMP );
             }
         }
-        // AB 19.12.95: Wenn SbxSINGLE beteiligt, auf SINGLE konvertieren,
+        // Wenn SbxSINGLE beteiligt, auf SINGLE konvertieren,
         //				sonst gibt es numerische Fehler
         else if( GetType() == SbxSINGLE || rOp.GetType() == SbxSINGLE )
         {
@@ -1526,7 +1521,7 @@ BOOL SbxValue::LoadData( SvStream& r, USHORT )
             if( aVal.Len() )
                 aData.pString = new XubString( aVal );
             else
-                aData.pString = NULL; // JSM 22.09.1995
+                aData.pString = NULL;
             break;
         }
         case SbxERROR:
