@@ -38,15 +38,10 @@
 #include "property.hrc"
 
 #include <comphelper/container.hxx>
-
 #include <vcl/svapp.hxx>
-
 #include <toolkit/helper/vclunohelper.hxx>
-
 #include <com/sun/star/beans/PropertyAttribute.hpp>
-
 #include <comphelper/property.hxx>
-
 #include <com/sun/star/io/XMarkableStream.hpp>
 
 namespace binfilter {
@@ -93,7 +88,6 @@ using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::sdb;
 using namespace ::com::sun::star::sdbc;
-//using namespace ::com::sun::star::sdbcx;
 using namespace ::com::sun::star::beans;
 using namespace ::com::sun::star::container;
 using namespace ::com::sun::star::form;
@@ -128,16 +122,16 @@ OGridControlModel::OGridControlModel(const Reference<XMultiServiceFactory>& _rxF
                     ,m_aSelectListeners(m_aMutex)
                     ,m_aResetListeners(m_aMutex)
                     ,m_aDefaultControl(FRM_CONTROL_GRID)		// use the old control name for compytibility reasons
+                    ,m_nFontRelief(awt::FontRelief::NONE)
+                    ,m_nFontEmphasis(awt::FontEmphasisMark::NONE)
                     ,m_nFontEvent(0)
+                    ,m_nBorder(1)
                     ,m_bEnable(sal_True)
                     ,m_bNavigation(sal_True)
-                    ,m_nBorder(1)
                     ,m_bRecordMarker(sal_True)
                     ,m_bPrintable(sal_True)
                     ,m_bAlwaysShowCursor(sal_False)
                     ,m_bDisplaySynchron(sal_True)
-                    ,m_nFontRelief(awt::FontRelief::NONE)
-                    ,m_nFontEmphasis(awt::FontEmphasisMark::NONE)
 {
     DBG_CTOR(OGridControlModel,NULL);
 
@@ -192,7 +186,7 @@ OGridControlModel::~OGridControlModel()
 IMPLEMENT_DEFAULT_CLONING( OGridControlModel )
 
 //------------------------------------------------------------------------------
-void OGridControlModel::cloneColumns( const OGridControlModel* _pOriginalContainer )
+void OGridControlModel::cloneColumns( const OGridControlModel* )
 {
     try
     {
@@ -223,7 +217,7 @@ void OGridControlModel::cloneColumns( const OGridControlModel* _pOriginalContain
     }
     catch( const Exception& )
     {
-        DBG_ERROR( "OGridControlModel::cloneColumns: caught an exception while cloning the columns!" );
+        OSL_FAIL( "OGridControlModel::cloneColumns: caught an exception while cloning the columns!" );
     }
 }
 
@@ -368,7 +362,7 @@ void OGridControlModel::removeSelectionChangeListener(const Reference< XSelectio
 Reference<XPropertySet> SAL_CALL OGridControlModel::createColumn(const ::rtl::OUString& ColumnType) throw ( :: com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException)
 {
     const Sequence< ::rtl::OUString >& rColumnTypes = frm::getColumnTypes();
-    return createColumn(::binfilter::internal::findPos(ColumnType, rColumnTypes));//STRIP008 	return createColumn(::internal::findPos(ColumnType, rColumnTypes));
+    return createColumn(::binfilter::internal::findPos(ColumnType, rColumnTypes));
 }
 
 //------------------------------------------------------------------------------
@@ -388,7 +382,7 @@ Reference<XPropertySet>  OGridControlModel::createColumn(sal_Int32 nTypeId) cons
         case TYPE_TIMEFIELD:		xReturn = new TimeFieldColumn(OControlModel::m_xServiceFactory); break;
         case TYPE_FORMATTEDFIELD:	xReturn = new FormattedFieldColumn(OControlModel::m_xServiceFactory); break;
         default:
-            DBG_ERROR("OGridControlModel::createColumn: Unknown Column");
+            OSL_FAIL("OGridControlModel::createColumn: Unknown Column");
             break;
     }
     return xReturn;
@@ -412,7 +406,7 @@ void SAL_CALL OGridControlModel::reset() throw ( ::com::sun::star::uno::RuntimeE
 
     if (bContinue)
     {
-        _reset();
+        //_reset();
         m_aResetListeners.notifyEach(&XResetListener::resetted, aEvt);
     }
 }
@@ -429,19 +423,6 @@ void SAL_CALL OGridControlModel::removeResetListener(const Reference<XResetListe
     m_aResetListeners.removeInterface(_rxListener);
 }
 
-//-----------------------------------------------------------------------------
-void OGridControlModel::_reset()
-{
-    Reference<XReset> xReset;
-    sal_Int32 nCount = getCount();
-    for (sal_Int32 nIndex=0; nIndex < nCount; nIndex++)
-    {
-        getByIndex( nIndex ) >>= xReset;
-        if (xReset.is())
-            xReset->reset();
-    }
-}
-
 // XPropertySet
 //------------------------------------------------------------------------------
 Reference<XPropertySetInfo> SAL_CALL OGridControlModel::getPropertySetInfo() throw(RuntimeException)
@@ -1008,7 +989,6 @@ OGridColumn* OGridControlModel::getColumnImplementation(const InterfaceRef& _rxI
 void OGridControlModel::gotColumn(const Reference< XInterface >& _rxColumn)
 {
     // if our form is already loaded, tell the column
-    // 18.05.2001 - 86558 - frank.schoenheit@germany.sun.com
     if (m_xParentFormLoadable.is() && m_xParentFormLoadable->isLoaded())
     {
         Reference< XLoadListener > xColumnLoadListener(_rxColumn, UNO_QUERY);
