@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -32,38 +32,12 @@
 
 #define _BIGINT_HXX
 #define _SFXMULTISEL_HXX
-//#define _STACK_HXX
-//#define _QUEUE_HXX
 #define _DYNARR_HXX
 #define _TREELIST_HXX
 #define _CACHESTR_HXX
 #define _NEW_HXX
-//#define _SHL_HXX ***
-//#define _LINK_HXX ***
-//#define _ERRCODE_HXX ***
-//#define _GEN_HXX ***
-//#define _FRACT_HXX ***
-//#define _STRING_HXX ***
-//#define _MTF_HXX ***
-//#define _CONTNR_HXX ***
-//#define _LIST_HXX ***
-//#define _TABLE_HXX ***
 #define _DYNARY_HXX
-//#define _UNQIDX_HXX ***
-//#define _SVMEMPOOL_HXX ***
-//#define _UNQID_HXX ***
-//#define _DEBUG_HXX ***
-//#define _DATE_HXX ***
-//#define _TIME_HXX ***
-//#define _DATETIME_HXX ***
-//#define _INTN_HXX ***
-//#define _WLDCRD_HXX ***
-//#define _FSYS_HXX ***
-//#define _STREAM_HXX ***
 #define _CACHESTR_HXX
-//#define _SV_MULTISEL_HXX
-
-
 
 #define _SV_NOXSOUND
 
@@ -82,7 +56,6 @@
 #define _MOREBUTTON_HXX
 #define _OUTLINER_HXX
 #define _PASSWD_HXX
-//#define _QUEUE_HXX
 #define _RULER_HXX
 #define _SCRWIN_HXX
 #define _SETBRW_HXX
@@ -98,19 +71,14 @@
 #define _STDMENU_HXX
 
 
-//#define _PRNDLG_HXX ***
-//#define _POLY_HXX **
 // TOOLS
 #define _BIGINT_HXX
 #define _SFXMULTISEL_HXX
-//#define _STACK_HXX
-//#define _QUEUE_HXX
 #define _DYNARR_HXX
 #define _TREELIST_HXX
 #define _CACHESTR_HXX
 
 //SV
-//#define _CLIP_HXX
 #define _CONFIG_HXX
 #define _CURSOR_HXX
 #define _FONTDLG_HXX
@@ -120,11 +88,6 @@
 #define _MENUBTN_HXX
 #endif
 
-//#define _SOBASE_HXX
-//#define _SOSTOR_HXX
-//#define _SOCORE_HXX
-//#define _SOINPL_HXX
-
 #define _SFX_DOCFILE_HXX
 #define _SFX_DOCFILT_HXX
 #define _SFX_DOCINF_HXX
@@ -149,7 +112,6 @@
 #define _SFXMNUITEM_HXX
 #define _SFXMNUMGR_HXX
 #define _SFXMULTISEL_HXX
-//#define _SFXMSG_HXX
 #define _SFXMSGDESCR_HXX
 #define _SFXMSGPOOL_HXX
 #define _SFX_MINFITEM_HXX
@@ -161,19 +123,16 @@
 #define _SFXTBXCTRL_HXX
 #define _SFXTBXMGR_HXX
 
-//#define _SI_HXX
-//#define SI_NODRW
 #define _SI_DLL_HXX
 #define _SIDLL_HXX
 #define _SI_NOITEMS
 #define _SI_NOOTHERFORMS
 #define _SI_NOSBXCONTROLS
 #define _SINOSBXCONTROLS
-#define _SI_NODRW		  //
+#define _SI_NODRW
 #define _SI_NOCONTROL
 #define _VCBRW_HXX
 #define _VCTRLS_HXX
-//#define _VCSBX_HXX
 #define _VCONT_HXX
 #define _VDRWOBJ_HXX
 #define _VCATTR_HXX
@@ -182,12 +141,10 @@
 #define _SVBOXITM_HXX
 #define _SVCONTNR_HXX
 #define _SVDIALDLL_HXX
-//#define _SVDATTR_HXX
 #define _SVDRAG_HXX
 #define _SVDXOUT_HXX
 #define _SVDEC_HXX
 #define _SVDIO_HXX
-//#define _SVDLAYER_HXX
 #define _SVINCVW_HXX
 #define _SVRTV_HXX
 #define _SVTABBX_HXX
@@ -241,7 +198,7 @@
 #include "chartlis.hxx"
 #include "validat.hxx"
 #include "detdata.hxx"
-#include "bf_sc.hrc"				// FID_DATACHANGED
+#include "bf_sc.hrc"                            // FID_DATACHANGED
 #include "chgtrack.hxx"
 #include "chgviset.hxx"
 #include "editutil.hxx"
@@ -249,84 +206,83 @@
 #include "indexmap.hxx"
 #include "scrdata.hxx"
 #include "poolhelp.hxx"
-#include <legacysmgr/legacy_binfilters_smgr.hxx>	//STRIP002 
+#include <legacysmgr/legacy_binfilters_smgr.hxx>
 namespace binfilter {
 // STATIC DATA -----------------------------------------------------------
 
 /*N*/ ScDocument::ScDocument( ScDocumentMode	eMode,
 /*N*/ 						SfxObjectShell* pDocShell ) :
 /*N*/ 		xServiceManager( ::legacy_binfilters::getLegacyProcessServiceFactory() ),
-/*N*/ 		pDrawLayer( NULL ),
-/*N*/ 		pColorTable( NULL ),
+/*N*/ 		pEditEngine( NULL ),
 /*N*/ 		pShell( pDocShell ),
 /*N*/ 		pPrinter( NULL ),
+/*N*/ 		pDrawLayer( NULL ),
+/*N*/ 		pColorTable( NULL ),
+/*N*/ 		pCondFormList( NULL ),
+/*N*/ 		pValidationList( NULL ),
+/*N*/ 		pFormatExchangeList( NULL ),
+/*N*/ 		pDPCollection( NULL ),
+/*N*/ 		pLinkManager( NULL ),
+/*N*/ 		pFormulaTree( NULL ),
+/*N*/ 		pEOFormulaTree( NULL ),
+/*N*/ 		pFormulaTrack( NULL ),
+/*N*/ 		pEOFormulaTrack( NULL ),
+/*N*/ 		pOtherObjects( NULL ),
+/*N*/ 		pClipData( NULL ),
+/*N*/ 		pDetOpList(NULL),
+/*N*/ 		pChangeTrack( NULL ),
+/*N*/ 		pUnoBroadcaster( NULL ),
+/*N*/ 		pChangeViewSettings( NULL ),
+/*N*/ 		pScriptTypeData( NULL ),
+/*N*/           pCacheFieldEditEngine( NULL ),
+/*N*/ 		pViewOptions( NULL ),
+/*N*/ 		pDocOptions( NULL ),
+/*N*/ 		pExtDocOptions( NULL ),
+/*N*/ 		pConsolidateDlgData( NULL ),
+/*N*/           pLoadedSymbolStringCellList( NULL ),
+/*N*/ 		aCurTextWidthCalcPos(MAXCOL,0,0),
+/*N*/ 		nFormulaCodeInTree(0),
+/*N*/           nXMLImportedFormulaCount( 0 ),
+/*N*/ 		nInterpretLevel(0),
+/*N*/ 		nMacroInterpretLevel(0),
+/*N*/ 		nInterpreterTableOpLevel(0),
+/*N*/ 		nMaxTableNumber( 0 ),
+/*N*/ 		nFormulaTrackCount(0),
+/*N*/ 		nHardRecalcState(0),
+/*N*/ 		nVisibleTab( 0 ),
+/*N*/ 		eLinkMode(LM_UNKNOWN),
+/*N*/ 		bProtected( FALSE ),
 /*N*/ 		bAutoCalc( eMode == SCDOCMODE_DOCUMENT ),
 /*N*/ 		bAutoCalcShellDisabled( FALSE ),
 /*N*/ 		bForcedFormulaPending( FALSE ),
 /*N*/ 		bCalculatingFormulaTree( FALSE ),
-/*N*/ 		bIsUndo( eMode == SCDOCMODE_UNDO ),
 /*N*/ 		bIsClip( eMode == SCDOCMODE_CLIP ),
 /*N*/ 		bCutMode( FALSE ),
-/*N*/ 		nMaxTableNumber( 0 ),
-/*N*/ 		pCondFormList( NULL ),
-/*N*/ 		pValidationList( NULL ),
-/*N*/ 		pFormatExchangeList( NULL ),
+/*N*/ 		bIsUndo( eMode == SCDOCMODE_UNDO ),
 /*N*/ 		bIsEmbedded( FALSE ),
-/*N*/ 		bProtected( FALSE ),
-/*N*/ 		pLinkManager( NULL ),
-/*N*/ 		pDocOptions( NULL ),
-/*N*/ 		pViewOptions( NULL ),
-/*N*/ 		pExtDocOptions( NULL ),
-/*N*/ 		pConsolidateDlgData( NULL ),
-/*N*/ 		pFormulaTree( NULL ),
-/*N*/ 		pEOFormulaTree( NULL ),
-/*N*/ 		aCurTextWidthCalcPos(MAXCOL,0,0),
-/*N*/ //		bNoSetDirty( TRUE ),
 /*N*/ 		bNoSetDirty( FALSE ),
-/*N*/ 		pFormulaTrack( NULL ),
-/*N*/ 		pEOFormulaTrack( NULL ),
-/*N*/ 		nFormulaTrackCount(0),
 /*N*/ 		bInsertingFromOtherDoc( FALSE ),
-            bImportingXML( FALSE ),             // #i41083# this has to be set in ScXMLImport::startDocument
-/*N*/ 		nHardRecalcState(0),
+                bImportingXML( FALSE ),             // #i41083# this has to be set in ScXMLImport::startDocument
 /*N*/ 		bCalcingAfterLoad( FALSE ),
 /*N*/ 		bNoListening( FALSE ),
 /*N*/ 		bLoadingDone( TRUE ),
-/*N*/ 		nVisibleTab( 0 ),
 /*N*/ 		bIdleDisabled( FALSE ),
 /*N*/ 		bInLinkUpdate( FALSE ),
+/*N*/ 		bChartListenerCollectionNeedsUpdate( FALSE ),
+/*N*/ 		bHasForcedFormulas( FALSE ),
+/*N*/ 		bLostData(FALSE),
+/*N*/ 		bInDtorClear( FALSE ),
+/*N*/ 		bExpandRefs( FALSE ),
 /*N*/ 		bDetectiveDirty( FALSE ),
 /*N*/ 		nMacroCallMode( SC_MACROCALL_ALLOWED ),
 /*N*/ 		bHasMacroFunc( FALSE ),
-/*N*/ 		bChartListenerCollectionNeedsUpdate( FALSE ),
-/*N*/ 		bHasForcedFormulas( FALSE ),
 /*N*/ 		nVisSpellState( 0 ),
-/*N*/ 		pOtherObjects( NULL ),
-/*N*/ 		pClipData( NULL ),
-/*N*/ 		nFormulaCodeInTree(0),
-/*N*/ 		nInterpretLevel(0),
-/*N*/ 		nMacroInterpretLevel(0),
-/*N*/ 		nInterpreterTableOpLevel(0),
-/*N*/ 		bLostData(FALSE),
-/*N*/ 		pDetOpList(NULL),
-/*N*/ 		bInDtorClear( FALSE ),
-/*N*/ 		bExpandRefs( FALSE ),
-/*N*/ 		pUnoBroadcaster( NULL ),
-/*N*/ 		pChangeTrack( NULL ),
-/*N*/ 		pChangeViewSettings( NULL ),
-/*N*/ 		pEditEngine( NULL ),
-/*N*/ 		eLinkMode(LM_UNKNOWN),
-/*N*/ 		pDPCollection( NULL ),
-/*N*/ 		pScriptTypeData( NULL ),
-/*N*/         nAsianCompression(SC_ASIANCOMPRESSION_INVALID),
-/*N*/         nAsianKerning(SC_ASIANKERNING_INVALID),
-/*N*/         pLoadedSymbolStringCellList( NULL ),
-/*N*/         bPastingDrawFromOtherDoc( FALSE ),
-/*N*/         pCacheFieldEditEngine( NULL ),
-/*N*/         nInDdeLinkUpdate( 0 ),
-/*N*/         nXMLImportedFormulaCount( 0 ),
-/*N*/         bInUnoBroadcast( FALSE ),
-/*N*/         bStyleSheetUsageInvalid( TRUE )
+/*N*/           nAsianCompression(SC_ASIANCOMPRESSION_INVALID),
+/*N*/           nAsianKerning(SC_ASIANKERNING_INVALID),
+/*N*/           bPastingDrawFromOtherDoc( FALSE ),
+/*N*/           nInDdeLinkUpdate( 0 ),
+/*N*/           bInUnoBroadcast( FALSE ),
+/*N*/           bStyleSheetUsageInvalid( TRUE )
 /*N*/ {
 /*N*/ 	eSrcSet = gsl_getSystemTextEncoding();
 /*N*/ 	nSrcVer = SC_CURRENT_VERSION;
@@ -396,9 +352,9 @@ namespace binfilter {
 /*N*/ }
 
 
-/*N*/  IMPL_LINK( ScDocument, TrackTimeHdl, Timer*, pTimer )
+/*N*/  IMPL_LINK( ScDocument, TrackTimeHdl, Timer*, EMPTYARG )
 /*N*/  {
-/*?*/  	DBG_BF_ASSERT(0, "STRIP"); //STRIP001 if ( ScDdeLink::IsInUpdate() )		// nicht verschachteln
+/*?*/  	DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 	return 0;
 /*N*/ }
 
@@ -517,11 +473,6 @@ namespace binfilter {
 /*N*/ 	return *pEditEngine;
 /*N*/ }
 
-/*N*/ void ScDocument::ResetClip( ScDocument* pSourceDoc, const ScMarkData* pMarks )
-/*N*/ {
-DBG_BF_ASSERT(0, "STRIP"); //STRIP001 //STRIP001 	if (bIsClip)
-/*N*/ }
-
 /*N*/ void lcl_RefreshPivotData( ScPivotCollection* pColl )
 /*N*/ {
 /*N*/ 	USHORT nCount = pColl->GetCount();
@@ -741,7 +692,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001 //STRIP001 	if (bIsClip)
 /*N*/ 					break;
 /*N*/ 				default:
 /*N*/ 					{
-/*N*/ 						DBG_ERROR("unbekannter Sub-Record in ScDocument::Load");
+/*N*/ 						OSL_FAIL("unbekannter Sub-Record in ScDocument::Load");
 /*N*/ 						ScReadHeader aDummyHdr( rStream );
 /*N*/ 					}
 /*N*/ 			}
@@ -1246,7 +1197,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001 //STRIP001 	if (bIsClip)
 /*N*/ 
 /*N*/ 	if (bValid)
 /*N*/ 	{
-/*N*/ 		BOOL bOldAutoCalcSrc;
+/*N*/ 		BOOL bOldAutoCalcSrc = FALSE;
 /*N*/ 		BOOL bOldAutoCalc = GetAutoCalc();
 /*N*/ 		SetAutoCalc( FALSE );	// Mehrfachberechnungen vermeiden
 /*N*/ 		SetNoListening( TRUE );
@@ -1283,16 +1234,16 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001 //STRIP001 	if (bIsClip)
 /*N*/ 			for (USHORT i = 0; i < nSrcRangeNames; i++)		//! DB-Bereiche Pivot-Bereiche auch !!!
 /*N*/ 			{
 /*?*/ 				ScRangeData* pSrcData = (*pSrcDoc->pRangeName)[i];
-/*?*/ 				USHORT nOldIndex = pSrcData->GetIndex();
+/*?*/ 				/*USHORT nOldIndex =*/ pSrcData->GetIndex();
 /*?*/ 				BOOL bInUse = FALSE;
 /*?*/ 				for (USHORT j = 0; !bInUse && (j <= MAXTAB); j++)
 /*?*/ 				{
 /*?*/ 					if (pSrcDoc->pTab[j])
-DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/ 						bInUse = pSrcDoc->pTab[j]->IsRangeNameInUse(0, 0, MAXCOL, MAXROW,
+DBG_BF_ASSERT(0, "STRIP");
 /*?*/ 				}
 /*?*/ 				if (bInUse)
 /*?*/ 				{
-/*?*/ 				DBG_BF_ASSERT(0, "STRIP"); //STRIP001 	ScRangeData* pData = new ScRangeData( *pSrcData );
+/*?*/ 				DBG_BF_ASSERT(0, "STRIP");
 /*?*/ 				}
 /*?*/ 				else
 /*?*/ 				{
@@ -1304,7 +1255,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/ 						bInUse = pSrcDoc->pTab[j]->IsR
 /*N*/ 			{
 /*?*/ 				// first update all inserted named formulas if they contain other
 /*?*/ 				// range names and used indices changed
-DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/ 				for (USHORT i = 0; i < nSrcRangeNames; i++)		//! DB-Bereiche Pivot-Bereiche auch
+DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 			}
 /*N*/ 			if ( pSrcRangeNames )
 /*?*/ 				delete [] pSrcRangeNames;
@@ -1380,18 +1331,18 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/ 				for (USHORT i = 0; i < nSrcRange
 
 /*N*/ ScFieldEditEngine* ScDocument::CreateFieldEditEngine()
 /*N*/ {
-/*N*/ 	ScFieldEditEngine* pEditEngine = NULL;
+/*N*/ 	ScFieldEditEngine* pLclEditEngine = NULL;
 /*N*/ 	if (!pCacheFieldEditEngine)
 /*N*/ 	{
-/*N*/ 		pEditEngine = new ScFieldEditEngine( GetEnginePool(),
+/*N*/ 		pLclEditEngine = new ScFieldEditEngine( GetEnginePool(),
 /*N*/ 			GetEditPool(), FALSE );
 /*N*/ 	}
 /*N*/ 	else
 /*N*/ 	{
-/*N*/ 		pEditEngine = pCacheFieldEditEngine;
+/*N*/ 		pLclEditEngine = pCacheFieldEditEngine;
 /*N*/ 		pCacheFieldEditEngine = NULL;
 /*N*/ 	}
-/*N*/ 	return pEditEngine;
+/*N*/ 	return pLclEditEngine;
 /*N*/ }
 
 /*N*/ void ScDocument::DisposeFieldEditEngine(ScFieldEditEngine*& rpEditEngine)
