@@ -48,12 +48,12 @@ namespace binfilter {
 
 //------------------------------------------------------------------------
 
-sal_Char *linker_dummy = "";
+const sal_Char *linker_dummy = "";
 
 //	Standard-Name ist jetzt STR_STYLENAME_STANDARD (wie Vorlagen)
-//static const sal_Char __FAR_DATA cStandardName[] = "Standard";
+//static const sal_Char cStandardName[] = "Standard";
 
-static const sal_Char __FAR_DATA sAutoTblFmtName[] = "autotbl.fmt";
+static const sal_Char sAutoTblFmtName[] = "autotbl.fmt";
 
 // bis SO5PF
 const USHORT AUTOFORMAT_ID_X		= 9501;
@@ -249,9 +249,9 @@ const USHORT AUTOFORMAT_OLD_ID_NEW 	= 4203;
 /*N*/  {
 /*N*/  }
 
-/*N*/ void ScAutoFormatDataField::SetAdjust( const SvxAdjustItem& rAdjust )
+/*N*/ void ScAutoFormatDataField::SetAdjust( const SvxAdjustItem& /*rAdjust*/ )
 /*N*/ {
-/*?*/     DBG_BF_ASSERT(0, "STRIP"); //STRIP001 aAdjust.SetAdjust( rAdjust.GetAdjust() );
+/*?*/     DBG_BF_ASSERT(0, "STRIP");
 /*N*/ }
 
 /*N*/ #define READ( aItem, ItemType, nVers )      \
@@ -393,8 +393,6 @@ const USHORT AUTOFORMAT_OLD_ID_NEW 	= 4203;
 /*N*/  }
 
 
-//	---------------------------------------------------------------------------
-
 /*N*/ ScAutoFormatData::ScAutoFormatData()
 /*N*/ {
 /*N*/ 	nStrResId = USHRT_MAX;
@@ -414,11 +412,11 @@ const USHORT AUTOFORMAT_OLD_ID_NEW 	= 4203;
 /*N*/ ScAutoFormatData::ScAutoFormatData( const ScAutoFormatData& rData ) :
 /*N*/ 		aName( rData.aName ),
 /*N*/ 		nStrResId( rData.nStrResId ),
-/*N*/ 		bIncludeValueFormat( rData.bIncludeValueFormat ),
 /*N*/ 		bIncludeFont( rData.bIncludeFont ),
 /*N*/ 		bIncludeJustify( rData.bIncludeJustify ),
 /*N*/ 		bIncludeFrame( rData.bIncludeFrame ),
 /*N*/ 		bIncludeBackground( rData.bIncludeBackground ),
+/*N*/ 		bIncludeValueFormat( rData.bIncludeValueFormat ),
 /*N*/ 		bIncludeWidthHeight( rData.bIncludeWidthHeight )
 /*N*/ {
 /*N*/     ppDataField = new ScAutoFormatDataField*[ 16 ];
@@ -516,12 +514,6 @@ const USHORT AUTOFORMAT_OLD_ID_NEW 	= 4203;
 /*N*/ 	}
 /*N*/ }
 
-
-
-
-
-
-
 /*N*/  BOOL ScAutoFormatData::Load( SvStream& rStream, const ScAfVersions& rVersions )
 /*N*/  {
 /*N*/  	BOOL    bRet = TRUE;
@@ -531,7 +523,7 @@ const USHORT AUTOFORMAT_OLD_ID_NEW 	= 4203;
 /*N*/      if( bRet && (nVer == AUTOFORMAT_DATA_ID_X ||
 /*N*/              (AUTOFORMAT_DATA_ID_504 <= nVer && nVer <= AUTOFORMAT_DATA_ID)) )
 /*N*/  	{
-/*N*/  		CharSet eSysSet = gsl_getSystemTextEncoding();
+/*N*/  		gsl_getSystemTextEncoding();
 /*N*/  		CharSet eSrcSet = rStream.GetStreamCharSet();
 /*N*/  
 /*N*/  		BOOL b;
@@ -600,31 +592,6 @@ const USHORT AUTOFORMAT_OLD_ID_NEW 	= 4203;
 /*N*/  	rStream << nVal;
 /*N*/  	rStream.WriteByteString( aName, rStream.GetStreamCharSet() );
 /*N*/  
-/*N*/  #if 0
-/*N*/  	//	This was an internal flag to allow creating AutoFormats with localized names
-/*N*/  
-/*N*/  	if ( USHRT_MAX == nStrResId )
-/*N*/  	{
-/*N*/  		String aIniVal( SFX_APP()->GetIniManager()->Get(
-/*N*/  			SFX_GROUP_WORKINGSET_IMPL,
-/*N*/  			String( RTL_CONSTASCII_USTRINGPARAM( "SaveTableAutoFmtNameId" ))));
-/*N*/  		if( 0 != aIniVal.ToInt32() )
-/*N*/  		{
-/*N*/  			// check Name for ResId
-/*N*/  			for( USHORT nId = RID_SVXSTR_TBLAFMT_BEGIN;
-/*N*/  						RID_SVXSTR_TBLAFMT_END > nId; ++nId )
-/*N*/  			{
-/*N*/  				String s( SVX_RES( nId ) );
-/*N*/  				if( s == aName )
-/*N*/  				{
-/*N*/  					nStrResId = nId - RID_SVXSTR_TBLAFMT_BEGIN;
-/*N*/  					break;
-/*N*/  				}
-/*N*/  			}
-/*N*/  		}
-/*N*/  	}
-/*N*/  #endif
-/*N*/  
 /*N*/  	rStream << nStrResId;
 /*N*/  	rStream << ( b = bIncludeFont );
 /*N*/  	rStream << ( b = bIncludeJustify );
@@ -640,8 +607,6 @@ const USHORT AUTOFORMAT_OLD_ID_NEW 	= 4203;
 /*N*/  	return bRet;
 /*N*/  }
 
-//---------------------------------------------------------------------------------------
-//---------------------------------------------------------------------------------------
 
 /*N*/ ScAutoFormat::ScAutoFormat(USHORT nLim, USHORT nDel, BOOL bDup):
 /*N*/ 	SortedCollection        (nLim, nDel, bDup),
@@ -780,8 +745,6 @@ const USHORT AUTOFORMAT_OLD_ID_NEW 	= 4203;
 /*N*/ 				BYTE nChrSet, nCnt;
 /*N*/ 				long nPos = rStream.Tell();
 /*N*/ 				rStream >> nCnt >> nChrSet;
-/*N*/ //				if( 4 <= nCnt )
-/*N*/ //					rStream >> nFileVers;
 /*N*/ 				if( rStream.Tell() != ULONG(nPos + nCnt) )
 /*N*/ 				{
 /*N*/ 					DBG_ERRORFILE( "Der Header enthaelt mehr/neuere Daten" );
@@ -884,7 +847,6 @@ const USHORT AUTOFORMAT_OLD_ID_NEW 	= 4203;
 /*N*/ 		ScAfVersions::Write(rStream);			// Item-Versionen
 /*N*/ 
 /*N*/ 		bRet = (rStream.GetError() == 0);
-/*N*/ 		//-----------------------------------------------------------
 /*N*/ 		rStream << (USHORT)(nCount - 1);
 /*N*/ 		bRet = (rStream.GetError() == 0);
 /*N*/ 		for (USHORT i=1; bRet && (i < nCount); i++)
