@@ -32,11 +32,7 @@
 
 // INCLUDE ---------------------------------------------------------------
 
-#if STLPORT_VERSION<321
-#include <stddef.h>
-#else
 #include <cstddef>
-#endif
 #include <string.h>
 
 #include <tools/debug.hxx>
@@ -56,32 +52,32 @@ namespace binfilter {
 
 // ImpTokenIterator wird je Interpreter angelegt, mehrfache auch durch
 // SubCode via ScTokenIterator Push/Pop moeglich
-/*N*/ IMPL_FIXEDMEMPOOL_NEWDEL( ImpTokenIterator, 32, 16 )//STRIP008 ;
+/*N*/ IMPL_FIXEDMEMPOOL_NEWDEL( ImpTokenIterator, 32, 16 )
 
 // Align MemPools on 4k boundaries - 64 bytes (4k is a MUST for OS/2)
 
 // Since RawTokens are temporary for the compiler, don't align on 4k and waste memory.
 // ScRawToken size is FixMembers + MAXSTRLEN ~= 264
-/*N*/ IMPL_FIXEDMEMPOOL_NEWDEL( ScRawToken, 8, 4 )//STRIP008 ;
+/*N*/ IMPL_FIXEDMEMPOOL_NEWDEL( ScRawToken, 8, 4 )
 // Some ScDoubleRawToken, FixMembers + sizeof(double) ~= 16
 /*N*/ const USHORT nMemPoolDoubleRawToken = 0x0400 / sizeof(ScDoubleRawToken);
-/*N*/ IMPL_FIXEDMEMPOOL_NEWDEL( ScDoubleRawToken, nMemPoolDoubleRawToken, nMemPoolDoubleRawToken )//STRIP008 ;
+/*N*/ IMPL_FIXEDMEMPOOL_NEWDEL( ScDoubleRawToken, nMemPoolDoubleRawToken, nMemPoolDoubleRawToken )
 
 // Need a whole bunch of ScSingleRefToken
 /*N*/ const USHORT nMemPoolSingleRefToken = (0x4000 - 64) / sizeof(ScSingleRefToken);
-/*N*/ IMPL_FIXEDMEMPOOL_NEWDEL( ScSingleRefToken, nMemPoolSingleRefToken, nMemPoolSingleRefToken )//STRIP008 ;
+/*N*/ IMPL_FIXEDMEMPOOL_NEWDEL( ScSingleRefToken, nMemPoolSingleRefToken, nMemPoolSingleRefToken )
 // Need a lot of ScDoubleToken
 /*N*/ const USHORT nMemPoolDoubleToken = (0x3000 - 64) / sizeof(ScDoubleToken);
-/*N*/ IMPL_FIXEDMEMPOOL_NEWDEL( ScDoubleToken, nMemPoolDoubleToken, nMemPoolDoubleToken )//STRIP008 ;
+/*N*/ IMPL_FIXEDMEMPOOL_NEWDEL( ScDoubleToken, nMemPoolDoubleToken, nMemPoolDoubleToken )
 // Need a lot of ScByteToken
 /*N*/ const USHORT nMemPoolByteToken = (0x3000 - 64) / sizeof(ScByteToken);
-/*N*/ IMPL_FIXEDMEMPOOL_NEWDEL( ScByteToken, nMemPoolByteToken, nMemPoolByteToken )//STRIP008 ;
+/*N*/ IMPL_FIXEDMEMPOOL_NEWDEL( ScByteToken, nMemPoolByteToken, nMemPoolByteToken )
 // Need quite a lot of ScDoubleRefToken
 /*N*/ const USHORT nMemPoolDoubleRefToken = (0x2000 - 64) / sizeof(ScDoubleRefToken);
-/*N*/ IMPL_FIXEDMEMPOOL_NEWDEL( ScDoubleRefToken, nMemPoolDoubleRefToken, nMemPoolDoubleRefToken )//STRIP008 ;
+/*N*/ IMPL_FIXEDMEMPOOL_NEWDEL( ScDoubleRefToken, nMemPoolDoubleRefToken, nMemPoolDoubleRefToken )
 // Need several ScStringToken
 /*N*/ const USHORT nMemPoolStringToken = (0x1000 - 64) / sizeof(ScStringToken);
-/*N*/ IMPL_FIXEDMEMPOOL_NEWDEL( ScStringToken, nMemPoolStringToken, nMemPoolStringToken )//STRIP008 ;
+/*N*/ IMPL_FIXEDMEMPOOL_NEWDEL( ScStringToken, nMemPoolStringToken, nMemPoolStringToken )
 
 
 // --- helpers --------------------------------------------------------------
@@ -191,6 +187,15 @@ namespace binfilter {
 /*N*/ 	nRefCnt = 0;
 /*N*/ }
 
+USHORT lcl_ScRawTokenOffset()
+{
+    // offset of cByte in ScRawToken
+    // offsetof(ScRawToken, cByte) gives a warning with gcc, because ScRawToken is no POD
+
+    ScRawToken aToken;
+    return static_cast<USHORT>( reinterpret_cast<char*>(&aToken.cByte) - reinterpret_cast<char*>(&aToken) );
+}
+
 /*N*/ ScRawToken* ScRawToken::Clone() const
 /*N*/ {
 /*N*/ 	ScRawToken* p;
@@ -203,7 +208,7 @@ namespace binfilter {
 /*N*/ 	}
 /*N*/ 	else
 /*N*/ 	{
-/*N*/ 		USHORT n = offsetof( ScRawToken, cByte );
+/*N*/ 		static USHORT n = lcl_ScRawTokenOffset();
 /*N*/ 		switch( eType )
 /*N*/ 		{
 /*N*/ 			case svByte:		n++; break;
@@ -449,7 +454,7 @@ namespace binfilter {
 /*N*/ 	return 0;
 /*N*/ }
 
-/*N*/ void ScToken::SetByte( BYTE n )
+/*N*/ void ScToken::SetByte( BYTE /*n*/ )
 /*N*/ {
 /*N*/  DBG_ERRORFILE( "ScToken::SetByte: virtual dummy called" );
 /*N*/ }
@@ -502,12 +507,12 @@ namespace binfilter {
 /*N*/  	return aDummySingleRef;
 /*N*/  }
 
-/*N*/ void ScToken::CalcAbsIfRel( const ScAddress& rPos )
+/*N*/ void ScToken::CalcAbsIfRel( const ScAddress& /*rPos*/ )
 /*N*/ {
 /*N*/ 	DBG_ERRORFILE( "ScToken::CalcAbsIfRel: virtual dummy called" );
 /*N*/ }
 
-/*N*/ void ScToken::CalcRelFromAbs( const ScAddress& rPos )
+/*N*/ void ScToken::CalcRelFromAbs( const ScAddress& /*rPos*/ )
 /*N*/ {
 /*N*/ 	DBG_ERRORFILE( "ScToken::CalcRelFromAbs: virtual dummy called" );
 /*N*/ }
@@ -524,7 +529,7 @@ namespace binfilter {
 /*N*/ 	return 0;
 /*N*/ }
 
-/*N*/  void ScToken::SetIndex( USHORT n )
+/*N*/  void ScToken::SetIndex( USHORT /*n*/ )
 /*N*/  {
 /*N*/  	DBG_ERRORFILE( "ScToken::SetIndex: virtual dummy called" );
 /*N*/  }
@@ -1394,7 +1399,7 @@ namespace binfilter {
 /*N*/ 				sp -= nParams;
 /*N*/ 				if ( sp < 0 )
 /*N*/ 				{
-/*N*/ 					DBG_ERROR( "ScTokenArray::HasMatrixDoubleRefOps: sp < 0" );
+/*N*/ 					OSL_FAIL( "ScTokenArray::HasMatrixDoubleRefOps: sp < 0" );
 /*N*/ 					sp = 0;
 /*N*/ 				}
 /*N*/ 				pStack[sp++] = pResult;
@@ -1439,7 +1444,7 @@ namespace binfilter {
 /*?*/ 					rStream >> nOp;
 /*?*/ 					if( nOp > MAXSTRLEN-1 )
 /*?*/ 					{
-/*?*/ 						DBG_ERROR("Dokument huehnerich");
+/*?*/ 						OSL_FAIL("Dokument huehnerich");
 /*?*/ 						USHORT nDiff = nOp - (MAXSTRLEN-1);
 /*?*/ 						nOp = MAXSTRLEN-1;
 /*?*/ 						rStream.Read( c, nOp );
@@ -1489,7 +1494,7 @@ namespace binfilter {
 /*N*/ 					aRef.Ref2.OldBoolsToNewFlags( aBools2 );
 /*N*/ 					break;
 /*N*/ 				}
-/*N*/ 				default: DBG_ERROR("Unknown Stack Variable");
+/*N*/ 				default: OSL_FAIL("Unknown Stack Variable");
 /*N*/ 				break;
 /*N*/ 			}
 /*N*/ 			break;
@@ -1505,7 +1510,7 @@ namespace binfilter {
 /*?*/ 			// lieber ein rottes Dokument als stack overwrite
 /*?*/ 			if( nOp > MAXSTRLEN-2 )
 /*?*/ 			{
-/*?*/ 				DBG_ERROR("Dokument huehnerich");
+/*?*/ 				OSL_FAIL("Dokument huehnerich");
 /*?*/ 				USHORT nDiff = nOp - (MAXSTRLEN-2);
 /*?*/ 				nOp = MAXSTRLEN-2;
 /*?*/ 				rStream.Read( c, nOp );
@@ -1570,16 +1575,7 @@ namespace binfilter {
 /*N*/ 		{
 /*N*/ 			sal_Char c[ MAXSTRLEN+1 ];
 /*N*/ 			rStream >> n;
-/*N*/ 			if( n > MAXSTRLEN-1 )
-/*N*/ 			{
-/*?*/ 				DBG_ERRORFILE( "bad string array boundary" );
-/*?*/ 				USHORT nDiff = n - (MAXSTRLEN-1);
-/*?*/ 				n = MAXSTRLEN-1;
-/*?*/ 				rStream.Read( c, n );
-/*?*/ 				rStream.SeekRel( nDiff );
-/*N*/ 			}
-/*N*/ 			else
-/*N*/ 				rStream.Read( c, n );
+/*N*/ 			rStream.Read( c, n );
 /*N*/ 			cStr[ n ] = 0;
 /*N*/ 			CharSet eSrc = rStream.GetStreamCharSet();
 /*N*/ 			for ( BYTE j=0; j<n; j++ )
@@ -1590,10 +1586,10 @@ namespace binfilter {
 /*N*/ 		case svSingleRef:
 /*N*/ 		case svDoubleRef:
 /*N*/ 		{
-/*N*/ 			SingleRefData& r = aRef.Ref1;
-/*N*/ 			rStream >> r.nCol
-/*N*/ 					>> r.nRow
-/*N*/ 					>> r.nTab
+/*N*/ 			SingleRefData& r1 = aRef.Ref1;
+/*N*/ 			rStream >> r1.nCol
+/*N*/ 					>> r1.nRow
+/*N*/ 					>> r1.nTab
 /*N*/ 					>> n;
 /*N*/ 			if ( nVer < SC_RELATIVE_REFS )
 /*N*/ 			{
@@ -1602,18 +1598,18 @@ namespace binfilter {
 /*N*/ 				aBools.bRelRow = ( ( n >> 2 ) & 0x03 );
 /*N*/ 				aBools.bRelTab = ( ( n >> 4 ) & 0x03 );
 /*N*/ 				aBools.bOldFlag3D = ( ( n >> 6 ) & 0x03 );
-/*N*/ 				r.OldBoolsToNewFlags( aBools );
+/*N*/ 				r1.OldBoolsToNewFlags( aBools );
 /*N*/ 			}
 /*N*/ 			else
-/*N*/ 				r.CreateFlagsFromLoadByte( n );
+/*N*/ 				r1.CreateFlagsFromLoadByte( n );
 /*N*/ 			if( eType == svSingleRef )
-/*N*/ 				aRef.Ref2 = r;
+/*N*/ 				aRef.Ref2 = r1;
 /*N*/ 			else
 /*N*/ 			{
-/*N*/ 				SingleRefData& r = aRef.Ref2;
-/*N*/ 				rStream >> r.nCol
-/*N*/ 						>> r.nRow
-/*N*/ 						>> r.nTab
+/*N*/ 				SingleRefData& r2 = aRef.Ref2;
+/*N*/ 				rStream >> r2.nCol
+/*N*/ 						>> r2.nRow
+/*N*/ 						>> r2.nTab
 /*N*/ 						>> n;
 /*N*/ 				if ( nVer < SC_RELATIVE_REFS )
 /*N*/ 				{
@@ -1622,10 +1618,10 @@ namespace binfilter {
 /*N*/ 					aBools.bRelRow = ( ( n >> 2 ) & 0x03 );
 /*N*/ 					aBools.bRelTab = ( ( n >> 4 ) & 0x03 );
 /*N*/ 					aBools.bOldFlag3D = ( ( n >> 6 ) & 0x03 );
-/*N*/ 					r.OldBoolsToNewFlags( aBools );
+/*N*/ 					r2.OldBoolsToNewFlags( aBools );
 /*N*/ 				}
 /*N*/ 				else
-/*N*/ 					r.CreateFlagsFromLoadByte( n );
+/*N*/ 					r2.CreateFlagsFromLoadByte( n );
 /*N*/ 			}
 /*N*/ 			break;
 /*N*/ 		}
