@@ -62,7 +62,7 @@
 #include "globstr.hrc"
 #include "scerrors.hxx"
 #include "XMLExportSharedData.hxx"
-#include <legacysmgr/legacy_binfilters_smgr.hxx>	//STRIP002 
+#include <legacysmgr/legacy_binfilters_smgr.hxx>
 #ifndef SEQTYPE
 namespace binfilter {
  #if defined(__SUNPRO_CC) && (__SUNPRO_CC == 0x500)
@@ -109,7 +109,7 @@ uno::Reference <task::XStatusIndicator> ScXMLImportWrapper::GetStatusIndicator(
                     }
                     catch( lang::DisposedException e )
                     {
-                        DBG_ERROR("Exception while trying to get a Status Indicator");
+                        OSL_FAIL("Exception while trying to get a Status Indicator");
                     }
                 }
             }
@@ -173,32 +173,6 @@ sal_uInt32 ScXMLImportWrapper::ImportFromComponent(uno::Reference<lang::XMultiSe
                         aAny.getValueType() == ::getBooleanCppuType() &&
                         *(sal_Bool *)aAny.getValue();
     }
-    // #99667#; no longer necessary
-/*	else if ( pMedium )
-    {
-        // if there is a medium and if this medium has a load environment,
-        // we get an active data source from the medium.
-        pMedium->GetInStream()->Seek( 0 );
-        xSource = pMedium->GetDataSource();
-        DBG_ASSERT( xSource.is(), "got no data source from medium" );
-        if( !xSource.is() )
-            return sal_False;
-
-        // get a pipe for connecting the data source to the parser
-        xPipe = xServiceFactory->createInstance(
-                OUString::createFromAscii("com.sun.star.io.Pipe") );
-        DBG_ASSERT( xPipe.is(),
-                "XMLReader::Read: com.sun.star.io.Pipe service missing" );
-        if( !xPipe.is() )
-            return sal_False;
-
-        // connect pipe's output stream to the data source
-        uno::Reference<io::XOutputStream> xPipeOutput( xPipe, uno::UNO_QUERY );
-        xSource->setOutputStream( xPipeOutput );
-
-        aParserInput.aInputStream =
-            uno::Reference< io::XInputStream >( xPipe, uno::UNO_QUERY );
-    }*/
     else
         return SCERR_IMPORT_UNKNOWN;
 
@@ -225,7 +199,6 @@ sal_uInt32 ScXMLImportWrapper::ImportFromComponent(uno::Reference<lang::XMultiSe
             xSourceControl->start();
     }
 
-    sal_Bool bFormatError = sal_False;
     try
     {
         xParser->parseStream( aParserInput );
@@ -240,7 +213,7 @@ sal_uInt32 ScXMLImportWrapper::ImportFromComponent(uno::Reference<lang::XMultiSe
 #ifdef DBG_UTIL
             ByteString aError( "SAX parse exception catched while importing:\n" );
             aError += ByteString( String( r.Message), RTL_TEXTENCODING_ASCII_US );
-            DBG_ERROR( aError.GetBuffer() );
+            OSL_FAIL( aError.GetBuffer() );
 #endif
 
             String sErr( String::CreateFromInt32( r.LineNumber ));
@@ -273,7 +246,7 @@ sal_uInt32 ScXMLImportWrapper::ImportFromComponent(uno::Reference<lang::XMultiSe
 #ifdef DBG_UTIL
             ByteString aError( "SAX exception catched while importing:\n" );
             aError += ByteString( String( r.Message), RTL_TEXTENCODING_ASCII_US );
-            DBG_ERROR( aError.GetBuffer() );
+            OSL_FAIL( aError.GetBuffer() );
 #endif
             nReturn = SCERR_IMPORT_FORMAT;
         }
@@ -283,7 +256,7 @@ sal_uInt32 ScXMLImportWrapper::ImportFromComponent(uno::Reference<lang::XMultiSe
 #ifdef DBG_UTIL
         ByteString aError( "Zip exception catched while importing:\n" );
         aError += ByteString( String( r.Message), RTL_TEXTENCODING_ASCII_US );
-        DBG_ERROR( aError.GetBuffer() );
+        OSL_FAIL( aError.GetBuffer() );
 #endif
         nReturn = ERRCODE_IO_BROKENPACKAGE;
     }
@@ -292,7 +265,7 @@ sal_uInt32 ScXMLImportWrapper::ImportFromComponent(uno::Reference<lang::XMultiSe
 #ifdef DBG_UTIL
         ByteString aError( "IO exception catched while importing:\n" );
         aError += ByteString( String( r.Message), RTL_TEXTENCODING_ASCII_US );
-        DBG_ERROR( aError.GetBuffer() );
+        OSL_FAIL( aError.GetBuffer() );
 #endif
         nReturn = SCERR_IMPORT_OPEN;
     }
@@ -301,7 +274,7 @@ sal_uInt32 ScXMLImportWrapper::ImportFromComponent(uno::Reference<lang::XMultiSe
 #ifdef DBG_UTIL
         ByteString aError( "uno exception catched while importing:\n" );
         aError += ByteString( String( r.Message), RTL_TEXTENCODING_ASCII_US );
-        DBG_ERROR( aError.GetBuffer() );
+        OSL_FAIL( aError.GetBuffer() );
 #endif
         nReturn = SCERR_IMPORT_UNKNOWN;
     }
