@@ -53,7 +53,6 @@ namespace binfilter {
 
 using namespace ::com::sun::star;
 
-//------------------------------------------------------------------------
 
 // Calc document
 extern uno::Sequence< ::rtl::OUString > SAL_CALL ScDocument_getSupportedServiceNames() throw();
@@ -105,7 +104,6 @@ extern ::rtl::OUString SAL_CALL ScXMLExport_Settings_getImplementationName() thr
 extern uno::Reference< uno::XInterface > SAL_CALL ScXMLExport_Settings_createInstance(
             const uno::Reference< lang::XMultiServiceFactory > & rSMgr ) throw( uno::Exception );
 
-//------------------------------------------------------------------------
 
 //	Anzahl der Funktionen, die als zuletzt benutzt gespeichert werden
 //!	Define mit funcpage.hxx und dwfunctr.hxx zusammenfassen !!!
@@ -120,7 +118,6 @@ extern uno::Reference< uno::XInterface > SAL_CALL ScXMLExport_Settings_createIns
 //	Anzahl der PropertyValues in einer Function-Description
 #define SC_FUNCDESC_PROPCOUNT	5
 
-//------------------------------------------------------------------------
 
 //	alles ohne Which-ID, Map nur fuer PropertySetInfo
 
@@ -128,30 +125,29 @@ const SfxItemPropertyMap* lcl_GetSettingsPropertyMap()
 {
     static SfxItemPropertyMap aSettingsPropertyMap_Impl[] =
     {
-        {MAP_CHAR_LEN(SC_UNONAME_DOAUTOCP),	0,	&getBooleanCppuType(),				0},
-        {MAP_CHAR_LEN(SC_UNONAME_ENTERED),	0,	&getBooleanCppuType(),				0},
-        {MAP_CHAR_LEN(SC_UNONAME_EXPREF),	0,	&getBooleanCppuType(),				0},
-        {MAP_CHAR_LEN(SC_UNONAME_EXTFMT),	0,	&getBooleanCppuType(),				0},
-        {MAP_CHAR_LEN(SC_UNONAME_LINKUPD),	0,	&getCppuType((sal_Int16*)0),		0},
-        {MAP_CHAR_LEN(SC_UNONAME_MARKHDR),	0,	&getBooleanCppuType(),				0},
-        {MAP_CHAR_LEN(SC_UNONAME_METRIC),	0,	&getCppuType((sal_Int16*)0),		0},
-        {MAP_CHAR_LEN(SC_UNONAME_MOVEDIR),	0,	&getCppuType((sal_Int16*)0),		0},
-        {MAP_CHAR_LEN(SC_UNONAME_MOVESEL),	0,	&getBooleanCppuType(),				0},
-        {MAP_CHAR_LEN(SC_UNONAME_PRALLSH),	0,	&getBooleanCppuType(),				0},
-        {MAP_CHAR_LEN(SC_UNONAME_PREMPTY),	0,	&getBooleanCppuType(),				0},
-        {MAP_CHAR_LEN(SC_UNONAME_RANGEFIN),	0,	&getBooleanCppuType(),				0},
-        {MAP_CHAR_LEN(SC_UNONAME_SCALE),	0,	&getCppuType((sal_Int16*)0),		0},
-        {MAP_CHAR_LEN(SC_UNONAME_STBFUNC),	0,	&getCppuType((sal_Int16*)0),		0},
-        {MAP_CHAR_LEN(SC_UNONAME_ULISTS),	0,	&getCppuType((uno::Sequence< ::rtl::OUString>*)0),	0},
-        {MAP_CHAR_LEN(SC_UNONAME_PRMETRICS),0,	&getBooleanCppuType(),				0},
-        {MAP_CHAR_LEN(SC_UNONAME_USETABCOL),0,	&getBooleanCppuType(),				0},
-        {MAP_CHAR_LEN(SC_UNONAME_REPLWARN), 0,  &getBooleanCppuType(),              0},
-        {0,0,0,0}
+        {MAP_CHAR_LEN(SC_UNONAME_DOAUTOCP),	0,	&getBooleanCppuType(),				0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_ENTERED),	0,	&getBooleanCppuType(),				0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_EXPREF),	0,	&getBooleanCppuType(),				0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_EXTFMT),	0,	&getBooleanCppuType(),				0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_LINKUPD),	0,	&getCppuType((sal_Int16*)0),		0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_MARKHDR),	0,	&getBooleanCppuType(),				0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_METRIC),	0,	&getCppuType((sal_Int16*)0),		0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_MOVEDIR),	0,	&getCppuType((sal_Int16*)0),		0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_MOVESEL),	0,	&getBooleanCppuType(),				0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_PRALLSH),	0,	&getBooleanCppuType(),				0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_PREMPTY),	0,	&getBooleanCppuType(),				0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_RANGEFIN),	0,	&getBooleanCppuType(),				0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_SCALE),	0,	&getCppuType((sal_Int16*)0),		0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_STBFUNC),	0,	&getCppuType((sal_Int16*)0),		0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_ULISTS),	0,	&getCppuType((uno::Sequence< ::rtl::OUString>*)0),	0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_PRMETRICS),0,	&getBooleanCppuType(),				0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_USETABCOL),0,	&getBooleanCppuType(),				0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_REPLWARN), 0,  &getBooleanCppuType(),              0,0},
+        {0,0,0,0,0,0}
     };
     return aSettingsPropertyMap_Impl;
 }
 
-//------------------------------------------------------------------------
 
 #define SCFUNCTIONLISTOBJ_SERVICE		"com.sun.star.sheet.FunctionDescriptions"
 #define SCRECENTFUNCTIONSOBJ_SERVICE	"com.sun.star.sheet.RecentFunctions"
@@ -161,118 +157,17 @@ SC_SIMPLE_SERVICE_INFO( ScFunctionListObj, "ScFunctionListObj", SCFUNCTIONLISTOB
 SC_SIMPLE_SERVICE_INFO( ScRecentFunctionsObj, "ScRecentFunctionsObj", SCRECENTFUNCTIONSOBJ_SERVICE )
 SC_SIMPLE_SERVICE_INFO( ScSpreadsheetSettings, "ScSpreadsheetSettings", SCSPREADSHEETSETTINGS_SERVICE )
 
-//------------------------------------------------------------------------
-
-void lcl_WriteInfo( registry::XRegistryKey* pRegistryKey,
-                        const ::rtl::OUString& rImplementationName,
-                        const uno::Sequence< ::rtl::OUString >& rServices )
-                    throw( registry::InvalidRegistryException )
-{
-    ::rtl::OUString aImpl = ::rtl::OUString::createFromAscii( "/" );
-    aImpl += rImplementationName;
-    aImpl += ::rtl::OUString::createFromAscii( "/UNO/SERVICES" );
-    uno::Reference<registry::XRegistryKey> xNewKey = pRegistryKey->createKey(aImpl);
-
-    const ::rtl::OUString* pArray = rServices.getConstArray();
-    for( sal_Int32 i = 0; i < rServices.getLength(); i++ )
-        xNewKey->createKey( pArray[i]);
-}
 
 extern "C" {
 
 void SAL_CALL component_getImplementationEnvironment(
-    const sal_Char ** ppEnvTypeName, uno_Environment ** ppEnv )
+    const sal_Char ** ppEnvTypeName, uno_Environment ** /*ppEnv*/ )
 {
     *ppEnvTypeName = CPPU_CURRENT_LANGUAGE_BINDING_NAME;
 }
 
-sal_Bool SAL_CALL component_writeInfo(
-    void * pServiceManager, registry::XRegistryKey * pRegistryKey )
-{
-    if (pRegistryKey)
-    {
-        try
-        {
-            lcl_WriteInfo( pRegistryKey,
-                            ScSpreadsheetSettings::getImplementationName_Static(),
-                            ScSpreadsheetSettings::getSupportedServiceNames_Static() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScRecentFunctionsObj::getImplementationName_Static(),
-                            ScRecentFunctionsObj::getSupportedServiceNames_Static() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScFunctionListObj::getImplementationName_Static(),
-                            ScFunctionListObj::getSupportedServiceNames_Static() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScAutoFormatsObj::getImplementationName_Static(),
-                            ScAutoFormatsObj::getSupportedServiceNames_Static() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScFunctionAccess::getImplementationName_Static(),
-                            ScFunctionAccess::getSupportedServiceNames_Static() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScFilterOptionsObj::getImplementationName_Static(),
-                            ScFilterOptionsObj::getSupportedServiceNames_Static() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLImport_getImplementationName(),
-                            ScXMLImport_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLImport_Meta_getImplementationName(),
-                            ScXMLImport_Meta_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLImport_Styles_getImplementationName(),
-                            ScXMLImport_Styles_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLImport_Content_getImplementationName(),
-                            ScXMLImport_Content_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLImport_Settings_getImplementationName(),
-                            ScXMLImport_Settings_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLExport_getImplementationName(),
-                            ScXMLExport_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLExport_Meta_getImplementationName(),
-                            ScXMLExport_Meta_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLExport_Styles_getImplementationName(),
-                            ScXMLExport_Styles_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLExport_Content_getImplementationName(),
-                            ScXMLExport_Content_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLExport_Settings_getImplementationName(),
-                            ScXMLExport_Settings_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScDocument_getImplementationName(),
-                            ScDocument_getSupportedServiceNames() );
-
-            return sal_True;
-        }
-        catch (registry::InvalidRegistryException&)
-        {
-            OSL_ENSURE( sal_False, "### InvalidRegistryException!" );
-        }
-    }
-    return sal_False;
-}
-
 void * SAL_CALL component_getFactory(
-    const sal_Char * pImplName, void * pServiceManager, void * pRegistryKey )
+    const sal_Char * pImplName, void * pServiceManager, void * /*pRegistryKey*/ )
 {
     if (!pServiceManager)
         return NULL;
@@ -411,7 +306,6 @@ void * SAL_CALL component_getFactory(
 
 }	// extern C
 
-//------------------------------------------------------------------------
 
 ScSpreadsheetSettings::ScSpreadsheetSettings() :
     aPropSet( lcl_GetSettingsPropertyMap() )
@@ -423,7 +317,7 @@ ScSpreadsheetSettings::~ScSpreadsheetSettings()
 }
 
 uno::Reference<uno::XInterface>	SAL_CALL ScSpreadsheetSettings_CreateInstance(
-                        const uno::Reference<lang::XMultiServiceFactory>& rSMgr )
+                        const uno::Reference<lang::XMultiServiceFactory>& /*rSMgr*/ )
 {
     SolarMutexGuard aGuard;
     SC_DLL()->Load();		// load module
@@ -433,14 +327,14 @@ uno::Reference<uno::XInterface>	SAL_CALL ScSpreadsheetSettings_CreateInstance(
 
 ::rtl::OUString ScSpreadsheetSettings::getImplementationName_Static()
 {
-    return ::rtl::OUString::createFromAscii( "stardiv.StarCalc.ScSpreadsheetSettings" );
+    return ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "stardiv.StarCalc.ScSpreadsheetSettings" ));
 }
 
 uno::Sequence< ::rtl::OUString> ScSpreadsheetSettings::getSupportedServiceNames_Static()
 {
     uno::Sequence< ::rtl::OUString> aRet(1);
     ::rtl::OUString* pArray = aRet.getArray();
-    pArray[0] = ::rtl::OUString::createFromAscii( SCSPREADSHEETSETTINGS_SERVICE );
+    pArray[0] = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SCSPREADSHEETSETTINGS_SERVICE ));
     return aRet;
 }
 
@@ -640,6 +534,7 @@ uno::Any SAL_CALL ScSpreadsheetSettings::getPropertyValue( const ::rtl::OUString
             case SVX_ZOOM_OPTIMAL:	 nZoomVal = SC_ZOOMVAL_OPTIMAL;	  break;
             case SVX_ZOOM_WHOLEPAGE: nZoomVal = SC_ZOOMVAL_WHOLEPAGE; break;
             case SVX_ZOOM_PAGEWIDTH: nZoomVal = SC_ZOOMVAL_PAGEWIDTH; break;
+            default: break;
         }
         aRet <<= (sal_Int16) nZoomVal;
     }
@@ -669,7 +564,6 @@ uno::Any SAL_CALL ScSpreadsheetSettings::getPropertyValue( const ::rtl::OUString
 
 SC_IMPL_DUMMY_PROPERTY_LISTENER( ScSpreadsheetSettings )
 
-//------------------------------------------------------------------------
 
 ScRecentFunctionsObj::ScRecentFunctionsObj()
 {
@@ -682,7 +576,7 @@ ScRecentFunctionsObj::~ScRecentFunctionsObj()
 // stuff for exService_...
 
 uno::Reference<uno::XInterface>	SAL_CALL ScRecentFunctionsObj_CreateInstance(
-                        const uno::Reference<lang::XMultiServiceFactory>& rSMgr )
+                        const uno::Reference<lang::XMultiServiceFactory>& /*rSMgr*/ )
 {
     SolarMutexGuard aGuard;
     SC_DLL()->Load();		// load module
@@ -692,14 +586,14 @@ uno::Reference<uno::XInterface>	SAL_CALL ScRecentFunctionsObj_CreateInstance(
 
 ::rtl::OUString ScRecentFunctionsObj::getImplementationName_Static()
 {
-    return ::rtl::OUString::createFromAscii( "stardiv.StarCalc.ScRecentFunctionsObj" );
+    return ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "stardiv.StarCalc.ScRecentFunctionsObj" ));
 }
 
 uno::Sequence< ::rtl::OUString> ScRecentFunctionsObj::getSupportedServiceNames_Static()
 {
     uno::Sequence< ::rtl::OUString> aRet(1);
     ::rtl::OUString* pArray = aRet.getArray();
-    pArray[0] = ::rtl::OUString::createFromAscii( SCRECENTFUNCTIONSOBJ_SERVICE );
+    pArray[0] = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SCRECENTFUNCTIONSOBJ_SERVICE ));
     return aRet;
 }
 
@@ -750,7 +644,6 @@ sal_Int32 SAL_CALL ScRecentFunctionsObj::getMaxRecentFunctions() throw(uno::Runt
     return LRU_MAX;
 }
 
-//------------------------------------------------------------------------
 
 ScFunctionListObj::ScFunctionListObj()
 {
@@ -763,7 +656,7 @@ ScFunctionListObj::~ScFunctionListObj()
 // stuff for exService_...
 
 uno::Reference<uno::XInterface>	SAL_CALL ScFunctionListObj_CreateInstance(
-                        const uno::Reference<lang::XMultiServiceFactory>& rSMgr )
+                        const uno::Reference<lang::XMultiServiceFactory>& /*rSMgr*/ )
 {
     SolarMutexGuard aGuard;
     SC_DLL()->Load();		// load module
@@ -773,14 +666,14 @@ uno::Reference<uno::XInterface>	SAL_CALL ScFunctionListObj_CreateInstance(
 
 ::rtl::OUString ScFunctionListObj::getImplementationName_Static()
 {
-    return ::rtl::OUString::createFromAscii( "stardiv.StarCalc.ScFunctionListObj" );
+    return ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "stardiv.StarCalc.ScFunctionListObj" ));
 }
 
 uno::Sequence< ::rtl::OUString> ScFunctionListObj::getSupportedServiceNames_Static()
 {
     uno::Sequence< ::rtl::OUString> aRet(1);
     ::rtl::OUString* pArray = aRet.getArray();
-    pArray[0] = ::rtl::OUString::createFromAscii( SCFUNCTIONLISTOBJ_SERVICE );
+    pArray[0] = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SCFUNCTIONLISTOBJ_SERVICE ));
     return aRet;
 }
 
@@ -791,21 +684,21 @@ void lcl_FillSequence( uno::Sequence<beans::PropertyValue>& rSequence, const ScF
 
     beans::PropertyValue* pArray = rSequence.getArray();
 
-    pArray[0].Name = ::rtl::OUString::createFromAscii( SC_UNONAME_ID );
+    pArray[0].Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SC_UNONAME_ID ));
     pArray[0].Value <<= (sal_Int32) rDesc.nFIndex;
 
-    pArray[1].Name = ::rtl::OUString::createFromAscii( SC_UNONAME_CATEGORY );
+    pArray[1].Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SC_UNONAME_CATEGORY ));
     pArray[1].Value <<= (sal_Int32) rDesc.nCategory;
 
-    pArray[2].Name = ::rtl::OUString::createFromAscii( SC_UNONAME_NAME );
+    pArray[2].Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SC_UNONAME_NAME ));
     if (rDesc.pFuncName)
         pArray[2].Value <<= ::rtl::OUString( *rDesc.pFuncName );
 
-    pArray[3].Name = ::rtl::OUString::createFromAscii( SC_UNONAME_DESCRIPTION );
+    pArray[3].Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SC_UNONAME_DESCRIPTION ));
     if (rDesc.pFuncDesc)
         pArray[3].Value <<= ::rtl::OUString( *rDesc.pFuncDesc );
 
-    pArray[4].Name = ::rtl::OUString::createFromAscii( SC_UNONAME_ARGUMENTS );
+    pArray[4].Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SC_UNONAME_ARGUMENTS ));
     if (rDesc.aDefArgNames && rDesc.aDefArgDescs && rDesc.aDefArgOpt )
     {
         USHORT nCount = rDesc.nArgCount;
@@ -996,11 +889,6 @@ sal_Bool SAL_CALL ScFunctionListObj::hasByName( const ::rtl::OUString& aName )
     return FALSE;
 }
 
-//------------------------------------------------------------------------
-
-
-
-
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
