@@ -54,7 +54,6 @@
 #include "styleuno.hxx"
 #include "linkuno.hxx"
 #include "servuno.hxx"
-#include "targuno.hxx"
 #include "convuno.hxx"
 #include "optuno.hxx"
 #include "forbiuno.hxx"
@@ -73,7 +72,7 @@
 #include "viewdata.hxx"
 
 #include "ViewSettingsSequenceDefines.hxx"
-#include <legacysmgr/legacy_binfilters_smgr.hxx>	//STRIP002 
+#include <legacysmgr/legacy_binfilters_smgr.hxx>
 namespace binfilter {
 using namespace ::com::sun::star;
 
@@ -88,35 +87,35 @@ const SfxItemPropertyMap* lcl_GetDocOptPropertyMap()
 {
     static SfxItemPropertyMap aDocOptPropertyMap_Impl[] =
     {
-        {MAP_CHAR_LEN(SC_UNO_APPLYFMDES),	0,	&getBooleanCppuType(),									  0},
-        {MAP_CHAR_LEN(SC_UNO_AREALINKS),	0,	&getCppuType((uno::Reference<sheet::XAreaLinks>*)0),	  0},
-        {MAP_CHAR_LEN(SC_UNO_AUTOCONTFOC),	0,	&getBooleanCppuType(),									  0},
-        {MAP_CHAR_LEN(SC_UNO_BASICLIBRARIES),0, &getCppuType((uno::Reference< script::XLibraryContainer >*)0), beans::PropertyAttribute::READONLY},
-        {MAP_CHAR_LEN(SC_UNO_CALCASSHOWN),	0,	&getBooleanCppuType(),									  0},
-        {MAP_CHAR_LEN(SC_UNONAME_CLOCAL),	0,	&getCppuType((lang::Locale*)0),							  0},
-        {MAP_CHAR_LEN(SC_UNO_CJK_CLOCAL),	0,	&getCppuType((lang::Locale*)0),							  0},
-        {MAP_CHAR_LEN(SC_UNO_CTL_CLOCAL),	0,	&getCppuType((lang::Locale*)0),							  0},
-        {MAP_CHAR_LEN(SC_UNO_COLLABELRNG),	0,	&getCppuType((uno::Reference<sheet::XLabelRanges>*)0),	  0},
-        {MAP_CHAR_LEN(SC_UNO_DDELINKS),		0,	&getCppuType((uno::Reference<container::XNameAccess>*)0), 0},
-        {MAP_CHAR_LEN(SC_UNO_DEFTABSTOP),	0,	&getCppuType((sal_Int16*)0),							  0},
-        {MAP_CHAR_LEN(SC_UNO_FORBIDDEN),	0,	&getCppuType((uno::Reference<i18n::XForbiddenCharacters>*)0), beans::PropertyAttribute::READONLY},
-        {MAP_CHAR_LEN(SC_UNO_HASDRAWPAGES),	0,	&getBooleanCppuType(),									  beans::PropertyAttribute::READONLY},
-        {MAP_CHAR_LEN(SC_UNO_IGNORECASE),	0,	&getBooleanCppuType(),									  0},
-        {MAP_CHAR_LEN(SC_UNO_ITERENABLED),	0,	&getBooleanCppuType(),									  0},
-        {MAP_CHAR_LEN(SC_UNO_ITERCOUNT),	0,	&getCppuType((sal_Int32*)0),							  0},
-        {MAP_CHAR_LEN(SC_UNO_ITEREPSILON),	0,	&getCppuType((double*)0),								  0},
-        {MAP_CHAR_LEN(SC_UNO_LOOKUPLABELS),	0,	&getBooleanCppuType(),									  0},
-        {MAP_CHAR_LEN(SC_UNO_MATCHWHOLE),	0,	&getBooleanCppuType(),									  0},
-        {MAP_CHAR_LEN(SC_UNO_NAMEDRANGES),	0,	&getCppuType((uno::Reference<sheet::XNamedRanges>*)0),	  0},
-        {MAP_CHAR_LEN(SC_UNO_DATABASERNG),	0,	&getCppuType((uno::Reference<sheet::XDatabaseRanges>*)0), 0},
-        {MAP_CHAR_LEN(SC_UNO_NULLDATE),		0,	&getCppuType((util::Date*)0),							  0},
-        {MAP_CHAR_LEN(SC_UNO_ROWLABELRNG),	0,	&getCppuType((uno::Reference<sheet::XLabelRanges>*)0),	  0},
-        {MAP_CHAR_LEN(SC_UNO_SHEETLINKS),	0,	&getCppuType((uno::Reference<container::XNameAccess>*)0), 0},
-        {MAP_CHAR_LEN(SC_UNO_SPELLONLINE),	0,	&getBooleanCppuType(),									  0},
-        {MAP_CHAR_LEN(SC_UNO_STANDARDDEC),	0,	&getCppuType((sal_Int16*)0),							  0},
-        {MAP_CHAR_LEN(SC_UNO_REGEXENABLED), 0,  &getBooleanCppuType(),                  0},
+        {MAP_CHAR_LEN(SC_UNO_APPLYFMDES),	0,	&getBooleanCppuType(),									  0,0},
+        {MAP_CHAR_LEN(SC_UNO_AREALINKS),	0,	&getCppuType((uno::Reference<sheet::XAreaLinks>*)0),	  0,0},
+        {MAP_CHAR_LEN(SC_UNO_AUTOCONTFOC),	0,	&getBooleanCppuType(),									  0,0},
+        {MAP_CHAR_LEN(SC_UNO_BASICLIBRARIES),0, &getCppuType((uno::Reference< script::XLibraryContainer >*)0), beans::PropertyAttribute::READONLY,0},
+        {MAP_CHAR_LEN(SC_UNO_CALCASSHOWN),	0,	&getBooleanCppuType(),									  0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_CLOCAL),	0,	&getCppuType((lang::Locale*)0),							  0,0},
+        {MAP_CHAR_LEN(SC_UNO_CJK_CLOCAL),	0,	&getCppuType((lang::Locale*)0),							  0,0},
+        {MAP_CHAR_LEN(SC_UNO_CTL_CLOCAL),	0,	&getCppuType((lang::Locale*)0),							  0,0},
+        {MAP_CHAR_LEN(SC_UNO_COLLABELRNG),	0,	&getCppuType((uno::Reference<sheet::XLabelRanges>*)0),	  0,0},
+        {MAP_CHAR_LEN(SC_UNO_DDELINKS),		0,	&getCppuType((uno::Reference<container::XNameAccess>*)0), 0,0},
+        {MAP_CHAR_LEN(SC_UNO_DEFTABSTOP),	0,	&getCppuType((sal_Int16*)0),							  0,0},
+        {MAP_CHAR_LEN(SC_UNO_FORBIDDEN),	0,	&getCppuType((uno::Reference<i18n::XForbiddenCharacters>*)0), beans::PropertyAttribute::READONLY,0},
+        {MAP_CHAR_LEN(SC_UNO_HASDRAWPAGES),	0,	&getBooleanCppuType(),									  beans::PropertyAttribute::READONLY,0},
+        {MAP_CHAR_LEN(SC_UNO_IGNORECASE),	0,	&getBooleanCppuType(),									  0,0},
+        {MAP_CHAR_LEN(SC_UNO_ITERENABLED),	0,	&getBooleanCppuType(),									  0,0},
+        {MAP_CHAR_LEN(SC_UNO_ITERCOUNT),	0,	&getCppuType((sal_Int32*)0),							  0,0},
+        {MAP_CHAR_LEN(SC_UNO_ITEREPSILON),	0,	&getCppuType((double*)0),								  0,0},
+        {MAP_CHAR_LEN(SC_UNO_LOOKUPLABELS),	0,	&getBooleanCppuType(),									  0,0},
+        {MAP_CHAR_LEN(SC_UNO_MATCHWHOLE),	0,	&getBooleanCppuType(),									  0,0},
+        {MAP_CHAR_LEN(SC_UNO_NAMEDRANGES),	0,	&getCppuType((uno::Reference<sheet::XNamedRanges>*)0),	  0,0},
+        {MAP_CHAR_LEN(SC_UNO_DATABASERNG),	0,	&getCppuType((uno::Reference<sheet::XDatabaseRanges>*)0), 0,0},
+        {MAP_CHAR_LEN(SC_UNO_NULLDATE),		0,	&getCppuType((util::Date*)0),							  0,0},
+        {MAP_CHAR_LEN(SC_UNO_ROWLABELRNG),	0,	&getCppuType((uno::Reference<sheet::XLabelRanges>*)0),	  0,0},
+        {MAP_CHAR_LEN(SC_UNO_SHEETLINKS),	0,	&getCppuType((uno::Reference<container::XNameAccess>*)0), 0,0},
+        {MAP_CHAR_LEN(SC_UNO_SPELLONLINE),	0,	&getBooleanCppuType(),									  0,0},
+        {MAP_CHAR_LEN(SC_UNO_STANDARDDEC),	0,	&getCppuType((sal_Int16*)0),							  0,0},
+        {MAP_CHAR_LEN(SC_UNO_REGEXENABLED), 0,  &getBooleanCppuType(),                  0,0},
 
-        {0,0,0,0}
+        {0,0,0,0,0,0}
     };
     return aDocOptPropertyMap_Impl;
 }
@@ -132,7 +131,7 @@ const SfxItemPropertyMap* lcl_GetColumnsPropertyMap()
         {MAP_CHAR_LEN(SC_UNONAME_CELLVIS),	0,	&getBooleanCppuType(),			0, 0 },
         {MAP_CHAR_LEN(SC_UNONAME_OWIDTH),	0,	&getBooleanCppuType(),			0, 0 },
         {MAP_CHAR_LEN(SC_UNONAME_CELLWID),	0,	&getCppuType((sal_Int32*)0),	0, 0 },
-        {0,0,0,0}
+        {0,0,0,0,0,0}
     };
     return aColumnsPropertyMap_Impl;
 }
@@ -147,7 +146,7 @@ const SfxItemPropertyMap* lcl_GetRowsPropertyMap()
         {MAP_CHAR_LEN(SC_UNONAME_MANPAGE),	0,	&getBooleanCppuType(),			0, 0 },
         {MAP_CHAR_LEN(SC_UNONAME_NEWPAGE),	0,	&getBooleanCppuType(),			0, 0 },
         {MAP_CHAR_LEN(SC_UNONAME_CELLVIS),	0,	&getBooleanCppuType(),			0, 0 },
-        {0,0,0,0}
+        {0,0,0,0,0,0}
     };
     return aRowsPropertyMap_Impl;
 }
@@ -452,28 +451,28 @@ uno::Reference<container::XNameAccess> SAL_CALL ScModelObj::getStyleFamilies()
 
 // XRenderable
 
-sal_Int32 SAL_CALL ScModelObj::getRendererCount( const uno::Any& aSelection,
-                                    const uno::Sequence<beans::PropertyValue>& xOptions )
+sal_Int32 SAL_CALL ScModelObj::getRendererCount( const uno::Any& /*aSelection*/,
+                                    const uno::Sequence<beans::PropertyValue>& /*xOptions*/ )
                                 throw (lang::IllegalArgumentException, uno::RuntimeException)
 {
-    DBG_ERROR("Strip!");
+    OSL_FAIL("Strip!");
     return 0;
 }
 
-uno::Sequence<beans::PropertyValue> SAL_CALL ScModelObj::getRenderer( sal_Int32 nRenderer,
-                                    const uno::Any& aSelection, const uno::Sequence<beans::PropertyValue>& xOptions )
+uno::Sequence<beans::PropertyValue> SAL_CALL ScModelObj::getRenderer( sal_Int32 /*nRenderer*/,
+                                    const uno::Any& /*aSelection*/, const uno::Sequence<beans::PropertyValue>& /*xOptions*/ )
                                 throw (lang::IllegalArgumentException, uno::RuntimeException)
 {
-    DBG_ERROR("Strip!");
+    OSL_FAIL("Strip!");
     uno::Sequence<beans::PropertyValue> aSequence;
     return aSequence;
 }
 
-void SAL_CALL ScModelObj::render( sal_Int32 nRenderer, const uno::Any& aSelection,
-                                    const uno::Sequence<beans::PropertyValue>& rOptions )
+void SAL_CALL ScModelObj::render( sal_Int32 /*nRenderer*/, const uno::Any& /*aSelection*/,
+                                    const uno::Sequence<beans::PropertyValue>& /*rOptions*/ )
                                 throw(lang::IllegalArgumentException, uno::RuntimeException)
 {
-    DBG_ERROR("Strip!");
+    OSL_FAIL("Strip!");
 }
 
 // XLinkTargetSupplier
@@ -554,7 +553,7 @@ void SAL_CALL ScModelObj::calculate() throw(uno::RuntimeException)
     if (pDocShell)
         pDocShell->DoRecalc(TRUE);
     else
-        DBG_ERROR("keine DocShell");		//! Exception oder so?
+        OSL_FAIL("keine DocShell");		//! Exception oder so?
 }
 
 void SAL_CALL ScModelObj::calculateAll() throw(uno::RuntimeException)
@@ -563,7 +562,7 @@ void SAL_CALL ScModelObj::calculateAll() throw(uno::RuntimeException)
     if (pDocShell)
         pDocShell->DoHardRecalc(TRUE);
     else
-        DBG_ERROR("keine DocShell");		//! Exception oder so?
+        OSL_FAIL("keine DocShell");		//! Exception oder so?
 }
 
 sal_Bool SAL_CALL ScModelObj::isAutomaticCalculationEnabled() throw(uno::RuntimeException)
@@ -572,7 +571,7 @@ sal_Bool SAL_CALL ScModelObj::isAutomaticCalculationEnabled() throw(uno::Runtime
     if (pDocShell)
         return pDocShell->GetDocument()->GetAutoCalc();
 
-    DBG_ERROR("keine DocShell");		//! Exception oder so?
+    OSL_FAIL("keine DocShell");		//! Exception oder so?
     return FALSE;
 }
 
@@ -590,7 +589,7 @@ void SAL_CALL ScModelObj::enableAutomaticCalculation( sal_Bool bEnabled )
         }
     }
     else
-        DBG_ERROR("keine DocShell");		//! Exception oder so?
+        OSL_FAIL("keine DocShell");		//! Exception oder so?
 }
 
 // XProtectable
@@ -628,7 +627,7 @@ sal_Bool SAL_CALL ScModelObj::isProtected() throw(uno::RuntimeException)
     if (pDocShell)
         return pDocShell->GetDocument()->IsDocProtected();
 
-    DBG_ERROR("keine DocShell");		//! Exception oder so?
+    OSL_FAIL("keine DocShell");		//! Exception oder so?
     return FALSE;
 }
 
@@ -640,7 +639,7 @@ uno::Reference<drawing::XDrawPages> SAL_CALL ScModelObj::getDrawPages() throw(un
     if (pDocShell)
         return new ScDrawPagesObj(pDocShell);
 
-    DBG_ERROR("keine DocShell");		//! Exception oder so?
+    OSL_FAIL("keine DocShell");		//! Exception oder so?
     return NULL;
 }
 
@@ -1046,7 +1045,7 @@ uno::Reference<uno::XInterface> SAL_CALL ScModelObj::createInstance(
 
 uno::Reference<uno::XInterface> SAL_CALL ScModelObj::createInstanceWithArguments(
                                 const ::rtl::OUString& ServiceSpecifier,
-                                const uno::Sequence<uno::Any>& Arguments )
+                                const uno::Sequence<uno::Any>& /*Arguments*/ )
                                 throw(uno::Exception, uno::RuntimeException)
 {
     //!	unterscheiden zwischen eigenen Services und denen vom Drawing-Layer?
@@ -1077,7 +1076,7 @@ uno::Sequence< ::rtl::OUString> SAL_CALL ScModelObj::getAvailableServiceNames()
 
 ::rtl::OUString SAL_CALL ScModelObj::getImplementationName() throw(uno::RuntimeException)
 {
-    return ::rtl::OUString::createFromAscii( "ScModelObj" );
+    return ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ScModelObj" ));
 }
 
 sal_Bool SAL_CALL ScModelObj::supportsService( const ::rtl::OUString& rServiceName )
@@ -1094,9 +1093,9 @@ uno::Sequence< ::rtl::OUString> SAL_CALL ScModelObj::getSupportedServiceNames()
 {
     uno::Sequence< ::rtl::OUString> aRet(3);
     ::rtl::OUString* pArray = aRet.getArray();
-    pArray[0] = ::rtl::OUString::createFromAscii( SCMODELOBJ_SERVICE );
-    pArray[1] = ::rtl::OUString::createFromAscii( SCDOCSETTINGS_SERVICE );
-    pArray[2] = ::rtl::OUString::createFromAscii( SCDOC_SERVICE );
+    pArray[0] = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SCMODELOBJ_SERVICE ));
+    pArray[1] = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SCDOCSETTINGS_SERVICE ));
+    pArray[2] = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SCDOC_SERVICE ));
     return aRet;
 }
 
@@ -1157,7 +1156,6 @@ ScModelObj* ScModelObj::getImplementation( const uno::Reference<uno::XInterface>
     return pRet;
 }
 
-//------------------------------------------------------------------------
 
 ScDrawPagesObj::ScDrawPagesObj(ScDocShell* pDocSh) :
     pDocShell( pDocSh )
@@ -1171,7 +1169,7 @@ ScDrawPagesObj::~ScDrawPagesObj()
         pDocShell->GetDocument()->RemoveUnoObject(*this);
 }
 
-void ScDrawPagesObj::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
+void ScDrawPagesObj::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
 {
     //	Referenz-Update interessiert hier nicht
 
@@ -1229,9 +1227,7 @@ void SAL_CALL ScDrawPagesObj::remove( const uno::Reference<drawing::XDrawPage>&
         SdrPage* pPage = pImp->GetSdrPage();
         if (pPage)
         {
-            USHORT nPageNum = pPage->GetPageNum();
-            ScDocFunc aFunc(*pDocShell);
-            aFunc.DeleteTable( nPageNum, TRUE, TRUE );
+            pPage->GetPageNum();
         }
     }
 }
@@ -1272,8 +1268,6 @@ sal_Bool SAL_CALL ScDrawPagesObj::hasElements() throw(uno::RuntimeException)
     return ( getCount() != 0 );
 }
 
-//------------------------------------------------------------------------
-
 ScTableSheetsObj::ScTableSheetsObj(ScDocShell* pDocSh) :
     pDocShell( pDocSh )
 {
@@ -1286,7 +1280,7 @@ ScTableSheetsObj::~ScTableSheetsObj()
         pDocShell->GetDocument()->RemoveUnoObject(*this);
 }
 
-void ScTableSheetsObj::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
+void ScTableSheetsObj::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
 {
     //	Referenz-Update interessiert hier nicht
 
@@ -1447,18 +1441,7 @@ void SAL_CALL ScTableSheetsObj::replaceByName( const ::rtl::OUString& aName, con
             {
                 String aNamStr = aName;
                 USHORT nPosition;
-                if ( pDocShell->GetDocument()->GetTable( aNamStr, nPosition ) )
-                {
-                    ScDocFunc aFunc(*pDocShell);
-                    if ( aFunc.DeleteTable( nPosition, TRUE, TRUE ) )
-                    {
-                        //	InsertTable kann jetzt eigentlich nicht schiefgehen...
-                        bDone = aFunc.InsertTable( nPosition, aNamStr, TRUE, TRUE );
-                        if (bDone)
-                            pSheetObj->InitInsertSheet( pDocShell, nPosition );
-                    }
-                }
-                else
+                if ( !pDocShell->GetDocument()->GetTable( aNamStr, nPosition ) )
                 {
                     //	not found
                     throw container::NoSuchElementException();
@@ -1490,12 +1473,7 @@ void SAL_CALL ScTableSheetsObj::removeByName( const ::rtl::OUString& aName )
     {
         USHORT nIndex;
         String aString = aName;
-        if ( pDocShell->GetDocument()->GetTable( aString, nIndex ) )
-        {
-            ScDocFunc aFunc(*pDocShell);
-            bDone = aFunc.DeleteTable( nIndex, TRUE, TRUE );
-        }
-        else
+        if ( !pDocShell->GetDocument()->GetTable( aString, nIndex ) )
         {
             //	not found
             throw container::NoSuchElementException();
@@ -1602,7 +1580,6 @@ sal_Bool SAL_CALL ScTableSheetsObj::hasByName( const ::rtl::OUString& aName )
     return FALSE;
 }
 
-//------------------------------------------------------------------------
 
 ScTableColumnsObj::ScTableColumnsObj(ScDocShell* pDocSh, USHORT nT, USHORT nSC, USHORT nEC) :
     pDocShell( pDocSh ),
@@ -1619,11 +1596,10 @@ ScTableColumnsObj::~ScTableColumnsObj()
         pDocShell->GetDocument()->RemoveUnoObject(*this);
 }
 
-void ScTableColumnsObj::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
+void ScTableColumnsObj::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
 {
     if ( rHint.ISA( ScUpdateRefHint ) )
     {
-        const ScUpdateRefHint& rRef = (const ScUpdateRefHint&)rHint;
 
         //!	Referenz-Update fuer Tab und Start/Ende
     }
@@ -1663,12 +1639,7 @@ void SAL_CALL ScTableColumnsObj::insertByIndex( sal_Int32 nPosition, sal_Int32 n
     BOOL bDone = FALSE;
     if ( pDocShell && nCount > 0 && nPosition >= 0 && nStartCol+nPosition <= nEndCol &&
             nStartCol+nPosition+nCount-1 <= MAXCOL )
-    {
-        ScDocFunc aFunc(*pDocShell);
-        ScRange aRange( (USHORT)(nStartCol+nPosition), 0, nTab,
-                        (USHORT)(nStartCol+nPosition+nCount-1), MAXROW, nTab );
-        bDone = aFunc.InsertCells( aRange, INS_INSCOLS, TRUE, TRUE );
-    }
+        bDone = false;
     if (!bDone)
         throw uno::RuntimeException();		// no other exceptions specified
 }
@@ -1680,12 +1651,7 @@ void SAL_CALL ScTableColumnsObj::removeByIndex( sal_Int32 nIndex, sal_Int32 nCou
     BOOL bDone = FALSE;
     //	Der zu loeschende Bereich muss innerhalb des Objekts liegen
     if ( pDocShell && nCount > 0 && nIndex >= 0 && nStartCol+nIndex+nCount-1 <= nEndCol )
-    {
-        ScDocFunc aFunc(*pDocShell);
-        ScRange aRange( (USHORT)(nStartCol+nIndex), 0, nTab,
-                        (USHORT)(nStartCol+nIndex+nCount-1), MAXROW, nTab );
-        bDone = aFunc.DeleteCells( aRange, DEL_DELCOLS, TRUE, TRUE );
-    }
+        bDone = true;
     if (!bDone)
         throw uno::RuntimeException();		// no other exceptions specified
 }
@@ -1795,7 +1761,7 @@ void SAL_CALL ScTableColumnsObj::setPropertyValue(
         throw uno::RuntimeException();
 
     ScDocFunc aFunc(*pDocShell);
-    ScDocument* pDoc = pDocShell->GetDocument();
+    pDocShell->GetDocument();
     USHORT nColArr[2];
     nColArr[0] = nStartCol;
     nColArr[1] = nEndCol;
@@ -1803,7 +1769,7 @@ void SAL_CALL ScTableColumnsObj::setPropertyValue(
 
     if ( aNameString.EqualsAscii( SC_UNONAME_CELLWID ) )
     {
-        sal_Int32 nNewWidth;
+        sal_Int32 nNewWidth = 0;
         if ( aValue >>= nNewWidth )
             aFunc.SetWidthOrHeight( TRUE, 1, nColArr, nTab, SC_SIZE_ORIGINAL,
                                     (USHORT)HMMToTwips(nNewWidth), TRUE, TRUE );
@@ -1828,10 +1794,8 @@ void SAL_CALL ScTableColumnsObj::setPropertyValue(
         //!	single function to set/remove all breaks?
         BOOL bSet = ScUnoHelpFunctions::GetBoolFromAny( aValue );
         for (USHORT nCol=nStartCol; nCol<=nEndCol; nCol++)
-            if (bSet)
-                aFunc.InsertPageBreak( TRUE, ScAddress(nCol,0,nTab), TRUE, TRUE, TRUE );
-            else
-                aFunc.RemovePageBreak( TRUE, ScAddress(nCol,0,nTab), TRUE, TRUE, TRUE );
+            if (!bSet)
+                aFunc.RemovePageBreak( TRUE, ScAddress(nCol,0,nTab), TRUE, TRUE );
     }
 }
 
@@ -1898,11 +1862,10 @@ ScTableRowsObj::~ScTableRowsObj()
         pDocShell->GetDocument()->RemoveUnoObject(*this);
 }
 
-void ScTableRowsObj::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
+void ScTableRowsObj::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
 {
     if ( rHint.ISA( ScUpdateRefHint ) )
     {
-        const ScUpdateRefHint& rRef = (const ScUpdateRefHint&)rHint;
 
         //!	Referenz-Update fuer Tab und Start/Ende
     }
@@ -1931,12 +1894,7 @@ void SAL_CALL ScTableRowsObj::insertByIndex( sal_Int32 nPosition, sal_Int32 nCou
     BOOL bDone = FALSE;
     if ( pDocShell && nCount > 0 && nPosition >= 0 && nStartRow+nPosition <= nEndRow &&
             nStartRow+nPosition+nCount-1 <= MAXROW )
-    {
-        ScDocFunc aFunc(*pDocShell);
-        ScRange aRange( 0, (USHORT)(nStartRow+nPosition), nTab,
-                        MAXCOL, (USHORT)(nStartRow+nPosition+nCount-1), nTab );
-        bDone = aFunc.InsertCells( aRange, INS_INSROWS, TRUE, TRUE );
-    }
+        bDone = false;
     if (!bDone)
         throw uno::RuntimeException();		// no other exceptions specified
 }
@@ -1948,12 +1906,7 @@ void SAL_CALL ScTableRowsObj::removeByIndex( sal_Int32 nIndex, sal_Int32 nCount
     BOOL bDone = FALSE;
     //	Der zu loeschende Bereich muss innerhalb des Objekts liegen
     if ( pDocShell && nCount > 0 && nIndex >= 0 && nStartRow+nIndex+nCount-1 <= nEndRow )
-    {
-        ScDocFunc aFunc(*pDocShell);
-        ScRange aRange( 0, (USHORT)(nStartRow+nIndex), nTab,
-                        MAXCOL, (USHORT)(nStartRow+nIndex+nCount-1), nTab );
-        bDone = aFunc.DeleteCells( aRange, DEL_DELROWS, TRUE, TRUE );
-    }
+        bDone = true;
     if (!bDone)
         throw uno::RuntimeException();		// no other exceptions specified
 }
@@ -2031,7 +1984,7 @@ void SAL_CALL ScTableRowsObj::setPropertyValue(
 
     if ( aNameString.EqualsAscii( SC_UNONAME_CELLHGT ) )
     {
-        sal_Int32 nNewHeight;
+        sal_Int32 nNewHeight = 0;
         if ( aValue >>= nNewHeight )
             aFunc.SetWidthOrHeight( FALSE, 1, nRowArr, nTab, SC_SIZE_ORIGINAL,
                                     (USHORT)HMMToTwips(nNewHeight), TRUE, TRUE );
@@ -2072,10 +2025,8 @@ void SAL_CALL ScTableRowsObj::setPropertyValue(
         //!	single function to set/remove all breaks?
         BOOL bSet = ScUnoHelpFunctions::GetBoolFromAny( aValue );
         for (USHORT nRow=nStartRow; nRow<=nEndRow; nRow++)
-            if (bSet)
-                aFunc.InsertPageBreak( FALSE, ScAddress(0,nRow,nTab), TRUE, TRUE, TRUE );
-            else
-                aFunc.RemovePageBreak( FALSE, ScAddress(0,nRow,nTab), TRUE, TRUE, TRUE );
+            if (!bSet)
+                aFunc.RemovePageBreak( FALSE, ScAddress(0,nRow,nTab), TRUE, TRUE );
     }
 }
 
@@ -2130,15 +2081,13 @@ uno::Any SAL_CALL ScTableRowsObj::getPropertyValue( const ::rtl::OUString& aProp
 
 SC_IMPL_DUMMY_PROPERTY_LISTENER( ScTableRowsObj )
 
-//------------------------------------------------------------------------
-
 ScSpreadsheetSettingsObj::~ScSpreadsheetSettingsObj()
 {
     if (pDocShell)
         pDocShell->GetDocument()->RemoveUnoObject(*this);
 }
 
-void ScSpreadsheetSettingsObj::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
+void ScSpreadsheetSettingsObj::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
 {
     //	Referenz-Update interessiert hier nicht
 
@@ -2159,7 +2108,7 @@ uno::Reference<beans::XPropertySetInfo> SAL_CALL ScSpreadsheetSettingsObj::getPr
 }
 
 void SAL_CALL ScSpreadsheetSettingsObj::setPropertyValue(
-                        const ::rtl::OUString& aPropertyName, const uno::Any& aValue )
+                        const ::rtl::OUString& /*aPropertyName*/, const uno::Any& /*aValue*/ )
                 throw(beans::UnknownPropertyException, beans::PropertyVetoException,
                         lang::IllegalArgumentException, lang::WrappedTargetException,
                         uno::RuntimeException)
@@ -2167,7 +2116,7 @@ void SAL_CALL ScSpreadsheetSettingsObj::setPropertyValue(
     //!	muss noch
 }
 
-uno::Any SAL_CALL ScSpreadsheetSettingsObj::getPropertyValue( const ::rtl::OUString& aPropertyName )
+uno::Any SAL_CALL ScSpreadsheetSettingsObj::getPropertyValue( const ::rtl::OUString& /*aPropertyName*/ )
                 throw(beans::UnknownPropertyException, lang::WrappedTargetException,
                         uno::RuntimeException)
 {
@@ -2192,7 +2141,7 @@ ScAnnotationsObj::~ScAnnotationsObj()
         pDocShell->GetDocument()->RemoveUnoObject(*this);
 }
 
-void ScAnnotationsObj::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
+void ScAnnotationsObj::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
 {
     //!	nTab bei Referenz-Update anpassen!!!
 
@@ -2334,8 +2283,6 @@ sal_Bool SAL_CALL ScAnnotationsObj::hasElements() throw(uno::RuntimeException)
     return ( getCount() != 0 );
 }
 
-//------------------------------------------------------------------------
-
 ScScenariosObj::ScScenariosObj(ScDocShell* pDocSh, USHORT nT) :
     pDocShell( pDocSh ),
     nTab	 ( nT )
@@ -2349,12 +2296,10 @@ ScScenariosObj::~ScScenariosObj()
         pDocShell->GetDocument()->RemoveUnoObject(*this);
 }
 
-void ScScenariosObj::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
+void ScScenariosObj::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
 {
     if ( rHint.ISA( ScUpdateRefHint ) )
     {
-        const ScUpdateRefHint& rRef = (const ScUpdateRefHint&)rHint;
-
         //!	Referenz-Update fuer Tab und Start/Ende
     }
     else if ( rHint.ISA( SfxSimpleHint ) &&
@@ -2447,11 +2392,8 @@ void SAL_CALL ScScenariosObj::removeByName( const ::rtl::OUString& aName )
 {
     SolarMutexGuard aGuard;
     USHORT nIndex;
-    if ( pDocShell && GetScenarioIndex_Impl( aName, nIndex ) )
-    {
-        ScDocFunc aFunc(*pDocShell);
-        aFunc.DeleteTable( nTab+nIndex+1, TRUE, TRUE );
-    }
+    if ( pDocShell )
+        GetScenarioIndex_Impl( aName, nIndex );
 }
 
 // XEnumerationAccess
