@@ -65,7 +65,6 @@ namespace binfilter {
 
 using namespace ::com::sun::star;
 
-//------------------------------------------------------------------------
 
 //	alles ohne Which-ID, Map nur fuer PropertySetInfo
 
@@ -73,13 +72,13 @@ const SfxItemPropertyMap* lcl_GetURLPropertyMap()
 {
     static SfxItemPropertyMap aURLPropertyMap_Impl[] =
     {
-        {MAP_CHAR_LEN(SC_UNONAME_ANCTYPE),	0,	&getCppuType((text::TextContentAnchorType*)0), beans::PropertyAttribute::READONLY },
-        {MAP_CHAR_LEN(SC_UNONAME_ANCTYPES),	0,	&getCppuType((uno::Sequence<text::TextContentAnchorType>*)0), beans::PropertyAttribute::READONLY },
-        {MAP_CHAR_LEN(SC_UNONAME_REPR),		0,	&getCppuType((::rtl::OUString*)0),	0},
-        {MAP_CHAR_LEN(SC_UNONAME_TARGET),	0,	&getCppuType((::rtl::OUString*)0),	0},
-        {MAP_CHAR_LEN(SC_UNONAME_TEXTWRAP),	0,	&getCppuType((text::WrapTextMode*)0), beans::PropertyAttribute::READONLY },
-        {MAP_CHAR_LEN(SC_UNONAME_URL),		0,	&getCppuType((::rtl::OUString*)0),	0},
-        {0,0,0,0}
+        {MAP_CHAR_LEN(SC_UNONAME_ANCTYPE),	0,	&getCppuType((text::TextContentAnchorType*)0), beans::PropertyAttribute::READONLY,0 },
+        {MAP_CHAR_LEN(SC_UNONAME_ANCTYPES),	0,	&getCppuType((uno::Sequence<text::TextContentAnchorType>*)0), beans::PropertyAttribute::READONLY,0 },
+        {MAP_CHAR_LEN(SC_UNONAME_REPR),		0,	&getCppuType((::rtl::OUString*)0),	0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_TARGET),	0,	&getCppuType((::rtl::OUString*)0),	0,0},
+        {MAP_CHAR_LEN(SC_UNONAME_TEXTWRAP),	0,	&getCppuType((text::WrapTextMode*)0), beans::PropertyAttribute::READONLY,0 },
+        {MAP_CHAR_LEN(SC_UNONAME_URL),		0,	&getCppuType((::rtl::OUString*)0),	0,0},
+        {0,0,0,0,0,0}
     };
     return aURLPropertyMap_Impl;
 }
@@ -88,10 +87,10 @@ const SfxItemPropertyMap* lcl_GetHeaderFieldPropertyMap()
 {
     static SfxItemPropertyMap aHeaderFieldPropertyMap_Impl[] =
     {
-        {MAP_CHAR_LEN(SC_UNONAME_ANCTYPE),	0,	&getCppuType((text::TextContentAnchorType*)0), beans::PropertyAttribute::READONLY },
-        {MAP_CHAR_LEN(SC_UNONAME_ANCTYPES),	0,	&getCppuType((uno::Sequence<text::TextContentAnchorType>*)0), beans::PropertyAttribute::READONLY },
-        {MAP_CHAR_LEN(SC_UNONAME_TEXTWRAP),	0,	&getCppuType((text::WrapTextMode*)0), beans::PropertyAttribute::READONLY },
-        {0,0,0,0}
+        {MAP_CHAR_LEN(SC_UNONAME_ANCTYPE),	0,	&getCppuType((text::TextContentAnchorType*)0), beans::PropertyAttribute::READONLY,0 },
+        {MAP_CHAR_LEN(SC_UNONAME_ANCTYPES),	0,	&getCppuType((uno::Sequence<text::TextContentAnchorType>*)0), beans::PropertyAttribute::READONLY,0 },
+        {MAP_CHAR_LEN(SC_UNONAME_TEXTWRAP),	0,	&getCppuType((text::WrapTextMode*)0), beans::PropertyAttribute::READONLY,0 },
+        {0,0,0,0,0,0}
     };
     return aHeaderFieldPropertyMap_Impl;
 }
@@ -100,16 +99,15 @@ const SfxItemPropertyMap* lcl_GetFileFieldPropertyMap()
 {
     static SfxItemPropertyMap aFileFieldPropertyMap_Impl[] =
     {
-        {MAP_CHAR_LEN(SC_UNONAME_ANCTYPE),	0,	&getCppuType((text::TextContentAnchorType*)0), beans::PropertyAttribute::READONLY },
-        {MAP_CHAR_LEN(SC_UNONAME_ANCTYPES),	0,	&getCppuType((uno::Sequence<text::TextContentAnchorType>*)0), beans::PropertyAttribute::READONLY },
-        {MAP_CHAR_LEN(SC_UNONAME_FILEFORM),	0,	&getCppuType((sal_Int16*)0),		0 },
-        {MAP_CHAR_LEN(SC_UNONAME_TEXTWRAP),	0,	&getCppuType((text::WrapTextMode*)0), beans::PropertyAttribute::READONLY },
-        {0,0,0,0}
+        {MAP_CHAR_LEN(SC_UNONAME_ANCTYPE),	0,	&getCppuType((text::TextContentAnchorType*)0), beans::PropertyAttribute::READONLY,0 },
+        {MAP_CHAR_LEN(SC_UNONAME_ANCTYPES),	0,	&getCppuType((uno::Sequence<text::TextContentAnchorType>*)0), beans::PropertyAttribute::READONLY,0 },
+        {MAP_CHAR_LEN(SC_UNONAME_FILEFORM),	0,	&getCppuType((sal_Int16*)0),		0,0 },
+        {MAP_CHAR_LEN(SC_UNONAME_TEXTWRAP),	0,	&getCppuType((text::WrapTextMode*)0), beans::PropertyAttribute::READONLY,0 },
+        {0,0,0,0,0,0}
     };
     return aFileFieldPropertyMap_Impl;
 }
 
-//------------------------------------------------------------------------
 
 #define SCTEXTFIELD_SERVICE			"com.sun.star.text.TextField"
 #define SCTEXTCONTENT_SERVICE		"com.sun.star.text.TextContent"
@@ -117,7 +115,6 @@ const SfxItemPropertyMap* lcl_GetFileFieldPropertyMap()
 SC_SIMPLE_SERVICE_INFO( ScCellFieldsObj, "ScCellFieldsObj", "com.sun.star.text.TextFields" )
 SC_SIMPLE_SERVICE_INFO( ScHeaderFieldsObj, "ScHeaderFieldsObj", "com.sun.star.text.TextFields" )
 
-//------------------------------------------------------------------------
 
 //	ScUnoEditEngine nur um aus einer EditEngine die Felder herauszubekommen...
 
@@ -244,7 +241,6 @@ SvxFieldData* ScUnoEditEngine::FindByPos(USHORT nPar, xub_StrLen nPos, TypeId aT
     return pFound;
 }
 
-//------------------------------------------------------------------------
 
 ScCellFieldsObj::ScCellFieldsObj(ScDocShell* pDocSh, const ScAddress& rPos) :
     pDocShell( pDocSh ),
@@ -278,12 +274,10 @@ ScCellFieldsObj::~ScCellFieldsObj()
     }
 }
 
-void ScCellFieldsObj::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
+void ScCellFieldsObj::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
 {
     if ( rHint.ISA( ScUpdateRefHint ) )
     {
-        const ScUpdateRefHint& rRef = (const ScUpdateRefHint&)rHint;
-
         //!	Ref-Update
     }
     else if ( rHint.ISA( SfxSimpleHint ) &&
@@ -358,17 +352,17 @@ uno::Reference<container::XEnumeration> SAL_CALL ScCellFieldsObj::createEnumerat
 }
 
 void SAL_CALL ScCellFieldsObj::addContainerListener(
-                                const uno::Reference<container::XContainerListener>& xListener )
+                                const uno::Reference<container::XContainerListener>& /*xListener*/ )
                                     throw(uno::RuntimeException)
 {
-    DBG_ERROR("not implemented");
+    OSL_FAIL("not implemented");
 }
 
 void SAL_CALL ScCellFieldsObj::removeContainerListener(
-                                const uno::Reference<container::XContainerListener>& xListener )
+                                const uno::Reference<container::XContainerListener>& /*xListener*/ )
                                     throw(uno::RuntimeException)
 {
-    DBG_ERROR("not implemented");
+    OSL_FAIL("not implemented");
 }
 
 // XRefreshable
@@ -401,7 +395,7 @@ void SAL_CALL ScCellFieldsObj::refresh(  )
                     }
                     catch(uno::RuntimeException&)
                     {
-//						DBG_ERROR("a object is gone without to remove from Broadcaster");
+//						OSL_FAIL("a object is gone without to remove from Broadcaster");
                         ++pInterfaces;
                         ++i;
                     }
@@ -434,7 +428,6 @@ void SAL_CALL ScCellFieldsObj::removeRefreshListener( const uno::Reference<util:
     }
 }
 
-//------------------------------------------------------------------------
 
 ScCellFieldObj::ScCellFieldObj(ScDocShell* pDocSh, const ScAddress& rPos,
                                             const ESelection& rSel) :
@@ -539,14 +532,12 @@ ScCellFieldObj::~ScCellFieldObj()
     delete pEditSource;
 }
 
-void ScCellFieldObj::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
+void ScCellFieldObj::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
 {
     //!	Updates fuer aSelection (muessen erst noch erzeugt werden) !!!!!!
 
     if ( rHint.ISA( ScUpdateRefHint ) )
     {
-        const ScUpdateRefHint& rRef = (const ScUpdateRefHint&)rHint;
-
         //!	Ref-Update
     }
     else if ( rHint.ISA( SfxSimpleHint ) &&
@@ -577,7 +568,6 @@ void ScCellFieldObj::DeleteField()
     if (pEditSource)
     {
         SvxTextForwarder* pForwarder = pEditSource->GetTextForwarder();
-//		pEditEngine->QuickDelete( aSelection );
         pForwarder->QuickInsertText( String(), aSelection );
         pEditSource->UpdateData();
 
@@ -844,7 +834,7 @@ ScCellFieldObj* ScCellFieldObj::getImplementation(
 
 ::rtl::OUString SAL_CALL ScCellFieldObj::getImplementationName() throw(uno::RuntimeException)
 {
-    return ::rtl::OUString::createFromAscii( "ScCellFieldObj" );
+    return ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ScCellFieldObj" ));
 }
 
 sal_Bool SAL_CALL ScCellFieldObj::supportsService( const ::rtl::OUString& rServiceName )
@@ -860,12 +850,11 @@ uno::Sequence< ::rtl::OUString> SAL_CALL ScCellFieldObj::getSupportedServiceName
 {
     uno::Sequence< ::rtl::OUString> aRet(2);
     ::rtl::OUString* pArray = aRet.getArray();
-    pArray[0] = ::rtl::OUString::createFromAscii( SCTEXTFIELD_SERVICE );
-    pArray[1] = ::rtl::OUString::createFromAscii( SCTEXTCONTENT_SERVICE );
+    pArray[0] = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SCTEXTFIELD_SERVICE ));
+    pArray[1] = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SCTEXTCONTENT_SERVICE ));
     return aRet;
 }
 
-//------------------------------------------------------------------------
 
 ScHeaderFieldsObj::ScHeaderFieldsObj(ScHeaderFooterContentObj* pContent, USHORT nP, USHORT nT) :
     pContentObj( pContent ),
@@ -1006,17 +995,17 @@ uno::Reference<container::XEnumeration> SAL_CALL ScHeaderFieldsObj::createEnumer
 }
 
 void SAL_CALL ScHeaderFieldsObj::addContainerListener(
-                                const uno::Reference<container::XContainerListener>& xListener )
+                                const uno::Reference<container::XContainerListener>& /*xListener*/ )
                                     throw(uno::RuntimeException)
 {
-    DBG_ERROR("not implemented");
+    OSL_FAIL("not implemented");
 }
 
 void SAL_CALL ScHeaderFieldsObj::removeContainerListener(
-                                const uno::Reference<container::XContainerListener>& xListener )
+                                const uno::Reference<container::XContainerListener>& /*xListener*/ )
                                     throw(uno::RuntimeException)
 {
-    DBG_ERROR("not implemented");
+    OSL_FAIL("not implemented");
 }
 
 // XRefreshable
@@ -1049,7 +1038,6 @@ void SAL_CALL ScHeaderFieldsObj::refresh(  )
                     }
                     catch(uno::RuntimeException&)
                     {
-//						DBG_ERROR("a object is gone without to remove from Broadcaster");
                         ++pInterfaces;
                         ++i;
                     }
@@ -1082,7 +1070,6 @@ void SAL_CALL ScHeaderFieldsObj::removeRefreshListener( const uno::Reference<uti
     }
 }
 
-//------------------------------------------------------------------------
 
 SvxFileFormat lcl_UnoToSvxFileFormat( sal_Int16 nUnoValue )
 {
@@ -1091,7 +1078,6 @@ SvxFileFormat lcl_UnoToSvxFileFormat( sal_Int16 nUnoValue )
         case text::FilenameDisplayFormat::FULL:	return SVXFILEFORMAT_FULLPATH;
         case text::FilenameDisplayFormat::PATH:	return SVXFILEFORMAT_PATH;
         case text::FilenameDisplayFormat::NAME:	return SVXFILEFORMAT_NAME;
-//		case text::FilenameDisplayFormat::NAME_AND_EXT:
         default:
             return SVXFILEFORMAT_NAME_EXT;
     }
@@ -1104,7 +1090,6 @@ sal_Int16 lcl_SvxToUnoFileFormat( SvxFileFormat nSvxValue )
         case SVXFILEFORMAT_NAME_EXT:	return text::FilenameDisplayFormat::NAME_AND_EXT;
         case SVXFILEFORMAT_FULLPATH:	return text::FilenameDisplayFormat::FULL;
         case SVXFILEFORMAT_PATH:		return text::FilenameDisplayFormat::PATH;
-//		case SVXFILEFORMAT_NAME:
         default:
             return text::FilenameDisplayFormat::NAME;
     }
@@ -1272,7 +1257,6 @@ void ScHeaderFieldObj::DeleteField()
     if (pEditSource)
     {
         SvxTextForwarder* pForwarder = pEditSource->GetTextForwarder();
-//		pEditEngine->QuickDelete( aSelection );
         pForwarder->QuickInsertText( String(), aSelection );
         pEditSource->UpdateData();
 
@@ -1286,7 +1270,7 @@ void ScHeaderFieldObj::DeleteField()
 
 // XTextField
 
-::rtl::OUString SAL_CALL ScHeaderFieldObj::getPresentation( sal_Bool bShowCommand )
+::rtl::OUString SAL_CALL ScHeaderFieldObj::getPresentation( sal_Bool /*bShowCommand*/ )
                                                     throw(uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
@@ -1388,7 +1372,7 @@ void SAL_CALL ScHeaderFieldObj::setPropertyValue(
     String aNameString = aPropertyName;
     if ( nType == SC_SERVICE_FILEFIELD && aNameString.EqualsAscii( SC_UNONAME_FILEFORM ) )
     {
-        sal_Int16 nIntVal;
+        sal_Int16 nIntVal = 0;
         if ( aValue >>= nIntVal )
         {
             SvxFileFormat eFormat = lcl_UnoToSvxFileFormat( nIntVal );
@@ -1509,7 +1493,7 @@ ScHeaderFieldObj* ScHeaderFieldObj::getImplementation(
 
 ::rtl::OUString SAL_CALL ScHeaderFieldObj::getImplementationName() throw(uno::RuntimeException)
 {
-    return ::rtl::OUString::createFromAscii( "ScHeaderFieldObj" );
+    return ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ScHeaderFieldObj" ));
 }
 
 sal_Bool SAL_CALL ScHeaderFieldObj::supportsService( const ::rtl::OUString& rServiceName )
@@ -1525,15 +1509,11 @@ uno::Sequence< ::rtl::OUString> SAL_CALL ScHeaderFieldObj::getSupportedServiceNa
 {
     uno::Sequence< ::rtl::OUString> aRet(2);
     ::rtl::OUString* pArray = aRet.getArray();
-    pArray[0] = ::rtl::OUString::createFromAscii( SCTEXTFIELD_SERVICE );
-    pArray[1] = ::rtl::OUString::createFromAscii( SCTEXTCONTENT_SERVICE );
+    pArray[0] = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SCTEXTFIELD_SERVICE ));
+    pArray[1] = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SCTEXTCONTENT_SERVICE ));
     return aRet;
 }
 
-//------------------------------------------------------------------------
-
-
-
 
 }
 
