@@ -120,7 +120,6 @@ ScDocument* ScTempDocSource::GetDocument()
         return rCache.GetDocument();
 }
 
-//------------------------------------------------------------------------
 
 ScTempDocCache::ScTempDocCache() :
     pDoc( NULL ),
@@ -147,8 +146,6 @@ void ScTempDocCache::Clear()
     pDoc = NULL;
 }
 
-//------------------------------------------------------------------------
-
 //	copy results from one document into another
 //!	merge this with ScAreaLink::Refresh
 //!	copy directly without a clipboard document?
@@ -190,11 +187,9 @@ BOOL lcl_CopyData( ScDocument* pSrcDoc, const ScRange& rSrcRange,
     return TRUE;
 }
 
-//------------------------------------------------------------------------
-
-ScFunctionAccess::ScFunctionAccess() :
-    bInvalid( FALSE ),
-    pOptions( NULL )
+ScFunctionAccess::ScFunctionAccess()
+    : pOptions( NULL )
+    , bInvalid( FALSE )
 {
     StartListening( *SFX_APP() );		// for SFX_HINT_DEINITIALIZING
 }
@@ -204,7 +199,7 @@ ScFunctionAccess::~ScFunctionAccess()
     delete pOptions;
 }
 
-void ScFunctionAccess::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
+void ScFunctionAccess::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
 {
     if ( rHint.ISA(SfxSimpleHint) &&
         ((SfxSimpleHint&)rHint).GetId() == SFX_HINT_DEINITIALIZING )
@@ -228,14 +223,14 @@ uno::Reference<uno::XInterface>	SAL_CALL ScFunctionAccess_CreateInstance(
 
 ::rtl::OUString ScFunctionAccess::getImplementationName_Static()
 {
-    return ::rtl::OUString::createFromAscii( "stardiv.StarCalc.ScFunctionAccess" );
+    return ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "stardiv.StarCalc.ScFunctionAccess" ));
 }
 
 uno::Sequence< ::rtl::OUString> ScFunctionAccess::getSupportedServiceNames_Static()
 {
     uno::Sequence< ::rtl::OUString> aRet(1);
     ::rtl::OUString* pArray = aRet.getArray();
-    pArray[0] = ::rtl::OUString::createFromAscii( SCFUNCTIONACCESS_SERVICE );
+    pArray[0] = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SCFUNCTIONACCESS_SERVICE ));
     return aRet;
 }
 
@@ -243,7 +238,7 @@ uno::Sequence< ::rtl::OUString> ScFunctionAccess::getSupportedServiceNames_Stati
 
 ::rtl::OUString SAL_CALL ScFunctionAccess::getImplementationName() throw(uno::RuntimeException)
 {
-    return ::rtl::OUString::createFromAscii( "ScFunctionAccess" );
+    return ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ScFunctionAccess" ));
 }
 
 sal_Bool SAL_CALL ScFunctionAccess::supportsService( const ::rtl::OUString& rServiceName )
@@ -259,8 +254,8 @@ uno::Sequence< ::rtl::OUString> SAL_CALL ScFunctionAccess::getSupportedServiceNa
 {
     uno::Sequence< ::rtl::OUString> aRet(2);
     ::rtl::OUString* pArray = aRet.getArray();
-    pArray[0] = ::rtl::OUString::createFromAscii( SCFUNCTIONACCESS_SERVICE );
-    pArray[1] = ::rtl::OUString::createFromAscii( SCDOCSETTINGS_SERVICE );
+    pArray[0] = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SCFUNCTIONACCESS_SERVICE ));
+    pArray[1] = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SCDOCSETTINGS_SERVICE ));
     return aRet;
 }
 
@@ -433,7 +428,7 @@ uno::Any SAL_CALL ScFunctionAccess::callFunction( const ::rtl::OUString& aName,
         {
             //	#87871# accept integer types because Basic passes a floating point 
             //	variable as byte, short or long if it's an integer number.
-            double fVal;
+            double fVal(0.0);
             rArg >>= fVal;
             aTokenArr.AddDouble( fVal );
         }
@@ -586,7 +581,7 @@ uno::Any SAL_CALL ScFunctionAccess::callFunction( const ::rtl::OUString& aName,
                         {
                             //	#87871# accept integer types because Basic passes a floating point 
                             //	variable as byte, short or long if it's an integer number.
-                            double fVal;
+                            double fVal(0.0);
                             rElement >>= fVal;
                             pDoc->SetValue( (USHORT) nCol, (USHORT) nDocRow, 0, fVal );
                         }
