@@ -41,7 +41,6 @@ using namespace ::com::sun::star;
 #include "miscuno.hxx"
 #include "cellsuno.hxx"
 #include "convuno.hxx"
-#include "targuno.hxx"
 #include "docsh.hxx"
 #include "docfunc.hxx"
 #include "rangenam.hxx"
@@ -58,12 +57,11 @@ const SfxItemPropertyMap* lcl_GetNamedRangeMap()
     {
         {MAP_CHAR_LEN(SC_UNO_LINKDISPBIT),	0,	&getCppuType((uno::Reference<awt::XBitmap>*)0),	beans::PropertyAttribute::READONLY, 0 },
         {MAP_CHAR_LEN(SC_UNO_LINKDISPNAME),	0,	&getCppuType((::rtl::OUString*)0),				beans::PropertyAttribute::READONLY, 0 },
-        {0,0,0,0}
+        {0,0,0,0,0,0}
     };
     return aNamedRangeMap_Impl;
 }
 
-//------------------------------------------------------------------------
 
 #define SCNAMEDRANGEOBJ_SERVICE		"com.sun.star.sheet.NamedRange"
 
@@ -71,7 +69,6 @@ SC_SIMPLE_SERVICE_INFO( ScLabelRangeObj, "ScLabelRangeObj", "com.sun.star.sheet.
 SC_SIMPLE_SERVICE_INFO( ScLabelRangesObj, "ScLabelRangesObj", "com.sun.star.sheet.LabelRanges" )
 SC_SIMPLE_SERVICE_INFO( ScNamedRangesObj, "ScNamedRangesObj", "com.sun.star.sheet.NamedRanges" )
 
-//------------------------------------------------------------------------
 
 sal_Bool lcl_UserVisibleName( const ScRangeData* pData )
 {
@@ -80,7 +77,6 @@ sal_Bool lcl_UserVisibleName( const ScRangeData* pData )
     return ( pData && !pData->HasType( RT_DATABASE ) && !pData->HasType( RT_SHARED ) );
 }
 
-//------------------------------------------------------------------------
 
 ScNamedRangeObj::ScNamedRangeObj(ScDocShell* pDocSh, const String& rNm) :
     pDocShell( pDocSh ),
@@ -95,7 +91,7 @@ ScNamedRangeObj::~ScNamedRangeObj()
         pDocShell->GetDocument()->RemoveUnoObject(*this);
 }
 
-void ScNamedRangeObj::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
+void ScNamedRangeObj::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
 {
     //	Ref-Update interessiert nicht
 
@@ -163,7 +159,7 @@ void ScNamedRangeObj::Modify_Impl( const String* pNewName, const String* pNewCon
                 if ( aNewRanges.Insert(pNew) )
                 {
                     ScDocFunc aFunc(*pDocShell);
-                    aFunc.ModifyRangeNames( aNewRanges, sal_True );
+                    aFunc.ModifyRangeNames( aNewRanges );
 
                     aName = aInsName;	//! broadcast?
                 }
@@ -190,7 +186,7 @@ void SAL_CALL ScNamedRangeObj::setName( const ::rtl::OUString& aNewName )
     String aNewStr = aNewName;
     Modify_Impl( &aNewStr, NULL, NULL, NULL );
 
-    if ( aName != aNewStr )					// some error occured...
+    if ( aName != aNewStr )					// some error occurred...
         throw uno::RuntimeException();		// no other exceptions specified
 }
 
@@ -306,7 +302,7 @@ uno::Reference<beans::XPropertySetInfo> SAL_CALL ScNamedRangeObj::getPropertySet
 }
 
 void SAL_CALL ScNamedRangeObj::setPropertyValue(
-                        const ::rtl::OUString& aPropertyName, const uno::Any& aValue )
+                        const ::rtl::OUString& /*aPropertyName*/, const uno::Any& /*aValue*/ )
                 throw(beans::UnknownPropertyException, beans::PropertyVetoException,
                         lang::IllegalArgumentException, lang::WrappedTargetException,
                         uno::RuntimeException)
@@ -337,7 +333,7 @@ SC_IMPL_DUMMY_PROPERTY_LISTENER( ScNamedRangeObj )
 
 ::rtl::OUString SAL_CALL ScNamedRangeObj::getImplementationName() throw(uno::RuntimeException)
 {
-    return ::rtl::OUString::createFromAscii( "ScNamedRangeObj" );
+    return ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ScNamedRangeObj" ));
 }
 
 sal_Bool SAL_CALL ScNamedRangeObj::supportsService( const ::rtl::OUString& rServiceName )
@@ -352,11 +348,10 @@ uno::Sequence< ::rtl::OUString> SAL_CALL ScNamedRangeObj::getSupportedServiceNam
 {
     uno::Sequence< ::rtl::OUString> aRet(1);
     ::rtl::OUString* pArray = aRet.getArray();
-    pArray[0] = ::rtl::OUString::createFromAscii( SCNAMEDRANGEOBJ_SERVICE );
+    pArray[0] = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SCNAMEDRANGEOBJ_SERVICE ));
     return aRet;
 }
 
-//------------------------------------------------------------------------
 
 ScNamedRangesObj::ScNamedRangesObj(ScDocShell* pDocSh) :
     pDocShell( pDocSh )
@@ -370,7 +365,7 @@ ScNamedRangesObj::~ScNamedRangesObj()
         pDocShell->GetDocument()->RemoveUnoObject(*this);
 }
 
-void ScNamedRangesObj::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
+void ScNamedRangesObj::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
 {
     //	Referenz-Update interessiert hier nicht
 
@@ -446,7 +441,7 @@ void SAL_CALL ScNamedRangesObj::addNewByName( const ::rtl::OUString& aName,
             if ( aNewRanges.Insert(pNew) )
             {
                 ScDocFunc aFunc(*pDocShell);
-                aFunc.ModifyRangeNames( aNewRanges, sal_True );
+                aFunc.ModifyRangeNames( aNewRanges );
                 bDone = TRUE;
             }
             else
@@ -503,7 +498,7 @@ void SAL_CALL ScNamedRangesObj::removeByName( const ::rtl::OUString& aName )
                     ScRangeName aNewRanges(*pNames);
                     aNewRanges.AtFree(nPos);
                     ScDocFunc aFunc(*pDocShell);
-                    aFunc.ModifyRangeNames( aNewRanges, sal_True );
+                    aFunc.ModifyRangeNames( aNewRanges );
                     bDone = TRUE;
                 }
         }
@@ -615,7 +610,6 @@ uno::Sequence< ::rtl::OUString> SAL_CALL ScNamedRangesObj::getElementNames()
                 if ( lcl_UserVisibleName(pData) )
                     pAry[nVisPos++] = pData->GetName();
             }
-//			DBG_ASSERT(nVisPos == nVisCount, "huch, verzaehlt?");
             return aSeq;
         }
     }
@@ -641,7 +635,6 @@ sal_Bool SAL_CALL ScNamedRangesObj::hasByName( const ::rtl::OUString& aName )
     return sal_False;
 }
 
-//------------------------------------------------------------------------
 
 ScLabelRangeObj::ScLabelRangeObj(ScDocShell* pDocSh, sal_Bool bCol, const ScRange& rR) :
     pDocShell( pDocSh ),
@@ -657,7 +650,7 @@ ScLabelRangeObj::~ScLabelRangeObj()
         pDocShell->GetDocument()->RemoveUnoObject(*this);
 }
 
-void ScLabelRangeObj::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
+void ScLabelRangeObj::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
 {
     //!	Ref-Update !!!
 
@@ -762,7 +755,6 @@ void SAL_CALL ScLabelRangeObj::setDataArea( const table::CellRangeAddress& aData
     Modify_Impl( NULL, &aDataRange );
 }
 
-//------------------------------------------------------------------------
 
 ScLabelRangesObj::ScLabelRangesObj(ScDocShell* pDocSh, sal_Bool bCol) :
     pDocShell( pDocSh ),
@@ -777,7 +769,7 @@ ScLabelRangesObj::~ScLabelRangesObj()
         pDocShell->GetDocument()->RemoveUnoObject(*this);
 }
 
-void ScLabelRangesObj::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
+void ScLabelRangesObj::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
 {
     //	Referenz-Update interessiert hier nicht
 
@@ -928,9 +920,6 @@ sal_Bool SAL_CALL ScLabelRangesObj::hasElements() throw(uno::RuntimeException)
     return ( getCount() != 0 );
 }
 
-//------------------------------------------------------------------------
-
-
 
 }
 
