@@ -90,10 +90,10 @@ uno::Sequence< ::rtl::OUString > SAL_CALL ChXChartAxis::getSupportedServiceNames
     SolarMutexGuard aGuard;
 
     uno::Sequence< ::rtl::OUString > aSeq( 4 );
-    aSeq[ 0 ] = ::rtl::OUString::createFromAscii( "com.sun.star.chart.ChartAxis" );
-    aSeq[ 1 ] = ::rtl::OUString::createFromAscii( "com.sun.star.drawing.LineProperties" );
-    aSeq[ 2 ] = ::rtl::OUString::createFromAscii( "com.sun.star.style.CharacterProperties" );
-    aSeq[ 3 ] = ::rtl::OUString::createFromAscii( "com.sun.star.xml.UserDefinedAttributeSupplier" );
+    aSeq[ 0 ] = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.chart.ChartAxis" ));
+    aSeq[ 1 ] = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.drawing.LineProperties" ));
+    aSeq[ 2 ] = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.style.CharacterProperties" ));
+    aSeq[ 3 ] = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.xml.UserDefinedAttributeSupplier" ));
 
     return aSeq;
 }
@@ -207,7 +207,7 @@ uno::Sequence< sal_Int8 > SAL_CALL ChXChartAxis::getImplementationId() throw( un
 ::rtl::OUString SAL_CALL ChXChartAxis::getShapeType()
     throw( uno::RuntimeException )
 {
-    return ::rtl::OUString::createFromAscii( "com.sun.star.chart.ChartAxis" );
+    return ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.chart.ChartAxis" ));
 }
 
 // XUnoTunnel
@@ -367,10 +367,10 @@ void SAL_CALL ChXChartAxis::setPropertyValue( const ::rtl::OUString& aPropertyNa
                 }
                 else if( nWID != SID_ATTR_NUMBERFORMAT_SOURCE )
                 {
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
                     String aTmpString( aPropertyName );
                     ByteString aProp( aTmpString, RTL_TEXTENCODING_ASCII_US );
-                    DBG_ERROR2( "ChartAxis: Property %s has an invalid ID (%d)", aProp.GetBuffer(), nWID );
+                    OSL_TRACE( "ChartAxis: Property %s has an invalid ID (%d)", aProp.GetBuffer(), nWID );
 #endif
                 }
             }
@@ -385,7 +385,7 @@ void SAL_CALL ChXChartAxis::setPropertyValue( const ::rtl::OUString& aPropertyNa
                         if( ! ( aValue >>= eArrOrder ))
                         {
                             // basic might give us an int instead of the enum type
-                            sal_Int32 nIntVal;
+                            sal_Int32 nIntVal = 0;
                             if( aValue >>= nIntVal )
                             {
                                 eArrOrder = SAL_STATIC_CAST( chart::ChartAxisArrangeOrderType, nIntVal );
@@ -408,7 +408,7 @@ void SAL_CALL ChXChartAxis::setPropertyValue( const ::rtl::OUString& aPropertyNa
                     break;
                 case SCHATTR_TEXT_ORIENT:
                     {
-                        sal_Bool bVal;
+                        sal_Bool bVal = sal_False;
                         if( aValue >>= bVal )
                         {
                             pSet->Put( SvxChartTextOrientItem(
@@ -421,7 +421,7 @@ void SAL_CALL ChXChartAxis::setPropertyValue( const ::rtl::OUString& aPropertyNa
                 case SCHATTR_AXIS_AUTO_STEP_MAIN:
                 case SCHATTR_AXIS_AUTO_STEP_HELP:
                     {
-                        sal_Bool bVal;
+                        sal_Bool bVal(sal_False);
                         aValue >>= bVal;
                         if( ! bVal )
                         {
@@ -446,7 +446,7 @@ void SAL_CALL ChXChartAxis::setPropertyValue( const ::rtl::OUString& aPropertyNa
                     break;
                 case SCHATTR_AXIS_LOGARITHM:
                     {
-                        sal_Bool bVal;
+                        sal_Bool bVal(sal_False);
                         aValue >>= bVal;
                         if( bVal )
                         {
@@ -478,7 +478,7 @@ void SAL_CALL ChXChartAxis::setPropertyValue( const ::rtl::OUString& aPropertyNa
                         ChartAxis* pAxis = mpModel->GetAxis( mnWhichId );
                         if( pAxis )
                             bLog = pAxis->IsLogarithm();
-                        double fVal;
+                        double fVal(0.0);
                         aValue >>= fVal;
                         if( fVal <= bLog? 1.0: 0.0 )
                             throw lang::IllegalArgumentException();
@@ -492,7 +492,7 @@ void SAL_CALL ChXChartAxis::setPropertyValue( const ::rtl::OUString& aPropertyNa
                 case SCHATTR_AXIS_MAX:
                     {
                         ChartAxis* pAxis = mpModel->GetAxis( mnWhichId );
-                        double fVal;
+                        double fVal(0.0);
                         aValue >>= fVal;
                         if( pAxis &&
                             pAxis->IsLogarithm() && fVal <= 0.0 )
@@ -511,7 +511,7 @@ void SAL_CALL ChXChartAxis::setPropertyValue( const ::rtl::OUString& aPropertyNa
                 case SCHATTR_AXIS_NUMFMTPERCENT:
                     // was mapped from SCHATTR_AXIS_NUMFMT, so don't use standard mechanism
                     {
-                        sal_Int32 nFmt;
+                        sal_Int32 nFmt(0);
                         aValue >>= nFmt;
                         pSet->Put( SfxUInt32Item( nWID, nFmt ));
                     }
@@ -603,12 +603,12 @@ void SAL_CALL ChXChartAxis::setPropertyValues	(
             //	Get default from the model's item pool.
             if (mpModel->GetItemPool().IsWhich (nWID))
                 aAttributes.Put (mpModel->GetItemPool().GetDefaultItem(nWID));
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
             else if (nWID != SID_ATTR_NUMBERFORMAT_SOURCE)
             {
                 String aTmpString (*pPropertyName);
                 ByteString aProp( aTmpString, RTL_TEXTENCODING_ASCII_US );
-                DBG_ERROR2( "ChartAxis: Property %s has an invalid ID (%d)", aProp.GetBuffer(), nWID );
+                OSL_TRACE( "ChartAxis: Property %s has an invalid ID (%d)", aProp.GetBuffer(), nWID );
             }
 #endif
         }
@@ -623,7 +623,7 @@ void SAL_CALL ChXChartAxis::setPropertyValues	(
                     if ( ! ( *pValue >>= eArrOrder ))
                     {
                         // basic might give us an int instead of the enum type
-                        sal_Int32 nIntVal;
+                        sal_Int32 nIntVal = 0;
                         if( *pValue >>= nIntVal )
                             eArrOrder = SAL_STATIC_CAST (chart::ChartAxisArrangeOrderType, nIntVal);
                     }
@@ -649,7 +649,7 @@ void SAL_CALL ChXChartAxis::setPropertyValues	(
             
             case SCHATTR_TEXT_ORIENT:
                 {
-                    sal_Bool bVal;
+                    sal_Bool bVal = sal_False;
                     if( *pValue >>= bVal )
                     {
                         aAttributes.Put( SvxChartTextOrientItem(
@@ -663,7 +663,7 @@ void SAL_CALL ChXChartAxis::setPropertyValues	(
             case SCHATTR_AXIS_AUTO_STEP_MAIN:
             case SCHATTR_AXIS_AUTO_STEP_HELP:
                 {
-                    sal_Bool bVal;
+                    sal_Bool bVal(sal_False);
                     *pValue >>= bVal;
                     if( ! bVal )
                     {
@@ -689,7 +689,7 @@ void SAL_CALL ChXChartAxis::setPropertyValues	(
                 
             case SCHATTR_AXIS_LOGARITHM:
                 {
-                    sal_Bool bVal;
+                    sal_Bool bVal(sal_False);
                     *pValue >>= bVal;
                     if( bVal )
                     {
@@ -721,7 +721,7 @@ void SAL_CALL ChXChartAxis::setPropertyValues	(
                     ChartAxis* pAxis = mpModel->GetAxis( mnWhichId );
                     if( pAxis )
                         bLog = pAxis->IsLogarithm();
-                    double fVal;
+                    double fVal(0.0);
                     *pValue >>= fVal;
                     if( fVal <= bLog? 1.0: 0.0 )
                         throw lang::IllegalArgumentException();
@@ -739,7 +739,7 @@ void SAL_CALL ChXChartAxis::setPropertyValues	(
             case SCHATTR_AXIS_MAX:
                 {
                     ChartAxis* pAxis = mpModel->GetAxis( mnWhichId );
-                    double fVal;
+                    double fVal(0.0);
                     *pValue >>= fVal;
                     if (	pAxis 
                         &&	pAxis->IsLogarithm()
@@ -763,7 +763,7 @@ void SAL_CALL ChXChartAxis::setPropertyValues	(
             case SCHATTR_AXIS_NUMFMTPERCENT:
                 // was mapped from SCHATTR_AXIS_NUMFMT, so don't use standard mechanism
                 {
-                    sal_Int32 nFmt;
+                    sal_Int32 nFmt(0);
                     *pValue >>= nFmt;
                     aAttributes.Put( SfxUInt32Item( nWID, nFmt ));
                 }
