@@ -189,7 +189,7 @@ awt::Point SAL_CALL ChXChartObject::getPosition() throw( uno::RuntimeException )
         return awt::Point( aPt.X(), aPt.Y() );
     }
     else
-        DBG_ERROR( "Couldn't get position due to invalid SdrObject" );
+        OSL_FAIL( "Couldn't get position due to invalid SdrObject" );
 
     return awt::Point();
 }
@@ -204,7 +204,7 @@ void SAL_CALL ChXChartObject::setPosition( const awt::Point& aPosition ) throw(
         case CHOBJID_DIAGRAM_Z_AXIS:
         case CHOBJID_DIAGRAM_AREA:
         case CHOBJID_DIAGRAM_WALL:
-            DBG_ERROR( "Cannot set position of this object" );
+            OSL_FAIL( "Cannot set position of this object" );
             return;
     }
 
@@ -235,7 +235,7 @@ void SAL_CALL ChXChartObject::setPosition( const awt::Point& aPosition ) throw(
         }
     }
     else
-        DBG_ERROR( "Couldn't set position due to invalid SdrObject" );
+        OSL_FAIL( "Couldn't set position due to invalid SdrObject" );
 }
 
 awt::Size SAL_CALL ChXChartObject::getSize() throw( uno::RuntimeException )
@@ -250,18 +250,18 @@ awt::Size SAL_CALL ChXChartObject::getSize() throw( uno::RuntimeException )
         return awt::Size( aObjSize.getWidth(), aObjSize.getHeight() );
     }
     else
-        DBG_ERROR( "Couldn't get size due to invalid SdrObject" );
+        OSL_FAIL( "Couldn't get size due to invalid SdrObject" );
 
     return awt::Size();
 }
 
-void SAL_CALL ChXChartObject::setSize( const awt::Size& aSize )
+void SAL_CALL ChXChartObject::setSize( const awt::Size& /*aSize*/ )
     throw( beans::PropertyVetoException, uno::RuntimeException )
 {
     // set size is not supported by any chart object except
     // the diagram which is covered by ChXDiagram
 
-    DBG_ERROR( "Size of chart objects cannot be changed" );
+    OSL_FAIL( "Size of chart objects cannot be changed" );
 }
 
 // XPropertySet
@@ -336,7 +336,7 @@ void SAL_CALL ChXChartObject::setPropertyValue( const ::rtl::OUString& aProperty
 
                 case SCHATTR_TEXT_ORIENT:
                     {
-                        sal_Bool bVal;
+                        sal_Bool bVal = sal_False;
                         if( aValue >>= bVal )
                         {
                             pSet->Put( SvxChartTextOrientItem(
@@ -353,7 +353,7 @@ void SAL_CALL ChXChartObject::setPropertyValue( const ::rtl::OUString& aProperty
                         drawing::BitmapMode eMode;
                         if(!(aValue >>= eMode) )
                         {
-                            sal_Int32 nMode;
+                            sal_Int32 nMode = 0;
                             if(!(aValue >>= nMode))
                                 break;
 
@@ -527,10 +527,10 @@ uno::Any SAL_CALL ChXChartObject::getPropertyValue( const ::rtl::OUString& Prope
                 }
                 else
                 {
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
                     String aTmpString( PropertyName );
                     ByteString aProp( aTmpString, RTL_TEXTENCODING_ASCII_US );
-                    DBG_ERROR2( "Diagram: Property %s has an invalid ID (%d)", aProp.GetBuffer(), nWID );
+                    OSL_TRACE( "Diagram: Property %s has an invalid ID (%d)", aProp.GetBuffer(), nWID );
 #endif
                 }
             }
@@ -597,13 +597,13 @@ uno::Any SAL_CALL ChXChartObject::getPropertyValue( const ::rtl::OUString& Prope
                         // since the sfx uint16 item now exports a sal_Int32, we may have to fix this here
                         if( ( *pMap->pType == ::getCppuType((const sal_Int16*)0)) && aResultaAny.getValueType() == ::getCppuType((const sal_Int32*)0) )
                         {
-                            sal_Int32 nValue;
+                            sal_Int32 nValue(0);
                             aResultaAny >>= nValue;
                             aResultaAny <<= static_cast< sal_Int16 >( nValue );
                         }
                         else
                         {
-                            DBG_ERROR( "getPropertyValue(): wrong Type!" );
+                            OSL_FAIL( "getPropertyValue(): wrong Type!" );
                         }
                     }
                 }
@@ -630,29 +630,29 @@ uno::Any SAL_CALL ChXChartObject::getPropertyValue( const ::rtl::OUString& Prope
     return aResultaAny;
 }
 
-void SAL_CALL ChXChartObject::addPropertyChangeListener( const ::rtl::OUString& aPropertyName,
-                                                     const uno::Reference< beans::XPropertyChangeListener >& xListener )
+void SAL_CALL ChXChartObject::addPropertyChangeListener( const ::rtl::OUString& /*aPropertyName*/,
+                                                     const uno::Reference< beans::XPropertyChangeListener >& /*xListener*/ )
     throw( beans::UnknownPropertyException,
            lang::WrappedTargetException,
            uno::RuntimeException )
 {}
 
-void SAL_CALL ChXChartObject::removePropertyChangeListener( const ::rtl::OUString& aPropertyName,
-                                                        const uno::Reference< beans::XPropertyChangeListener >& aListener )
+void SAL_CALL ChXChartObject::removePropertyChangeListener( const ::rtl::OUString& /*aPropertyName*/,
+                                                        const uno::Reference< beans::XPropertyChangeListener >& /*aListener*/ )
     throw( beans::UnknownPropertyException,
            lang::WrappedTargetException,
            uno::RuntimeException )
 {}
 
-void SAL_CALL ChXChartObject::addVetoableChangeListener( const ::rtl::OUString& PropertyName,
-                                                     const uno::Reference< beans::XVetoableChangeListener >& aListener )
+void SAL_CALL ChXChartObject::addVetoableChangeListener( const ::rtl::OUString& /*PropertyName*/,
+                                                     const uno::Reference< beans::XVetoableChangeListener >& /*aListener*/ )
     throw( beans::UnknownPropertyException,
            lang::WrappedTargetException,
            uno::RuntimeException )
 {}
 
-void SAL_CALL ChXChartObject::removeVetoableChangeListener( const ::rtl::OUString& PropertyName,
-                                                        const uno::Reference< beans::XVetoableChangeListener >& aListener )
+void SAL_CALL ChXChartObject::removeVetoableChangeListener( const ::rtl::OUString& /*PropertyName*/,
+                                                        const uno::Reference< beans::XVetoableChangeListener >& /*aListener*/ )
     throw( beans::UnknownPropertyException,
            lang::WrappedTargetException,
            uno::RuntimeException )
@@ -743,7 +743,7 @@ void SAL_CALL ChXChartObject::setPropertyValues	(
 
             case SCHATTR_TEXT_ORIENT:
                 {
-                    sal_Bool bVal;
+                    sal_Bool bVal = sal_False;
                     if( *pValue >>= bVal )
                     {
                         aModifications.Put( SvxChartTextOrientItem(
@@ -759,7 +759,7 @@ void SAL_CALL ChXChartObject::setPropertyValues	(
                 drawing::BitmapMode eMode;
                 if ( ! (*pValue >>= eMode))
                 {
-                    sal_Int32 nMode;
+                    sal_Int32 nMode = 0;
                     if ( ! (*pValue >>= nMode))
                         break;
                     eMode = (drawing::BitmapMode)nMode;
@@ -832,16 +832,6 @@ uno::Sequence< uno::Any > SAL_CALL ChXChartObject::getPropertyValues	(
         const uno::Sequence< ::rtl::OUString >& aPropertyNames ) 
     throw ( uno::RuntimeException)
 {
-#if 0
-    uno::Sequence<uno::Any>	aResult (aPropertyNames.getLength());
-    
-    for (sal_Int32 i=0; i<aPropertyNames.getLength(); i++)
-    {
-        aResult[i] = getPropertyValue (aPropertyNames[i]);
-    }
-    
-    return aResult;
-#endif
     SolarMutexGuard aGuard;
     
     //	This sequence is filled with the requested values for the given property names.
@@ -880,8 +870,8 @@ uno::Sequence< uno::Any > SAL_CALL ChXChartObject::getPropertyValues	(
 
 
 void SAL_CALL ChXChartObject::addPropertiesChangeListener	(
-        const uno::Sequence< ::rtl::OUString >& aPropertyNames,
-        const uno::Reference< beans::XPropertiesChangeListener >& xListener ) 
+        const uno::Sequence< ::rtl::OUString >& /*aPropertyNames*/,
+        const uno::Reference< beans::XPropertiesChangeListener >& /*xListener*/ )
     throw (	uno::RuntimeException)
 {
     //	Not implemented.
@@ -891,7 +881,7 @@ void SAL_CALL ChXChartObject::addPropertiesChangeListener	(
 
 
 void SAL_CALL ChXChartObject::removePropertiesChangeListener	(
-        const uno::Reference< beans::XPropertiesChangeListener >& xListener ) 
+        const uno::Reference< beans::XPropertiesChangeListener >& /*xListener*/ )
     throw (	uno::RuntimeException)
 {
     //	Not implemented.
@@ -901,8 +891,8 @@ void SAL_CALL ChXChartObject::removePropertiesChangeListener	(
 
 
 void SAL_CALL ChXChartObject::firePropertiesChangeEvent	(
-        const uno::Sequence< ::rtl::OUString >& aPropertyNames,
-        const uno::Reference< beans::XPropertiesChangeListener >& xListener )
+        const uno::Sequence< ::rtl::OUString >& /*aPropertyNames*/,
+        const uno::Reference< beans::XPropertiesChangeListener >& /*xListener*/ )
     throw (	uno::RuntimeException)
 {
     //	Not implemented.
@@ -982,22 +972,6 @@ uno::Sequence< beans::PropertyState > SAL_CALL ChXChartObject::getPropertyStates
         throw( beans::UnknownPropertyException,
                uno::RuntimeException )
 {
-#if 0
-    SolarMutexGuard aGuard;
-
-    const sal_Int32 nCount = aPropertyNames.getLength();
-    const ::rtl::OUString * pName = aPropertyNames.getConstArray();
-    Sequence<PropertyState > aStates (nCount);
-    PropertyState * pState = aStates.getArray();
-    
-    if (mpModel == NULL)
-        return aStates;
-
-    for (sal_Int32 nIdx = 0; nIdx < nCount; nIdx++)
-        pState[nIdx] = getPropertyState (pName[nIdx]);
-
-    return aStates;
-#else
     SolarMutexGuard aGuard;
 
     //	Get pointers to first elements of lists.
@@ -1091,7 +1065,6 @@ uno::Sequence< beans::PropertyState > SAL_CALL ChXChartObject::getPropertyStates
     }
 
     return aStates;
-#endif
 }
 
 void SAL_CALL ChXChartObject::setPropertyToDefault( const ::rtl::OUString& PropertyName )
@@ -1140,13 +1113,13 @@ uno::Any SAL_CALL ChXChartObject::getPropertyDefault( const ::rtl::OUString& aPr
         // since the sfx uint16 item now exports a sal_Int32, we may have to fix this here
         if( ( *pMap->pType == ::getCppuType((const sal_Int16*)0)) && aAny.getValueType() == ::getCppuType((const sal_Int32*)0) )
         {
-            sal_Int32 nValue;
+            sal_Int32 nValue(0);
             aAny >>= nValue;
             aAny <<= static_cast< sal_Int16 >( nValue );
         }
         else
         {
-            DBG_ERROR( "getPropertyDefault(): wrong Type!" );
+            OSL_FAIL( "getPropertyDefault(): wrong Type!" );
         }
     }
 
@@ -1165,7 +1138,7 @@ uno::Any SAL_CALL ChXChartObject::getPropertyDefault( const ::rtl::OUString& aPr
 void SAL_CALL ChXChartObject::setAllPropertiesToDefault	(void)
     throw (	uno::RuntimeException)
 {
-    DBG_ERROR ("ChXChartObject::setAllPropertiesToDefault");
+    OSL_FAIL("ChXChartObject::setAllPropertiesToDefault");
 }
 
 
@@ -1388,8 +1361,8 @@ void	ChXChartObject::GetPropertyValue	(const SfxItemPropertyMap & rProperty,
                     }
                     else
                     {
-#ifdef DBG_UTIL
-                        DBG_ERROR2( "Diagram: Property %s has an invalid ID (%d)", 
+#if OSL_DEBUG_LEVEL > 1
+                        OSL_TRACE( "Diagram: Property %s has an invalid ID (%d)",
                             rProperty.pName, nWID );
 #endif
                     }
@@ -1402,13 +1375,13 @@ void	ChXChartObject::GetPropertyValue	(const SfxItemPropertyMap & rProperty,
                         // since the sfx uint16 item now exports a sal_Int32, we may have to fix this here
                         if( ( *rProperty.pType == ::getCppuType((const sal_Int16*)0)) && rValue.getValueType() == ::getCppuType((const sal_Int32*)0) )
                         {
-                            sal_Int32 nValue;
+                            sal_Int32 nValue(0);
                             rValue >>= nValue;
                             rValue <<= static_cast< sal_Int16 >( nValue );
                         }
                         else
                         {
-                            DBG_ERROR( "GetPropertyValue(): wrong Type!" );
+                            OSL_FAIL( "GetPropertyValue(): wrong Type!" );
                         }
                     }
             }
