@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -29,41 +29,25 @@
 #include <com/sun/star/lang/DisposedException.hpp>
 #include <com/sun/star/lang/ServiceNotRegisteredException.hpp>
 
-
-
 #include <rtl/uuid.h>
 #include <rtl/memory.h>
 
 #include <bf_svx/unofield.hxx>
-
-
-
-
 #include <bf_svx/UnoForbiddenCharsTable.hxx>
-
 #include <bf_svx/forbiddencharacterstable.hxx>
-
 #include <bf_svx/UnoNamespaceMap.hxx>
-
 #include <bf_svx/unoapi.hxx>
-
 #include <bf_svx/unofill.hxx>
-
 #include <bf_svx/svdorect.hxx>
 
 #include <toolkit/awt/vclxdevice.hxx>
 
 #include <bf_svtools/unoimap.hxx>
-
 #include <bf_svx/unolingu.hxx>
 #include <bf_svx/svdpagv.hxx>
-
 #include <bf_svx/unoshape.hxx>
 #include <bf_svx/unonrule.hxx>
-
-// #99870# Support creation of GraphicObjectResolver and EmbeddedObjectResolver
 #include <bf_svx/xmleohlp.hxx>
-
 #include <bf_svx/xmlgrhlp.hxx>
 
 #include "bf_sd/docshell.hxx"
@@ -87,7 +71,8 @@
 #include <unokywds.hxx>
 #include <frmview.hxx>
 
-#include <legacysmgr/legacy_binfilters_smgr.hxx>	//STRIP002
+#include <legacysmgr/legacy_binfilters_smgr.hxx>
+
 namespace binfilter {
 
 using namespace ::osl;
@@ -136,7 +121,7 @@ SdUnoForbiddenCharsTable::~SdUnoForbiddenCharsTable()
         EndListening( *mpModel );
 }
 
-void SdUnoForbiddenCharsTable::Notify( SfxBroadcaster& rBC, const SfxHint& rHint ) throw()
+void SdUnoForbiddenCharsTable::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint ) throw()
 {
     const SdrHint* pSdrHint = PTR_CAST( SdrHint, &rHint );
 
@@ -173,7 +158,7 @@ const SfxItemPropertyMap* ImplGetDrawModelPropertyMap()
         { MAP_CHAR_LEN(sUNO_Prop_AutomContFocus ),	WID_MODEL_CONTFOCUS,	&::getBooleanCppuType(),					0,	0},
         { MAP_CHAR_LEN(sUNO_Prop_ApplyFrmDsgnMode),	WID_MODEL_DSGNMODE,		&::getBooleanCppuType(),					0,	0},
         { MAP_CHAR_LEN("BasicLibraries"),				WID_MODEL_BASICLIBS,&::getCppuType((const uno::Reference< script::XLibraryContainer > *)0), beans::PropertyAttribute::READONLY, 0 },
-        { 0,0,0,0,0 }
+        { 0,0,0,0,0,0 }
     };
 
     return aDrawModelPropertyMap_Impl;
@@ -183,8 +168,8 @@ const SfxItemPropertyMap* ImplGetDrawModelPropertyMap()
 SdXImpressDocument::SdXImpressDocument( SdDrawDocShell* pShell ) throw()
 :	SfxBaseModel( pShell ),
     pDocShell( pShell ),
-    aPropSet( ImplGetDrawModelPropertyMap() ),
-    mbClipBoard( sal_False )
+    mbClipBoard( sal_False ),
+    aPropSet( ImplGetDrawModelPropertyMap() )
 {
     if( pDocShell )
     {
@@ -193,15 +178,12 @@ SdXImpressDocument::SdXImpressDocument( SdDrawDocShell* pShell ) throw()
     }
     else
     {
-        DBG_ERROR("DocShell is invalid");
+        OSL_FAIL("DocShell is invalid");
     }
 
     mbImpressDoc = pDoc && pDoc->GetDocumentType() == DOCUMENT_TYPE_IMPRESS;
 }
 
-/***********************************************************************
-*                                                                      *
-***********************************************************************/
 SdXImpressDocument::~SdXImpressDocument() throw()
 {
 }
@@ -209,38 +191,6 @@ SdXImpressDocument::~SdXImpressDocument() throw()
 // uno helper
 
 
-/******************************************************************************
-* Erzeugt anhand der uebergebennen SdPage eine SdDrawPage. Wurde fuer diese   *
-* SdPage bereits eine SdDrawPage erzeugt, wird keine neue SdDrawPage erzeug.  *
-******************************************************************************/
-/*
-uno::Reference< drawing::XDrawPage >  SdXImpressDocument::CreateXDrawPage( SdPage* pPage ) throw()
-{
-    DBG_ASSERT(pPage,"SdXImpressDocument::CreateXDrawPage( NULL? )");
-
-    uno::Reference< drawing::XDrawPage >  xDrawPage;
-
-    if(pPage)
-    {
-        xDrawPage = SvxDrawPage::GetPageForSdrPage(pPage);
-
-        if(!xDrawPage.is())
-        {
-            if(pPage->IsMasterPage())
-            {
-                xDrawPage = (presentation::XPresentationPage*)new SdMasterPage( this, pPage );
-            }
-            else
-            {
-                xDrawPage = (SvxDrawPage*)new SdDrawPage( this, pPage );
-            }
-        }
-    }
-
-    return xDrawPage;
-}
-*/
-
 UNO3_GETIMPLEMENTATION_IMPL( SdXImpressDocument );
 
 // XInterface
@@ -332,9 +282,6 @@ uno::Sequence< sal_Int8 > SAL_CALL SdXImpressDocument::getImplementationId(  ) t
     return aId;
 }
 
-/***********************************************************************
-*                                                                      *
-***********************************************************************/
 void SdXImpressDocument::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
 {
     if( pDoc )
@@ -398,9 +345,6 @@ void SdXImpressDocument::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
     SfxBaseModel::Notify( rBC, rHint );
 }
 
-/******************************************************************************
-*                                                                             *
-******************************************************************************/
 SdPage* SdXImpressDocument::InsertSdPage( sal_uInt16 nPage, sal_Bool bDuplicate ) throw()
 {
     sal_uInt16 nPageCount = pDoc->GetSdPageCount( PK_STANDARD );
@@ -545,7 +489,7 @@ sal_Bool SAL_CALL SdXImpressDocument::hasControllersLocked(  )
     return pDoc && pDoc->isLocked();
 }
 } //namespace binfilter
-namespace binfilter {//STRIP009
+namespace binfilter {
 uno::Reference < container::XIndexAccess > SAL_CALL SdXImpressDocument::getViewData() throw( uno::RuntimeException )
 {
     if( NULL == pDoc )
@@ -1108,7 +1052,7 @@ void SAL_CALL SdXImpressDocument::setPropertyValue( const OUString& aPropertyNam
         }
         case WID_MODEL_TABSTOP:
         {
-            sal_Int32 nValue;
+            sal_Int32 nValue(0);
             if(!(aValue >>= nValue) || nValue < 0 )
                 throw lang::IllegalArgumentException();
 
@@ -1130,7 +1074,7 @@ void SAL_CALL SdXImpressDocument::setPropertyValue( const OUString& aPropertyNam
             break;
         case WID_MODEL_CONTFOCUS:
             {
-                sal_Bool bFocus;
+                sal_Bool bFocus(sal_False);
                 if( !(aValue >>= bFocus ) )
                     throw lang::IllegalArgumentException();
                 pDoc->SetAutoControlFocus( bFocus );
@@ -1138,7 +1082,7 @@ void SAL_CALL SdXImpressDocument::setPropertyValue( const OUString& aPropertyNam
             break;
         case WID_MODEL_DSGNMODE:
             {
-                sal_Bool bMode;
+                sal_Bool bMode(sal_False);
                 if( !(aValue >>= bMode ) )
                     throw lang::IllegalArgumentException();
                 pDoc->SetOpenInDesignMode( bMode );
@@ -1224,10 +1168,10 @@ uno::Any SAL_CALL SdXImpressDocument::getPropertyValue( const OUString& Property
     return aAny;
 }
 
-void SAL_CALL SdXImpressDocument::addPropertyChangeListener( const OUString& aPropertyName, const uno::Reference< beans::XPropertyChangeListener >& xListener ) throw(beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException) {}
-void SAL_CALL SdXImpressDocument::removePropertyChangeListener( const OUString& aPropertyName, const uno::Reference< beans::XPropertyChangeListener >& aListener ) throw(beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException) {}
-void SAL_CALL SdXImpressDocument::addVetoableChangeListener( const OUString& PropertyName, const uno::Reference< beans::XVetoableChangeListener >& aListener ) throw(beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException) {}
-void SAL_CALL SdXImpressDocument::removeVetoableChangeListener( const OUString& PropertyName, const uno::Reference< beans::XVetoableChangeListener >& aListener ) throw(beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException) {}
+void SAL_CALL SdXImpressDocument::addPropertyChangeListener( const OUString& /*aPropertyName*/, const uno::Reference< beans::XPropertyChangeListener >& /*xListener*/ ) throw(beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException) {}
+void SAL_CALL SdXImpressDocument::removePropertyChangeListener( const OUString& /*aPropertyName*/, const uno::Reference< beans::XPropertyChangeListener >& /*aListener*/ ) throw(beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException) {}
+void SAL_CALL SdXImpressDocument::addVetoableChangeListener( const OUString& /*PropertyName*/, const uno::Reference< beans::XVetoableChangeListener >& /*aListener*/ ) throw(beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException) {}
+void SAL_CALL SdXImpressDocument::removeVetoableChangeListener( const OUString& /*PropertyName*/, const uno::Reference< beans::XVetoableChangeListener >& /*aListener*/ ) throw(beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException) {}
 
 // XLinkTargetSupplier
 uno::Reference< container::XNameAccess > SAL_CALL SdXImpressDocument::getLinks()
@@ -1259,7 +1203,7 @@ uno::Reference< container::XNameAccess > SAL_CALL SdXImpressDocument::getStyleFa
 }
 
 // XAnyCompareFactory
-uno::Reference< ::com::sun::star::ucb::XAnyCompare > SAL_CALL SdXImpressDocument::createAnyCompareByName( const OUString& PropertyName )
+uno::Reference< ::com::sun::star::ucb::XAnyCompare > SAL_CALL SdXImpressDocument::createAnyCompareByName( const OUString& /*PropertyName*/ )
     throw (uno::RuntimeException)
 {
     return SvxCreateNumRuleCompare();
@@ -1267,7 +1211,7 @@ uno::Reference< ::com::sun::star::ucb::XAnyCompare > SAL_CALL SdXImpressDocument
 
 // XRenderable
 sal_Int32 SAL_CALL SdXImpressDocument::getRendererCount( const uno::Any& rSelection,
-                                                         const uno::Sequence< beans::PropertyValue >& rxOptions )
+                                                         const uno::Sequence< beans::PropertyValue >& /*rxOptions*/ )
     throw (lang::IllegalArgumentException, uno::RuntimeException)
 {
     ::SolarMutexGuard aGuard;
@@ -1300,8 +1244,8 @@ sal_Int32 SAL_CALL SdXImpressDocument::getRendererCount( const uno::Any& rSelect
     return nRet;
 }
 
-uno::Sequence< beans::PropertyValue > SAL_CALL SdXImpressDocument::getRenderer( sal_Int32 nRenderer, const uno::Any& rSelection,
-                                                                                const uno::Sequence< beans::PropertyValue >& rxOptions )
+uno::Sequence< beans::PropertyValue > SAL_CALL SdXImpressDocument::getRenderer( sal_Int32 /*nRenderer*/, const uno::Any& /*rSelection*/,
+                                                                                const uno::Sequence< beans::PropertyValue >& /*rxOptions*/ )
     throw (lang::IllegalArgumentException, uno::RuntimeException)
 {
     ::SolarMutexGuard aGuard;
@@ -1386,7 +1330,7 @@ IMPL_LINK( ImplRenderPaintProc, _ImplRenderPaintProc, SdrPaintProcRec*, pRecord
     return 0;
 }
 
-void SAL_CALL SdXImpressDocument::render( sal_Int32 nRenderer, const uno::Any& rSelection,
+void SAL_CALL SdXImpressDocument::render( sal_Int32 nRenderer, const uno::Any& /*rSelection*/,
                                           const uno::Sequence< beans::PropertyValue >& rxOptions )
     throw (lang::IllegalArgumentException, uno::RuntimeException)
 {
@@ -1413,7 +1357,7 @@ void SAL_CALL SdXImpressDocument::render( sal_Int32 nRenderer, const uno::Any& r
 
             if( pOut )
             {
-                DBG_BF_ASSERT(0, "STRIP"); //STRIP001 SdClientView*			pView = new SdClientView( pDocShell, pOut, NULL );
+                DBG_BF_ASSERT(0, "STRIP");
             }
         }
     }
@@ -1842,7 +1786,6 @@ uno::Reference< drawing::XDrawPage > SAL_CALL SdMasterPagesAccess::insertNewByIn
                                 pRefNotesPage->GetRgtBorder(),
                                 pRefNotesPage->GetLwrBorder() );
         pDoc->InsertMasterPage(pMNotesPage,  nInsertPos + 1);
-//		pMNotesPage->InsertMasterPage( pMPage->GetPageNum() );
         pMNotesPage->SetLayoutName( aLayoutName );
         pMNotesPage->SetAutoLayout(AUTOLAYOUT_NOTES, sal_True, sal_True);
         rModel.SetModified();
