@@ -124,7 +124,6 @@ void RectConvertMappings(LPRECT pRect, HDC hDC, WIN_BOOL fToDevice)
         {
         hDC=GetDC(NULL);
         SetMapMode(hDC, MM_HIMETRIC);
-        //SetMapMode(hDC, MM_LOMETRIC);
         fSysDC=TRUE;
         }
 
@@ -155,7 +154,6 @@ void RectConvertMappings(LPRECT pRect, HDC hDC, WIN_BOOL fToDevice)
  */
 
 CSO_Cont::CSO_Cont(DWORD dwID, HWND hWnd, SvOutPlaceObject * pPG)
-//CSO_Cont::CSO_Cont(DWORD dwID, HWND hWnd, PCPages pPG)
     {
     m_hWnd=hWnd;
     m_dwID=dwID;
@@ -170,7 +168,6 @@ CSO_Cont::CSO_Cont(DWORD dwID, HWND hWnd, SvOutPlaceObject * pPG)
     m_clsID=CLSID_NULL;
     m_fSetExtent=FALSE;
 
-    //CHAPTER17MOD
     m_cRef=0;
     m_pIOleObject=NULL;
     m_pIViewObject2=NULL;
@@ -180,27 +177,22 @@ CSO_Cont::CSO_Cont(DWORD dwID, HWND hWnd, SvOutPlaceObject * pPG)
     m_pImpIAdviseSink=NULL;
 
     m_fRepaintEnabled=TRUE;
-    //End CHAPTER17MOD
+
     return;
     }
 
 
 CSO_Cont::~CSO_Cont(void)
     {
-    //CHAPTER17MOD
     //Object pointers cleaned up in Close.
-
     DeleteInterfaceImp(m_pImpIAdviseSink);
     DeleteInterfaceImp(m_pImpIOleClientSite);
-    //End CHAPTER17MOD
 
     return;
     }
 
 
 
-
-//CHAPTER17MOD
 /*
  * CSO_Cont::QueryInterface
  * CSO_Cont::AddRef
@@ -247,10 +239,6 @@ STDMETHODIMP_(ULONG) CSO_Cont::Release(void)
     return 0;
     }
 
-//End CHAPTER17MOD
-
-
-
 
 
 /*
@@ -278,7 +266,6 @@ DWORD CSO_Cont::GetID(void)
  *  UINT            Number of characters stored.
  */
 
-//UINT CSO_Cont::GetStorageName(LPOLESTR pszName)
 String CSO_Cont::GetStorageName()
 {
     // used in SvOutPlaceObject too, don't change name
@@ -286,41 +273,6 @@ String CSO_Cont::GetStorageName()
 }
 
 
-
-//CHAPTER17MOD
-/*
- * CSO_Cont::StorageGet
- *
- * Purpose:
- *  Returns the IStorage pointer maintained by this tenant,
- *  AddRef'd of course.
- *
- * Parameters:
- *  ppStg           LPSTORAGE * in which to return the pointer.
- *
- * Return Value:
- *  None
- */
-
-/* MM ???
-void CSO_Cont::StorageGet(LPSTORAGE *ppStg)
-    {
-    if (NULL==ppStg)
-        return;
-
-    *ppStg=m_pIStorage;
-
-    if (NULL!=*ppStg)
-        (*ppStg)->AddRef();
-
-    return;
-    }
-*/
-//End CHAPTER17MOD
-
-
-
-
 /*
  * CSO_Cont::Create
  *
@@ -352,14 +304,10 @@ void CSO_Cont::StorageGet(LPSTORAGE *ppStg)
 UINT CSO_Cont::Create(TENANTTYPE tType, LPVOID pvType
     , LPFORMATETC pFE, PPOINTL pptl, LPSIZEL pszl
     , SotStorage * pIStorage, PPATRONOBJECT ppo, DWORD dwData)
-//    , LPSTORAGE pIStorage, PPATRONOBJECT ppo, DWORD dwData)
     {
     HRESULT             hr;
     LPUNKNOWN           pObj = NULL;
     UINT                uRet=CREATE_GRAPHICONLY;
-    //CHAPTER17MOD
-    //Some things moves to ObjectInitialize
-    //End CHAPTER17MOD
 
     if (NULL==pvType || NULL==pIStorage)
         return CREATE_FAILED;
@@ -519,8 +467,6 @@ WIN_BOOL CSO_Cont::Save(SotStorage *pIStorage)
         xStm->SetSize( 0 );
         ULONG nMaxLen = GlobalSize( hGlobal );
         xStm->Write( pMem, nMaxLen );
-//SvFileStream aFS( "d:\\temp\\test.ttt", STREAM_STD_READWRITE );
-//aFS.Write( pMem, nMaxLen );
         GlobalUnlock( hGlobal );
 
         return TRUE;
@@ -577,7 +523,6 @@ WIN_BOOL CSO_Cont::Load(SotStorage *pIStorage, DWORD dwAspect, WIN_BOOL fSetExte
         if (NULL!=m_pIViewObject2)
             {
             m_pIViewObject2->SetAdvise(dwAspect, 0, NULL);
-//            m_pIViewObject2->SetAdvise(m_fe.dwAspect, 0, NULL);
             ReleaseInterface(m_pIViewObject2);
             }
 
@@ -604,18 +549,13 @@ WIN_BOOL CSO_Cont::Load(SotStorage *pIStorage, DWORD dwAspect, WIN_BOOL fSetExte
         return FALSE;
         }
 
-    //CHAPTER17MOD
     m_fSetExtent=fSetExtent;
-    //m_fSetExtent=pti->fSetExtent;
     ObjectInitialize(pObj, dwAspect, NULL);
-    //ObjectInitialize(pObj, &pti->fe, NULL);
 
     //Restore the original state before reloading.
     m_dwState=dwState;
-    //End CHAPTER17MOD
 
     RectSet(&rcl, FALSE, FALSE);
-    //RectSet(&pti->rcl, FALSE, FALSE);
     return TRUE;
     }
 
@@ -635,28 +575,12 @@ WIN_BOOL CSO_Cont::Load(SotStorage *pIStorage, DWORD dwAspect, WIN_BOOL fSetExte
  *  None
  */
 
-//void CSO_Cont::GetInfo(PTENANTINFO pti)
 void CSO_Cont::GetInfo(DWORD& rAspect, WIN_BOOL & rSetExtend )
 {
     rAspect = dwAspect;
     rSetExtend = m_fSetExtent;
-    /*
-    if (NULL!=pti)
-        {
-        pti->dwID=m_dwID;
-        pti->rcl=m_rcl;
-        pti->fe=m_fe;
-        pti->fSetExtent=m_fSetExtent;
-        }
-
-    return;
-    */
 }
 
-
-
-
-//CHAPTER17MOD
 /*
  * CSO_Cont::ObjectInitialize
  * (Protected)
@@ -675,22 +599,15 @@ void CSO_Cont::GetInfo(DWORD& rAspect, WIN_BOOL & rSetExtend )
  *  WIN_BOOL            TRUE if the function succeeded, FALSE otherwise.
  */
 
-//WIN_BOOL CSO_Cont::ObjectInitialize(LPUNKNOWN pObj, LPFORMATETC pFE, DWORD dwData)
 WIN_BOOL CSO_Cont::ObjectInitialize(LPUNKNOWN pObj, DWORD dwAspect_, DWORD dwData)
     {
     HRESULT         hr;
     LPPERSIST       pIPersist=NULL;
     DWORD           dw;
-    //PCDocument      pDoc;
     TCHAR           szFile[CCHPATHMAX];
 
-    //if (NULL==pObj || NULL==pFE)
-    //    return FALSE;
-
     m_pObj=pObj;
     dwAspect = dwAspect_;
-    //m_fe=*pFE;
-    //m_fe.ptd=NULL;
     m_dwState=TENANTSTATE_DEFAULT;
 
     /*
@@ -724,7 +641,6 @@ WIN_BOOL CSO_Cont::ObjectInitialize(LPUNKNOWN pObj, DWORD dwAspect_, DWORD dwDat
         return FALSE;
 
     m_pIViewObject2->SetAdvise(dwAspect, 0, m_pImpIAdviseSink);
-    //m_pIViewObject2->SetAdvise(m_fe.dwAspect, 0, m_pImpIAdviseSink);
 
     IOleCache* pIOleCache = NULL;
     if ( SUCCEEDED(m_pIViewObject2->QueryInterface(IID_IOleCache, (PPVOID)&pIOleCache)) && pIOleCache )
@@ -753,15 +669,6 @@ WIN_BOOL CSO_Cont::ObjectInitialize(LPUNKNOWN pObj, DWORD dwAspect_, DWORD dwDat
             DWORD nConn;
             FORMATETC aFormat = { 0, 0, ASPECT_CONTENT, -1, TYMED_MFPICT };
             hr = pIOleCache->Cache( &aFormat, /*ADVFCACHE_FORCEBUILTIN*/ /*ADVF_PRIMEFIRST*/ ADVFCACHE_ONSAVE, &nConn );
-/*
-            IDataObject* pIDataObject = NULL;
-            if ( SUCCEEDED(pObj->QueryInterface(IID_IDataObject, (PPVOID)&pIDataObject)) && pIDataObject )
-            {
-                pIOleCache->InitCache( pIDataObject );
-                pIDataObject->Release();
-                pIDataObject = NULL;
-            }
-*/
         }
 
         pIOleCache->Release();
@@ -788,11 +695,9 @@ WIN_BOOL CSO_Cont::ObjectInitialize(LPUNKNOWN pObj, DWORD dwAspect_, DWORD dwDat
      * remember to draw it properly and do extents right.
      */
     m_pIOleObject->GetMiscStatus(dwAspect, &m_grfMisc);
-    //m_pIOleObject->GetMiscStatus(m_fe.dwAspect, &m_grfMisc);
 
     if (OLEMISC_ONLYICONIC & m_grfMisc)
         dwAspect=DVASPECT_ICON;
-        //m_fe.dwAspect=DVASPECT_ICON;
 
     /*
      * We could pass m_pImpIOleClientSite in an OleCreate* call, but
@@ -814,14 +719,6 @@ WIN_BOOL CSO_Cont::ObjectInitialize(LPUNKNOWN pObj, DWORD dwAspect_, DWORD dwDat
      * Roundabout, but it works.
      */
 
-    /* MM ???
-    pDoc=(PCDocument)SendMessage(GetParent(m_hWnd), DOCM_PDOCUMENT
-        , 0, 0L);
-
-    if (NULL!=pDoc)
-        pDoc->FilenameGet(szFile, CCHPATHMAX);
-    else
-    */
         szFile[0]=0;
 
     NotifyOfRename(szFile, NULL);
@@ -838,7 +735,6 @@ WIN_BOOL CSO_Cont::ObjectInitialize(LPUNKNOWN pObj, DWORD dwAspect_, DWORD dwDat
      * a view advise.
      */
 
-    //if (DVASPECT_ICON & m_fe.dwAspect)
     if (DVASPECT_ICON & dwAspect)
         {
         DWORD           dw=DVASPECT_CONTENT;
@@ -853,9 +749,6 @@ WIN_BOOL CSO_Cont::ObjectInitialize(LPUNKNOWN pObj, DWORD dwAspect_, DWORD dwDat
 
     return TRUE;
     }
-//End CHAPTER17MOD
-
-
 
 
 /*
@@ -878,16 +771,8 @@ WIN_BOOL CSO_Cont::ObjectInitialize(LPUNKNOWN pObj, DWORD dwAspect_, DWORD dwDat
  *  WIN_BOOL            TRUE if opening succeeds, FALSE otherwise.
  */
 
-//WIN_BOOL CSO_Cont::Open(LPSTORAGE pIStorage)
 WIN_BOOL CSO_Cont::Open(SotStorage * pIStorage)
     {
-    /*
-    HRESULT     hr=NOERROR;
-    DWORD       dwMode=STGM_TRANSACTED | STGM_READWRITE
-                    | STGM_SHARE_EXCLUSIVE;
-    OLECHAR     szTemp[32];
-    */
-
     if (NULL==m_pIStorage)
         {
         if (NULL==pIStorage)
@@ -899,8 +784,6 @@ WIN_BOOL CSO_Cont::Open(SotStorage * pIStorage)
          * IStorage that we either save in pPage or release.
          */
 
-//		StgCreateDocfile( "d:\\temp\\test.ttt", STGM_CREATE | STGM_READWRITE | STGM_SHARE_EXCLUSIVE, NULL, &m_pIStorage );
-
         SotStorageStreamRef xStm;
         String szTemp = GetStorageName();
         if( pIStorage->IsContained( szTemp ) )
@@ -956,20 +839,6 @@ WIN_BOOL CSO_Cont::Open(SotStorage * pIStorage)
                 &m_pIStorage	//Indirect pointer to the new storage object
             );
         }
-
-        /* MM ??? StgOpenStorage
-        GetStorageName(szTemp);
-        hr=pIStorage->OpenStorage(szTemp, NULL, dwMode, NULL, 0
-            , &m_pIStorage);
-
-        if (FAILED(hr))
-            {
-            hr=pIStorage->CreateStorage(szTemp, dwMode, 0, 0
-                , &m_pIStorage);
-            }
-        if (FAILED(hr))
-            return FALSE;
-        */
         }
     else
     {
@@ -980,7 +849,6 @@ WIN_BOOL CSO_Cont::Open(SotStorage * pIStorage)
 
     m_cOpens++;
 
-    //CHAPTER17MOD
     //Create these if we don't have them already.
     if (NULL==m_pImpIOleClientSite && NULL==m_pImpIAdviseSink)
         {
@@ -990,7 +858,6 @@ WIN_BOOL CSO_Cont::Open(SotStorage * pIStorage)
         if (NULL==m_pImpIOleClientSite || NULL==m_pImpIAdviseSink)
             return FALSE;
         }
-    //End CHAPTER17MOD
 
     return TRUE;
     }
@@ -1030,7 +897,6 @@ void CSO_Cont::Close(WIN_BOOL fCommit)
          * We can't use a zero reference count to know when to NULL
          * this since other things might have AddRef'd the storage.
          */
-        //CHAPTER17MOD
         if (0==--m_cOpens)
             {
             m_pIStorage=NULL;
@@ -1047,13 +913,11 @@ void CSO_Cont::Close(WIN_BOOL fCommit)
             if (NULL!=m_pIViewObject2)
                 {
                 m_pIViewObject2->SetAdvise(dwAspect, 0, NULL);
-                //m_pIViewObject2->SetAdvise(m_fe.dwAspect, 0, NULL);
                 ReleaseInterface(m_pIViewObject2);
                 }
 
             ReleaseInterface(m_pObj);
             }
-        //End CHAPTER17MOD
         }
 
     return;
@@ -1075,7 +939,6 @@ void CSO_Cont::Close(WIN_BOOL fCommit)
  *  WIN_BOOL            TRUE if the object is open, FALSE otherwise.
  */
 
-//WIN_BOOL CSO_Cont::Update(void)
 WIN_BOOL CSO_Cont::Update()
     {
     Save( m_pPG->GetWorkingStorage());
@@ -1106,15 +969,12 @@ WIN_BOOL CSO_Cont::Update()
  *  None
  */
 
-//void CSO_Cont::Destroy(LPSTORAGE pIStorage)
 void CSO_Cont::Destroy(SotStorage * pIStorage)
     {
     if (NULL!=pIStorage)
         {
-        //CHAPTER17MOD
         if (NULL!=m_pIOleObject)
             m_pIOleObject->Close(OLECLOSE_NOSAVE);
-        //End CHAPTER17MOD
 
         if (NULL!=m_pIStorage)
             {
@@ -1129,8 +989,6 @@ void CSO_Cont::Destroy(SotStorage * pIStorage)
 
         String szTemp = GetStorageName();
         pIStorage->Remove(szTemp);
-        //GetStorageName(szTemp);
-        //pIStorage->DestroyElement(szTemp);
 
         m_pIStorage=NULL;
         pTmpStorage = NULL;
@@ -1178,21 +1036,8 @@ void CSO_Cont::Select(WIN_BOOL fSelect)
     RECTFROMRECTL(rc, m_rcl);
     RectConvertMappings(&rc, NULL, TRUE);
 
-    /* MM ???
-    OffsetRect(&rc, -(int)m_pPG->m_xPos, -(int)m_pPG->m_yPos);
-
-    hDC=GetDC(m_hWnd);
-
-    UIDrawHandles(&rc, hDC, UI_HANDLES_INSIDE
-        | UI_HANDLES_NOBORDER | UI_HANDLES_USEINVERSE
-        , CXYHANDLE, !fWasSelected);
-
-    ReleaseDC(m_hWnd, hDC);
-    */
-
     if (fSelect)
         m_pPG->SetModified();
-        //m_pPG->m_fDirty=TRUE;
 
     return;
     }
@@ -1200,7 +1045,6 @@ void CSO_Cont::Select(WIN_BOOL fSelect)
 
 
 
-//CHAPTER17MOD
 /*
  * CSO_Cont::ShowAsOpen
  *
@@ -1230,13 +1074,6 @@ void CSO_Cont::ShowAsOpen(WIN_BOOL fOpen)
         {
         RECTFROMRECTL(rc, m_rcl);
         RectConvertMappings(&rc, NULL, TRUE);
-        /* MM ???
-        OffsetRect(&rc, -(int)m_pPG->m_xPos, -(int)m_pPG->m_yPos);
-
-        hDC=GetDC(m_hWnd);
-        UIDrawShading(&rc, hDC, UI_SHADE_FULLRECT, 0);
-        ReleaseDC(m_hWnd, hDC);
-        */
         }
 
     if (fWasOpen && !fOpen)
@@ -1286,27 +1123,6 @@ void CSO_Cont::ShowYourself(void)
 
     //Get the window rectangle offset for the current scroll pos.
     GetClientRect(m_hWnd, &rc);
-    /* MM ???
-    OffsetRect(&rc, m_pPG->m_xPos, m_pPG->m_yPos);
-
-    //Check if the object is already visible. (macro in bookguid.h)
-    SETPOINT(pt1, (int)rcl.left,  (int)rcl.top);
-    SETPOINT(pt2, (int)rcl.right, (int)rcl.bottom);
-
-    if (PtInRect(&rc, pt1) && PtInRect(&rc, pt2))
-        return;
-
-    //Check if the upper left is within the upper left quadrant
-    if (((int)rcl.left > rc.left
-        && (int)rcl.left < ((rc.right+rc.left)/2))
-        && ((int)rcl.top > rc.top
-        && (int)rcl.top < ((rc.bottom+rc.top)/2)))
-        return;
-
-    //These are macros in INC\BOOK1632.H
-    SendScrollPosition(m_hWnd, WM_HSCROLL, rcl.left-8);
-    SendScrollPosition(m_hWnd, WM_VSCROLL, rcl.top-8);
-    */
     return;
     }
 
@@ -1329,19 +1145,6 @@ void CSO_Cont::ShowYourself(void)
 
 void CSO_Cont::AddVerbMenu(HMENU, UINT)
     {
-    /* MM ???
-    HMENU       hMenuTemp;
-    LPOLEOBJECT pObj=m_pIOleObject;
-
-    //If we're static, say we have no object.
-    if (TENANTTYPE_STATIC==m_tType)
-        pObj=NULL;
-
-    OleUIAddVerbMenu(pObj, NULL, hMenu, iPos, IDM_VERBMIN
-        , IDM_VERBMAX, TRUE, IDM_EDITCONVERT, &hMenuTemp);
-
-    return;
-    */
     }
 
 
@@ -1506,13 +1309,11 @@ void CSO_Cont::NotifyOfRename(LPTSTR pszFile, LPVOID)
         {
         // MM ???
         lstrcpyn( szObj, "untitled", SAL_N_ELEMENTS(szObj) );
-        //LoadString(m_pPG->m_hInst, IDS_UNTITLED, szObj, sizeof(szObj));
         }
     else
         {
         // MM ???
         lstrcpyn( szObj, "untitled", SAL_N_ELEMENTS(szObj) );
-        //GetFileTitle(pszFile, szObj, sizeof(szObj));
 
        #ifndef WIN32
         //Force filenames to uppercase in DOS versions.
@@ -1522,7 +1323,6 @@ void CSO_Cont::NotifyOfRename(LPTSTR pszFile, LPVOID)
 
     // MM ???
     lstrcpyn( szApp, "app name", SAL_N_ELEMENTS(szApp) );
-    //LoadString(m_pPG->m_hInst, IDS_CAPTION, szApp, sizeof(szApp));
    #ifdef WIN32ANSI
     OLECHAR     szObjW[40], szAppW[40];
 
@@ -1535,11 +1335,6 @@ void CSO_Cont::NotifyOfRename(LPTSTR pszFile, LPVOID)
     return;
     }
 
-//End CHAPTER17MOD
-
-
-
-
 
 /*
  * CSO_Cont::Activate
@@ -1558,9 +1353,7 @@ void CSO_Cont::NotifyOfRename(LPTSTR pszFile, LPVOID)
 
 WIN_BOOL CSO_Cont::Activate(LONG iVerb, HWND hParent )
     {
-    //CHAPTER17MOD
     RECT        rc, rcH;
-    //CHourglass *pHour;
     SIZEL       szl;
 
     //Can't activate statics.
@@ -1574,8 +1367,6 @@ WIN_BOOL CSO_Cont::Activate(LONG iVerb, HWND hParent )
     RectConvertMappings(&rc, NULL, TRUE);
     SO_MetricRectInPixelsToHimetric( &rc, &rcH);
 
-    //pHour=new CHourglass;
-
     //Get the server running first, then do a SetExtent, then show it
     OleRun(m_pIOleObject);
 
@@ -1583,7 +1374,6 @@ WIN_BOOL CSO_Cont::Activate(LONG iVerb, HWND hParent )
         {
         SETSIZEL(szl, rcH.right-rcH.left, rcH.top-rcH.bottom);
         m_pIOleObject->SetExtent(dwAspect, &szl);
-        //m_pIOleObject->SetExtent(m_fe.dwAspect, &szl);
         m_fSetExtent=FALSE;
         }
 
@@ -1596,7 +1386,6 @@ WIN_BOOL CSO_Cont::Activate(LONG iVerb, HWND hParent )
 
     //If object changes, IAdviseSink::OnViewChange will see it.
     return SUCCEEDED( hr );
-    //End CHAPTER17MOD
     }
 
 
@@ -1662,15 +1451,6 @@ void CSO_Cont::Draw(HDC hDC, DVTARGETDEVICE *ptd, HDC hIC
     RECTL           rcl = { 0, 0, xOff, -yOff };
     UINT            uMM;
 
-    //CHAPTER17MOD
-    //We hold IViewObject2 all the time now, so no QueryInterface
-    //End CHAPTER17MOD
-
-    //RECTFROMRECTL(rc, m_rcl);
-    //OffsetRect(&rc, -xOff, -yOff);
-    //RECTLFROMRECT(rcl, rc);
-
-    //CHAPTER17MOD
     //Repaint erases the rectangle to insure full object cleanup
 
     if (!fNoColor && !fPrinter)
@@ -1684,9 +1464,6 @@ void CSO_Cont::Draw(HDC hDC, DVTARGETDEVICE *ptd, HDC hIC
 
     //We have to use Draw since we have a target device and IC.
     hr=m_pIViewObject2->Draw(dwAspect, -1, NULL, ptd, hIC, hDC, NULL, &rcl, NULL, 0);
-    //hr=m_pIViewObject2->Draw(dwAspect, -1, NULL, ptd, hIC, hDC, &rcl, NULL, NULL, 0);
-
-    //End CHAPTER17MOD
 
     /*
      * If Draw failed, then perhaps it couldn't work for the device,
@@ -1695,9 +1472,7 @@ void CSO_Cont::Draw(HDC hDC, DVTARGETDEVICE *ptd, HDC hIC
      */
     if (FAILED(hr))
         OleDraw(m_pObj, dwAspect, hDC, &rc);
-        //OleDraw(m_pObj, m_fe.dwAspect, hDC, &rc);
 
-    //CHAPTER17MOD
     if (!fPrinter
         && (TENANTSTATE_SELECTED | TENANTSTATE_OPEN) & m_dwState)
         {
@@ -1721,7 +1496,6 @@ void CSO_Cont::Draw(HDC hDC, DVTARGETDEVICE *ptd, HDC hIC
 
         uMM=SetMapMode(hDC, uMM);
         }
-    //End CHAPTER17MOD
 
     return;
     }
@@ -1748,7 +1522,6 @@ void CSO_Cont::Draw(HDC hDC, DVTARGETDEVICE *ptd, HDC hIC
 void CSO_Cont::Repaint(void)
     {
 
-    //CHAPTER17MOD
     /*
      * We might be asked to repaint from
      * IOleClientSite::OnShowWindow after we've switched pages if
@@ -1756,18 +1529,7 @@ void CSO_Cont::Repaint(void)
      */
     if (0==m_cOpens || !m_fRepaintEnabled)
         return;
-    //End CHAPTER17MOD
 
-    /* MM ???
-    hDC=GetDC(m_hWnd);
-    SetRect(&rc, m_pPG->m_xPos, m_pPG->m_yPos, 0, 0);
-    RectConvertMappings(&rc, NULL, FALSE);
-
-    SetMapMode(hDC, MM_LOMETRIC);
-    Draw(hDC, NULL, NULL, rc.left, rc.top, FALSE, FALSE);
-
-    ReleaseDC(m_hWnd, hDC);
-    */
     return;
     }
 
@@ -1780,18 +1542,12 @@ void CSO_Cont::Invalidate(void)
     RectGet(&rcl, TRUE);
     RECTFROMRECTL(rc, rcl);
 
-    /* MMM ???
-    OffsetRect(&rc, -(int)m_pPG->m_xPos, -(int)m_pPG->m_yPos);
-    InvalidateRect(m_hWnd, &rc, FALSE);
-    */
-
     return;
     }
 
 
 
 
-//CHAPTER17MOD
 /*
  * CSO_Cont::ObjectClassFormatAndIcon
  *
@@ -1925,12 +1681,10 @@ WIN_BOOL CSO_Cont::SwitchOrUpdateAspect(HGLOBAL hMetaIcon
     WIN_BOOL        fUpdate=FALSE;
 
     //Nothing to do if we're content already and there's no icon.
-    //if (NULL==hMetaIcon && DVASPECT_CONTENT==m_fe.dwAspect)
     if (NULL==hMetaIcon && DVASPECT_CONTENT==dwAspect)
         return FALSE;
 
     //If we're iconic already, just cache the new icon
-    //if (NULL!=hMetaIcon && DVASPECT_ICON==m_fe.dwAspect)
     if (NULL!=hMetaIcon && DVASPECT_ICON==dwAspect)
         hr=StarObject_SetIconInCache(m_pIOleObject, hMetaIcon);
     else
@@ -1944,14 +1698,12 @@ WIN_BOOL CSO_Cont::SwitchOrUpdateAspect(HGLOBAL hMetaIcon
          */
         hr=StarObject_SwitchDisplayAspect(m_pIOleObject
             , &dwAspect, dwAspect, hMetaIcon, !fPreserve
-            //, &m_fe.dwAspect, dwAspect, hMetaIcon, !fPreserve
             , TRUE, m_pImpIAdviseSink, &fUpdate);
 
         if (SUCCEEDED(hr))
             {
             //Update MiscStatus for the new aspect
             m_pIOleObject->GetMiscStatus(dwAspect, &m_grfMisc);
-            //m_pIOleObject->GetMiscStatus(m_fe.dwAspect, &m_grfMisc);
 
             if (fUpdate)
                 m_pIOleObject->Update();    //This repaints.
@@ -1964,15 +1716,11 @@ WIN_BOOL CSO_Cont::SwitchOrUpdateAspect(HGLOBAL hMetaIcon
         SIZEL       szl;
 
         m_pIOleObject->GetExtent(dwAspect, &szl);
-        //m_pIOleObject->GetExtent(m_fe.dwAspect, &szl);
 
         if (0 > szl.cy)
             szl.cy=-szl.cy;
 
         //Convert HIMETRIC absolute units to our LOMETRIC mapping
-        //if (0!=szl.cx && 0!=szl.cy)
-        //    SETSIZEL(szl, szl.cx/10, -szl.cy/10);
-
         Invalidate();                   //Remove old aspect
         SizeSet(&szl, FALSE, FALSE);    //Change size
         Repaint();                      //Paint the new one
@@ -2003,13 +1751,6 @@ void CSO_Cont::EnableRepaint(WIN_BOOL fEnable)
     m_fRepaintEnabled=fEnable;
     return;
     }
-//End CHAPTER17MOD
-
-
-
-
-
-
 
 
 /*
@@ -2061,9 +1802,7 @@ void CSO_Cont::FormatEtcGet(LPFORMATETC pFE, WIN_BOOL fPresentation)
     if (NULL!=pFE)
         {
         SETDefFormatEtc(*pFE, 0, TYMED_NULL);
-        //*pFE=m_fe;
 
-        //CHAPTER17MOD
         //If there is no format, use metafile (for embedded objects)
         if (fPresentation || 0==pFE->cfFormat)
             {
@@ -2071,7 +1810,6 @@ void CSO_Cont::FormatEtcGet(LPFORMATETC pFE, WIN_BOOL fPresentation)
             pFE->cfFormat=CF_METAFILEPICT;
             pFE->tymed=TYMED_MFPICT;
             }
-        //End CHAPTER17MOD
         }
 
     return;
@@ -2082,7 +1820,6 @@ void CSO_Cont::FormatEtcGet(LPFORMATETC pFE, WIN_BOOL fPresentation)
 
 WIN_BOOL CSO_Cont::GetExtent(LPSIZEL pszl)
 {
-    //SETSIZEL((*pszl), 2*LOMETRIC_PER_INCH, 2*LOMETRIC_PER_INCH);
     SETSIZEL((*pszl), 2*HIMETRIC_PER_INCH, 2*HIMETRIC_PER_INCH);
     SIZEL szl = SIZEL();
     HRESULT hr=ResultFromScode(E_FAIL);
@@ -2091,19 +1828,15 @@ WIN_BOOL CSO_Cont::GetExtent(LPSIZEL pszl)
     if (NULL!=m_pIViewObject2)
         {
         hr = m_pIViewObject2->GetExtent(dwAspect, -1, NULL, &szl);
-        //hr=m_pIViewObject2->GetExtent(m_fe.dwAspect, -1, NULL, &szl);
         }
     else
         {
         if (NULL!=m_pIOleObject)
             hr = m_pIOleObject->GetExtent(dwAspect, &szl);
-            //hr=m_pIOleObject->GetExtent(m_fe.dwAspect, &szl);
         }
     if (SUCCEEDED(hr))
         {
         *pszl = szl;
-        //Convert HIMETRIC to our LOMETRIC mapping
-        //SETSIZEL((*pszl), szl.cx/10, szl.cy/10);
         }
 
     return SUCCEEDED( hr );
@@ -2155,9 +1888,7 @@ void CSO_Cont::SizeGet(LPSIZEL pszl, WIN_BOOL fDevice)
     return;
     }
 
-//CHAPTER17MOD
 void CSO_Cont::SizeSet(LPSIZEL pszl, WIN_BOOL fDevice, WIN_BOOL fInformObj)
-//End CHAPTER17MOD
     {
     SIZEL           szl;
 
@@ -2182,15 +1913,11 @@ void CSO_Cont::SizeSet(LPSIZEL pszl, WIN_BOOL fDevice, WIN_BOOL fInformObj)
 
 
     //Tell OLE that this object was resized.
-    //CHAPTER17MOD
     if (NULL!=m_pIOleObject && fInformObj)
         {
         HRESULT     hr;
         WIN_BOOL        fRun=FALSE;
 
-        //Convert our LOMETRIC into HIMETRIC by *=10
-        //szl.cx*=10;
-        //szl.cy*=-10;    //Our size is stored negative.
         if( szl.cy < 0 )
             szl.cy *= -1;
 
@@ -2212,7 +1939,6 @@ void CSO_Cont::SizeSet(LPSIZEL pszl, WIN_BOOL fDevice, WIN_BOOL fInformObj)
             }
 
         hr=m_pIOleObject->SetExtent(dwAspect, &szl);
-        //hr=m_pIOleObject->SetExtent(m_fe.dwAspect, &szl);
 
         /*
          * If the object is not running and it does not have
@@ -2236,7 +1962,6 @@ void CSO_Cont::SizeSet(LPSIZEL pszl, WIN_BOOL fDevice, WIN_BOOL fInformObj)
                 m_fSetExtent=TRUE;
             }
         }
-    //End CHAPTER17MOD
 
     return;
     }
@@ -2259,9 +1984,7 @@ void CSO_Cont::RectGet(LPRECTL prcl, WIN_BOOL fDevice)
     }
 
 
-//CHAPTER17MOD
 void CSO_Cont::RectSet(LPRECTL prcl, WIN_BOOL fDevice, WIN_BOOL fInformObj)
-//End CHAPTER17MOD
     {
     SIZEL   szl;
     LONG    cx, cy;
@@ -2287,9 +2010,7 @@ void CSO_Cont::RectSet(LPRECTL prcl, WIN_BOOL fDevice, WIN_BOOL fInformObj)
     if ((m_rcl.right-m_rcl.left)!=cx || (m_rcl.bottom-m_rcl.top)!=cy)
         {
         SETSIZEL(szl, m_rcl.right-m_rcl.left, m_rcl.bottom-m_rcl.top);
-        //CHAPTER17MOD
         SizeSet(&szl, FALSE, fInformObj);
-        //End CHAPTER17MOD
         }
 
     return;
