@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -26,7 +26,7 @@
  *
  ************************************************************************/
 
-#define _TRANSPRT_CXX "$Revision: 1.6 $"
+#define _TRANSPRT_CXX
 
 #include <com/sun/star/beans/PropertyValue.hpp>
 #include <com/sun/star/beans/XPropertiesChangeListener.hpp>
@@ -66,13 +66,12 @@
 #include <osl/mutex.hxx>
 #include <rtl/ref.hxx>
 
-#include <tools/solar.h>
+#include <bf_svtools/bf_solar.h>
 #include <tools/debug.hxx>
 #include <tools/datetime.hxx>
 #include <tools/errcode.hxx>
 #include <tools/errinf.hxx>
 #include <tools/inetmsg.hxx>
-#include <tools/list.hxx>
 #include <tools/stream.hxx>
 #include <tools/string.hxx>
 #include <tools/urlobj.hxx>
@@ -145,13 +144,23 @@ SvBindingTransport::~SvBindingTransport (void)
 SvBindingTransportFactory::SvBindingTransportFactory (void)
 {
     SvBindingTransportFactoryList &rList = BAPP()->m_aTransportFactories;
-    rList.Insert (this, rList.Count());
+    rList.push_back( this );
 }
 
 SvBindingTransportFactory::~SvBindingTransportFactory (void)
 {
     SvBindingTransportFactoryList &rList = BAPP()->m_aTransportFactories;
-    rList.Remove (this);
+    for ( SvBindingTransportFactoryList::iterator it = rList.begin();
+          it < rList.end();
+          ++it
+        )
+    {
+        if ( *it == this )
+        {
+            rList.erase( it );
+            break;
+        }
+    }
 }
 
 SvBindingTransportContext::~SvBindingTransportContext (void)
@@ -170,7 +179,17 @@ SvBindingTransportContext::~SvBindingTransportContext (void)
 SvLockBytesFactory::~SvLockBytesFactory (void)
 {
     SvLockBytesFactoryList &rList = BAPP()->m_aLockBytesFactories;
-    rList.Remove (this);
+    for ( SvLockBytesFactoryList::iterator it = rList.begin();
+          it < rList.end();
+          ++it
+        )
+    {
+        if ( *it == this )
+        {
+            rList.erase( it );
+            break;
+        }
+    }
 }
 
 /*
@@ -181,10 +200,10 @@ SvLockBytesFactory* SvLockBytesFactory::GetFactory (const String &rUrl)
     SvLockBytesFactoryList &rList = BAPP()->m_aLockBytesFactories;
     SvLockBytesFactory *pFactory = NULL;
 
-    ULONG i, n = rList.Count();
+    size_t i, n = rList.size();
     for (i = 0; i < n; i++)
     {
-        pFactory = rList.GetObject(i);
+        pFactory = rList[ i ];
         if (pFactory)
         {
             WildCard aWild (pFactory->GetWildcard());
@@ -1342,8 +1361,8 @@ void UcbTransport_Impl::start (void)
         {
             m_aContentType = getContentType_Impl (xProcessor);
             if (m_aContentType.getLength() == 0)
-                m_aContentType = OUString::createFromAscii(
-                                     CONTENT_TYPE_STR_APP_OCTSTREAM);
+                m_aContentType = OUString(RTL_CONSTASCII_USTRINGPARAM(
+                                     CONTENT_TYPE_STR_APP_OCTSTREAM));
             m_bMimeAvail = sal_True;
             xProps->addPropertiesChangeListener (Sequence<OUString>(), this);
         }
@@ -1356,9 +1375,9 @@ void UcbTransport_Impl::start (void)
         aArgument.Sink = SAL_STATIC_CAST(OWeakObject*, m_xSink.get());
 
         if (m_rCtx.GetBindMode() & SVBIND_NEWESTVERSION)
-            m_aCommand.Name = OUString::createFromAscii ("synchronize");
+            m_aCommand.Name = OUString( RTL_CONSTASCII_USTRINGPARAM( "synchronize" ));
         else
-            m_aCommand.Name = OUString::createFromAscii ("open");
+            m_aCommand.Name = OUString( RTL_CONSTASCII_USTRINGPARAM( "open" ));
         m_aCommand.Handle = -1;
         m_aCommand.Argument <<= aArgument;
 
@@ -1375,7 +1394,7 @@ void UcbTransport_Impl::start (void)
             return;
         }
 
-        m_aCommand.Name = OUString::createFromAscii ("insert");
+        m_aCommand.Name = OUString( RTL_CONSTASCII_USTRINGPARAM( "insert" ));
         m_aCommand.Handle = -1;
         m_aCommand.Argument <<= InsertCommandArgument( Reference<XInputStream> ( new UcbTransportInputStream_Impl(xLockBytes) ),
                                                        sal_False );
@@ -1472,8 +1491,7 @@ void SAL_CALL UcbTransport_Impl::handle ( const Reference<XInteractionRequest> &
                 = Reference< XInteractionHandler >(
                       xFactory->
                           createInstance(
-                              OUString::createFromAscii(
-                                  "com.sun.star.task.InteractionHandler")),
+                              OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.task.InteractionHandler" ))),
                       UNO_QUERY);
     }
     DBG_ASSERT(m_xInteractionHdl.is(),
@@ -1568,7 +1586,7 @@ void SAL_CALL UcbTransport_Impl::propertiesChange ( const Sequence<PropertyChang
     for (i = 0; i < n; i++)
     {
         PropertyChangeEvent evt (rEvent[i]);
-        if (evt.PropertyName == OUString::createFromAscii ("ContentType"))
+        if (evt.PropertyName == OUString( RTL_CONSTASCII_USTRINGPARAM( "ContentType" )))
         {
             if (evt.NewValue >>= m_aContentType)
             {
@@ -1581,7 +1599,7 @@ void SAL_CALL UcbTransport_Impl::propertiesChange ( const Sequence<PropertyChang
             }
             continue;
         }
-        if (evt.PropertyName == OUString::createFromAscii ("DocumentBody"))
+        if (evt.PropertyName == OUString( RTL_CONSTASCII_USTRINGPARAM( "DocumentBody" )))
         {
             if (m_xSink.is())
                 m_xLockBytes = m_xSink->getLockBytes();
@@ -1612,7 +1630,7 @@ OUString UcbTransport_Impl::getContentType_Impl ( const Reference<XCommandProces
     OUString aResult;
     if (rxProcessor.is())
     {
-        OUString aName (OUString::createFromAscii ("ContentType"));
+        OUString aName (OUString( RTL_CONSTASCII_USTRINGPARAM( "ContentType" )));
         Sequence<Property> aProps(1);
 
         aProps[0].Name = aName;
@@ -1753,7 +1771,7 @@ void UcbHTTPTransport_Impl::start (void)
         sal_Int32 n = aProps.getLength();
         aProps.realloc (n + 1);
 
-        aProps[n].Name = OUString::createFromAscii ("Referer");
+        aProps[n].Name = OUString( RTL_CONSTASCII_USTRINGPARAM( "Referer" ));
         aProps[n].Handle = -1;
         aProps[n].Value <<= OUString(aUrl);
     }
@@ -1772,9 +1790,9 @@ void UcbHTTPTransport_Impl::start (void)
         m_xSink = new UcbTransportDataSink_Impl();
 
         if (m_rCtx.GetBindMode() & SVBIND_NEWESTVERSION)
-            m_aCommand.Name = OUString::createFromAscii ("synchronize");
+            m_aCommand.Name = OUString( RTL_CONSTASCII_USTRINGPARAM( "synchronize" ));
         else
-            m_aCommand.Name = OUString::createFromAscii ("open");
+            m_aCommand.Name = OUString( RTL_CONSTASCII_USTRINGPARAM( "open" ));
         m_aCommand.Handle = -1;
 
         OpenCommandArgument2 aArgument;
@@ -1810,7 +1828,7 @@ void UcbHTTPTransport_Impl::start (void)
 
             sal_Int32 n = aProps.getLength();
             aProps.realloc (n + 1);
-            aProps[n].Name = OUString::createFromAscii ("ContentType");
+            aProps[n].Name = OUString( RTL_CONSTASCII_USTRINGPARAM( "ContentType" ));
             aProps[n].Value <<= OUString(aMimeType);
 
             SvBindingTransport_Impl::setProperties (xProcessor, aProps);
@@ -1819,7 +1837,7 @@ void UcbHTTPTransport_Impl::start (void)
 
         if (eAction == BINDACTION_PUT)
         {
-            m_aCommand.Name = OUString::createFromAscii ("insert");
+            m_aCommand.Name = OUString( RTL_CONSTASCII_USTRINGPARAM( "insert" ));
             m_aCommand.Handle = -1;
             m_aCommand.Argument <<= InsertCommandArgument( Reference<XInputStream> ( new UcbTransportInputStream_Impl(xLockBytes)),
                                                            sal_False );
@@ -1828,7 +1846,7 @@ void UcbHTTPTransport_Impl::start (void)
         {
             m_xSink = new UcbTransportDataSink_Impl();
 
-            m_aCommand.Name = OUString::createFromAscii ("post");
+            m_aCommand.Name = OUString( RTL_CONSTASCII_USTRINGPARAM( "post" ));
             m_aCommand.Handle = -1;
 
             PostCommandArgument aArgument;
@@ -1910,7 +1928,7 @@ void SAL_CALL UcbHTTPTransport_Impl::propertiesChange ( const Sequence<PropertyC
     for (i = 0; i < n; i++)
     {
         PropertyChangeEvent evt (rEvent[i]);
-        if (evt.PropertyName == OUString::createFromAscii ("DocumentHeader"))
+        if (evt.PropertyName == OUString( RTL_CONSTASCII_USTRINGPARAM( "DocumentHeader" )))
         {
             Sequence<DocumentHeaderField> aHead;
             if (evt.NewValue >>= aHead)
@@ -1930,12 +1948,12 @@ void SAL_CALL UcbHTTPTransport_Impl::propertiesChange ( const Sequence<PropertyC
             }
             continue;
         }
-        if (evt.PropertyName == OUString::createFromAscii ("PresentationURL"))
+        if (evt.PropertyName == OUString( RTL_CONSTASCII_USTRINGPARAM( "PresentationURL" )))
         {
             OUString aUrl;
             if (evt.NewValue >>= aUrl)
             {
-                OUString aBad (OUString::createFromAscii ("private:"));
+                OUString aBad (OUString( RTL_CONSTASCII_USTRINGPARAM( "private:" )));
                 if (!(aUrl.compareTo (aBad, aBad.getLength()) == 0))
                 {
                     // URL changed (Redirection).
