@@ -86,7 +86,7 @@ SO2_DECL_REF(SvStorage)
 
 #define DOCUMENT_BUFFER_SIZE	(USHORT)32768
 
-static const char __FAR_DATA pStarMathDoc[] = "StarMathDocument";
+static const char pStarMathDoc[] = "StarMathDocument";
 
 
 /**************************************************************************/
@@ -319,8 +319,8 @@ static const char __FAR_DATA pStarMathDoc[] = "StarMathDocument";
 /*N*/ }
 
 
-/*N*/ void SmDocShell::SetPrinter( SfxPrinter *pNew )
-/*N*/ {DBG_BF_ASSERT(0, "STRIP"); //STRIP001
+/*N*/ void SmDocShell::SetPrinter( SfxPrinter * /*pNew*/ )
+/*N*/ {DBG_BF_ASSERT(0, "STRIP");
 /*N*/ }
 
 /*N*/ void SmDocShell::OnDocumentPrinterChanged( Printer *pPrt )
@@ -354,10 +354,10 @@ static const char __FAR_DATA pStarMathDoc[] = "StarMathDocument";
 /*N*/ 	SfxObjectShell(eMode),
 /*N*/ 	pSymSetMgr			( 0 ),
 /*N*/ 	pTree				( 0 ),
-/*N*/ 	pPrinter			( 0 ),
-/*N*/ 	pTmpPrinter			( 0 ),
 /*N*/ 	pEditEngineItemPool	( 0 ),
 /*N*/ 	pEditEngine			( 0 ),
+/*N*/ 	pPrinter			( 0 ),
+/*N*/ 	pTmpPrinter			( 0 ),
 /*N*/ 	nModifyCount		( 0 ),
 /*N*/ 	bIsFormulaArranged	( FALSE )
 /*N*/ {
@@ -432,17 +432,6 @@ static const char __FAR_DATA pStarMathDoc[] = "StarMathDocument";
 /*N*/ 	{
 /*N*/ 		bRet = TRUE;
 /*N*/ 		SetVisArea(Rectangle(Point(0, 0), Size(2000, 1000)));
-/*N*/ #if 0
-/*N*/ 		if (pStor)
-/*N*/ 		{
-/*N*/ 			aDocStream = pStor->OpenStream(String::CreateFromAscii(pStarMathDoc));
-/*N*/ 			aDocStream->SetVersion (pStor->GetVersion ());
-/*N*/ 			GetPool().SetFileFormatVersion(USHORT(pStor->GetVersion()));
-/*N*/
-/*N*/ 			if (! aDocStream )
-/*N*/ 				bRet = FALSE;
-/*N*/ 		}
-/*N*/ #endif
 /*N*/ 	}
 /*N*/ 	return bRet;
 /*N*/ }
@@ -457,7 +446,7 @@ static const char __FAR_DATA pStarMathDoc[] = "StarMathDocument";
 /*N*/ 		if( pStor->IsStream( aTmpStr ))
 /*N*/ 		{
 /*N*/ 			// is this a MathType Storage?
-/*?*/ 			DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/  			MathType aEquation(aText);
+/*?*/ 			DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 		}
 /*N*/ 		else if( pStor->IsStream(C2S("content.xml")) ||
 /*N*/ 				 pStor->IsStream(C2S("Content.xml")) )
@@ -570,79 +559,9 @@ static const char __FAR_DATA pStarMathDoc[] = "StarMathDocument";
 /*N*/ }
 
 
-/*N*/ BOOL SmDocShell::SaveAs(SvStorage * pNewStor)
-/*N*/ {
-/*N*/ 	BOOL bRet = FALSE;
-/*N*/
-/*N*/     //! apply latest changes if necessary
-/*N*/     UpdateText();
-/*N*/
-/*N*/     if ( SfxInPlaceObject::SaveAs( pNewStor ) )
-/*N*/ 	{
-/*N*/ 		if( !pTree )
-/*?*/ 			Parse();
-/*N*/ 		if( pTree && !IsFormulaArranged() )
-/*?*/ 			ArrangeFormula();
-/*N*/
-/*N*/ 		if (pNewStor->GetVersion() >= SOFFICE_FILEFORMAT_60)
-/*N*/ 		{
-/*N*/ 			// a math package as a storage
-/*?*/              Reference< ::com::sun::star::frame::XModel> xModel(GetModel());
-/*?*/  			SmXMLWrapper aEquation(xModel);
-/*?*/  			SfxMedium aMedium(pNewStor);
-/*?*/  			aEquation.SetFlat(sal_False);
-/*?*/  			bRet = aEquation.Export(aMedium);
-/*N*/ 		}
-/*N*/ 		else
-/*N*/ 		{
-/*N*/ 			SvStorageStreamRef aStm = pNewStor->OpenStream(
-/*N*/ 										String::CreateFromAscii(pStarMathDoc));
-/*N*/ 			aStm->SetVersion( pNewStor->GetVersion() );
-/*N*/ 			GetPool().SetFileFormatVersion( USHORT( pNewStor->GetVersion() ));
-/*N*/ 			aStm->SetBufferSize(DOCUMENT_BUFFER_SIZE);
-/*N*/ 			aStm->SetKey( pNewStor->GetKey() ); // Passwort setzen
-/*N*/
-/*N*/ 			if ( aStm.Is() )
-/*N*/ 			{
-/*N*/ 				ImplSave( aStm );
-/*N*/ 				bRet = TRUE;
-/*N*/ 			}
-/*N*/ 		}
-/*N*/ 	}
-/*N*/ 	return bRet;
-/*N*/ }
-
-
-/*N*/ BOOL SmDocShell::SaveCompleted(SvStorage * pStor)
-/*N*/ {
-/*N*/ 	if( SfxInPlaceObject::SaveCompleted( pStor ))
-/*N*/ 	{
-/*N*/ #if 0
-/*N*/ 		if (! pStor)
-/*N*/ 			return TRUE;
-/*N*/
-/*N*/ 		aDocStream = pStor->OpenStream(String::CreateFromAscii(pStarMathDoc));
-/*N*/ 		aDocStream->SetVersion (pStor->GetVersion ());
-/*N*/ 		GetPool().SetFileFormatVersion(USHORT(pStor->GetVersion()));
-/*N*/ 		aDocStream->SetBufferSize(DOCUMENT_BUFFER_SIZE);
-/*N*/ 		aDocStream->SetKey( pStor->GetKey() ); // Passwort setzen
-/*N*/ 		return aDocStream.Is();
-/*N*/ #endif
-/*N*/ 		return TRUE;
-/*N*/ 	}
-/*N*/ 	return FALSE;
-/*N*/ }
-
-
-
-
-
 /*N*/ void SmDocShell::HandsOff()
 /*N*/ {
 /*N*/ 	SfxInPlaceObject::HandsOff();
-/*N*/ #if 0
-/*N*/ 	aDocStream.Clear();
-/*N*/ #endif
 /*N*/ }
 
 
@@ -755,9 +674,6 @@ static const char __FAR_DATA pStarMathDoc[] = "StarMathDocument";
 /*N*/ 			}
 /*N*/
 /*N*/ 			bRet = TRUE;
-/*N*/ #if 0
-/*N*/ 			aDocStream = aTempStream;
-/*N*/ #endif
 /*N*/ 		}
 /*N*/ 	}
 /*N*/
@@ -799,7 +715,6 @@ BOOL SmDocShell::Try2x (SvStorage *pStor,
         UINT32       lDataSize;
         String       aBuffer;
         ByteString   aByteStr;
-        SmSymSet    *pSymbolSet;
 
         *pSvStream >> lDataSize >> lIdent >> lVersion;
 
@@ -840,10 +755,6 @@ BOOL SmDocShell::Try2x (SvStorage *pStor,
 
                     case 'S':
                     {
-                        // not sure about this...
-                        /* ??? pSymbolSet = new SmSymSet();
-                        ReadSM20SymSet(pSvStream, pSymbolSet);
-                        delete pSymbolSet; */
                         String      aTmp;
                         USHORT      n;
                         pSvStream->ReadByteString(aTmp, eEnc);
