@@ -56,7 +56,7 @@
 #include <symbol.hxx>
 #include <starmath.hrc>
 #include <config.hxx>
-#include <legacysmgr/legacy_binfilters_smgr.hxx>	//STRIP002
+#include <legacysmgr/legacy_binfilters_smgr.hxx>
 
 #include <rtl/uuid.h>
 
@@ -171,10 +171,10 @@ PropertySetInfo * lcl_createModelPropertyInfo ()
         { RTL_CONSTASCII_STRINGPARAM( "FontSansIsItalic"),   HANDLE_CUSTOM_FONT_SANS_POSTURE   ,  &::getBooleanCppuType(),  PROPERTY_NONE, FNT_SANS},
         { RTL_CONSTASCII_STRINGPARAM( "FontSerifIsBold"),	 HANDLE_CUSTOM_FONT_SERIF_WEIGHT    ,  &::getBooleanCppuType(),  			PROPERTY_NONE,  FNT_SERIF},
         { RTL_CONSTASCII_STRINGPARAM( "FontSerifIsItalic"),   HANDLE_CUSTOM_FONT_SERIF_POSTURE   ,  &::getBooleanCppuType(),  PROPERTY_NONE, FNT_SERIF},
-        { RTL_CONSTASCII_STRINGPARAM( "FontTextIsBold"),	 HANDLE_FONT_TEXT_WEIGHT    ,  &::getBooleanCppuType(),  			PROPERTY_NONE, },
-        { RTL_CONSTASCII_STRINGPARAM( "FontTextIsItalic"),   HANDLE_FONT_TEXT_POSTURE   ,  &::getBooleanCppuType(),  PROPERTY_NONE, },
-        { RTL_CONSTASCII_STRINGPARAM( "FontVariablesIsBold"),	 HANDLE_FONT_VARIABLES_WEIGHT    ,  &::getBooleanCppuType(),  			PROPERTY_NONE, },
-        { RTL_CONSTASCII_STRINGPARAM( "FontVariablesIsItalic"),   HANDLE_FONT_VARIABLES_POSTURE,  &::getBooleanCppuType(),  PROPERTY_NONE, },
+        { RTL_CONSTASCII_STRINGPARAM( "FontTextIsBold"),	 HANDLE_FONT_TEXT_WEIGHT    ,  &::getBooleanCppuType(),  			PROPERTY_NONE, 0 },
+        { RTL_CONSTASCII_STRINGPARAM( "FontTextIsItalic"),   HANDLE_FONT_TEXT_POSTURE   ,  &::getBooleanCppuType(),  PROPERTY_NONE, 0 },
+        { RTL_CONSTASCII_STRINGPARAM( "FontVariablesIsBold"),	 HANDLE_FONT_VARIABLES_WEIGHT    ,  &::getBooleanCppuType(),  			PROPERTY_NONE, 0 },
+        { RTL_CONSTASCII_STRINGPARAM( "FontVariablesIsItalic"),   HANDLE_FONT_VARIABLES_POSTURE,  &::getBooleanCppuType(),  PROPERTY_NONE, 0 },
         { RTL_CONSTASCII_STRINGPARAM( "Formula"							  ),	HANDLE_FORMULA							   , 		&::getCppuType((const OUString*)0), 	PROPERTY_NONE, 0},
         { RTL_CONSTASCII_STRINGPARAM( "IsScaleAllBrackets"              ), HANDLE_IS_SCALE_ALL_BRACKETS              , 		&::getBooleanCppuType(), 	PROPERTY_NONE, 0},
         { RTL_CONSTASCII_STRINGPARAM( "IsTextMode"                       ), HANDLE_IS_TEXT_MODE                       , 		&::getBooleanCppuType(), 	PROPERTY_NONE, 0},
@@ -224,9 +224,8 @@ SmModel::SmModel( SfxObjectShell *pObjSh )
 SmModel::~SmModel() throw ()
 {
 }
-/*-- 28.03.00 14:18:17---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
+
 uno::Any SAL_CALL SmModel::queryInterface( const uno::Type& rType ) throw(uno::RuntimeException)
 {
     uno::Any aRet =  ::cppu::queryInterface ( rType,
@@ -245,25 +244,22 @@ uno::Any SAL_CALL SmModel::queryInterface( const uno::Type& rType ) throw(uno::R
         aRet = SfxBaseModel::queryInterface ( rType );
     return aRet;
 }
-/*-- 28.03.00 14:18:18---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
+
 void SAL_CALL SmModel::acquire() throw()
 {
     SolarMutexGuard aGuard;
     OWeakObject::acquire();
 }
-/*-- 28.03.00 14:18:18---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
+
 void SAL_CALL SmModel::release() throw()
 {
     SolarMutexGuard aGuard;
     OWeakObject::release();
 }
-/*-- 28.03.00 14:18:19---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
+
 uno::Sequence< uno::Type > SAL_CALL SmModel::getTypes(  ) throw(uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
@@ -283,9 +279,8 @@ uno::Sequence< uno::Type > SAL_CALL SmModel::getTypes(  ) throw(uno::RuntimeExce
 
     return aTypes;
 }
-/* -----------------------------28.03.00 14:23--------------------------------
 
- ---------------------------------------------------------------------------*/
+
 const uno::Sequence< sal_Int8 > & SmModel::getUnoTunnelId()
 {
     static osl::Mutex aCreateMutex;
@@ -298,9 +293,8 @@ const uno::Sequence< sal_Int8 > & SmModel::getUnoTunnelId()
         rtl_createUuid( (sal_uInt8*)aSeq.getArray(), 0,	sal_True );
     }
     return aSeq;
-} /* -----------------------------28.03.00 14:23--------------------------------
+}
 
- ---------------------------------------------------------------------------*/
 sal_Int64 SAL_CALL SmModel::getSomething( const uno::Sequence< sal_Int8 >& rId )
     throw(uno::RuntimeException)
 {
@@ -312,12 +306,10 @@ sal_Int64 SAL_CALL SmModel::getSomething( const uno::Sequence< sal_Int8 >& rId )
     }
     return 0;
 }
-/*-- 07.01.00 16:32:59---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
-/*-- 07.01.00 16:33:00---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
+
+
 sal_Int16 lcl_AnyToINT16(const uno::Any& rAny)
 {
     uno::TypeClass eType = rAny.getValueType().getTypeClass();
@@ -337,9 +329,8 @@ OUString SmModel::getImplementationName(void) throw( uno::RuntimeException )
 {
     return C2U("SmModel");
 }
-/*-- 07.02.00 13:24:09---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
+
 sal_Bool SmModel::supportsService(const OUString& rServiceName) throw( uno::RuntimeException )
 {
     return (
@@ -348,9 +339,8 @@ sal_Bool SmModel::supportsService(const OUString& rServiceName) throw( uno::Runt
            );
 
 }
-/*-- 07.02.00 13:24:09---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
+
 uno::Sequence< OUString > SmModel::getSupportedServiceNames(void) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -469,7 +459,7 @@ void SmModel::_setPropertyValues(const PropertyMapEntry** ppEntries, const Any*
             case HANDLE_RELATIVE_FONT_HEIGHT_OPERATORS     :
             case HANDLE_RELATIVE_FONT_HEIGHT_LIMITS        :
             {
-                sal_Int16 nVal;
+                sal_Int16 nVal(0);
                 *pValues >>= nVal;
                 if(nVal < 1)
                     throw IllegalArgumentException();
@@ -486,7 +476,7 @@ void SmModel::_setPropertyValues(const PropertyMapEntry** ppEntries, const Any*
             case HANDLE_ALIGNMENT                          :
             {
                 // SmHorAlign uses the same values as HorizontalAlignment
-                sal_Int16 nVal;
+                sal_Int16 nVal(0);
                 *pValues >>= nVal;
                 if(nVal < 0 || nVal > 2)
                     throw IllegalArgumentException();
@@ -519,7 +509,7 @@ void SmModel::_setPropertyValues(const PropertyMapEntry** ppEntries, const Any*
             case HANDLE_TOP_MARGIN                :
             case HANDLE_BOTTOM_MARGIN             :
             {
-                sal_Int16 nVal;
+                sal_Int16 nVal(0);
                 *pValues >>= nVal;
                 if(nVal < 0)
                     throw IllegalArgumentException();
@@ -556,7 +546,7 @@ void SmModel::_setPropertyValues(const PropertyMapEntry** ppEntries, const Any*
                     sal_uInt32 nSize = aSequence.getLength();
                     SvMemoryStream aStream ( aSequence.getArray(), nSize, STREAM_READ );
                     aStream.Seek ( STREAM_SEEK_TO_BEGIN );
-                    static sal_uInt16 __READONLY_DATA nRange[] =
+                    static sal_uInt16 const nRange[] =
                     {
                         SID_PRINTSIZE,       SID_PRINTSIZE,
                         SID_PRINTZOOM,       SID_PRINTZOOM,
@@ -584,7 +574,7 @@ void SmModel::_setPropertyValues(const PropertyMapEntry** ppEntries, const Any*
                 if ( *pValues >>= aSequence )
                 {
                     sal_uInt32 nSize = aSequence.getLength();
-                    SmSymSetManager &rManager = pDocSh->GetSymSetManager();
+                    /*SmSymSetManager &rManager =*/ pDocSh->GetSymSetManager();
                     SymbolDescriptor *pDescriptor = aSequence.getArray();
                     for (sal_uInt32 i = 0; i < nSize ; i++, pDescriptor++)
                     {
@@ -599,7 +589,6 @@ void SmModel::_setPropertyValues(const PropertyMapEntry** ppEntries, const Any*
                                         pDescriptor->sSymbolSet );
                         aSymbol.SetExportName ( pDescriptor->sExportName );
                         aSymbol.SetDocSymbol( TRUE );
-                        rManager.AddReplaceSymbol ( aSymbol );
                     }
                 }
                 else
@@ -796,8 +785,8 @@ void SmModel::_getPropertyValues( const PropertyMapEntry **ppEntries, Any *pValu
 //////////////////////////////////////////////////////////////////////
 
 sal_Int32 SAL_CALL SmModel::getRendererCount(
-        const uno::Any& rSelection,
-        const uno::Sequence< beans::PropertyValue >& xOptions )
+        const uno::Any& /*rSelection*/,
+        const uno::Sequence< beans::PropertyValue >& /*xOptions*/ )
     throw (IllegalArgumentException, RuntimeException)
 {
     SolarMutexGuard aGuard;
@@ -830,8 +819,8 @@ static Size lcl_GuessPaperSize()
 
 uno::Sequence< beans::PropertyValue > SAL_CALL SmModel::getRenderer(
         sal_Int32 nRenderer,
-        const uno::Any& rSelection,
-        const uno::Sequence< beans::PropertyValue >& xOptions )
+        const uno::Any& /*rSelection*/,
+        const uno::Sequence< beans::PropertyValue >& /*xOptions*/ )
     throw (IllegalArgumentException, RuntimeException)
 {
     SolarMutexGuard aGuard;
