@@ -28,33 +28,21 @@
 
 // MARKER(update_precomp.py): autogen include statement, do not remove
 
-
 //_________________________________________________________________________________________________________________
 //	includes
 //_________________________________________________________________________________________________________________
-
 #include <bf_svtools/cmdoptions.hxx>
-
 #include <unotools/configmgr.hxx>
-
 #include <unotools/configitem.hxx>
-
 #include <tools/debug.hxx>
-
 #include <com/sun/star/uno/Any.hxx>
-
 #include <com/sun/star/uno/Sequence.hxx>
-
 #include <cppuhelper/weakref.hxx>
-
 #include <tools/urlobj.hxx>
-
 #include <rtl/ustrbuf.hxx>
-
 #include <itemholder1.hxx>
-
 #include <algorithm>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 
 //_________________________________________________________________________________________________________________
 //	namespaces
@@ -116,11 +104,6 @@ class SvtCmdOptions
             return ( m_aCommandHashMap.size() > 0 );
         }
         
-        void SetContainerSize( sal_Int32 nSize )
-        {
-            m_aCommandHashMap.resize( nSize );
-        }
-
         sal_Bool Lookup( const OUString& aCmd ) const
         {
             CommandHashMap::const_iterator pEntry = m_aCommandHashMap.find( aCmd );
@@ -154,7 +137,7 @@ class SvtCmdOptions
         }
 
     private:
-        class CommandHashMap : public ::std::hash_map< ::rtl::OUString		,
+        class CommandHashMap : public ::boost::unordered_map< ::rtl::OUString		,
                                                         sal_Int32			,
                                                         OUStringHashCode	,
                                                         ::std::equal_to< ::rtl::OUString >	>
@@ -278,9 +261,6 @@ SvtCommandOptions_Impl::SvtCommandOptions_Impl()
     sal_Int32	nItem     = 0 ;
     OUString    sCmd		  ;
 
-    // Set size of hash_map reach a used size of approx. 60%
-    m_aDisabledCommands.SetContainerSize( lNames.getLength() * 10 / 6 );
-
     // Get names/values for disabled commands.
     for( nItem=0; nItem < lNames.getLength(); ++nItem )
     {
@@ -329,10 +309,6 @@ void SvtCommandOptions_Impl::Notify( const Sequence< OUString >& )
     sal_Int32	nItem     = 0 ;
     OUString    sCmd		  ;
 
-    // Set size of hash_map reach a used size of approx. 60%
-    m_aDisabledCommands.Clear();
-    m_aDisabledCommands.SetContainerSize( lNames.getLength() * 10 / 6 );
-
     // Get names/values for disabled commands.
     for( nItem=0; nItem < lNames.getLength(); ++nItem )
     {
@@ -358,7 +334,7 @@ void SvtCommandOptions_Impl::Notify( const Sequence< OUString >& )
 //*****************************************************************************************************************
 void SvtCommandOptions_Impl::Commit()
 {
-    DBG_ERROR( "SvtCommandOptions_Impl::Commit()\nNot implemented yet!\n" );
+    OSL_FAIL( "SvtCommandOptions_Impl::Commit()\nNot implemented yet!\n" );
 }
 
 //*****************************************************************************************************************
