@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -31,24 +31,17 @@
 //_________________________________________________________________________________________________________________
 //	includes
 //_________________________________________________________________________________________________________________
-
+#include <bf_svtools/bf_solar.h>
 #include <bf_svtools/menuoptions.hxx>
-
 #include <unotools/configmgr.hxx>
-
 #include <unotools/configitem.hxx>
-
 #include <tools/debug.hxx>
-
 #include <com/sun/star/uno/Any.hxx>
-
 #include <com/sun/star/uno/Sequence.hxx>
-
 #include <rtl/logfile.hxx>
 #include "itemholder1.hxx"
 
 #include <tools/link.hxx>
-#include <tools/list.hxx>
 
 //_________________________________________________________________________________________________________________
 //	namespaces
@@ -81,8 +74,6 @@ namespace binfilter
 
 #define PROPERTYCOUNT                           3
 
-DECLARE_LIST( LinkList, Link * )
-
 //_________________________________________________________________________________________________________________
 //	private declarations!
 //_________________________________________________________________________________________________________________
@@ -94,7 +85,6 @@ class SvtMenuOptions_Impl : public ConfigItem
     //-------------------------------------------------------------------------------------------------------------
 
     private:
-        LinkList    aList;
         sal_Bool	m_bDontHideDisabledEntries			;	/// cache "DontHideDisabledEntries" of Menu section
         sal_Bool	m_bFollowMouse						;	/// cache "FollowMouse" of Menu section
         sal_Bool	m_bMenuIcons						;	/// cache "MenuIcons" of Menu section
@@ -177,8 +167,6 @@ class SvtMenuOptions_Impl : public ConfigItem
                     {
                         m_bDontHideDisabledEntries = bState;
                         SetModified();
-                        for ( USHORT n=0; n<aList.Count(); n++ )
-                            aList.GetObject(n)->Call( this );
                         Commit();
                     }
 
@@ -186,8 +174,6 @@ class SvtMenuOptions_Impl : public ConfigItem
                     {
                         m_bFollowMouse = bState;
                         SetModified();
-                        for ( USHORT n=0; n<aList.Count(); n++ )
-                            aList.GetObject(n)->Call( this );
                         Commit();
                     }
 
@@ -195,8 +181,6 @@ class SvtMenuOptions_Impl : public ConfigItem
                     {
                         m_bMenuIcons = bState;
                         SetModified();
-                        for ( USHORT n=0; n<aList.Count(); n++ )
-                            aList.GetObject(n)->Call( this );
                         Commit();
                     }
 
@@ -289,9 +273,6 @@ SvtMenuOptions_Impl::~SvtMenuOptions_Impl()
     {
         Commit();
     }
-
-    for ( USHORT n=0; n<aList.Count(); )
-        delete aList.Remove(n);
 }
 
 //*****************************************************************************************************************
@@ -328,9 +309,6 @@ void SvtMenuOptions_Impl::Notify( const Sequence< OUString >& seqPropertyNames )
         else DBG_ASSERT( sal_False, "SvtMenuOptions_Impl::Notify()\nUnkown property detected ... I can't handle these!\n" );
         #endif
     }
-
-    for ( USHORT n=0; n<aList.Count(); n++ )
-        aList.GetObject(n)->Call( this );
 }
 
 //*****************************************************************************************************************
@@ -405,7 +383,7 @@ SvtMenuOptions::SvtMenuOptions()
     {
         RTL_LOGFILE_CONTEXT(aLog, "svtools ( ??? ) ::SvtMenuOptions_Impl::ctor()");
         m_pDataContainer = new SvtMenuOptions_Impl();
-        
+
         ItemHolder1::holdConfigItem(E_MENUOPTIONS);
     }
 }
