@@ -33,27 +33,16 @@
 //_________________________________________________________________________________________________________________
 
 #include <bf_svtools/viewoptions.hxx>
-
 #include <com/sun/star/uno/Any.hxx>
-
-#include <hash_map>
-
+#include <boost/unordered_map.hpp>
 #include <com/sun/star/beans/PropertyValue.hpp>
-
 #include <com/sun/star/container/XNameContainer.hpp>
-
 #include <com/sun/star/container/XNameAccess.hpp>
-
 #include <com/sun/star/beans/XPropertySet.hpp>
-
 #include <rtl/ustrbuf.hxx>
-
 #include <unotools/configpathes.hxx>
-
 #include <comphelper/configurationhelper.hxx>
-
 #include <unotools/processfactory.hxx>
-
 #include <itemholder1.hxx>
 
 namespace binfilter
@@ -116,7 +105,7 @@ namespace css = ::com::sun::star;
         sMsg.appendAscii("Unexpected exception catched. Original message was:\n\""      );                          \
         sMsg.append     (SVTVIEWOPTIONS_LOG_UNEXPECTED_EXCEPTION_PARAM_EXCEPTION.Message);                          \
         sMsg.appendAscii("\""                                                           );                          \
-        OSL_ENSURE(sal_False, ::rtl::OUStringToOString(sMsg.makeStringAndClear(), RTL_TEXTENCODING_UTF8).getStr()); \
+        OSL_FAIL(::rtl::OUStringToOString(sMsg.makeStringAndClear(), RTL_TEXTENCODING_UTF8).getStr()); \
     }
 
 //_________________________________________________________________________________________________________________
@@ -285,7 +274,7 @@ struct IMPL_TStringHashCode
     }
 };
 
-typedef ::std::hash_map< ::rtl::OUString                    ,
+typedef ::boost::unordered_map< ::rtl::OUString                    ,
                          IMPL_TViewData                     ,
                          IMPL_TStringHashCode               ,
                          ::std::equal_to< ::rtl::OUString > > IMPL_TViewHash;
@@ -336,8 +325,6 @@ class SvtViewOptionsBase_Impl
 
     @param          -
     @return         -
-
-    @last change    19.10.2001 07:54
 *//*-*************************************************************************************************************/
 SvtViewOptionsBase_Impl::SvtViewOptionsBase_Impl( const ::rtl::OUString& sList )
         :   m_sListName  ( sList )    // we must know, which view type we must support
@@ -382,8 +369,6 @@ SvtViewOptionsBase_Impl::SvtViewOptionsBase_Impl( const ::rtl::OUString& sList )
 
     @param          -
     @return         -
-
-    @last change    19.10.2001 08:02
 *//*-*************************************************************************************************************/
 SvtViewOptionsBase_Impl::~SvtViewOptionsBase_Impl()
 {
@@ -467,7 +452,7 @@ SvtViewOptions::SvtViewOptions(       EViewType        eType     ,
                                     }
                                 }
                                 break;
-        default             :   OSL_ENSURE( sal_False, "SvtViewOptions::SvtViewOptions()\nThese view type is unknown! All following calls at these instance will do nothing!\n" );
+        default             :   OSL_FAIL( "SvtViewOptions::SvtViewOptions()\nThese view type is unknown! All following calls at these instance will do nothing!\n" );
     }
 }
 
