@@ -333,10 +333,6 @@ SvStream& operator>>(SvStream& rInp, GrupType& rGrup)
 |*
 |*    Sgv2SvFarbe()
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 Color Sgv2SvFarbe(BYTE nFrb1, BYTE nFrb2, BYTE nInts)
 {
@@ -429,10 +425,6 @@ void SetArea(ObjAreaType& rArea, OutputDevice& rOut)
 |*
 |*    ObjkType::DrawObjekt()
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 void ObjkType::Draw(OutputDevice&)
 {
@@ -445,10 +437,6 @@ void Obj0Type::Draw(OutputDevice&) {}
 |*
 |*    StrkType::DrawObjekt()
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 void StrkType::Draw(OutputDevice& rOut)
 {
@@ -460,10 +448,6 @@ void StrkType::Draw(OutputDevice& rOut)
 |*
 |*    RectType::DrawObjekt()
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 void SgfAreaColorIntens(UINT16 Muster, BYTE Col1, BYTE Col2, BYTE Int, OutputDevice& rOut)
 {
@@ -605,10 +589,6 @@ void RectType::Draw(OutputDevice& rOut)
 |*
 |*    PolyType::Draw()
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 void PolyType::Draw(OutputDevice& rOut)
 {
@@ -628,10 +608,6 @@ void PolyType::Draw(OutputDevice& rOut)
 |*
 |*    SplnType::Draw()
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 void SplnType::Draw(OutputDevice& rOut)
 {
@@ -654,10 +630,6 @@ void SplnType::Draw(OutputDevice& rOut)
 |*
 |*    CircType::Draw()
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 void DrawSlideCirc(INT16 cx, INT16 cy, INT16 rx, INT16 ry, ObjAreaType& F, OutputDevice& rOut)
 {
@@ -801,10 +773,6 @@ void CircType::Draw(OutputDevice& rOut)
 |*
 |*    BmapType::Draw()
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 
 void BmapType::Draw(OutputDevice& rOut)
@@ -825,8 +793,7 @@ void BmapType::Draw(OutputDevice& rOut)
             case SGF_BITIMAGE: {
                 GraphicFilter aFlt;
                 Graphic aGrf;
-                USHORT nRet;
-                nRet=aFlt.ImportGraphic(aGrf,aFNam);
+                aFlt.ImportGraphic(aGrf,aFNam);
                 aGrf.Draw(&rOut,Point(Pos1.x,Pos1.y),Size(Pos2.x-Pos1.x,Pos2.y-Pos1.y));
             } break;
             case SGF_SIMPVECT: {
@@ -858,10 +825,6 @@ void BmapType::Draw(OutputDevice& rOut)
 |*
 |*    GrupType::...
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 UINT32 GrupType::GetSubPtr()
 {
@@ -872,10 +835,6 @@ UINT32 GrupType::GetSubPtr()
 |*
 |*    DrawObjkList()
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 void DrawObjkList( SvStream& rInp, OutputDevice& rOut )
 {
@@ -961,10 +920,6 @@ void DrawObjkList( SvStream& rInp, OutputDevice& rOut )
 |*
 |*    SkipObjkList()
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 void SkipObjkList(SvStream& rInp)
 {
@@ -987,10 +942,6 @@ void SkipObjkList(SvStream& rInp)
 |*
 |*    SgfFilterSDrw()
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 BOOL SgfFilterSDrw( SvStream& rInp, SgfHeader&, SgfEntry&, GDIMetaFile& rMtf )
 {
@@ -1047,10 +998,6 @@ BOOL SgfFilterSDrw( SvStream& rInp, SgfHeader&, SgfEntry&, GDIMetaFile& rMtf )
 |*
 |*    SgfSDrwFilter()
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 BOOL SgfSDrwFilter(SvStream& rInp, GDIMetaFile& rMtf, INetURLObject aIniPath )
 {
