@@ -31,6 +31,7 @@
 
 #include <math.h>
 
+#include <bf_svtools/bf_solar.h>
 
 #include <tools/poly.hxx>
 
@@ -462,8 +463,6 @@ USHORT ZyklTriDiagGS(BOOL rep, USHORT n, double* lower, double* diag,
 |*
 |*    Beschreibung      Berechnet die Koeffizienten eines natuerlichen
 |*                      kubischen Polynomsplines mit n Stuetzstellen.
-|*    Ersterstellung    JOE 17-08.93
-|*    Letzte Aenderung  JOE 17-08.93
 |*
 *************************************************************************/
 
@@ -570,8 +569,6 @@ USHORT NaturalSpline(USHORT n, double* x, double* y,
 |*
 |*    Beschreibung      Berechnet die Koeffizienten eines periodischen
 |*                      kubischen Polynomsplines mit n Stuetzstellen.
-|*    Ersterstellung    JOE 17-08.93
-|*    Letzte Aenderung  JOE 17-08.93
 |*
 *************************************************************************/
 
@@ -649,8 +646,6 @@ USHORT PeriodicSpline(USHORT n, double* x, double* y,
 |*    Beschreibung      Berechnet die Koeffizienten eines parametrischen
 |*                      natuerlichen oder periodischen kubischen
 |*                      Polynomsplines mit n Stuetzstellen.
-|*    Ersterstellung    JOE 17-08.93
-|*    Letzte Aenderung  JOE 17-08.93
 |*
 *************************************************************************/
 
@@ -661,7 +656,7 @@ USHORT ParaSpline(USHORT n, double* x, double* y, BYTE MargCond,
                   double* bx, double* cx, double* dx,
                   double* by, double* cy, double* dy)
 {
-    USHORT Error,Marg;
+    USHORT Error;
     USHORT i;
     double deltX,deltY,delt,
            alphX = 0,alphY = 0,
@@ -679,9 +674,8 @@ USHORT ParaSpline(USHORT n, double* x, double* y, BYTE MargCond,
         }
     }
     switch (MargCond) {
-        case 0: Marg=0; break;
+        case 0: break;
         case 1: case 2: {
-            Marg=MargCond;
             alphX=Marg01; betX=MargN1;
             alphY=Marg02; betY=MargN2;
         } break;
@@ -690,7 +684,6 @@ USHORT ParaSpline(USHORT n, double* x, double* y, BYTE MargCond,
             if (y[n]!=y[0]) return 4;
         } break;
         case 4: {
-            Marg=1;
             if (abs(Marg01)>=MAXROOT) {
                 alphX=0.0;
                 alphY=sign(1.0,y[1]-y[0]);
@@ -737,8 +730,6 @@ USHORT ParaSpline(USHORT n, double* x, double* y, BYTE MargCond,
 |*                      ist Speicher fuer die Koeffizientenarrays
 |*                      allokiert, der dann spaeter vom Aufrufer mittels
 |*                      delete freizugeben ist.
-|*    Ersterstellung    JOE 17-08.93
-|*    Letzte Aenderung  JOE 17-08.93
 |*
 *************************************************************************/
 
@@ -747,7 +738,7 @@ BOOL CalcSpline(Polygon& rPoly, BOOL Periodic, USHORT& n,
                 double*& cx, double*& cy, double*& dx, double*& dy, double*& T)
 {
     BYTE   Marg;
-    double Marg01,Marg02;
+    double Marg01;
     double MargN1,MargN2;
     USHORT i;
     Point  P0(-32768,-32768);
@@ -786,7 +777,6 @@ BOOL CalcSpline(Polygon& rPoly, BOOL Periodic, USHORT& n,
     T =new double[n+1];
 
     Marg01=0.0;
-    Marg02=0.0;
     MargN1=0.0;
     MargN2=0.0;
     if (n>0) n--; // n Korregieren (Anzahl der Teilpolynome)
@@ -826,8 +816,6 @@ BOOL CalcSpline(Polygon& rPoly, BOOL Periodic, USHORT& n,
 |*                      Fall hat das Polygon 0, im 2. Fall PolyMax Punkte.
 |*                      Um Koordinatenueberlaeufe zu vermeiden werden diese
 |*                      auf +/-32000 begrenzt.
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
 |*
 *************************************************************************/
 BOOL Spline2Poly(Polygon& rSpln, BOOL Periodic, Polygon& rPoly)
