@@ -29,62 +29,16 @@
 #define ITEMID_COLOR			SID_ATTR_3D_LIGHTCOLOR
 
 #include "svdstr.hrc"
-
 #include "svdview.hxx"
-
-
-
-
-
-
 #include "globl3d.hxx"
-
-
-
 #include "polyob3d.hxx"
-
-
 #include "polysc3d.hxx"
-
-
-
-
-
-
 #include "xoutx.hxx"
-
-
-
-
-
-
-
-
-
-
-
 #include "xlnwtit.hxx"
-
-
 #include "svdio.hxx"
-
-
-
 #include "svxids.hrc"
-
-
-
-
-
-
-
-
-
-
-
 #include "eeitem.hxx"
 
-
 namespace binfilter {
 
 #define ITEMVALUE(ItemSet,Id,Cast)	((const Cast&)(ItemSet).Get(Id)).GetValue()
@@ -135,7 +89,7 @@ namespace binfilter {
 /*N*/ {
 /*N*/ 	// Owner holen
 /*N*/ 	DBG_ASSERT(GetOwnerObj()->ISA(E3dObject), "AW: Entfernen 3DObject aus Parent != 3DObject");
-/*N*/ 	E3dObject* pOwner = (E3dObject*)GetOwnerObj();
+/*N*/ 	/*E3dObject* pOwner =*/ (E3dObject*)GetOwnerObj();
 /*N*/ 
 /*N*/ 	// call parent
 /*N*/ 	SdrObject* pRetval = SdrObjList::RemoveObject(nObjNum);
@@ -158,8 +112,8 @@ namespace binfilter {
 /*N*/ E3dObject::E3dObject() :
 /*N*/ 	nLogicalGroup(0),
 /*N*/ 	nObjTreeLevel(0),
-/*N*/ 	eDragDetail(E3DDETAIL_ONEBOX),
 /*N*/ 	nPartOfParent(0),
+/*N*/ 	eDragDetail(E3DDETAIL_ONEBOX),
 /*N*/ 	bTfHasChanged(TRUE),
 /*N*/ 	bBoundVolValid(TRUE),
 /*N*/ 	bIsSelected(FALSE)
@@ -183,13 +137,6 @@ namespace binfilter {
 /*N*/ 	pSub = NULL;
 /*N*/ }
 
-/*************************************************************************
-|*
-|* Selektions-Flag setzen
-|*
-\************************************************************************/
-
-
 /*************************************************************************
 |*
 |* Aufbrechen, default-Implementierungen
@@ -208,7 +155,7 @@ namespace binfilter {
 |*
 \************************************************************************/
 
-/*N*/ void E3dObject::SetRectsDirty(FASTBOOL bNotMyself)
+/*N*/ void E3dObject::SetRectsDirty(bool bNotMyself)
 /*N*/ {
 /*N*/ 	// call parent
 /*N*/ 	SdrAttrObj::SetRectsDirty(bNotMyself);
@@ -247,13 +194,6 @@ namespace binfilter {
 /*N*/ 	return E3D_OBJECT_ID;
 /*N*/ }
 
-/*************************************************************************
-|*
-|* Faehigkeiten des Objektes feststellen
-|*
-\************************************************************************/
-
-
 /*************************************************************************
 |*
 |* Layer abfragen
@@ -262,7 +202,7 @@ namespace binfilter {
 
 /*N*/ SdrLayerID E3dObject::GetLayer() const
 /*N*/ {
-/*N*/ 	FASTBOOL bFirst = TRUE;
+/*N*/ 	bool bFirst = TRUE;
 /*N*/ 	E3dObjList* pOL = pSub;
 /*N*/ 	ULONG       nObjCnt = pOL->GetObjCount();
 /*N*/ 	SdrLayerID  nLayer = SdrLayerID(nLayerID);
@@ -388,12 +328,6 @@ namespace binfilter {
 /*N*/ #endif
 /*N*/ }
 
-/*************************************************************************
-|*
-|* Objekt verschieben in 2D, wird bei Cursortasten benoetigt
-|*
-\************************************************************************/
-
 /*************************************************************************
 |*
 |* liefere die Sublist, aber nur dann, wenn darin Objekte enthalten sind !
@@ -405,47 +339,6 @@ namespace binfilter {
 /*N*/ 	return pSub;
 /*N*/ }
 
-/*************************************************************************
-|*
-|* Anzahl der Handles zurueckgeben
-|*
-\************************************************************************/
-
-
-/*************************************************************************
-|*
-|* Handle-Liste fuellen
-|*
-\************************************************************************/
-
-
-/*************************************************************************
-|*
-\************************************************************************/
-
-
-/*************************************************************************
-|*
-|* Paint; wird z.Z. nicht benutzt, da das Paint ueber die
-|* (2D-)Displayliste der Szene laeuft
-|*
-\************************************************************************/
-
-
-/*************************************************************************
-|*
-|* Objekt als Kontur in das Polygon einfuegen
-|*
-\************************************************************************/
-
-
-/*************************************************************************
-|*
-|* Schatten fuer 3D-Objekte zeichnen
-|*
-\************************************************************************/
-
-
 /*************************************************************************
 |*
 |* SnapRect berechnen
@@ -700,14 +593,6 @@ namespace binfilter {
 /*N*/ 	}
 /*N*/ }
 
-/*************************************************************************
-|*
-|* hierarchische Transformation ueber alle Parents bestimmen und mit
-|* der uebergebenen Matrix verketten
-|*
-\************************************************************************/
-
-
 /*************************************************************************
 |*
 |* hierarchische Transformation ueber alle Parents bestimmen, in
@@ -782,94 +667,6 @@ namespace binfilter {
 /*N*/ 	if (pUserCall != NULL) pUserCall->Changed(*this, SDRUSERCALL_RESIZE, Rectangle());
 /*N*/ }
 
-/*************************************************************************
-|*
-|* Transformationsmatrix zuruecksetzen mit Repaint-Broadcast
-|*
-\************************************************************************/
-
-
-/*************************************************************************
-|*
-|* Translation
-|*
-\************************************************************************/
-
-/*************************************************************************
-|*
-|* Translation mit Repaint-Broadcast
-|*
-\************************************************************************/
-
-
-/*************************************************************************
-|*
-|* Skalierungen
-|*
-\************************************************************************/
-
-
-/************************************************************************/
-
-
-/************************************************************************/
-
-
-/************************************************************************/
-
-
-/*************************************************************************
-|*
-|* gleichmaessige Skalierung
-|*
-\************************************************************************/
-
-
-/*************************************************************************
-|*
-|* Skalierungen mit mit Repaint-Broadcast
-|*
-\************************************************************************/
-
-
-/************************************************************************/
-
-
-/************************************************************************/
-
-
-/************************************************************************/
-
-
-/************************************************************************/
-
-
-/*************************************************************************
-|*
-|* Rotationen mit Winkel in Radiant
-|*
-\************************************************************************/
-
-
-/************************************************************************/
-
-
-/************************************************************************/
-
-
-/*************************************************************************
-|*
-|* Rotationen mit Repaint-Broadcast
-|*
-\************************************************************************/
-
-
-/************************************************************************/
-
-
-/************************************************************************/
-
-
 /*************************************************************************
 |*
 |* Objektbaum-Ebene des Objekts und aller Children setzen
@@ -893,49 +690,6 @@ namespace binfilter {
 /*N*/ 	}
 /*N*/ }
 
-/*************************************************************************
-|*
-|* logische Gruppe setzen
-|*
-\************************************************************************/
-
-
-/*************************************************************************
-|*
-|* Linien fuer die Wireframe-Darstellung des Objekts dem uebergebenen
-|* Polygon3D hinzufuegen. Als default wird das BoundVolume verwendet.
-|*
-\************************************************************************/
-
-
-/*************************************************************************
-|*
-|* Get the name of the object (singular)
-|*
-\************************************************************************/
-
-
-/*************************************************************************
-|*
-|* Get the name of the object (plural)
-|*
-\************************************************************************/
-
-
-/*************************************************************************
-|*
-|* Wireframe-XPolyPolygon erzeugen
-|*
-\************************************************************************/
-
-
-/*************************************************************************
-|*
-|* Drag-Polygon zurueckgeben
-|*
-\************************************************************************/
-
-
 /*************************************************************************
 |*
 |* Zuweisungsoperator
@@ -1024,7 +778,7 @@ namespace binfilter {
 \************************************************************************/
 
 /*N*/ void E3dObject::NbcSetStyleSheet(SfxStyleSheet* pNewStyleSheet,
-/*N*/ 	FASTBOOL bDontRemoveHardAttr)
+/*N*/ 	bool bDontRemoveHardAttr)
 /*N*/ {
 /*N*/ 	// call parent
 /*N*/ 	SdrAttrObj::NbcSetStyleSheet(pNewStyleSheet, bDontRemoveHardAttr);
@@ -1074,9 +828,7 @@ namespace binfilter {
 /*N*/ void E3dObject::WriteData(SvStream& rOut) const
 /*N*/ {
 /*N*/ #ifndef SVX_LIGHT
-/*N*/ 	long position = rOut.Tell();
 /*N*/ 	SdrAttrObj::WriteData(rOut);
-/*N*/ 	position = rOut.Tell();
 /*N*/ 
 /*N*/ 	// Fuer Abwaertskompatibilitaet (Lesen neuer Daten mit altem Code)
 /*N*/ 	SdrDownCompat aCompat(rOut, STREAM_WRITE);
@@ -1084,9 +836,7 @@ namespace binfilter {
 /*N*/ 	aCompat.SetID("E3dObject");
 /*N*/ #endif
 /*N*/ 
-/*N*/ 	position = rOut.Tell();
 /*N*/ 	pSub->Save(rOut);
-/*N*/ 	position = rOut.Tell();
 /*N*/ 
 /*N*/ 	if (rOut.GetVersion() < 3560)
 /*N*/ 	{
@@ -1105,7 +855,6 @@ namespace binfilter {
 /*N*/ 	{
 /*N*/ 		WriteOnlyOwnMembers(rOut);
 /*N*/ 	}
-/*N*/ 	position = rOut.Tell();
 /*N*/ #endif
 /*N*/ }
 
@@ -1117,12 +866,9 @@ namespace binfilter {
 
 /*N*/ void E3dObject::ReadData(const SdrObjIOHeader& rHead, SvStream& rIn)
 /*N*/ {
-/*N*/ 	long position = rIn.Tell();
 /*N*/ 	if (ImpCheckSubRecords (rHead, rIn))
 /*N*/ 	{
-/*N*/ 		position = rIn.Tell();
 /*N*/ 		SdrAttrObj::ReadData(rHead, rIn);
-/*N*/ 		position = rIn.Tell();
 /*N*/ 		// Fuer Abwaertskompatibilitaet (Lesen neuer Daten mit altem Code)
 /*N*/ 		SdrDownCompat aCompat(rIn, STREAM_READ);
 /*N*/ #ifdef DBG_UTIL
@@ -1130,7 +876,6 @@ namespace binfilter {
 /*N*/ #endif
 /*N*/ 		pSub->Load(rIn, *pPage);
 /*N*/ 
-/*N*/ 		position = rIn.Tell();
 /*N*/ 		if ((rIn.GetVersion() < 3560) || (rHead.GetVersion() <= 12))
 /*N*/ 		{
 /*N*/ 			UINT16  nTmp16;
@@ -1150,7 +895,6 @@ namespace binfilter {
 /*N*/ 		{
 /*N*/ 			ReadOnlyOwnMembers(rHead, rIn);
 /*N*/ 		}
-/*N*/ 		position = rIn.Tell();
 /*N*/ 
 /*N*/ 		// Wie ein veraendertes Objekt behandeln
 /*N*/ 		SetTransformChanged();
@@ -1171,7 +915,7 @@ namespace binfilter {
 |*
 \************************************************************************/
 
-/*N*/ void E3dObject::ReadOnlyOwnMembers(const SdrObjIOHeader& rHead, SvStream& rIn)
+/*N*/ void E3dObject::ReadOnlyOwnMembers(const SdrObjIOHeader& /*rHead*/, SvStream& rIn)
 /*N*/ {
 /*N*/ 	// Fuer Abwaertskompatibilitaet (Lesen neuer Daten mit altem Code)
 /*N*/ 	SdrDownCompat aCompat(rIn, STREAM_READ);
@@ -1436,7 +1180,7 @@ namespace binfilter {
 /*N*/ 	{
 /*N*/ 		// Schatten beruecksichtigen
 /*N*/ 		if(DoDrawShadow())
-/*N*/ 		{DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
+/*N*/ 		{DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 		}
 
         // Linienbreite beruecksichtigen
@@ -1576,7 +1320,6 @@ namespace binfilter {
 /*N*/ 	if (aCompat.GetBytesLeft () >= sizeof (BOOL))
 /*N*/ 	{
 /*N*/ 		BOOL bTmp, bTmp2;
-/*N*/ 		sal_uInt16 nTmp;
 /*N*/ 
 /*N*/ 		rIn >> bTmp; 
 /*N*/ 		mpObjectItemSet->Put(Svx3DDoubleSidedItem(bTmp));
@@ -1584,6 +1327,8 @@ namespace binfilter {
 /*N*/ 		// neue Parameter zur Geometrieerzeugung
 /*N*/ 		if (aCompat.GetBytesLeft () >= sizeof (BOOL))
 /*N*/ 		{
+/*N*/ 		    sal_uInt16 nTmp;
+/*N*/
 /*N*/ 			rIn >> bTmp; 
 /*N*/ 			bCreateNormals = bTmp;
 /*N*/ 
@@ -1672,22 +1417,6 @@ namespace binfilter {
 /*N*/ 	}
 /*N*/ }
 
-/*************************************************************************
-|*
-|* Bitmaps fuer 3D-Darstellung von Gradients und Hatches holen
-|*
-\************************************************************************/
-
-
-
-
-/*************************************************************************
-|*
-|* Give out simple line geometry
-|*
-\************************************************************************/
-
-
 /*************************************************************************
 |*
 |* Geometrieerzeugung
@@ -1936,13 +1665,13 @@ namespace binfilter {
 /*N*/ void E3dCompoundObject::CreateFront(
 /*N*/ 	const PolyPolygon3D& rPolyPoly3D,
 /*N*/ 	const PolyPolygon3D& rFrontNormals,
-/*N*/ 	BOOL bCreateNormals,
-/*N*/ 	BOOL bCreateTexture)
+/*N*/ 	BOOL bInCreateNormals,
+/*N*/ 	BOOL bInCreateTexture)
 /*N*/ {
 /*N*/ 	// Vorderseite
-/*N*/ 	if(bCreateNormals)
+/*N*/ 	if(bInCreateNormals)
 /*N*/ 	{
-/*N*/ 		if(bCreateTexture)
+/*N*/ 		if(bInCreateTexture)
 /*N*/ 		{
 /*N*/ 			// Polygon fuer die Textur erzeugen
 /*N*/ 			PolyPolygon3D aPolyTexture = rPolyPoly3D;
@@ -2004,19 +1733,19 @@ namespace binfilter {
 /*N*/ void E3dCompoundObject::CreateBack(
 /*N*/ 	const PolyPolygon3D& rPolyPoly3D,
 /*N*/ 	const PolyPolygon3D& rBackNormals,
-/*N*/ 	BOOL bCreateNormals,
-/*N*/ 	BOOL bCreateTexture)
+/*N*/ 	BOOL bInCreateNormals,
+/*N*/ 	BOOL bInCreateTexture)
 /*N*/ {
 /*N*/ 	// PolyPolygon umdrehen
 /*N*/ 	PolyPolygon3D aLocalPoly = rPolyPoly3D;
 /*N*/ 	aLocalPoly.FlipDirections();
 /*N*/ 
 /*N*/ 	// Rueckseite
-/*N*/ 	if(bCreateNormals)
+/*N*/ 	if(bInCreateNormals)
 /*N*/ 	{
 /*N*/ 		PolyPolygon3D aLocalNormals = rBackNormals;
 /*N*/ 		aLocalNormals.FlipDirections();
-/*N*/ 		if(bCreateTexture)
+/*N*/ 		if(bInCreateTexture)
 /*N*/ 		{
 /*N*/ 			// Polygon fuer die Textur erzeugen
 /*N*/ 			PolyPolygon3D aPolyTexture(aLocalPoly);
@@ -2082,19 +1811,19 @@ namespace binfilter {
 /*N*/ 	const PolyPolygon3D& rPolyPolyBack,
 /*N*/ 	const PolyPolygon3D& rFrontNormals,
 /*N*/ 	const PolyPolygon3D& rBackNormals,
-/*N*/ 	BOOL bCreateNormals,
+/*N*/ 	BOOL bInCreateNormals,
 /*N*/ 	double fSurroundFactor,
 /*N*/ 	double fTextureStart,
 /*N*/ 	double fTextureDepth,
 /*N*/ 	BOOL bRotateTexture90)
 /*N*/ {
 /*N*/ 	USHORT nPolyCnt = rPolyPolyFront.Count();
-/*N*/ 	BOOL bCreateTexture = (fTextureDepth == 0.0) ? FALSE : TRUE;
-/*N*/ 	double fPolyLength, fPolyPos;
-/*N*/ 	USHORT nLastIndex;
+/*N*/ 	BOOL bLclCreateTexture = (fTextureDepth == 0.0) ? FALSE : TRUE;
+/*N*/ 	double fPolyLength(0.0), fPolyPos(0.0);
+/*N*/ 	USHORT nLastIndex(0);
 /*N*/ 
 /*N*/ 	// Verbindungsstuecke
-/*N*/ 	if(bCreateNormals)
+/*N*/ 	if(bInCreateNormals)
 /*N*/ 	{
 /*N*/ 		for(UINT16 a=0;a<nPolyCnt;a++)
 /*N*/ 		{
@@ -2115,7 +1844,7 @@ namespace binfilter {
 /*N*/ 			aNormal3D[3] = rPolyNormalsFront[nPrefillIndex];
 /*N*/ 			aNormal3D[2] = rPolyNormalsBack[nPrefillIndex];
 /*N*/ 
-/*N*/ 			if(bCreateTexture)
+/*N*/ 			if(bLclCreateTexture)
 /*N*/ 			{
 /*N*/ 				fPolyLength = rPoly3DFront.GetLength();
 /*N*/ 				fPolyPos = 0.0;
@@ -2154,7 +1883,7 @@ namespace binfilter {
 /*N*/ 				aNormal3D[3] = rPolyNormalsFront[i];
 /*N*/ 				aNormal3D[2] = rPolyNormalsBack[i];
 /*N*/ 
-/*N*/ 				if(bCreateTexture)
+/*N*/ 				if(bLclCreateTexture)
 /*N*/ 				{
 /*N*/ 					// Texturkoordinaten ermitteln
 /*N*/ 					Vector3D aPart = rPoly3DFront[i] - rPoly3DFront[nLastIndex];
@@ -2300,22 +2029,6 @@ namespace binfilter {
 /*N*/ 	}
 /*N*/ }
 
-/*************************************************************************
-|*
-|* Copy-Operator
-|*
-\************************************************************************/
-
-
-/*************************************************************************
-|*
-|* Ausgabeparameter an 3D-Kontext setzen
-|*
-\************************************************************************/
-
-
-
-
 /*************************************************************************
 |*
 |* Hittest fuer 3D-Objekte, wird an Geometrie weitergegeben
@@ -2323,7 +2036,7 @@ namespace binfilter {
 \************************************************************************/
 
 /*N*/ SdrObject* E3dCompoundObject::CheckHit(const Point& rPnt, USHORT nTol,
-/*N*/ 	const SetOfByte* pVisiLayer) const
+/*N*/ 	const SetOfByte* /*pVisiLayer*/) const
 /*N*/ {
 /*N*/ 	E3dPolyScene* pScene = (E3dPolyScene*)GetScene();
 /*N*/ 	if(pScene)
@@ -2381,7 +2094,7 @@ namespace binfilter {
 /*N*/ 
 /*N*/ 						// 3D Volumes schneiden sich, teste in der Geometrie
 /*N*/ 						// auf Basis der Projektion weiter
-/*N*/ 						if(((E3dCompoundObject*)this)->aDisplayGeometry.CheckHit(aFront, aBack, nTol) != -1L)
+/*N*/ 						if(((E3dCompoundObject*)this)->aDisplayGeometry.CheckHit(aFront, aBack, nTol) == sal_True)
 /*?*/ 							return ((E3dCompoundObject*)this);
 /*N*/ 					}
 /*N*/ 				}
@@ -2391,24 +2104,12 @@ namespace binfilter {
 /*N*/ 	return NULL;
 /*N*/ }
 
-/*************************************************************************
-|*
-|* Geometrie des Objektes auf angegebenen Punkt zentrieren
-|*
-\************************************************************************/
-
-
 /*************************************************************************
 |*
 |* Schattenattribute holen
 |*
 \************************************************************************/
 
-
-
-
-
-
 /*N*/ BOOL E3dCompoundObject::DoDrawShadow()
 /*N*/ {
 /*N*/ 	const SfxItemSet& rSet = GetItemSet();
@@ -2430,13 +2131,6 @@ namespace binfilter {
 /*N*/ 	return bRetval;
 /*N*/ }
 
-/*************************************************************************
-|*
-|* Objekt als WireFrame zeichnen
-|*
-\************************************************************************/
-
-
 /*************************************************************************
 |*
 |* Create vertical polygons for line polygon
@@ -2509,8 +2203,8 @@ namespace binfilter {
 /*N*/ 	double fSurroundFactor,				// Wertebereich der Texturkoordinaten im Umlauf
 /*N*/ 	double fTextureStart,				// TexCoor ueber Extrude-Tiefe
 /*N*/ 	double fTextureDepth,				// TexCoor ueber Extrude-Tiefe
-/*N*/ 	BOOL bCreateTexture,
-/*N*/ 	BOOL bCreateNormals,
+/*N*/ 	BOOL bInCreateTexture,
+/*N*/ 	BOOL bInCreateNormals,
 /*N*/ 	BOOL bCharacterExtrude,				// FALSE=exakt, TRUE=ohne Ueberschneidungen
 /*N*/ 	BOOL bRotateTexture90,				// Textur der Seitenflaechen um 90 Grad kippen
 /*N*/ 	PolyPolygon3D* pLineGeometry		// For creation of line geometry
@@ -2546,11 +2240,11 @@ namespace binfilter {
 /*N*/ 			AddFrontNormals(rFront, aNormalsFront, aOffset);
 /*N*/ 
 /*N*/ 			if(!bSmoothFrontBack)
-/*N*/ 				CreateFront(rFront, aNormalsFront, bCreateNormals, bCreateTexture);
+/*N*/ 				CreateFront(rFront, aNormalsFront, bInCreateNormals, bInCreateTexture);
 /*N*/ 			if(bSmoothLeft)
 /*N*/ 				AddFrontNormals(rFront, aNormalsLeft, aOffset);
 /*N*/ 			if(bSmoothFrontBack)
-/*?*/ 				CreateFront(rFront, aNormalsLeft, bCreateNormals, bCreateTexture);
+/*?*/ 				CreateFront(rFront, aNormalsLeft, bInCreateNormals, bInCreateTexture);
 /*N*/ 		}
 /*N*/ 		else
 /*N*/ 		{
@@ -2565,11 +2259,11 @@ namespace binfilter {
 /*N*/ 			AddBackNormals(rBack, aNormalsBack, aOffset);
 /*N*/ 
 /*N*/ 			if(!bSmoothFrontBack)
-/*N*/ 				CreateBack(rBack, aNormalsBack, bCreateNormals, bCreateTexture);
+/*N*/ 				CreateBack(rBack, aNormalsBack, bInCreateNormals, bInCreateTexture);
 /*N*/ 			if(bSmoothRight)
 /*N*/ 				AddBackNormals(rBack, aNormalsRight, aOffset);
 /*N*/ 			if(bSmoothFrontBack)
-/*?*/ 				CreateBack(rBack, aNormalsRight, bCreateNormals, bCreateTexture);
+/*?*/ 				CreateBack(rBack, aNormalsRight, bInCreateNormals, bInCreateTexture);
 /*N*/ 		}
 /*N*/ 		else
 /*N*/ 		{
@@ -2580,7 +2274,7 @@ namespace binfilter {
 /*N*/ 		// eigentliches Zwischenstueck
 /*N*/ 		CreateInBetween(rFront, rBack,
 /*N*/ 			aNormalsLeft, aNormalsRight,
-/*N*/ 			bCreateNormals,
+/*N*/ 			bInCreateNormals,
 /*N*/ 			fSurroundFactor,
 /*N*/ 			fTextureStart,
 /*N*/ 			fTextureDepth,
@@ -2599,7 +2293,7 @@ namespace binfilter {
 /*N*/ 		// Mit Scraegen, Vorderseite
 /*N*/ 		PolyPolygon3D aLocalFront = rFront;
 /*N*/ 		PolyPolygon3D aLocalBack = rBack;
-/*N*/ 		double fExtrudeDepth, fDiagLen;
+/*N*/ 		double fExtrudeDepth, fDiagLen = 0.0;
 /*N*/ 		double fTexMidStart = fTextureStart;
 /*N*/ 		double fTexMidDepth = fTextureDepth;
 /*N*/ 
@@ -2700,14 +2394,14 @@ namespace binfilter {
 /*N*/ 			// vordere Zwischenstuecke erzeugen
 /*N*/ 			CreateInBetween(aOuterFront, aLocalFront,
 /*N*/ 				aNormalsOuterFront, aNormalsLeft,
-/*N*/ 				bCreateNormals,
+/*N*/ 				bInCreateNormals,
 /*N*/ 				fSurroundFactor,
 /*N*/ 				fTextureStart,
 /*N*/ 				fTextureDepth * fPercentDiag,
 /*N*/ 				bRotateTexture90);
 /*N*/ 
 /*N*/ 			// Vorderseite erzeugen
-/*N*/ 			CreateFront(aOuterFront, aNormalsOuterFront, bCreateNormals, bCreateTexture);
+/*N*/ 			CreateFront(aOuterFront, aNormalsOuterFront, bInCreateNormals, bInCreateTexture);
 /*N*/ 
 /*N*/ 			// Weitere Texturwerte setzen
 /*N*/ 			fTexMidStart += fTextureDepth * fPercentDiag;
@@ -2809,14 +2503,14 @@ namespace binfilter {
 /*N*/ 			// hintere Zwischenstuecke erzeugen
 /*N*/ 			CreateInBetween(aLocalBack, aOuterBack,
 /*N*/ 				aNormalsRight, aNormalsOuterBack,
-/*N*/ 				bCreateNormals,
+/*N*/ 				bInCreateNormals,
 /*N*/ 				fSurroundFactor,
 /*N*/ 				fTextureStart + (fTextureDepth * (1.0 - fPercentDiag)),
 /*N*/ 				fTextureDepth * fPercentDiag,
 /*N*/ 				bRotateTexture90);
 /*N*/ 
 /*N*/ 			// Rueckseite erzeugen
-/*N*/ 			CreateBack(aOuterBack, aNormalsOuterBack, bCreateNormals, bCreateTexture);
+/*N*/ 			CreateBack(aOuterBack, aNormalsOuterBack, bInCreateNormals, bInCreateTexture);
 /*N*/ 
 /*N*/ 			// Weitere Texturwerte setzen
 /*N*/ 			fTexMidDepth -= fTextureDepth * fPercentDiag;
@@ -2830,7 +2524,7 @@ namespace binfilter {
 /*N*/ 		// eigentliches Zwischenstueck
 /*N*/ 		CreateInBetween(aLocalFront, aLocalBack,
 /*N*/ 			aNormalsLeft, aNormalsRight,
-/*N*/ 			bCreateNormals,
+/*N*/ 			bInCreateNormals,
 /*N*/ 			fSurroundFactor,
 /*N*/ 			fTexMidStart,
 /*N*/ 			fTexMidDepth,
@@ -2851,14 +2545,6 @@ namespace binfilter {
 /*N*/ 	}
 /*N*/ }
 
-/*************************************************************************
-|*
-|* Parameter Geometrieerzeugung setzen
-|*
-\************************************************************************/
-
-
-
 /*************************************************************************
 |*
 |* DisplayGeometry rausruecken
@@ -2888,38 +2574,6 @@ namespace binfilter {
 /*N*/ 	}
 /*N*/ }
 
-
-
-/*************************************************************************
-|*
-|* 3D Ausgabe
-|*
-\************************************************************************/
-
-
-/*************************************************************************
-|*
-|* Objekt als Kontur in das Polygon einfuegen
-|*
-\************************************************************************/
-
-
-/*************************************************************************
-|*
-|* Schatten fuer 3D-Objekte zeichnen
-|*
-\************************************************************************/
-
-
-
-
-/*************************************************************************
-|*
-|* convert given PolyPolygon3D to screen coor
-|*
-\************************************************************************/
-
-
 /*************************************************************************
 |*
 |* Attribute setzen
