@@ -98,7 +98,9 @@ using namespace ::com::sun::star;
 
 // Konvertierung fuer UNO
 #define TWIP_TO_MM100(TWIP) 	((TWIP) >= 0 ? (((TWIP)*127L+36L)/72L) : (((TWIP)*127L-36L)/72L))
+#define UTWIP_TO_MM100(TWIP) 	(((TWIP)*127L+36L)/72L)
 #define MM100_TO_TWIP(MM100)	((MM100) >= 0 ? (((MM100)*72L+63L)/127L) : (((MM100)*72L-63L)/127L))
+#define UMM100_TO_TWIP(MM100)	(((MM100)*72L+63L)/127L)
 
 
 // STATIC DATA -----------------------------------------------------------
@@ -160,14 +162,11 @@ using namespace ::com::sun::star;
 /*N*/ 				1 : 0;
 /*N*/ }
 
-/*-----------------18.03.98 16:32-------------------
-    os: wer weiss noch, wieso das LineSpacingItem so
+/* os: wer weiss noch, wieso das LineSpacingItem so
     kompliziert ist? Fuer UNO koennen wir das nicht
     gebrauchen. Da gibt es nur zwei Werte:
         - ein sal_uInt16 fuer den Modus
-        - ein sal_uInt32 fuer alle Werte (Abstand, Hoehe, rel. Angaben)
-
---------------------------------------------------*/
+        - ein sal_uInt32 fuer alle Werte (Abstand, Hoehe, rel. Angaben) */
 /*N*/ bool SvxLineSpacingItem::QueryValue( uno::Any& rVal, BYTE nMemberId ) const
 /*N*/ {
 /*N*/ 	sal_Bool bConvert = 0!=(nMemberId&CONVERT_TWIPS);
@@ -196,8 +195,10 @@ using namespace ::com::sun::star;
 /*N*/ 		case SVX_LINE_SPACE_FIX :
 /*N*/ 		case SVX_LINE_SPACE_MIN :
 /*N*/ 			aLSp.Mode = eLineSpace == SVX_LINE_SPACE_FIX ? style::LineSpacingMode::FIX : style::LineSpacingMode::MINIMUM;
-/*N*/             aLSp.Height = ( bConvert ? (short)TWIP_TO_MM100(nLineHeight) : nLineHeight );
+/*N*/             aLSp.Height = ( bConvert ? (short)UTWIP_TO_MM100(nLineHeight) : nLineHeight );
 /*N*/ 		break;
+            default:
+                break;
 /*N*/ 	}
 /*N*/ 
 /*N*/     switch ( nMemberId )
@@ -205,14 +206,13 @@ using namespace ::com::sun::star;
 /*?*/         case 0 :                rVal <<= aLSp; break;
 /*?*/         case MID_LINESPACE :    rVal <<= aLSp.Mode; break;
 /*?*/         case MID_HEIGHT :       rVal <<= aLSp.Height; break;
-/*?*/         default: DBG_ERROR("Wrong MemberId!"); break;
+/*?*/         default: OSL_FAIL("Wrong MemberId!"); break;
 /*N*/     }
 /*N*/ 
 /*N*/ 	return sal_True;
 /*N*/ }
-/*-----------------18.03.98 16:32-------------------
 
---------------------------------------------------*/
+
 /*N*/ bool SvxLineSpacingItem::PutValue( const uno::Any& rVal, BYTE nMemberId )
 /*N*/ {
 /*N*/ 	sal_Bool bConvert = 0!=(nMemberId&CONVERT_TWIPS);
@@ -229,7 +229,7 @@ using namespace ::com::sun::star;
 /*N*/         case 0 :                bRet = (rVal >>= aLSp); break;
 /*?*/         case MID_LINESPACE :    bRet = (rVal >>= aLSp.Mode); break;
 /*?*/         case MID_HEIGHT :       bRet = (rVal >>= aLSp.Height); break;
-/*N*/         default: DBG_ERROR("Wrong MemberId!"); break;
+/*N*/         default: OSL_FAIL("Wrong MemberId!"); break;
 /*N*/     }
 /*N*/ 
 /*N*/     if( bRet )
@@ -261,7 +261,7 @@ using namespace ::com::sun::star;
 /*N*/                 eLineSpace = aLSp.Mode == style::LineSpacingMode::FIX ? SVX_LINE_SPACE_FIX : SVX_LINE_SPACE_MIN;
 /*N*/                 nLineHeight = aLSp.Height;
 /*N*/                 if(bConvert)
-/*N*/                     nLineHeight = (USHORT)MM100_TO_TWIP(nLineHeight);
+/*N*/                     nLineHeight = (USHORT)UMM100_TO_TWIP(nLineHeight);
 /*N*/             }
 /*N*/             break;
 /*N*/         }
@@ -305,7 +305,7 @@ using namespace ::com::sun::star;
 
 // -----------------------------------------------------------------------
 
-/*N*/ SvStream& SvxLineSpacingItem::Store( SvStream& rStrm, sal_uInt16 nItemVersion ) const
+/*N*/ SvStream& SvxLineSpacingItem::Store( SvStream& rStrm, sal_uInt16 /*nItemVersion*/ ) const
 /*N*/ {
 /*N*/ 	rStrm << (sal_Int8)  GetPropLineSpace()
 /*N*/ 		  << (short)  GetInterLineSpace()
@@ -319,14 +319,14 @@ using namespace ::com::sun::star;
 
 /*?*/ sal_uInt16 SvxLineSpacingItem::GetValueCount() const
 /*?*/ {
-/*?*/ 		DBG_BF_ASSERT(0, "STRIP"); return SVX_LINESPACE_END;//STRIP001 /*?*/ 	return SVX_LINESPACE_END;	// SVX_LINESPACE_TWO_LINES + 1
+/*?*/ 		DBG_BF_ASSERT(0, "STRIP"); return SVX_LINESPACE_END;
 /*?*/ }
 
 // -----------------------------------------------------------------------
 
-/*?*/ XubString SvxLineSpacingItem::GetValueTextByPos( sal_uInt16 nPos ) const
+/*?*/ XubString SvxLineSpacingItem::GetValueTextByPos( sal_uInt16 /*nPos*/ ) const
 /*?*/ {
-/*?*/ DBG_BF_ASSERT(0, "STRIP"); XubString aText;//STRIP001 //STRIP001 	//! Strings demnaechst aus Resource laden
+/*?*/ DBG_BF_ASSERT(0, "STRIP"); XubString aText;
 /*?*/ 	return aText;
 /*?*/ }
 
@@ -334,14 +334,14 @@ using namespace ::com::sun::star;
 
 /*?*/ sal_uInt16 SvxLineSpacingItem::GetEnumValue() const
 /*?*/ {
-/*?*/ DBG_BF_ASSERT(0, "STRIP"); return 0;//STRIP001 //STRIP001 	sal_uInt16 nVal;
+/*?*/ DBG_BF_ASSERT(0, "STRIP"); return 0;
 /*?*/ }
 
 // -----------------------------------------------------------------------
 
-/*?*/ void SvxLineSpacingItem::SetEnumValue( sal_uInt16 nVal )
+/*?*/ void SvxLineSpacingItem::SetEnumValue( sal_uInt16 /*nVal*/ )
 /*?*/ {
-/*?*/ 		DBG_BF_ASSERT(0, "STRIP"); //STRIP001 //STRIP001 	switch ( nVal )
+/*?*/ 		DBG_BF_ASSERT(0, "STRIP");
 /*?*/ }
 
 // class SvxAdjustItem ---------------------------------------------------
@@ -366,12 +366,11 @@ using namespace ::com::sun::star;
 /*N*/ 		? 1 : 0 );
 /*N*/ }
 
-/*-----------------18.03.98 16:15-------------------
 
---------------------------------------------------*/
+
 /*N*/ bool SvxAdjustItem::QueryValue( uno::Any& rVal, BYTE nMemberId ) const
 /*N*/ {
-/*N*/     sal_Bool bConvert = 0!=(nMemberId&CONVERT_TWIPS);
+/*N*/
 /*N*/     nMemberId &= ~CONVERT_TWIPS;
 /*N*/ 	switch( nMemberId )
 /*N*/ 	{
@@ -386,13 +385,12 @@ using namespace ::com::sun::star;
 /*N*/ 	}
 /*N*/ 	return sal_True;
 /*N*/ }
-/*-----------------18.03.98 16:15-------------------
 
---------------------------------------------------*/
+
 
 /*N*/ bool SvxAdjustItem::PutValue( const uno::Any& rVal, BYTE nMemberId  )
 /*N*/ {
-/*N*/     sal_Bool bConvert = 0!=(nMemberId&CONVERT_TWIPS);
+/*N*/
 /*N*/     nMemberId &= ~CONVERT_TWIPS;
 /*N*/ 	switch( nMemberId )
 /*N*/ 	{
@@ -440,7 +438,7 @@ using namespace ::com::sun::star;
 
 /*?*/ sal_uInt16 SvxAdjustItem::GetValueCount() const
 /*?*/ {
-/*?*/ DBG_BF_ASSERT(0, "STRIP"); return 0;//STRIP001 	return SVX_ADJUST_END;	// SVX_ADJUST_BLOCKLINE + 1
+/*?*/ DBG_BF_ASSERT(0, "STRIP"); return 0;
 /*?*/ }
 
 // -----------------------------------------------------------------------
@@ -450,13 +448,13 @@ using namespace ::com::sun::star;
 
 /*?*/ sal_uInt16 SvxAdjustItem::GetEnumValue() const
 /*?*/ {
-/*?*/ DBG_BF_ASSERT(0, "STRIP"); return 0;//STRIP001 	return GetAdjust();
+/*?*/ DBG_BF_ASSERT(0, "STRIP"); return 0;
 /*?*/ }
 
 // -----------------------------------------------------------------------
 
-/*N*/ void SvxAdjustItem::SetEnumValue( sal_uInt16 nVal )
-/*N*/ {DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
+/*N*/ void SvxAdjustItem::SetEnumValue( sal_uInt16 /*nVal*/ )
+/*N*/ {DBG_BF_ASSERT(0, "STRIP");
 /*N*/ }
 
 // -----------------------------------------------------------------------
@@ -576,7 +574,7 @@ using namespace ::com::sun::star;
 // -----------------------------------------------------------------------
 /*N*/ bool	SvxHyphenZoneItem::QueryValue( uno::Any& rVal, BYTE nMemberId ) const
 /*N*/ {
-/*N*/     sal_Bool bConvert = 0!=(nMemberId&CONVERT_TWIPS);
+/*N*/
 /*N*/     nMemberId &= ~CONVERT_TWIPS;
 /*N*/ 	switch(nMemberId)
 /*N*/ 	{
@@ -598,7 +596,7 @@ using namespace ::com::sun::star;
 // -----------------------------------------------------------------------
 /*N*/ bool SvxHyphenZoneItem::PutValue( const uno::Any& rVal, BYTE nMemberId )
 /*N*/ {
-/*N*/     sal_Bool bConvert = 0!=(nMemberId&CONVERT_TWIPS);
+/*N*/
 /*N*/     nMemberId &= ~CONVERT_TWIPS;
 /*N*/ 	sal_Int16 nNewVal = 0;
 /*N*/ 
@@ -651,21 +649,21 @@ using namespace ::com::sun::star;
 
 /*N*/ SfxPoolItem* SvxHyphenZoneItem::Create(SvStream& rStrm, sal_uInt16) const
 /*N*/ {
-/*N*/ 	sal_Int8 bHyphen, bHyphenPageEnd;
-/*N*/ 	sal_Int8 nMinLead, nMinTrail, nMaxHyphens;
-/*N*/ 	rStrm >> bHyphen >> bHyphenPageEnd >> nMinLead >> nMinTrail >> nMaxHyphens;
+/*N*/ 	sal_Int8 _bHyphen, bHyphenPageEnd;
+/*N*/ 	sal_Int8 _nMinLead, _nMinTrail, _nMaxHyphens;
+/*N*/ 	rStrm >> _bHyphen >> bHyphenPageEnd >> _nMinLead >> _nMinTrail >> _nMaxHyphens;
 /*N*/ 	SvxHyphenZoneItem* pAttr = new SvxHyphenZoneItem( sal_False, Which() );
-/*N*/ 	pAttr->SetHyphen( sal_Bool( bHyphen != 0 ) );
+/*N*/ 	pAttr->SetHyphen( sal_Bool( _bHyphen != 0 ) );
 /*N*/ 	pAttr->SetPageEnd( sal_Bool( bHyphenPageEnd != 0 ) );
-/*N*/ 	pAttr->GetMinLead() = nMinLead;
-/*N*/ 	pAttr->GetMinTrail() = nMinTrail;
-/*N*/ 	pAttr->GetMaxHyphens() = nMaxHyphens;
+/*N*/ 	pAttr->GetMinLead() = _nMinLead;
+/*N*/ 	pAttr->GetMinTrail() = _nMinTrail;
+/*N*/ 	pAttr->GetMaxHyphens() = _nMaxHyphens;
 /*N*/ 	return pAttr;
 /*N*/ }
 
 // -----------------------------------------------------------------------
 
-/*N*/ SvStream& SvxHyphenZoneItem::Store( SvStream& rStrm, sal_uInt16 nItemVersion ) const
+/*N*/ SvStream& SvxHyphenZoneItem::Store( SvStream& rStrm, sal_uInt16 /*nItemVersion*/ ) const
 /*N*/ {
 /*N*/ 	rStrm << (sal_Int8) IsHyphen()
 /*N*/ 		  << (sal_Int8) IsPageEnd()
@@ -774,9 +772,8 @@ struct	 ::com::sun::star::style::TabStop
 typedef sequence ::com::sun::star::style::TabStop> TabSTopSequence;
 
  */
-/*-----------------19.03.98 08:50-------------------
 
---------------------------------------------------*/
+
 
 /*N*/ bool SvxTabStopItem::QueryValue( uno::Any& rVal, BYTE nMemberId ) const
 /*N*/ {
@@ -818,9 +815,8 @@ typedef sequence ::com::sun::star::style::TabStop> TabSTopSequence;
 /*N*/ 	}
 /*N*/ 	return sal_True;
 /*N*/ }
-/*-----------------19.03.98 08:50-------------------
 
---------------------------------------------------*/
+
 
 /*N*/ bool SvxTabStopItem::PutValue( const uno::Any& rVal, BYTE nMemberId )
 /*N*/ {
@@ -846,7 +842,7 @@ typedef sequence ::com::sun::star::style::TabStop> TabSTopSequence;
 /*?*/                         if (!(rAnySeq[0] >>= aSeq[n].Position)) return sal_False;
 /*?*/                         if (!(rAnySeq[1] >>= aSeq[n].Alignment))
 /*?*/                         {
-/*?*/                             sal_Int32 nVal;
+/*?*/                             sal_Int32 nVal = 0;
 /*?*/                             if (rAnySeq[1] >>= nVal)
 /*?*/                                 aSeq[n].Alignment = (::com::sun::star::style::TabAlign) nVal;
 /*?*/                             else
@@ -886,6 +882,7 @@ typedef sequence ::com::sun::star::style::TabStop> TabSTopSequence;
 /*N*/                 case style::TabAlign_CENTER : eAdjust = SVX_TAB_ADJUST_CENTER; break;
 /*N*/                 case style::TabAlign_RIGHT  : eAdjust = SVX_TAB_ADJUST_RIGHT; break;
 /*N*/                 case style::TabAlign_DECIMAL: eAdjust = SVX_TAB_ADJUST_DECIMAL; break;
+                      default: break;
 /*N*/                 }
 /*N*/                 sal_Unicode cFill = pArr[i].FillChar;
 /*N*/                 sal_Unicode cDecimal = pArr[i].DecimalChar;
@@ -899,7 +896,7 @@ typedef sequence ::com::sun::star::style::TabStop> TabSTopSequence;
 /*N*/         }
 /*N*/         case MID_STD_TAB:
 /*N*/         {
-/*N*/             sal_Int32 nNewPos;
+/*N*/             sal_Int32 nNewPos = 0;
 /*N*/             if (!(rVal >>= nNewPos) )
 /*N*/                 return sal_False;
 /*N*/             const SvxTabStop& rTab = *(GetStart());
@@ -963,7 +960,7 @@ typedef sequence ::com::sun::star::style::TabStop> TabSTopSequence;
 
 // -----------------------------------------------------------------------
 
-/*N*/ SvStream& SvxTabStopItem::Store( SvStream& rStrm, sal_uInt16 nItemVersion ) const
+/*N*/ SvStream& SvxTabStopItem::Store( SvStream& rStrm, sal_uInt16 /*nItemVersion*/ ) const
 /*N*/ {
 /*N*/ 	//MA 05. Sep. 96: Default-Tabs werden nur noch fuer das default-Attr
 /*N*/ 	//expandiert. Fuer vollstaendige Rueckwaertskompatibilitaet (<=304)
@@ -972,13 +969,13 @@ typedef sequence ::com::sun::star::style::TabStop> TabSTopSequence;
 /*N*/ 	//Alles nur SWG!
 /*N*/ 
 /*N*/ 	const SfxItemPool *pPool = SfxItemPool::GetStoringPool();
-/*N*/ 	const FASTBOOL bStoreDefTabs = pPool
+/*N*/ 	const bool bStoreDefTabs = pPool
 /*N*/ 		&& pPool->GetName().EqualsAscii("SWG")
 /*N*/ 		&& binfilter::IsDefaultItem( this );
 /*N*/ 
 /*N*/ 	const short nTabs = Count();
-/*N*/ 	sal_uInt16 	nCount = 0, nDefDist;
-/*N*/ 	long nNew;
+/*N*/ 	sal_uInt16 	nCount = 0, nDefDist = 0;
+/*N*/ 	long nNew = 0;
 /*N*/ 
 /*N*/ 	if( bStoreDefTabs )
 /*N*/ 	{
@@ -1043,7 +1040,7 @@ typedef sequence ::com::sun::star::style::TabStop> TabSTopSequence;
 
 // -----------------------------------------------------------------------
 
-/*N*/ SvStream& SvxFmtSplitItem::Store( SvStream& rStrm, sal_uInt16 nItemVersion ) const
+/*N*/ SvStream& SvxFmtSplitItem::Store( SvStream& rStrm, sal_uInt16 /*nItemVersion*/ ) const
 /*N*/ {
 /*N*/ 	rStrm << (sal_Int8)GetValue();
 /*N*/ 	return rStrm;
@@ -1076,7 +1073,7 @@ typedef sequence ::com::sun::star::style::TabStop> TabSTopSequence;
 /*N*/ {
 /*N*/ }
 
-/*N*/ SfxPoolItem* SvxScriptSpaceItem::Clone( SfxItemPool *pPool ) const
+/*N*/ SfxPoolItem* SvxScriptSpaceItem::Clone( SfxItemPool* /*pPool*/ ) const
 /*N*/ {
 /*N*/ 	return new SvxScriptSpaceItem( GetValue(), Which() );
 /*N*/ }
@@ -1107,7 +1104,7 @@ typedef sequence ::com::sun::star::style::TabStop> TabSTopSequence;
 /*N*/ {
 /*N*/ }
 
-/*N*/ SfxPoolItem* SvxHangingPunctuationItem::Clone( SfxItemPool *pPool ) const
+/*N*/ SfxPoolItem* SvxHangingPunctuationItem::Clone( SfxItemPool* /*pPool*/ ) const
 /*N*/ {
 /*N*/ 	return new SvxHangingPunctuationItem( GetValue(), Which() );
 /*N*/ }
@@ -1136,25 +1133,22 @@ typedef sequence ::com::sun::star::style::TabStop> TabSTopSequence;
 /*N*/ 	: SfxBoolItem( nId, bOn )
 /*N*/ {
 /*N*/ }
-/* -----------------------------29.11.00 11:23--------------------------------
 
- ---------------------------------------------------------------------------*/
-/*N*/ SfxPoolItem* SvxForbiddenRuleItem::Clone( SfxItemPool *pPool ) const
+
+/*N*/ SfxPoolItem* SvxForbiddenRuleItem::Clone( SfxItemPool* /*pPool*/ ) const
 /*N*/ {
 /*N*/ 	return new SvxForbiddenRuleItem( GetValue(), Which() );
 /*N*/ }
-/* -----------------------------29.11.00 11:23--------------------------------
 
- ---------------------------------------------------------------------------*/
+
 /*N*/ SfxPoolItem* SvxForbiddenRuleItem::Create(SvStream & rStrm, USHORT) const
 /*N*/ {
 /*N*/ 	sal_Bool nValue;
 /*N*/ 	rStrm >> nValue;
 /*N*/ 	return new SvxForbiddenRuleItem( nValue, Which() );
 /*N*/ }
-/* -----------------------------29.11.00 11:23--------------------------------
 
- ---------------------------------------------------------------------------*/
+
 /*N*/ USHORT SvxForbiddenRuleItem::GetVersion( USHORT nFFVer ) const
 /*N*/ {
 /*N*/ 	DBG_ASSERT( SOFFICE_FILEFORMAT_31==nFFVer ||
@@ -1164,9 +1158,8 @@ typedef sequence ::com::sun::star::style::TabStop> TabSTopSequence;
 /*N*/ 
 /*N*/ 	return SOFFICE_FILEFORMAT_50 > nFFVer ? USHRT_MAX : 0;
 /*N*/ }
-/* -----------------------------29.11.00 11:23--------------------------------
 
- ---------------------------------------------------------------------------*/
+
 
 /*************************************************************************
 |*    class SvxParaVertAlignItem
@@ -1196,12 +1189,12 @@ typedef sequence ::com::sun::star::style::TabStop> TabSTopSequence;
 /*N*/ {
 /*N*/ }
 
-/*N*/ SfxPoolItem* SvxParaGridItem::Clone( SfxItemPool *pPool ) const
-/*N*/ {DBG_BF_ASSERT(0, "STRIP"); return NULL;//STRIP001 
+/*N*/ SfxPoolItem* SvxParaGridItem::Clone( SfxItemPool* /*pPool*/ ) const
+/*N*/ {DBG_BF_ASSERT(0, "STRIP"); return NULL;
 /*N*/ }
 
-/*N*/ SfxPoolItem* SvxParaGridItem::Create(SvStream & rStrm, USHORT) const
-/*N*/ {DBG_BF_ASSERT(0, "STRIP"); return NULL;//STRIP001 
+/*N*/ SfxPoolItem* SvxParaGridItem::Create(SvStream & /*rStrm*/, USHORT) const
+/*N*/ {DBG_BF_ASSERT(0, "STRIP"); return NULL;
 /*N*/ }
 
 /*N*/ USHORT  SvxParaGridItem::GetVersion( USHORT nFFVer ) const
@@ -1216,8 +1209,8 @@ typedef sequence ::com::sun::star::style::TabStop> TabSTopSequence;
 
 /*N*/ SfxItemPresentation SvxParaGridItem::GetPresentation(
 /*N*/ 		SfxItemPresentation ePres,
-/*N*/ 		SfxMapUnit eCoreMetric, SfxMapUnit ePresMetric,
-/*N*/         String &rText, const ::IntlWrapper* pIntl ) const
+/*N*/ 		SfxMapUnit /*eCoreMetric*/, SfxMapUnit /*ePresMetric*/,
+/*N*/         String &rText, const ::IntlWrapper* /*pIntl*/ ) const
 /*N*/ {
 /*?*/ 	switch( ePres )
 /*?*/ 	{
@@ -1234,6 +1227,8 @@ typedef sequence ::com::sun::star::style::TabStop> TabSTopSequence;
 /*?*/ 			return ePres;
 /*?*/ 		}
 /*?*/ 		break;
+        default:
+            break;
 /*?*/ 	}
 /*?*/ 	return SFX_ITEM_PRESENTATION_NONE;
 /*N*/ }
