@@ -68,7 +68,7 @@ class InputStorageWrapper_Impl : public ::cppu::WeakImplHelper1<stario::XInputSt
     TempFile aTempFile;
 
 public:
-    InputStorageWrapper_Impl( SvPersist *pPersist );
+    InputStorageWrapper_Impl( SvPersist * );
     virtual ~InputStorageWrapper_Impl();
 
     virtual sal_Int32	SAL_CALL	readBytes(staruno::Sequence< sal_Int8 >& aData, sal_Int32 nBytesToRead) throw(stario::NotConnectedException, stario::BufferSizeExceededException, staruno::RuntimeException);
@@ -80,7 +80,7 @@ public:
 
 
 /*N*/ InputStorageWrapper_Impl::InputStorageWrapper_Impl(
-/*N*/ 		SvPersist *pPersist )
+/*N*/ 		SvPersist * )
 /*N*/ {
 /*N*/ 	SvStream *pStream = 0;
 /*N*/ 	aTempFile.EnableKillingFile();
@@ -88,10 +88,8 @@ public:
 /*N*/ 	SvStorageRef aTempStor = new SvStorage( sal_False, *pStream );
 /*N*/	// the object should not be stored in 5.2 storage since the alien objects are stored in a wrapped way in this case
 /*N*/	aTempStor->SetVersion( SOFFICE_FILEFORMAT_31 );
-/*N*/ 	if( pPersist->DoSaveAs( aTempStor ) )
-/*N*/ 	{
-/*N*/ 		aTempStor->Commit();
-/*N*/ 	}
+/*N*/ 	if( false )
+/*N*/ 	{}
 /*N*/ 	else
 /*N*/ 	{
 /*?*/ 		aTempStor.Clear();
@@ -121,29 +119,29 @@ public:
 /*N*/ }
 
 /*?*/ sal_Int32 SAL_CALL InputStorageWrapper_Impl::readSomeBytes(
-/*?*/ 		Sequence< sal_Int8 >& aData,
-/*?*/ 		sal_Int32 nMaxBytesToRead)
+/*?*/ 		Sequence< sal_Int8 >& /*rData*/,
+/*?*/ 		sal_Int32 /*nMaxBytesToRead*/)
 /*?*/ 	throw(NotConnectedException, BufferSizeExceededException, RuntimeException)
 /*?*/ {
-/*?*/ DBG_BF_ASSERT(0, "STRIP"); return 0;//STRIP001 	MutexGuard			aGuard( maMutex );
+/*?*/ DBG_BF_ASSERT(0, "STRIP"); return 0;
 /*?*/ }
 
-/*?*/ void SAL_CALL InputStorageWrapper_Impl::skipBytes( sal_Int32 nBytesToSkip )
+/*?*/ void SAL_CALL InputStorageWrapper_Impl::skipBytes( sal_Int32 /*nBytesToSkip*/ )
 /*?*/ 	throw(NotConnectedException, BufferSizeExceededException, RuntimeException)
 /*?*/ {
-/*?*/ DBG_BF_ASSERT(0, "STRIP"); //STRIP001 	MutexGuard			aGuard( maMutex );
+/*?*/ DBG_BF_ASSERT(0, "STRIP");
 /*?*/ }
 
 /*?*/ sal_Int32 SAL_CALL InputStorageWrapper_Impl::available()
 /*?*/ 	throw(NotConnectedException, RuntimeException)
 /*?*/ {
-/*?*/ DBG_BF_ASSERT(0, "STRIP"); return NULL;//STRIP001 	MutexGuard			aGuard( maMutex );
+/*?*/ DBG_BF_ASSERT(0, "STRIP"); return 0;
 /*?*/ }
 
 /*?*/ void SAL_CALL InputStorageWrapper_Impl::closeInput()
 /*?*/ 	throw(NotConnectedException, RuntimeException)
 /*?*/ {
-/*?*/ DBG_BF_ASSERT(0, "STRIP"); //STRIP001 	MutexGuard			aGuard( maMutex );
+/*?*/ DBG_BF_ASSERT(0, "STRIP");
 /*?*/ }
 
 // -----------------------------------------------------------------------------
@@ -213,7 +211,7 @@ public:
 /*?*/ void SAL_CALL OutputStorageWrapper_Impl::flush()
 /*?*/ 	throw(NotConnectedException, BufferSizeExceededException, RuntimeException)
 /*?*/ {
-/*?*/ DBG_BF_ASSERT(0, "STRIP"); //STRIP001 	MutexGuard			aGuard( maMutex );
+/*?*/ DBG_BF_ASSERT(0, "STRIP");
 /*?*/ }
 
 /*N*/ void SAL_CALL OutputStorageWrapper_Impl::closeOutput()
@@ -245,8 +243,8 @@ struct OUStringLess
 /*N*/ 	maDefaultContainerStorageName( RTL_CONSTASCII_USTRINGPARAM(XML_CONTAINERSTORAGE_NAME) ),
 /*N*/ 	mpRootStorage( 0 ),
 /*N*/ 	mpDocPersist( 0 ),
-/*N*/ 	mpStreamMap( 0 ),
-/*N*/ 	meCreateMode( EMBEDDEDOBJECTHELPER_MODE_READ )
+/*N*/ 	meCreateMode( EMBEDDEDOBJECTHELPER_MODE_READ ),
+/*N*/ 	mpStreamMap( 0 )
 /*N*/ {
 /*N*/ }
 
@@ -255,8 +253,8 @@ struct OUStringLess
 /*N*/ 	maDefaultContainerStorageName( RTL_CONSTASCII_USTRINGPARAM(XML_CONTAINERSTORAGE_NAME) ),
 /*N*/ 	mpRootStorage( 0 ),
 /*N*/ 	mpDocPersist( 0 ),
-/*N*/ 	mpStreamMap( 0 ),
-/*N*/ 	meCreateMode( EMBEDDEDOBJECTHELPER_MODE_READ )
+/*N*/ 	meCreateMode( EMBEDDEDOBJECTHELPER_MODE_READ ),
+/*N*/ 	mpStreamMap( 0 )
 /*N*/ {
 /*N*/ 	Init( 0, rDocPersist, eCreateMode );
 /*N*/ }
@@ -270,7 +268,7 @@ struct OUStringLess
 /*N*/ 	{
 /*?*/ 		SvXMLEmbeddedObjectHelper_Impl::iterator aIter = mpStreamMap->begin();
 /*?*/ 		SvXMLEmbeddedObjectHelper_Impl::iterator aEnd = mpStreamMap->end();
-/*?*/ 		for( aIter; aIter != aEnd; aIter++ )
+/*?*/ 		for( ; aIter != aEnd; ++aIter )
 /*?*/ 		{
 /*?*/ 			if( aIter->second )
 /*?*/ 			{
@@ -302,7 +300,6 @@ struct OUStringLess
 /*N*/ 	// 			 or: #<path>/<object-name>
 /*N*/ 	// 			 or: #<object-name>
 /*N*/ 	// currently, path may only consist of a single directory name
-/*N*/ 	sal_Bool	bRet = sal_False;
 /*N*/ 
 /*N*/ 	if( !rURLStr.getLength() )
 /*N*/ 		return sal_False;
@@ -354,7 +351,7 @@ struct OUStringLess
 /*N*/ 
 /*N*/ 	if( -1 != rContainerStorageName.indexOf( '/' ) )
 /*N*/ 	{
-/*?*/ 		DBG_ERROR( "SvXMLEmbeddedObjectHelper: invalid path name" );
+/*?*/ 		OSL_FAIL( "SvXMLEmbeddedObjectHelper: invalid path name" );
 /*?*/ 		return sal_False;
 /*N*/ 	}
 /*N*/ 
@@ -401,7 +398,7 @@ struct OUStringLess
 /*?*/ SvStorageRef SvXMLEmbeddedObjectHelper::ImplGetObjectStorage(
 /*?*/ 		const OUString& rContainerStorageName,
 /*?*/ 		const OUString& rObjectStorageName,
-/*?*/ 		sal_Bool bUCBStorage )
+/*?*/ 		sal_Bool /*bUCBStorage*/ )
 /*?*/ {
 /*?*/ 	SvStorageRef xObjStor;
 /*?*/ 	SvStorageRef xCntnrStor( ImplGetContainerStorage( rContainerStorageName ) ); 
@@ -520,7 +517,7 @@ struct OUStringLess
 /*N*/ 
 /*N*/ 	// For all unkown class id, the OLE object has to be wrapped by an
 /*N*/ 	// outplace object.
-/*N*/ 	SvGlobalName aOutClassId( SO3_OUT_CLASSID ); //STRIP003 
+/*N*/ 	SvGlobalName aOutClassId( SO3_OUT_CLASSID );
 /*N*/ 	if( SvGlobalName() == aClassId ||
 /*N*/ 		( aOutClassId != aClassId &&
 /*N*/ 		  !SvFactory::IsIntern( aClassId, 0 ) ) )
@@ -608,7 +605,7 @@ struct OUStringLess
 /*N*/ 		SvStorage& rRootStorage, 
 /*N*/ 		SvPersist& rDocPersist, 
 /*N*/ 		SvXMLEmbeddedObjectHelperMode eCreateMode,
-/*N*/ 		sal_Bool bDirect )
+/*N*/ 		sal_Bool /*bDirect*/ )
 /*N*/ {
 /*N*/ 	SvXMLEmbeddedObjectHelper* pThis = new SvXMLEmbeddedObjectHelper;
 /*N*/ 
@@ -707,26 +704,26 @@ struct OUStringLess
 /*?*/ Sequence< OUString > SAL_CALL SvXMLEmbeddedObjectHelper::getElementNames()
 /*?*/ 	throw (RuntimeException)
 /*?*/ {
-/*?*/ DBG_BF_ASSERT(0, "STRIP"); Sequence< OUString > aSeq; return aSeq;//STRIP001 	MutexGuard			aGuard( maMutex );
+/*?*/ DBG_BF_ASSERT(0, "STRIP"); Sequence< OUString > aSeq; return aSeq;
 /*?*/ }
 
-/*?*/ sal_Bool SAL_CALL SvXMLEmbeddedObjectHelper::hasByName( const OUString& rURLStr )
+/*?*/ sal_Bool SAL_CALL SvXMLEmbeddedObjectHelper::hasByName( const OUString& )
 /*?*/ 	throw (RuntimeException)
 /*?*/ {
-/*?*/ DBG_BF_ASSERT(0, "STRIP"); return FALSE;//STRIP001 	MutexGuard			aGuard( maMutex );
+/*?*/ DBG_BF_ASSERT(0, "STRIP"); return FALSE;
 /*?*/ }
 
 // XNameAccess
 /*?*/ Type SAL_CALL SvXMLEmbeddedObjectHelper::getElementType()
 /*?*/ 	throw (RuntimeException)
 /*?*/ {
-/*?*/ DBG_BF_ASSERT(0, "STRIP"); Type aType; return aType;//STRIP001 	MutexGuard			aGuard( maMutex );
+/*?*/ DBG_BF_ASSERT(0, "STRIP"); Type aType; return aType;
 /*?*/ }
 
 /*?*/ sal_Bool SAL_CALL SvXMLEmbeddedObjectHelper::hasElements()
 /*?*/ 	throw (RuntimeException)
 /*?*/ {
-/*?*/ DBG_BF_ASSERT(0, "STRIP"); return FALSE;//STRIP001 	MutexGuard			aGuard( maMutex );
+/*?*/ DBG_BF_ASSERT(0, "STRIP"); return FALSE;
 /*?*/ }
 }
 
