@@ -47,7 +47,8 @@ namespace binfilter {
 #define GLOBALOVERFLOW
 
 using namespace ::com::sun::star;
-using namespace rtl;
+
+using ::rtl::OUString;
 
 sal_Unicode const pszExtColor[]	 = {'s','o','c'};
 
@@ -200,7 +201,7 @@ static char const aChckXML[]    = { '<', '?', 'x', 'm', 'l' };		// = 6.0
 /*N*/ 	xub_StrLen nLen;
 /*N*/ 	ResMgr& rRes = DIALOG_MGR();
 /*N*/ 
-/*N*/ 	static USHORT __READONLY_DATA aResId[] =
+/*N*/ 	static USHORT const aResId[] =
 /*N*/ 	{
 /*N*/ 		RID_SVXSTR_BLACK,
 /*N*/ 		RID_SVXSTR_BLUE,
@@ -229,7 +230,7 @@ static char const aChckXML[]    = { '<', '?', 'x', 'm', 'l' };		// = 6.0
 /*N*/ 
 /*N*/ 	// BM: ifndef VCL part removed (deprecated)
 /*N*/ 
-/*N*/ 	static ColorData __READONLY_DATA aColTab[] =
+/*N*/ 	static ColorData const aColTab[] =
 /*N*/ 	{
 /*N*/ 		COL_BLACK,
 /*N*/ 		COL_BLUE,
@@ -460,7 +461,7 @@ static char const aChckXML[]    = { '<', '?', 'x', 'm', 'l' };		// = 6.0
 
 /************************************************************************/
 
-/*N*/ Bitmap* XColorTable::CreateBitmapForUI( long nIndex, BOOL bDelete )
+/*N*/ Bitmap* XColorTable::CreateBitmapForUI( long /*nIndex*/, BOOL /*bDelete*/ )
 /*N*/ {
 /*N*/ 	return( NULL );
 /*N*/ }
@@ -469,7 +470,7 @@ static char const aChckXML[]    = { '<', '?', 'x', 'm', 'l' };		// = 6.0
 
 /*N*/ XubString& XColorTable::ConvertName( XubString& rStrName )
 /*N*/ {
-/*N*/ 	static USHORT __READONLY_DATA aDefResId[] =
+/*N*/ 	static USHORT const aDefResId[] =
 /*N*/ 	{
 /*N*/ 		RID_SVXSTR_BLUEGREY_DEF,
 /*N*/ 		RID_SVXSTR_BLACK_DEF,
@@ -498,7 +499,7 @@ static char const aChckXML[]    = { '<', '?', 'x', 'm', 'l' };		// = 6.0
 /*N*/ 		RID_SVXSTR_SEABLUE_DEF,
 /*N*/ 		RID_SVXSTR_COLOR_SUN_DEF
 /*N*/ 	};
-/*N*/ 	static USHORT __READONLY_DATA aResId[] =
+/*N*/ 	static USHORT const aResId[] =
 /*N*/ 	{
 /*N*/ 		RID_SVXSTR_BLUEGREY,
 /*N*/ 		RID_SVXSTR_BLACK,
@@ -530,7 +531,7 @@ static char const aChckXML[]    = { '<', '?', 'x', 'm', 'l' };		// = 6.0
 /*N*/ 
 /*N*/ 	BOOL bFound = FALSE;
 /*N*/ 
-/*N*/ 	for( int i=0; i<(sizeof(aDefResId) / sizeof(USHORT)) && !bFound; i++ )
+/*N*/ 	for( size_t i=0; i<(sizeof(aDefResId) / sizeof(USHORT)) && !bFound; i++ )
 /*N*/ 	{
 /*N*/ 		XubString aStrDefName = SVX_RESSTR( aDefResId[i] );
 /*N*/ 		if( rStrName.Search( aStrDefName ) == 0 )
@@ -561,7 +562,7 @@ static char const aChckXML[]    = { '<', '?', 'x', 'm', 'l' };		// = 6.0
 /*N*/ 	USHORT		 nGreen;
 /*N*/ 	USHORT		 nBlue;
 /*N*/ 	Color		 aColor;
-/*N*/ 	XubString	 aName;
+/*N*/ 	XubString	 aLclName;
 /*N*/ 
 /*N*/ 	rIn >> nType;
 /*N*/ 
@@ -573,9 +574,9 @@ static char const aChckXML[]    = { '<', '?', 'x', 'm', 'l' };		// = 6.0
 /*N*/ 		{
 /*N*/ 			rIn >> nIndex;
 /*N*/ 
-/*N*/ 			// UNICODE: rIn >> aName;
-/*N*/ 			rIn.ReadByteString(aName);
-/*N*/ 			aName = ConvertName( aName );
+/*N*/ 			// UNICODE: rIn >> aLclName;
+/*N*/ 			rIn.ReadByteString(aLclName);
+/*N*/ 			aLclName = ConvertName( aLclName );
 /*N*/ 		
 /*N*/ 			rIn >> nRed;
 /*N*/ 			rIn >> nGreen;
@@ -584,7 +585,7 @@ static char const aChckXML[]    = { '<', '?', 'x', 'm', 'l' };		// = 6.0
 /*N*/ 			aColor = Color( (BYTE) ( nRed   >> 8 ),
 /*N*/ 							(BYTE) ( nGreen >> 8 ),
 /*N*/ 							(BYTE) ( nBlue  >> 8 ) );
-/*N*/ 			pEntry = new XColorEntry( aColor, aName);
+/*N*/ 			pEntry = new XColorEntry( aColor, aLclName);
 /*N*/ 			Insert (nIndex, pEntry);
 /*N*/ 		}
 /*N*/ 	}
@@ -598,11 +599,11 @@ static char const aChckXML[]    = { '<', '?', 'x', 'm', 'l' };		// = 6.0
 /*N*/ 
 /*N*/ 			rIn >> nIndex;
 /*N*/ 
-/*N*/ 			// UNICODE: rIn >> aName;
-/*N*/ 			rIn.ReadByteString(aName);
-/*N*/ 			aName = ConvertName( aName );
+/*N*/ 			// UNICODE: rIn >> aLclName;
+/*N*/ 			rIn.ReadByteString(aLclName);
+/*N*/ 			aLclName = ConvertName( aLclName );
 /*N*/ 
-/*N*/ 			if( aIOC.GetVersion() >= 0 )
+/*N*/ 			/*if( aIOC.GetVersion() >= 0 )*/
 /*N*/ 			{
 /*N*/ 				rIn >> nRed;
 /*N*/ 				rIn >> nGreen;
@@ -611,14 +612,8 @@ static char const aChckXML[]    = { '<', '?', 'x', 'm', 'l' };		// = 6.0
 /*N*/ 								(BYTE) ( nGreen >> 8 ),
 /*N*/ 								(BYTE) ( nBlue  >> 8 ) );
 /*N*/ 			}
-            /*
-            else if( aIOC.GetVersion() >= 1 )
-            {
-                // lesen neuer Daten ...
-            }
-            */
-/*N*/ 
-/*N*/ 			pEntry = new XColorEntry( aColor, aName );
+/*N*/
+/*N*/ 			pEntry = new XColorEntry( aColor, aLclName );
 /*N*/ 			Insert( nIndex, pEntry );
 /*N*/ 		}
 /*N*/ 	}
