@@ -50,7 +50,7 @@
 #include <ftninfo.hxx>
 
 #include <horiornt.hxx>
-#include <errhdl.hxx>
+#include <osl/diagnose.h>
 #include <viscrs.hxx>
 #include <fesh.hxx>
 #include <ndole.hxx>
@@ -114,10 +114,6 @@ namespace binfilter {
 /*N*/ 		//werden die SV'ler noch eine Methode anbieten.
 /*N*/ 		const Size aPhysSize( SvxPaperInfo::GetPaperSize( (Printer*)pPrt ));
 /*N*/
-/*N*/ 		//if ( aPhysSize.Width() <= 0 )
-/*N*/ 		//	aPhysSize.Width() = lA4Width;
-/*N*/ 		//if ( aPhysSize.Height() <= 0 )
-/*N*/ 		//	aPhysSize.Height() = lA4Height;
 /*N*/ 		aFrmSize.SetSize( aPhysSize );
 /*N*/
 /*N*/ 		//Raender
@@ -128,7 +124,7 @@ namespace binfilter {
 /*N*/ 		//Raender haben eine defaultmaessige Mindestgroesse.
 /*N*/ 		//wenn der Drucker einen groesseren Rand vorgibt, so
 /*N*/ 		//ist mir dass auch recht.
-/*N*/ 		// MIB 06/25/2002, #99397#: The HTML page desc had A4 as page size
+/*N*/ 		// The HTML page desc had A4 as page size
 /*N*/ 		// always. This has been changed to take the page size from the printer.
 /*N*/ 		// Unfortunately, the margins of the HTML page desc are smaller than
 /*N*/ 		// the margins used here in general, so one extra case is required.
@@ -186,9 +182,6 @@ namespace binfilter {
 |*
 |*	SwDoc::ChgPageDesc()
 |*
-|*	Ersterstellung		MA 25. Jan. 93
-|*	Letzte Aenderung	MA 01. Mar. 95
-|*
 |*************************************************************************/
 
 /*N*/ void lcl_DescSetAttr( const SwFrmFmt &rSource, SwFrmFmt &rDest,
@@ -200,7 +193,7 @@ namespace binfilter {
 /*N*/ // funktioniert nicht richtig, wenn man unterschiedliche WhichRanges hat.
 /*N*/ /////////////// !!!!!!!!!!!!!!!!
 /*N*/ 	//Die interressanten Attribute uebernehmen.
-/*N*/ 	USHORT __READONLY_DATA aIdArr[] = { RES_FRM_SIZE, RES_UL_SPACE,
+/*N*/ 	USHORT const aIdArr[] = { RES_FRM_SIZE, RES_UL_SPACE,
 /*N*/ 										RES_BACKGROUND, RES_SHADOW,
 /*N*/ 										RES_COL, RES_COL,
 /*N*/ 										RES_FRAMEDIR, RES_FRAMEDIR,
@@ -232,7 +225,7 @@ namespace binfilter {
 
 /*N*/ void SwDoc::ChgPageDesc( USHORT i, const SwPageDesc &rChged )
 /*N*/ {
-/*N*/ 	ASSERT( i < aPageDescs.Count(), "PageDescs ueberindiziert." );
+/*N*/ 	OSL_ENSURE( i < aPageDescs.Count(), "PageDescs ueberindiziert." );
 /*N*/
 /*N*/ 	SwPageDesc *pDesc = aPageDescs[i];
 /*N*/
@@ -434,12 +427,10 @@ namespace binfilter {
 |*
 |* 	Beschreibung		Alle Descriptoren, deren Follow auf den zu loeschenden
 |*		zeigen muessen angepasst werden.
-|*	Ersterstellung		MA 25. Jan. 93
-|*	Letzte Aenderung	JP 04.09.95
 |*
 |*************************************************************************/
 
-void lcl_RemoveFrms( SwFrmFmt& rFmt, FASTBOOL& rbFtnsRemoved )
+void lcl_RemoveFrms( SwFrmFmt& rFmt, bool& rbFtnsRemoved )
 {
     SwClientIter aIter( rFmt );
     SwFrm *pFrm;
@@ -461,8 +452,8 @@ void lcl_RemoveFrms( SwFrmFmt& rFmt, FASTBOOL& rbFtnsRemoved )
 
 void SwDoc::DelPageDesc( USHORT i )
 {
-    ASSERT( i < aPageDescs.Count(), "PageDescs ueberindiziert." );
-    ASSERT( i != 0, "Default Pagedesc loeschen is nicht." );
+    OSL_ENSURE( i < aPageDescs.Count(), "PageDescs ueberindiziert." );
+    OSL_ENSURE( i != 0, "Default Pagedesc loeschen is nicht." );
     if ( i == 0 )
         return;
 
@@ -484,7 +475,7 @@ void SwDoc::DelPageDesc( USHORT i )
                     ((SwFmt*)pMod)->SetAttr( aDfltDesc );
                 else
                 {
-                    ASSERT( !this, "was ist das fuer ein Mofify-Obj?" );
+                    OSL_ENSURE( !this, "was ist das fuer ein Mofify-Obj?" );
                     aPageDescs[0]->Add( pLast );
                 }
             }
@@ -525,7 +516,7 @@ void SwDoc::DelPageDesc( USHORT i )
         // Wenn wir auf Endnotenseiten stossen, schmeissen wir alle Fussnoten weg,
         // anders kann die Reihenfolge der Seiten (FollowsPageDescs usw.)
         // nicht garantiert werden.
-        FASTBOOL bFtnsRemoved = FALSE;
+        bool bFtnsRemoved = FALSE;
 
         ::binfilter::lcl_RemoveFrms( pDel->GetMaster(), bFtnsRemoved );
         ::binfilter::lcl_RemoveFrms( pDel->GetLeft(), bFtnsRemoved );
@@ -542,9 +533,6 @@ void SwDoc::DelPageDesc( USHORT i )
 |*
 |*	SwDoc::MakePageDesc()
 |*
-|*	Ersterstellung		MA 25. Jan. 93
-|*	Letzte Aenderung	MA 20. Aug. 93
-|*
 |*************************************************************************/
 
 /*N*/ USHORT SwDoc::MakePageDesc( const String &rName, const SwPageDesc *pCpy,
@@ -603,9 +591,6 @@ void SwDoc::DelPageDesc( USHORT i )
 
 /******************************************************************************
  *	Methode		:	void SwDoc::SetPrt( SfxPrinter *pP )
- *	Beschreibung:
- *	Erstellt	:	OK 27.10.94 10:20
- *	Aenderung	:	MA 26. Mar. 98
  ******************************************************************************/
 
 /*N*/ void SwDoc::PrtDataChanged()
@@ -782,7 +767,7 @@ extern SvPtrarr *pGlobalOLEExcludeList;
 /*N*/ 	}
 /*N*/ }
 
-/*N*/ void SwDoc::SetVirDev( VirtualDevice* pVd, sal_Bool bCallVirDevDataChanged )
+/*N*/ void SwDoc::SetVirDev( VirtualDevice* pVd, sal_Bool /*bCallVirDevDataChanged*/ )
 /*N*/ {
 /*N*/     if ( (ULONG)pVirDev != (ULONG)pVd )
 /*N*/     {
@@ -793,7 +778,7 @@ extern SvPtrarr *pGlobalOLEExcludeList;
 
 /*N*/ void SwDoc::SetPrt( SfxPrinter *pP, sal_Bool bCallPrtDataChanged )
 /*N*/ {
-/*N*/ 	ASSERT( pP, "Kein Drucker!" );
+/*N*/ 	OSL_ENSURE( pP, "Kein Drucker!" );
 /*N*/
 /*N*/ 	const BOOL bInitPageDesc = pPrt == 0;
 /*N*/
@@ -802,7 +787,7 @@ extern SvPtrarr *pGlobalOLEExcludeList;
 /*N*/ 		delete pPrt;
 /*N*/ 		pPrt = pP;
 /*N*/ 	}
-/*N*/     // OD 05.03.2003 #107870# - first adjust page description, before trigger formatting.
+/*N*/     // first adjust page description, before trigger formatting.
 /*N*/     if( bInitPageDesc )
 /*N*/     {
 /*N*/         // JP 17.04.97: Bug 38924 - falls noch kein Drucker gesetzt war
@@ -838,27 +823,8 @@ extern SvPtrarr *pGlobalOLEExcludeList;
 /*N*/
 /*N*/ }
 
-/*
- *	Kleiner Hack;
- *
-const SwPageDesc& SwDoc::GetPageDesc( USHORT i ) const
-{
-    if( !i && !aPageDescs.Count() )            // noch keiner vorhanden?
-        ((SwDoc*)this)->InitPageDescs();		//Default PageDescriptor
-    return *aPageDescs[i];
-}
 
-SwPageDesc& SwDoc::_GetPageDesc( USHORT i ) const
-{
-    if( !i && !aPageDescs.Count() )			// noch keiner vorhanden?
-        ((SwDoc*)this)->InitPageDescs();		//Default PageDescriptor
-    return *aPageDescs[i];
-}
-*/
-
-
-
-/*N*/ IMPL_LINK( SwDoc, DoUpdateModifiedOLE, Timer *, pTimer )
+/*N*/ IMPL_LINK( SwDoc, DoUpdateModifiedOLE, Timer *, EMPTYARG )
 /*N*/ {
 /*N*/ 	SwFEShell* pSh = (SwFEShell*)GetEditShell();
 /*N*/ 	if( pSh )
