@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -31,10 +31,6 @@
 #pragma hdrstop
 #endif
 
-#ifdef WTC
-#define private public
-#endif
-
 #include <ctype.h>
 #include <float.h>
 
@@ -109,9 +105,6 @@ namespace binfilter {
 |*
 |*	SwTable::SwTable()
 |*
-|*	Ersterstellung		MA 09. Mar. 93
-|*	Letzte Aenderung	MA 05. May. 93
-|*
 |*************************************************************************/
 /*N*/ SwTable::SwTable( SwTableFmt* pFmt )
 /*N*/ 	: SwClient( pFmt ),
@@ -122,7 +115,7 @@ namespace binfilter {
 /*N*/ 	bHeadlineRepeat = TRUE;
 /*N*/
 /*N*/ 	// default Wert aus den Optionen setzen
-/*N*/   eTblChgMode = (TblChgMode)0;//STRIP001 GetTblChgDefaultMode();
+/*N*/   eTblChgMode = (TblChgMode)0;
 /*N*/ }
 
 /*N*/ SwTable::SwTable( const SwTable& rTable )
@@ -174,9 +167,6 @@ namespace binfilter {
 |*
 |*	SwTable::Modify()
 |*
-|*	Ersterstellung		JP ??
-|*	Letzte Aenderung	MA 06. May. 93
-|*
 |*************************************************************************/
 /*?*/ inline BOOL FmtInArr( SvPtrarr& rFmtArr, SwFmt* pBoxFmt )
 /*?*/ {
@@ -241,7 +231,7 @@ namespace binfilter {
 /*N*/ 	{
 /*N*/ 		if ( !IsModifyLocked() )
 /*N*/ 		{
-/*N*/ 			ASSERT( pOldSize && pOldSize->Which() == RES_FRM_SIZE &&
+/*N*/ 			OSL_ENSURE( pOldSize && pOldSize->Which() == RES_FRM_SIZE &&
 /*N*/ 					pNewSize && pNewSize->Which() == RES_FRM_SIZE,
 /*N*/ 					"Kein Old oder New fuer FmtFrmSize-Modify der SwTable." );
 /*N*/
@@ -262,9 +252,6 @@ namespace binfilter {
 |*
 |*	SwTable::GetTabCols()
 |*
-|*	Ersterstellung		MA 04. May. 93
-|*	Letzte Aenderung	MA 30. Nov. 95
-|*
 |*************************************************************************/
 
 
@@ -277,10 +264,10 @@ namespace binfilter {
 #endif
 
 
-/*N*/ void SwTable::GetTabCols( SwTabCols &rToFill, const SwTableBox *pStart,
-/*N*/ 						  FASTBOOL bRefreshHidden, BOOL bCurRowOnly ) const
+/*N*/ void SwTable::GetTabCols( SwTabCols& /*rToFill*/, const SwTableBox* /*pStart*/,
+/*N*/ 						  bool /*bRefreshHidden*/, BOOL /*bCurRowOnly*/ ) const
 /*N*/ {
-/*N*/ 	DBG_BF_ASSERT(0, "STRIP"); //STRIP001 //MA 30. Nov. 95: Opt: wenn bHidden gesetzt ist, wird neu das Hidden
+/*N*/ 	DBG_BF_ASSERT(0, "STRIP");
 /*N*/ }
 
 #if defined(ALPHA) && defined(_MSC_VER)
@@ -291,9 +278,6 @@ namespace binfilter {
 |*
 |*	SwTable::SetTabCols()
 |*
-|*	Ersterstellung		MA 04. May. 93
-|*	Letzte Aenderung	MA 26. Aug. 98
-|*
 |*************************************************************************/
 //Struktur zur Parameteruebergabe
 
@@ -307,12 +291,9 @@ namespace binfilter {
 
 /*************************************************************************
 |*
-|*	const SwTableBox* SwTable::GetTblBox( const Strnng& rName ) const
+|*	const SwTableBox* SwTable::GetTblBox( const Strn?ng& rName ) const
 |*		gebe den Pointer auf die benannte Box zurueck.
 |*
-|*	Ersterstellung		JP 30. Jun. 93
-|*	Letzte Aenderung	JP 30. Jun. 93
-|*
 |*************************************************************************/
 /*N*/ USHORT SwTable::_GetBoxNum( String& rStr, BOOL bFirst )
 /*N*/ {
@@ -391,7 +372,7 @@ namespace binfilter {
     // Box ist ??
 /*N*/ 	if( pBox && !pBox->GetSttNd() )
 /*N*/ 	{
-/*?*/ 		ASSERT( FALSE, "Box ohne Inhalt, suche die naechste !!" );
+/*?*/ 		OSL_ENSURE( FALSE, "Box ohne Inhalt, suche die naechste !!" );
 /*?*/ 		// "herunterfallen lassen" bis zur ersten Box
 /*?*/ 		while( pBox->GetTabLines().Count() )
 /*?*/ 			pBox = pBox->GetTabLines()[0]->GetTabBoxes()[0];
@@ -453,9 +434,6 @@ namespace binfilter {
 |*
 |*	SwTableLine::SwTableLine()
 |*
-|*	Ersterstellung		MA 09. Mar. 93
-|*	Letzte Aenderung	MA 09. Mar. 93
-|*
 |*************************************************************************/
 /*N*/ SwTableLine::SwTableLine( SwTableLineFmt *pFmt, USHORT nBoxes,
 /*N*/ 							SwTableBox *pUp )
@@ -479,9 +457,6 @@ namespace binfilter {
 |*
 |*	SwTableLine::ClaimFrmFmt(), ChgFrmFmt()
 |*
-|*	Ersterstellung		MA 03. May. 93
-|*	Letzte Aenderung	MA 07. Feb. 96
-|*
 |*************************************************************************/
 /*N*/ SwFrmFmt* SwTableLine::ClaimFrmFmt()
 /*N*/ {
@@ -546,9 +521,6 @@ namespace binfilter {
 |*
 |*	SwTableBox::SwTableBox()
 |*
-|*	Ersterstellung		MA 04. May. 93
-|*	Letzte Aenderung	MA 04. May. 93
-|*
 |*************************************************************************/
 /*N*/ SwTableBox::SwTableBox( SwTableBoxFmt* pFmt, USHORT nLines, SwTableLine *pUp )
 /*N*/ 	: SwClient( 0 ),
@@ -574,7 +546,7 @@ namespace binfilter {
 /*N*/
 /*N*/ 	// an der Table eintragen
 /*N*/ 	const SwTableNode* pTblNd = pSttNd->FindTableNode();
-/*N*/ 	ASSERT( pTblNd, "in welcher Tabelle steht denn die Box?" );
+/*N*/ 	OSL_ENSURE( pTblNd, "in welcher Tabelle steht denn die Box?" );
 /*N*/ 	SwTableSortBoxes& rSrtArr = (SwTableSortBoxes&)pTblNd->GetTable().
 /*N*/ 								GetTabSortBoxes();
 /*N*/ 	SwTableBox* p = this;	// error: &this
@@ -588,12 +560,12 @@ namespace binfilter {
 /*N*/ 	pImpl( 0 ),
 /*N*/ 	pSttNd( &rSttNd )
 /*N*/ {
-/*N*/ 	SwDoc* pDoc = pFmt->GetDoc();
+/*N*/ 	pFmt->GetDoc();
 /*N*/ 	CheckBoxFmt( pFmt )->Add( this );
 /*N*/
 /*N*/ 	// an der Table eintragen
 /*N*/ 	const SwTableNode* pTblNd = pSttNd->FindTableNode();
-/*N*/ 	ASSERT( pTblNd, "in welcher Tabelle steht denn die Box?" );
+/*N*/ 	OSL_ENSURE( pTblNd, "in welcher Tabelle steht denn die Box?" );
 /*N*/ 	SwTableSortBoxes& rSrtArr = (SwTableSortBoxes&)pTblNd->GetTable().
 /*N*/ 								GetTabSortBoxes();
 /*N*/ 	SwTableBox* p = this;	// error: &this
@@ -607,7 +579,7 @@ namespace binfilter {
 /*N*/ 	{
 /*N*/ 		// an der Table austragen
 /*?*/ 		const SwTableNode* pTblNd = pSttNd->FindTableNode();
-/*?*/ 		ASSERT( pTblNd, "in welcher Tabelle steht denn die Box?" );
+/*?*/ 		OSL_ENSURE( pTblNd, "in welcher Tabelle steht denn die Box?" );
 /*?*/ 		SwTableSortBoxes& rSrtArr = (SwTableSortBoxes&)pTblNd->GetTable().
 /*?*/ 									GetTabSortBoxes();
 /*?*/ 		SwTableBox *p = this;	// error: &this
@@ -652,9 +624,6 @@ namespace binfilter {
 |*
 |*	SwTableBox::ClaimFrmFmt(), ChgFrmFmt()
 |*
-|*	Ersterstellung		MA 04. May. 93
-|*	Letzte Aenderung	MA 07. Feb. 96
-|*
 |*************************************************************************/
 /*N*/ SwFrmFmt* SwTableBox::ClaimFrmFmt()
 /*N*/ {
@@ -724,9 +693,6 @@ namespace binfilter {
 |*		gebe den Namen dieser Box zurueck. Dieser wird dynamisch bestimmt
 |*		und ergibt sich aus der Position in den Lines/Boxen/Tabelle
 |*
-|*	Ersterstellung		JP 30. Jun. 93
-|*	Letzte Aenderung	JP 30. Jun. 93
-|*
 |*************************************************************************/
 /*N*/ void lcl_GetTblBoxColStr( USHORT nCol, String& rNm )
 /*N*/ {
@@ -828,7 +794,7 @@ namespace binfilter {
 /*N*/ 		break;
 /*N*/
 /*N*/ 	case RES_FINDNEARESTNODE:
-/*?*/ 	DBG_BF_ASSERT(0, "STRIP"); //STRIP001 	if( GetFrmFmt() && ((SwFmtPageDesc&)GetFrmFmt()->GetAttr(
+/*?*/ 	DBG_BF_ASSERT(0, "STRIP");
 /*?*/ 		break;
 /*?*/
 /*?*/ 	case RES_CONTENT_VISIBLE:
@@ -864,14 +830,11 @@ namespace binfilter {
 /*N*/ {
 /*N*/ 	if( !IsModifyLocked() && !IsInDocDTOR() )
 /*N*/ 	{
-/*N*/ 		const SwTblBoxNumFormat *pNewFmt = 0, *pOldFmt = 0;
-/*N*/ 		const SwTblBoxFormula *pNewFml = 0, *pOldFml = 0;
-/*N*/ 		const SwTblBoxValue *pNewVal = 0, *pOldVal = 0;
-/*N*/ 		double aOldValue = 0;
+/*N*/ 		const SwTblBoxNumFormat *pNewFmt = 0;
+/*N*/ 		const SwTblBoxFormula *pNewFml = 0;
+/*N*/ 		const SwTblBoxValue *pNewVal = 0;
 /*N*/ 		ULONG nOldFmt = NUMBERFORMAT_TEXT;
 /*N*/
-/*N*/ 		SwAttrSetChg *pNewChgSet = 0,  *pOldChgSet = 0;
-/*N*/
 /*N*/ 		switch( pNew ? pNew->Which() : 0 )
 /*N*/ 		{
 /*N*/ 		case RES_ATTRSET_CHG:
@@ -885,7 +848,7 @@ namespace binfilter {
 /*N*/ 									(const SfxPoolItem**)&pNewFml );
 /*N*/ 				if( SFX_ITEM_SET == rSet.GetItemState( RES_BOXATR_VALUE,
 /*N*/ 									FALSE, (const SfxPoolItem**)&pNewVal ) )
-/*N*/ 					aOldValue = ((SwTblBoxValue&)((SwAttrSetChg*)pOld)->
+/*N*/ 					((SwTblBoxValue&)((SwAttrSetChg*)pOld)->
 /*N*/ 							GetChgSet()->Get( RES_BOXATR_VALUE )).GetValue();
 /*N*/ 			}
 /*N*/ 			break;
@@ -899,7 +862,7 @@ namespace binfilter {
 /*N*/ 			break;
 /*N*/ 		case RES_BOXATR_VALUE:
 /*N*/ 			pNewVal = (SwTblBoxValue*)pNew;
-/*N*/ 			aOldValue = ((SwTblBoxValue*)pOld)->GetValue();
+/*N*/ 			((SwTblBoxValue*)pOld)->GetValue();
 /*N*/ 			break;
 /*N*/ 		}
 /*N*/
@@ -918,7 +881,7 @@ namespace binfilter {
 /*N*/ 				SwTableBox* pBox = (SwTableBox*)aIter.First( TYPE( SwTableBox ) );
 /*N*/ 				if( pBox )
 /*N*/ 				{
-/*?*/ 					ASSERT( !aIter.Next(), "keine Box oder mehrere am Format" );
+/*?*/ 					OSL_ENSURE( !aIter.Next(), "keine Box oder mehrere am Format" );
 /*?*/
 /*?*/ 					ULONG nNewFmt;
 /*?*/ 					if( pNewFmt )
@@ -971,7 +934,7 @@ namespace binfilter {
 /*?*/
 /*?*/ 					if( !bNewIsTxtFmt && nOldFmt != nNewFmt || pNewFml )
 /*?*/ 					{
-/*?*/ 				DBG_BF_ASSERT(0, "STRIP"); //STRIP001 		BOOL bChgTxt = TRUE;
+/*?*/ 				DBG_BF_ASSERT(0, "STRIP");
 /*?*/ 					}
 /*?*/ 					else if( bNewIsTxtFmt && nOldFmt != nNewFmt )
 /*?*/ 					{
@@ -982,7 +945,7 @@ namespace binfilter {
 /*?*/ 	//					UnlockModify();
 /*?*/
 /*?*/
-/*?*/ 					DBG_BF_ASSERT(0, "STRIP"); //STRIP001 	ChgNumToText( *pBox, nNewFmt );
+/*?*/ 					DBG_BF_ASSERT(0, "STRIP");
 /*?*/ 					}
 /*?*/ 				}
 /*N*/ 			}
@@ -1064,7 +1027,7 @@ namespace binfilter {
 /*N*/
 /*N*/ 			const String& rTxt = pSttNd->GetNodes()[ nNdPos ]->GetTxtNode()->GetTxt();
 /*N*/ 			if( rTxt != sNewTxt )
-/*?*/ 				{DBG_BF_ASSERT(0, "STRIP");} //STRIP001 ChgTextToNum( *this, sNewTxt, pCol, FALSE );
+/*?*/ 				{DBG_BF_ASSERT(0, "STRIP");}
 /*N*/ 		}
 /*N*/ 	}
 /*N*/ }
