@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -33,7 +33,7 @@
 
 #include <stdlib.h>
 
-#include <errhdl.hxx>
+#include <osl/diagnose.h>
 
 
 #include <horiornt.hxx>
@@ -48,16 +48,13 @@
 #include <ddefld.hxx>
 #include <swddetbl.hxx>
 #include <frame.hxx>
-namespace binfilter {//STRIP009
-/*N*/ extern FASTBOOL CheckNodesRange( const SwNodeIndex& rStt,
-/*N*/ 							const SwNodeIndex& rEnd, FASTBOOL bChkSection );
 
-SV_DECL_PTRARR(SwSttNdPtrs,SwStartNode*,2,2)//STRIP008 ;
+namespace binfilter {
+    extern bool CheckNodesRange( const SwNodeIndex& rStt, const SwNodeIndex& rEnd, bool bChkSection );
+
+    SV_DECL_PTRARR(SwSttNdPtrs,SwStartNode*,2,2)
 } //namespace binfilter
 
-//#define JP_DEBUG
-#ifdef JP_DEBUG
-#endif
 namespace binfilter {
 
 
@@ -78,7 +75,7 @@ namespace binfilter {
 /*N*/ {
 /*N*/ 	bInNodesDel = bInDelUpdOutl = bInDelUpdNum = FALSE;
 /*N*/
-/*N*/ 	ASSERT( pMyDoc, "in welchem Doc stehe ich denn?" );
+/*N*/ 	OSL_ENSURE( pMyDoc, "in welchem Doc stehe ich denn?" );
 /*N*/
 /*N*/ 	ULONG nPos = 0;
 /*N*/ 	SwStartNode* pSttNd = new SwStartNode( *this, nPos++ );
@@ -112,12 +109,6 @@ namespace binfilter {
 |*		Arrays nicht erzeugt werden koennen und somit auch nicht
 |*		in mehreren drin sein koennen
 |*
-|*	Ersterstellung
-|*		VER0100 vb 901214
-|*
-|*	Stand
-|*		VER0100 vb 901214
-|*
 *******************************************************************/
 
 /*N*/ SwNodes::~SwNodes()
@@ -180,12 +171,6 @@ namespace binfilter {
 |*		die Debugging Tools geben rRange beim Eintritt und beim
 |*		Verlassen der Funktion aus
 |*
-|*	Ersterstellung
-|*		VER0100 vb 901214
-|*
-|*	Stand
-|*		VER0100 vb 901214
-|*
 *******************************************************************/
 /*N*/ void SwNodes::SectionDown(SwNodeRange *pRange, SwStartNodeType eSttNdTyp )
 /*N*/ {
@@ -227,45 +212,6 @@ namespace binfilter {
 /*N*/ 	SectionUpDown( aTmpIdx, pRange->aEnd );
 /*N*/ }
 
-/*******************************************************************
-|*
-|*	SwNodes::SectionUp
-|*
-|*	Beschreibung
-|*		Der von rRange umspannte Bereich wird auf die naechst hoehere
-|*		Ebene gehoben. Das geschieht dadurch, dass bei
-|*		rRange.aStart ein Endnode und bei rRange.aEnd ein
-|*		Startnode eingefuegt wird. Die Indices fuer den Bereich
-|*		innerhalb von rRange werden geupdated.
-|*
-|*	Allg.: aRange beschreibt den Bereich  -exklusive- aEnd !!
-|*				( 1.Node: aStart, letzer Node: aEnd-1 !! )
-|*
-|*	Parameter
-|*		SwRange &rRange
-|*			IO:
-|*			IN
-|*			rRange.aStart: Anfang des hoeher zubewegenden Bereiches
-|*			rRange.aEnd:   der 1.Node hinter dem Bereich
-|*			OUT
-|*			rRange.aStart:	an der ersten Position innerhalb des
-|*							hochbewegten Bereiches
-|*			rRange.aEnd:	an der letzten Position innerhalb des
-|*							hochbewegten Bereiches
-|*
-|*	Debug-Funktionen
-|*		die Debugging Tools geben rRange beim Eintritt und beim
-|*		Verlassen der Funktion aus
-|*
-|*	Ersterstellung
-|*		VER0100 vb 901214
-|*
-|*	Stand
-|*		VER0100 vb 901214
-|*
-*******************************************************************/
-
-
 /*************************************************************************
 |*
 |*	SwNodes::SectionUpDown()
@@ -279,9 +225,6 @@ namespace binfilter {
 |*						SwIndex & aStart		StartNode !!!
 |*						SwIndex & aEnd			EndPunkt
 |*
-|*	  Ersterstellung	JP 23.04.91
-|*	  Letzte Aenderung	JP 23.04.91
-|*
 *************************************************************************/
 /*N*/ void SwNodes::SectionUpDown( const SwNodeIndex & aStart, const SwNodeIndex & aEnd )
 /*N*/ {
@@ -350,12 +293,6 @@ namespace binfilter {
 |*		geben beim Eintritt in die Funktion Position und Anzahl
 |*		der zu loeschenden Nodes aus.
 |*
-|*	Ersterstellung
-|*		VER0100 vb 901214
-|*
-|*	Stand
-|*		VER0100 vb 901214
-|*
 *******************************************************************/
 /*N*/ void SwNodes::Delete(const SwNodeIndex &rIndex, ULONG nNodes)
 /*N*/ {
@@ -552,16 +489,10 @@ namespace binfilter {
 |*      eine Sonderbehandlung; es wird davon ausgegangen, dass der
 |*		erste Node auch ein Startnode ist.
 |*
-|*	Ersterstellung
-|*		VER0100 vb 901214
-|*
-|*	Stand
-|*		VER0100 vb 901214
-|*
 *******************************************************************/
 
-/*N*/ void SwNodes::GoStartOfSection(SwNodeIndex *pIdx) const
-/*N*/ {DBG_BF_ASSERT(0, "STRIP"); //STRIP001
+/*N*/ void SwNodes::GoStartOfSection(SwNodeIndex* /*pIdx*/) const
+/*N*/ {DBG_BF_ASSERT(0, "STRIP");
 /*N*/ }
 
 /*N*/ void SwNodes::GoEndOfSection(SwNodeIndex *pIdx) const
@@ -577,8 +508,8 @@ namespace binfilter {
 /*?*/ 		return 0;
 /*N*/
 /*N*/ 	SwNodeIndex aTmp(*pIdx, +1);
-/*N*/ 	SwNode* pNd;
-/*N*/ 	while( aTmp < Count()-1 && 0 == ( pNd = &aTmp.GetNode())->IsCntntNode() )
+/*N*/ 	SwNode* pNd(NULL);
+/*N*/ 	while( aTmp < Count()-1 && 0 == ( pNd = &aTmp.GetNode() )->IsCntntNode() )
 /*N*/ 		aTmp++;
 /*N*/
 /*N*/ 	if( aTmp == Count()-1 )
@@ -594,7 +525,7 @@ namespace binfilter {
 /*?*/ 		return 0;
 /*N*/
 /*N*/ 	SwNodeIndex aTmp( *pIdx, -1 );
-/*N*/ 	SwNode* pNd;
+/*N*/ 	SwNode* pNd(NULL);
 /*N*/ 	while( aTmp.GetIndex() && 0 == ( pNd = &aTmp.GetNode())->IsCntntNode() )
 /*N*/ 		aTmp--;
 /*N*/
@@ -611,7 +542,7 @@ namespace binfilter {
 /*?*/ 		return 0;
 /*N*/
 /*N*/ 	SwNodeIndex aTmp(*pIdx, +1);
-/*N*/ 	SwNode* pNd;
+/*N*/ 	SwNode* pNd(NULL);
 /*N*/ 	while( aTmp < Count()-1 )
 /*N*/ 	{
 /*N*/ 		pNd = &aTmp.GetNode();
@@ -663,9 +594,6 @@ namespace binfilter {
 |*	  Return-Wert		BOOL		TRUE:	gueltiger SRange
 |*									FALSE:	ungueltiger SRange
 |*
-|*	  Ersterstellung	JP 23.04.91
-|*	  Letzte Aenderung	JP 18.06.92
-|*
 *************************************************************************/
 
 /*N*/ inline int TstIdx( ULONG nSttIdx, ULONG nEndIdx, ULONG nStt, ULONG nEnd )
@@ -702,9 +630,6 @@ namespace binfilter {
 |*	  Parameter 		SwIndex &	Der Startpunkt im Nodes-Array
 |*						USHORT		die Anzahl
 |*
-|*	  Ersterstellung	JP 23.04.91
-|*	  Letzte Aenderung	JP 23.04.91
-|*
 *************************************************************************/
 /*N*/ void SwNodes::DelNodes( const SwNodeIndex & rStart, ULONG nCnt )
 /*N*/ {
@@ -762,40 +687,6 @@ namespace binfilter {
 /*N*/ }
 
 
-/*************************************************************************
-|*
-|*	  USHORT HighestLevel( SwNodes & rNodes, const SwNodeRange & rRange )
-|*
-|*	  Beschreibung
-|*		Berechne den hoehsten Level innerhalb des Bereiches
-|*
-|*	  Parameter 		SwNodes &	das Node-Array
-|*						SwNodeRange &	der zu ueberpruefende Bereich
-|*	  Return			USHORT		der hoechste Level
-|*
-|*	  Ersterstellung	JP 24.04.91
-|*	  Letzte Aenderung	JP 24.04.91
-|*
-*************************************************************************/
-
-
-
-
-/*************************************************************************
-|*
-|*    SwNodes::Move()
-|*
-|*    Beschreibung
-|*    Parameter         SwPaM&		zu kopierender Bereich
-|*                      SwNodes&	in dieses Nodes-Array
-|*                      SwPosition&	auf diese Position im Nodes-Array
-|*    Ersterstellung    JP 09.07.92
-|*    Letzte Aenderung  JP 09.07.92
-|*
-*************************************************************************/
-
-
-
 /*************************************************************************
 |*
 |*    SwNodes::_Copy()
@@ -804,8 +695,6 @@ namespace binfilter {
 |*    Parameter         SwNodeRange&	zu kopierender Bereich
 |*                      SwDoc&		in dieses Dokument
 |*                      SwIndex&	auf diese Position im Nodes-Array
-|*    Ersterstellung    JP 11.11.92
-|*    Letzte Aenderung  JP 11.11.92
 |*
 *************************************************************************/
 
@@ -924,7 +813,7 @@ namespace binfilter {
 /*?*/ 			if( pAktNode->EndOfSectionIndex() < aRg.aEnd.GetIndex() )
 /*?*/ 			{
 /*?*/ 				// also der gesamte, lege einen neuen SectionNode an
-/*?*/ 				DBG_BF_ASSERT(0, "STRIP"); //STRIP001 SwNodeIndex nStt( aInsPos, -1 );
+/*?*/ 				DBG_BF_ASSERT(0, "STRIP");
 /*?*/ 			}
 /*?*/ 			break;
 /*?*/
@@ -965,41 +854,16 @@ namespace binfilter {
 /*N*/ 			break;
 /*N*/
 /*N*/ 		case ND_SECTIONDUMMY:
-            /*if( (const SwNodes*)this == GetDoc()->GetUndoNds() )
-            {
-                // dann muss an der akt. InsPos auch ein SectionNode
-                // (Start/Ende) stehen; dann diesen ueberspringen.
-                // Andernfalls nicht weiter beachten.
-                SwNode* pTmpNd = pDoc->GetNodes()[ aInsPos ];
-                if( pTmpNd->IsSectionNode() ||
-                    pTmpNd->FindStartNode()->IsSectionNode() )
-                    aInsPos++;  // ueberspringen
-            }
-            else */
-                ASSERT( FALSE, "wie kommt diser Node ins Nodes-Array??" );
+                OSL_ENSURE( FALSE, "wie kommt diser Node ins Nodes-Array??" );
             break;
 
 /*?*/ 		default:
-/*?*/ 			ASSERT( FALSE, "weder Start-/End-/Content-Node, unbekannter Typ" );
+/*?*/ 			OSL_ENSURE( FALSE, "weder Start-/End-/Content-Node, unbekannter Typ" );
 /*N*/ 		}
 /*N*/ 		aRg.aStart++;
 /*N*/ 	}
 /*N*/
 /*N*/
-/*N*/ #ifdef JP_DEBUG
-/*N*/ 	{
-/*N*/ 			extern Writer* GetDebugWriter(const String&);
-/*N*/
-/*N*/ 		Writer* pWriter = GetDebugWriter(aEmptyStr);
-/*N*/ 		if( pWriter )
-/*N*/ 		{
-/*N*/ 			int nError;
-/*N*/ 			SvFileStream aStrm( "c:\\$$copy.db", STREAM_WRITE );
-/*N*/ 			SwWriter aWriter( aStrm, *pMyDoc );
-/*N*/ 			aWriter.Write( &nError, pWriter );
-/*N*/ 		}
-/*N*/ 	}
-/*N*/ #endif
 /*N*/ }
 
 /*N*/ void SwNodes::_DelDummyNodes( const SwNodeRange& rRg )
@@ -1154,12 +1018,12 @@ namespace binfilter {
 /*N*/ 									const SwNode* pEnd ) const
 /*N*/ {
 /*N*/ 	SwNode* pFrmNd = 0;
-/*N*/ 
+/*N*/
 /*N*/ 	// habe wir gar kein Layout, vergiss es
 /*N*/ 	if( GetDoc()->GetRootFrm() )
 /*N*/ 	{
 /*N*/ 		SwNode* pSttNd = &rFrmIdx.GetNode();
-/*N*/ 
+/*N*/
 /*N*/ 		// wird in eine versteckte Section verschoben ??
 /*N*/ 		SwSectionNode* pSectNd = pSttNd->IsSectionNode()
 /*N*/ 					? pSttNd->FindStartNode()->FindSectionNode()
@@ -1175,10 +1039,10 @@ namespace binfilter {
 /*N*/ 			}
 /*N*/ 			else
 /*?*/ 				pNd = pSttNd;
-/*N*/ 
+/*N*/
 /*N*/ 			if( ( pFrmNd = pNd )->IsCntntNode() )
 /*N*/ 				rFrmIdx = aIdx;
-/*N*/ 
+/*N*/
 /*N*/ 				// suche nach vorne/hinten nach einem Content Node
 /*N*/ 			else if( 0 != ( pFrmNd = GoPrevSection( &aIdx, TRUE, FALSE )) &&
 /*N*/ 					::binfilter::CheckNodesRange( aIdx, rFrmIdx, TRUE ) &&
@@ -1199,7 +1063,7 @@ namespace binfilter {
 /*N*/ 					aIdx = pEnd->GetIndex() + 1;
 /*N*/ 				else
 /*?*/ 					aIdx = rFrmIdx;
-/*N*/ 
+/*N*/
 /*N*/ 				// JP 19.09.93: aber nie die Section dafuer verlassen !!
 /*N*/ 				if( ( pEnd && ( pFrmNd = &aIdx.GetNode())->IsCntntNode() ) ||
 /*N*/ 					( 0 != ( pFrmNd = GoNextSection( &aIdx, TRUE, FALSE )) &&
@@ -1241,13 +1105,13 @@ namespace binfilter {
 /*?*/ 						aIdx = pEnd->GetIndex() + 1;
 /*?*/ 					else
 /*?*/ 						aIdx = rFrmIdx.GetIndex() + 1;
-/*?*/ 
+/*?*/
 /*?*/ 					if( (pFrmNd = &aIdx.GetNode())->IsTableNode() )
 /*?*/ 						rFrmIdx = aIdx;
 /*?*/ 					else
 /*?*/ 					{
 /*?*/ 						pFrmNd = 0;
-/*?*/ 
+/*?*/
 /*?*/ 						// is there some sectionnodes before a tablenode?
 /*?*/ 						while( aIdx.GetNode().IsSectionNode() )
 /*?*/ 						{
@@ -1285,11 +1149,11 @@ namespace binfilter {
 /*N*/ };
 
 
-/*N*/ void SwNodes::RemoveNode( ULONG nDelPos, ULONG nSize, FASTBOOL bDel )
+/*N*/ void SwNodes::RemoveNode( ULONG nDelPos, ULONG nSize, bool bDel )
 /*N*/ {
 /*N*/ 	ULONG nEnd = nDelPos + nSize;
 /*N*/ 	SwNode* pNew = (*this)[ nEnd ];
-/*N*/ 
+/*N*/
 /*N*/ 	if( pRoot )
 /*N*/ 	{
 /*N*/ 		SwNodeIndex *p = pRoot;
@@ -1299,10 +1163,10 @@ namespace binfilter {
 /*N*/ 			SwNodeIndex* pNext = p->pNext;
 /*N*/ 			if( nDelPos <= nIdx && nIdx < nEnd )
 /*N*/ 				(*p) = *pNew;
-/*N*/ 
+/*N*/
 /*N*/ 			p = pNext;
 /*N*/ 		}
-/*N*/ 
+/*N*/
 /*N*/ 		p = pRoot->pPrev;
 /*N*/ 		while( p )
 /*N*/ 		{
@@ -1310,16 +1174,16 @@ namespace binfilter {
 /*?*/ 			SwNodeIndex* pPrev = p->pPrev;
 /*?*/ 			if( nDelPos <= nIdx && nIdx < nEnd )
 /*?*/ 				(*p) = *pNew;
-/*?*/ 
+/*?*/
 /*?*/ 			p = pPrev;
 /*N*/ 		}
 /*N*/ 	}
-/*N*/ 
+/*N*/
 /*N*/ 	if( bDel )
 /*N*/ 	{
 /*N*/ 		ULONG nCnt = nSize;
 /*N*/ 		SwNode *pDel = (*this)[ nDelPos+nCnt-1 ], *pPrev = (*this)[ nDelPos+nCnt-2 ];
-/*N*/ 
+/*N*/
 /*N*/ #if 1
 /*N*/ // temp. Object setzen
 /*N*/ 		//JP 24.08.98: muessten eigentlich einzeln removed werden, weil
@@ -1330,7 +1194,7 @@ namespace binfilter {
 /*N*/ 		// siehe Bug 55406
 /*N*/ 		_TempBigPtrEntry aTempEntry;
 /*N*/ 		BigPtrEntry* pTempEntry = &aTempEntry;
-/*N*/ 
+/*N*/
 /*N*/ 		while( nCnt-- )
 /*N*/ 		{
 /*N*/ 			delete pDel;
@@ -1359,7 +1223,7 @@ namespace binfilter {
 /*N*/ 	}
 /*N*/ 	else
 /*N*/ #endif
-/*N*/ 
+/*N*/
 /*N*/ 	BigPtrArray::Remove( nDelPos, nSize );
 /*N*/ }
 
@@ -1386,15 +1250,15 @@ namespace binfilter {
 /*N*/ {
 /*N*/ 	register SwNodeIndex* pN = rIdx.pNext;
 /*N*/ 	register SwNodeIndex* pP = rIdx.pPrev;
-/*N*/ 
+/*N*/
 /*N*/ 	if( pRoot == &rIdx )
 /*N*/ 		pRoot = pP ? pP : pN;
-/*N*/ 
+/*N*/
 /*N*/ 	if( pP )
 /*N*/ 		pP->pNext = pN;
 /*N*/ 	if( pN )
 /*N*/ 		pN->pPrev = pP;
-/*N*/ 
+/*N*/
 /*N*/ 	rIdx.pNext = 0;
 /*N*/ 	rIdx.pPrev = 0;
 /*N*/ }
@@ -1411,7 +1275,7 @@ namespace binfilter {
 /*N*/ 	BigPtrArray::Insert( pIns, nPos );
 /*N*/ }
 
-    // #i31620# 
+    // #i31620#
     SwNode * SwNodes::operator[](int n) const
     {
         return operator[]((ULONG) n);
