@@ -43,7 +43,7 @@
 
 #include <doc.hxx>
 
-#include <errhdl.hxx>
+#include <osl/diagnose.h>
 
 #include <pagefrm.hxx>
 #include <docary.hxx>
@@ -66,9 +66,9 @@
 #include <SwStyleNameMapper.hxx>
 #include <poolfmt.hxx>
 #include <poolfmt.hrc>
-#include <legacysmgr/legacy_binfilters_smgr.hxx>	//STRIP002 
+#include <legacysmgr/legacy_binfilters_smgr.hxx>
 namespace binfilter {
-extern String& GetString( const ::com::sun::star::uno::Any& rAny, String& rStr ); //STRIP008
+extern String& GetString( const ::com::sun::star::uno::Any& rAny, String& rStr );
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::text;
 using namespace ::com::sun::star::lang;
@@ -471,9 +471,7 @@ String SwGetRefField::GetPar2() const
     return Expand();
 }
 
-/*-----------------06.03.98 13:34-------------------
 
---------------------------------------------------*/
 /*N*/ BOOL SwGetRefField::QueryValue( uno::Any& rAny, BYTE nMId ) const
 /*N*/ {
 /*N*/     nMId &= ~CONVERT_TWIPS;
@@ -504,7 +502,7 @@ String SwGetRefField::GetPar2() const
 /*N*/ 			case  REF_SETREFATTR : nSource = ReferenceFieldSource::REFERENCE_MARK; break;
 /*N*/ 			case  REF_SEQUENCEFLD: nSource = ReferenceFieldSource::SEQUENCE_FIELD; break;
 /*?*/ 			case  REF_BOOKMARK   : nSource = ReferenceFieldSource::BOOKMARK; break;
-/*?*/ 			case  REF_OUTLINE    : DBG_ERROR("not implemented"); break;
+/*?*/ 			case  REF_OUTLINE    : OSL_FAIL("not implemented"); break;
 /*?*/ 			case  REF_FOOTNOTE   : nSource = ReferenceFieldSource::FOOTNOTE; break;
 /*?*/ 			case  REF_ENDNOTE    : nSource = ReferenceFieldSource::ENDNOTE; break;
 /*N*/ 			}
@@ -537,13 +535,11 @@ String SwGetRefField::GetPar2() const
 /*N*/ 		rAny <<= (sal_Int16)nSeqNo;
 /*N*/ 		break;
 /*N*/ 	default:
-/*?*/ 		DBG_ERROR("illegal property");
+/*?*/ 		OSL_FAIL("illegal property");
 /*N*/ 	}
 /*N*/ 	return TRUE;
 /*N*/ }
-/*-----------------06.03.98 13:34-------------------
 
---------------------------------------------------*/
 /*N*/ BOOL SwGetRefField::PutValue( const uno::Any& rAny, BYTE nMId )
 /*N*/ {
 /*N*/ 	String sTmp;
@@ -552,7 +548,7 @@ String SwGetRefField::GetPar2() const
 /*N*/ 	{
 /*N*/ 	case FIELD_PROP_USHORT1:
 /*N*/ 		{
-/*N*/ 			sal_Int16 nPart;
+/*N*/ 			sal_Int16 nPart(0);
 /*N*/ 			rAny >>= nPart;
 /*N*/ 			switch(nPart)
 /*N*/ 			{
@@ -571,7 +567,7 @@ String SwGetRefField::GetPar2() const
 /*N*/ 		break;
 /*N*/ 	case FIELD_PROP_USHORT2:
 /*N*/ 		{
-/*N*/ 			sal_Int16 nSource;
+/*N*/ 			sal_Int16 nSource(0);
 /*N*/ 			rAny >>= nSource;
 /*N*/ 			switch(nSource)
 /*N*/ 			{
@@ -592,7 +588,7 @@ String SwGetRefField::GetPar2() const
 /*N*/ 		break;
 /*N*/ 	case FIELD_PROP_PAR1:
 /*?*/     {
-/*?*/         DBG_BF_ASSERT(0, "STRIP"); //STRIP001 OUString sTmp;
+/*?*/         DBG_BF_ASSERT(0, "STRIP");
 /*?*/     }
 /*?*/     break;
 /*?*/ 	case FIELD_PROP_PAR3:
@@ -600,20 +596,18 @@ String SwGetRefField::GetPar2() const
 /*?*/ 		break;
 /*N*/ 	case FIELD_PROP_SHORT1:
 /*N*/ 		{
-/*N*/ 			sal_Int16 nSetSeq;
+/*N*/ 			sal_Int16 nSetSeq(0);
 /*N*/ 			rAny >>= nSetSeq;
 /*N*/ 			if(nSetSeq >= 0)
 /*N*/ 				nSeqNo = nSetSeq;
 /*N*/ 		}
 /*N*/ 		break;
 /*N*/ 	default:
-/*?*/ 		DBG_ERROR("illegal property");
+/*?*/ 		OSL_FAIL("illegal property");
 /*N*/ 	}
 /*N*/ 	return TRUE;
 /*N*/ }
-/* -----------------------------11.01.2002 12:50------------------------------
 
- ---------------------------------------------------------------------------*/
 /*N*/ void SwGetRefField::ConvertProgrammaticToUIName()
 /*N*/ {
 /*N*/     if(GetTyp() && REF_SEQUENCEFLD == nSubType)
@@ -641,7 +635,7 @@ String SwGetRefField::GetPar2() const
 /*?*/                 break;
 /*N*/             }
 /*N*/             if( nResId != USHRT_MAX )
-/*?*/             {DBG_BF_ASSERT(0, "STRIP");} //STRIP001     SetPar1(SW_RESSTR( nResId ));
+/*?*/             {DBG_BF_ASSERT(0, "STRIP");}
 /*N*/         }
 /*N*/     }
 /*N*/ }
@@ -657,7 +651,7 @@ String SwGetRefField::GetPar2() const
 
 /*N*/ SwFieldType* SwGetRefFieldType::Copy() const
 /*N*/ {
-DBG_BF_ASSERT(0, "STRIP");return NULL; //STRIP001 //STRIP001 	return new SwGetRefFieldType( pDoc );
+DBG_BF_ASSERT(0, "STRIP");return NULL;
 /*N*/ }
 
 
@@ -691,7 +685,7 @@ DBG_BF_ASSERT(0, "STRIP");return NULL; //STRIP001 //STRIP001 	return new SwGetRe
 /*N*/ 										USHORT nSubType, USHORT nSeqNo,
 /*N*/ 										USHORT* pStt, USHORT* pEnd )
 /*N*/ {
-/*N*/ 	ASSERT( pStt, "warum wird keine StartPos abgefragt?" );
+/*N*/ 	OSL_ENSURE( pStt, "warum wird keine StartPos abgefragt?" );
 /*N*/ 
 /*N*/ 	SwTxtNode* pTxtNd = 0;
 /*N*/ 	switch( nSubType )
@@ -806,7 +800,7 @@ DBG_BF_ASSERT(0, "STRIP");return NULL; //STRIP001 //STRIP001 	return new SwGetRe
 /*?*/ 		// dann gibt es im DestDoc RefFelder, also muessen im SourceDoc
 /*?*/ 		// alle RefFelder auf einduetige Ids in beiden Docs umgestellt
 /*?*/ 		// werden.
-/*?*/ 		DBG_BF_ASSERT(0, "STRIP"); //STRIP001 _RefIdsMap aFntMap( aEmptyStr );
+/*?*/ 		DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 	}
 /*N*/ }
 
