@@ -63,9 +63,6 @@ namespace binfilter {
 |*
 |*	SwFlyAtCntFrm::SwFlyAtCntFrm()
 |*
-|*	Ersterstellung		MA 11. Nov. 92
-|*	Letzte Aenderung	MA 09. Apr. 99
-|*
 |*************************************************************************/
 
 /*N*/ SwFlyAtCntFrm::SwFlyAtCntFrm( SwFlyFrmFmt *pFmt, SwFrm *pAnch ) :
@@ -86,9 +83,6 @@ namespace binfilter {
 |*
 |*	SwFlyAtCntFrm::Modify()
 |*
-|*	Ersterstellung		MA 08. Feb. 93
-|*	Letzte Aenderung	MA 23. Nov. 94
-|*
 |*************************************************************************/
 
 /*N*/ void SwFlyAtCntFrm::Modify( SfxPoolItem *pOld, SfxPoolItem *pNew )
@@ -110,7 +104,7 @@ namespace binfilter {
 /*N*/ 
 /*N*/ 	if( pAnch )
 /*N*/ 	{
-/*N*/ 		ASSERT( pAnch->GetAnchorId() == GetFmt()->GetAnchor().GetAnchorId(),
+/*N*/ 		OSL_ENSURE( pAnch->GetAnchorId() == GetFmt()->GetAnchor().GetAnchorId(),
 /*N*/ 				"Unzulaessiger Wechsel des Ankertyps." );
 /*N*/ 
 /*N*/ 		//Abmelden, neuen Anker besorgen und 'dranhaengen.
@@ -135,7 +129,7 @@ namespace binfilter {
 /*N*/ 		//Richtung. Wenn der neue Anker nicht gefunden wird koennen wir uns
 /*N*/ 		//immer noch vom Node einen Frame besorgen. Die Change, dass dies dann
 /*N*/ 		//der richtige ist, ist gut.
-/*N*/ 		const FASTBOOL bNext = aOldIdx < aNewIdx;
+/*N*/ 		const bool bNext = aOldIdx < aNewIdx;
 /*N*/ 		while ( pCntnt && aOldIdx != aNewIdx )
 /*N*/ 		{
 /*N*/ 			do
@@ -153,7 +147,7 @@ namespace binfilter {
 /*N*/ 		{
 /*?*/ 			SwCntntNode *pNode = aNewIdx.GetNode().GetCntntNode();
 /*?*/ 			pCntnt = pNode->GetFrm( &pOldAnchor->Frm().Pos(), 0, FALSE );
-/*?*/ 			ASSERT( pCntnt, "Neuen Anker nicht gefunden" );
+/*?*/ 			OSL_ENSURE( pCntnt, "Neuen Anker nicht gefunden" );
 /*N*/ 		}
 /*N*/ 		//Flys haengen niemals an einem Follow sondern immer am
 /*N*/ 		//Master, den suchen wir uns jetzt.
@@ -199,9 +193,6 @@ namespace binfilter {
 |*		fall das Attribut des Rahmens auf automatische Ausrichtung oben
 |* 		eingestellt.
 |*
-|*	Ersterstellung		MA 12. Nov. 92
-|*	Letzte Aenderung	MA 20. Sep. 96
-|*
 |*************************************************************************/
 //Wir brauchen ein Paar Hilfsklassen zur Kontrolle der Ozillation und ein paar
 //Funktionen um die Uebersicht zu gewaehrleisten.
@@ -220,8 +211,8 @@ namespace binfilter {
 /*N*/ public:
 /*N*/ 	SwOszControl( const SwFlyFrm *pFrm );
 /*N*/ 	~SwOszControl();
-/*N*/ 	FASTBOOL ChkOsz();
-/*N*/ 	static FASTBOOL IsInProgress( const SwFlyFrm *pFly );
+/*N*/ 	bool ChkOsz();
+/*N*/ 	static bool IsInProgress( const SwFlyFrm *pFly );
 /*N*/ };
 /*N*/ const SwFlyFrm *SwOszControl::pStk1 = 0;
 /*N*/ const SwFlyFrm *SwOszControl::pStk2 = 0;
@@ -258,12 +249,12 @@ namespace binfilter {
 /*?*/ 		SwOszControl::pStk5 = 0;
 /*N*/ }
 
-/*N*/ FASTBOOL IsInProgress( const SwFlyFrm *pFly )
+/*N*/ bool IsInProgress( const SwFlyFrm* /*pFly*/ )
 /*N*/ {
-        DBG_BF_ASSERT(0, "STRIP"); return FALSE;//STRIP001 //STRIP001 	return SwOszControl::IsInProgress( pFly );
+        DBG_BF_ASSERT(0, "STRIP"); return FALSE;
 /*N*/ }
 
-/*N*/ FASTBOOL SwOszControl::IsInProgress( const SwFlyFrm *pFly )
+/*N*/ bool SwOszControl::IsInProgress( const SwFlyFrm *pFly )
 /*N*/ {
 /*N*/ 	if ( SwOszControl::pStk1 && !pFly->IsLowerOf( SwOszControl::pStk1 ) )
 /*N*/ 		return TRUE;
@@ -278,9 +269,9 @@ namespace binfilter {
 /*N*/ 	return FALSE;
 /*N*/ }
 
-/*N*/ FASTBOOL SwOszControl::ChkOsz()
+/*N*/ bool SwOszControl::ChkOsz()
 /*N*/ {
-/*N*/ 	FASTBOOL bRet = TRUE;
+/*N*/ 	bool bRet = TRUE;
 /*N*/ 	Point aTmp = pFly->Frm().Pos();
 /*N*/ 	if( aTmp == Point() )
 /*N*/ 		aTmp.X() = 1;
@@ -359,8 +350,8 @@ namespace binfilter {
 /*M*/             SwFrm* pFooter = GetAnchor()->FindFooterOrHeader();
 /*M*/             if( pFooter && !pFooter->IsFooterFrm() )
 /*M*/                 pFooter = NULL;
-/*M*/             FASTBOOL bOsz = FALSE;
-/*M*/             FASTBOOL bExtra = Lower() && Lower()->IsColumnFrm();
+/*M*/             bool bOsz = FALSE;
+/*M*/             bool bExtra = Lower() && Lower()->IsColumnFrm();
 /*M*/ 
 /*M*/             do {
 /*M*/                 SWRECTFN( this )
@@ -443,8 +434,6 @@ namespace binfilter {
 |*		Absatzgebundene Objekte.
 |*		Wird beim Draggen von Absatzgebundenen Objekten zur Ankeranzeige sowie
 |*		fuer Ankerwechsel benoetigt.
-|*	Ersterstellung		MA 22. Jun. 93
-|*	Letzte Aenderung	MA 30. Jan. 95
 |*
 |*************************************************************************/
 
@@ -1012,9 +1001,6 @@ namespace binfilter {
 |*
 |*	SwFlyAtCntFrm::SetAbsPos()
 |*
-|*	Ersterstellung		MA 22. Jun. 93
-|*	Letzte Aenderung	MA 11. Sep. 98
-|*
 |*************************************************************************/
 
 
@@ -1063,9 +1049,6 @@ namespace binfilter {
 |* 		angegebenen Werten uebereinstimmen, denn diese geben die Entfernung
 |* 		'im Textfluss' an.
 |*
-|*	Ersterstellung		MA 19. Nov. 92
-|*	Letzte Aenderung	MA 14. Nov. 96
-|*
 |*************************************************************************/
 
 /*N*/ inline void ValidateSz( SwFrm *pFrm )
@@ -1085,15 +1068,15 @@ namespace binfilter {
 /*M*/ 
 /*M*/ 	USHORT nCnt = 0;
 /*M*/ 
-/*M*/ 	FASTBOOL bContinue = FALSE;
+/*M*/ 	bool bContinue = FALSE;
 /*M*/ 	do
 /*M*/ 	{	if ( ++nCnt == 10 )
 /*M*/ 		{
-/*M*/ 			ASSERT( !nCnt, "DeepCalc: Loop detected1?" );
+/*M*/ 			OSL_ENSURE( !nCnt, "DeepCalc: Loop detected1?" );
 /*M*/ 			break;
 /*M*/ 		}
 /*M*/ 
-/*M*/ 		const FASTBOOL bSetComplete = !pFrm->IsValid();
+/*M*/ 		const bool bSetComplete = !pFrm->IsValid();
 /*M*/ 		const SwRect aOldFrm( pFrm->Frm() );
 /*M*/ 		const SwRect aOldPrt( pFrm->Prt() );
 /*M*/ 
@@ -1218,7 +1201,7 @@ namespace binfilter {
 /*N*/ 			if ( Frm().Top() < pNewPage->Frm().Top() && pNewPage->GetPrev() )
 /*N*/ 			{
 /*N*/ 				pNewPage = (SwPageFrm*)pNewPage->GetPrev();
-/*N*/                 // OD 19.02.2003 #105643# - skip empty page and consider empty
+/*N*/                 // skip empty page and consider empty
 /*N*/                 // page at the beginning of the document.
 /*N*/                 // Assumption about document layout:
 /*N*/                 //      No two empty pages following each other.
@@ -1283,7 +1266,7 @@ namespace binfilter {
 /*N*/ 
 /*N*/ 	if ( pMyPage != pNewPage )
 /*N*/ 	{
-/*N*/ 		ASSERT( IsLocked(), "AssertPage: Unlocked Frame??" );
+/*N*/ 		OSL_ENSURE( IsLocked(), "AssertPage: Unlocked Frame??" );
 /*N*/ 		pMyPage->MoveFly( this, pNewPage );
 /*N*/ 		if ( bSuperfluous && pMyPage->GetPhyPageNum() > pNewPage->GetPhyPageNum() )
 /*?*/ 			((SwRootFrm*)pNewPage->GetUpper())->SetSuperfluous();
@@ -1307,51 +1290,45 @@ namespace binfilter {
 /*N*/ }
 
 // Wer weicht wem aus bzw. welcher Bereich ist "linker"/"rechter" als welcher?
-/*N*/ BOOL MA_FASTCALL lcl_Minor( SwRelationOrient eRelO, SwRelationOrient eRelO2,
-/*N*/ 	BOOL bLeft )
-/*N*/ {DBG_BF_ASSERT(0, "STRIP"); return FALSE;//STRIP001 
+/*N*/ BOOL MA_FASTCALL lcl_Minor( SwRelationOrient /*eRelO*/, SwRelationOrient /*eRelO2*/,
+/*N*/ 	BOOL /*bLeft*/ )
+/*N*/ {DBG_BF_ASSERT(0, "STRIP"); return FALSE;
 /*N*/ }
 
 /*N*/ void SwFlyAtCntFrm::MakeFlyPos()
 /*N*/ {
-/*N*/     /// OD 02.10.2002 #102646#
 /*N*/     /// if fly frame position is valid, nothing is to do, Thus, return
 /*N*/     if ( bValidPos )
 /*N*/ 	{
 /*N*/         return;
 /*N*/     }
 /*N*/ 
-/*N*/     /// OD 02.10.2002 #102646# - NOTE
 /*N*/     /// declare and set <pFooter> to footer frame, if fly frame is anchored
 /*N*/     /// at a frame belonging to the footer.
 /*N*/     const SwFrm* pFooter = GetAnchor()->FindFooterOrHeader();
 /*N*/     if( pFooter && !pFooter->IsFooterFrm() )
 /*N*/         pFooter = NULL;
 /*N*/ 
-/*N*/     /// OD 02.10.2002 #102646# - NOTE
 /*N*/     /// declare and set <bBrowse> to TRUE, if document is in browser mode and
 /*N*/     /// fly frame is anchored at the body, but not at frame belonging to a table.
-/*N*/     const FASTBOOL bBrowse = GetAnchor()->IsInDocBody() && !GetAnchor()->IsInTab() ?
+/*N*/     const bool bBrowse = GetAnchor()->IsInDocBody() && !GetAnchor()->IsInTab() ?
 /*N*/                                  GetFmt()->GetDoc()->IsBrowseMode() : FALSE;
 /*N*/ 
-/*N*/     /// OD 02.10.2002 #102646# - NOTE
 /*N*/     /// declare and init <bInvalidatePage> to FALSE, in order to invalidate
 /*N*/     /// page size, if <bInvalidatePage> is set during the calculation of the
 /*N*/     /// fly frame position.
-/*N*/     FASTBOOL bInvalidatePage = FALSE;
+/*N*/     bool bInvalidatePage = FALSE;
 /*N*/ 
-/*N*/     /// OD 02.10.2002 #102646# - NOTE
 /*N*/     /// determine fly frame format and its left/right and its upper/lower spacing.
 /*N*/     SwFlyFrmFmt *pFmt = (SwFlyFrmFmt*)GetFmt();
 /*N*/     const SvxLRSpaceItem &rLR = pFmt->GetLRSpace();
 /*N*/     const SvxULSpaceItem &rUL = pFmt->GetULSpace();
 /*N*/ 
-/*N*/     /// OD 02.10.2002 #102646# - NOTE
 /*N*/     /// determine, if fly frame has no surrounding.
 /*N*/     const SwFmtSurround& rSurround = pFmt->GetSurround();
-/*N*/     const FASTBOOL bNoSurround =
+/*N*/     const bool bNoSurround =
 /*N*/         rSurround.GetSurround() == SURROUND_NONE;
-/*N*/     const FASTBOOL bWrapThrough =
+/*N*/     const bool bWrapThrough =
 /*N*/         rSurround.GetSurround() == SURROUND_THROUGHT;
 /*N*/ 
 /*N*/     BOOL bGrow =
@@ -1478,7 +1455,6 @@ namespace binfilter {
 /*N*/ 		SwTwips nRelDiff = 0;
 /*N*/ 		if ( aVert.GetVertOrient() == VERT_NONE )
 /*N*/ 		{
-/*N*/             /// OD 02.10.2002 #102646# - NOTE
 /*N*/             /// local variable <nRel> for calculation of relative vertical
 /*N*/             /// distance to anchor.
 /*N*/ 			SwTwips nRel;
@@ -1504,7 +1480,6 @@ namespace binfilter {
 /*N*/ 			}
 /*N*/ 			else
 /*N*/             {
-/*N*/                 /// OD 02.10.2002 #102646#
 /*N*/                 /// consider that vertical position can be relativ to "margin"
 /*N*/                 /// or to "text area".
 /*N*/                 /// Thus, increase <nRel> by margin height, if position is
@@ -1774,7 +1749,7 @@ namespace binfilter {
 /*N*/ 		const SwFrm *pPage = pOrient;
 /*N*/ 		while( !pPage->IsPageFrm() && !pPage->IsFlyFrm() && !pPage->IsCellFrm() )
 /*N*/ 		{
-/*N*/ 			ASSERT( pPage->GetUpper(), "MakeFlyPos: No Page/FlyFrm Found" );
+/*N*/ 			OSL_ENSURE( pPage->GetUpper(), "MakeFlyPos: No Page/FlyFrm Found" );
 /*N*/ 			pPage = pPage->GetUpper();
 /*N*/ 		}
 /*N*/ 
@@ -2179,13 +2154,13 @@ namespace binfilter {
 /*N*/ 		pFmt->UnlockModify();
 /*N*/ 
 /*N*/ 		break;
-/*N*/     } /// OD 02.10.2002 #102646# - End of loop
+/*N*/     }
 /*N*/ 
 /*N*/     if ( bInvalidatePage )
 /*N*/         FindPageFrm()->InvalidateSize();
 /*N*/     if ( !bValidPos && !GetAnchor()->IsValid() )
 /*N*/     {
-/*N*/ //      ASSERT( StackHack::IsLocked(), "invalid Anchor" );
+/*N*/ //      OSL_ENSURE( StackHack::IsLocked(), "invalid Anchor" );
 /*N*/         bValidPos = TRUE;
 /*N*/     }
 /*N*/ }
