@@ -69,7 +69,7 @@
 #include "bf_so3/staticbaseurl.hxx"
 namespace binfilter {
 
-#if !defined(UNX) && !defined(MSC) && !defined(PPC) && !defined(CSET) && !defined(WTC) && !defined(__MINGW32__) && !defined(OS2)
+#if !defined(UNX) && !defined(MSC) && !defined(PPC) && !defined(CSET) && !defined(__MINGW32__) && !defined(OS2)
 
 #define FIELDFNTAB_SIZE 37
 #if FIELDFNTAB_SIZE != RES_FIELDS_END - RES_FIELDS_BEGIN
@@ -80,131 +80,124 @@ namespace binfilter {
 
 #define SWG_AUTHORITY_ENTRY_LCL	'E'
 
-sal_Char __FAR_DATA sSW3IO_FixedField[] = "FixedExport";
-sal_Char __FAR_DATA sSW3IO_AuthorityField[] = "AuthorityExport";
+sal_Char sSW3IO_FixedField[] = "FixedExport";
+sal_Char sSW3IO_AuthorityField[] = "AuthorityExport";
 /* #108791# */
-sal_Char __FAR_DATA sSW3IO_DropDownField[] = "DropDownExport";
+sal_Char sSW3IO_DropDownField[] = "DropDownExport";
 
 struct OldFormats
 {
     NfIndexTableOffset	eFormatIdx;
-    USHORT				nOldFormat;
+    USHORT		nOldFormat;
 };
 
 static OldFormats aOldDateFmt40[] =
 {
     // Datumsfelder:
-    NF_DATE_SYSTEM_SHORT,			DFF_SSYS,		// Kurzes Systemdatum
-    NF_DATE_SYSTEM_LONG,			DFF_LSYS,		// Langes Systemdatum
-    NF_DATE_SYS_DDMMYY,				DFF_DMY,        // 06.10.64
-    NF_DATE_SYS_DDMMYYYY,			DFF_DMYY,		// 06.10.1964
-    NF_DATE_SYS_DMMMYY,				DFF_DMMY,		// 06. Okt 64
-    NF_DATE_SYS_DMMMYYYY,			DFF_DMMYY,		// 06. Okt 1964
-    NF_DATE_DIN_DMMMMYYYY,			DFF_DMMMYY,		// 06. Oktober 1964
-    NF_DATE_DIN_DMMMMYYYY,			DFF_DMMMY,		// 06. Oktober 64
-    NF_DATE_SYS_NNDMMMYY,			DFF_DDMMY,		// Di, 06. Okt 64
-    NF_DATE_SYS_NNDMMMMYYYY,		DFF_DDMMMY,		// Di, 06. Oktober 64
-    NF_DATE_SYS_NNDMMMMYYYY,		DFF_DDMMMYY,	// Di, 06. Oktober 1964
-    NF_DATE_SYS_NNNNDMMMMYYYY,		DFF_DDDMMMYY,	// Dienstag, 06. Oktober 1964
-    NF_DATE_SYS_NNNNDMMMMYYYY,		DFF_DDDMMMY,	// Dienstag, 06. Oktober 64
-    NF_DATE_SYS_MMYY,				DFF_MY,			// 10.64
-    NF_DATE_DIN_MMDD,				DFF_MD,			// 10-06
-    NF_DATE_DIN_YYMMDD,				DFF_YMD,		// 64-10-06
-    NF_DATE_DIN_YYYYMMDD,			DFF_YYMD,		// 1964-10-06
-
-    NF_NUMERIC_START,				0				// Tabellenende
+    { NF_DATE_SYSTEM_SHORT,         DFF_SSYS },	       // Kurzes Systemdatum
+    { NF_DATE_SYSTEM_LONG,          DFF_LSYS },	       // Langes Systemdatum
+    { NF_DATE_SYS_DDMMYY,           DFF_DMY },         // 06.10.64
+    { NF_DATE_SYS_DDMMYYYY,         DFF_DMYY },	       // 06.10.1964
+    { NF_DATE_SYS_DMMMYY,           DFF_DMMY },	       // 06. Okt 64
+    { NF_DATE_SYS_DMMMYYYY,         DFF_DMMYY },       // 06. Okt 1964
+    { NF_DATE_DIN_DMMMMYYYY,        DFF_DMMMYY },      // 06. Oktober 1964
+    { NF_DATE_DIN_DMMMMYYYY,        DFF_DMMMY },       // 06. Oktober 64
+    { NF_DATE_SYS_NNDMMMYY,         DFF_DDMMY },       // Di, 06. Okt 64
+    { NF_DATE_SYS_NNDMMMMYYYY,	    DFF_DDMMMY },      // Di, 06. Oktober 64
+    { NF_DATE_SYS_NNDMMMMYYYY,      DFF_DDMMMYY },     // Di, 06. Oktober 1964
+    { NF_DATE_SYS_NNNNDMMMMYYYY,    DFF_DDDMMMYY },    // Dienstag, 06. Oktober 1964
+    { NF_DATE_SYS_NNNNDMMMMYYYY,    DFF_DDDMMMY },     // Dienstag, 06. Oktober 64
+    { NF_DATE_SYS_MMYY,	            DFF_MY },          // 10.64
+    { NF_DATE_DIN_MMDD,	            DFF_MD },          // 10-06
+    { NF_DATE_DIN_YYMMDD,           DFF_YMD },         // 64-10-06
+    { NF_DATE_DIN_YYYYMMDD,         DFF_YYMD },	       // 1964-10-06
+    { NF_NUMERIC_START,	            0 }	               // Tabellenende
 };
 
 static OldFormats aOldDateFmt30[] =
 {
     // Datumsfelder:
-    NF_DATE_SYSTEM_SHORT,			DFF_SSYS,		// Kurzes Systemdatum
-    NF_DATE_SYSTEM_LONG,			DFF_LSYS,		// Langes Systemdatum
-    NF_DATE_SYS_DDMMYY,				DFF_DMY,        // 06.10.64
-    NF_DATE_SYS_DDMMYYYY,			DFF_DMYY,		// 06.10.1964
-    NF_DATE_SYS_DMMMYY,				DFF_DMMY,		// 06. Okt 64
-    NF_DATE_SYS_DMMMYYYY,			4 /*DFF_DMMYY*/,	// 06. Okt 1964
-    NF_DATE_DIN_DMMMMYYYY,			5 /*DFF_DMMMYY*/,	// 06. Oktober 1964
-    NF_DATE_DIN_DMMMMYYYY,			5 /*DFF_DMMMY*/,	// 06. Oktober 64
-    NF_DATE_SYS_NNDMMMMYYYY,		6 /*DFF_DDMMMYY*/,	// Di, 06. Oktober 1964
-    NF_DATE_SYS_NNDMMMYY,			6 /*DFF_DDMMY*/,	// Di, 06. Okt 64
-    NF_DATE_SYS_NNDMMMMYYYY,		6 /*DFF_DDMMMY*/,	// Di, 06. Oktober 64
-    NF_DATE_SYS_NNNNDMMMMYYYY,		7 /*DFF_DDDMMMYY*/,	// Dienstag, 06. Oktober 1964
-    NF_DATE_SYS_NNNNDMMMMYYYY,		7 /*DFF_DDDMMMY*/,	// Dienstag, 06. Oktober 64
-    NF_DATE_SYS_MMYY,				2 /*DFF_MY*/,		// 10.64
-    NF_DATE_DIN_MMDD,				DFF_MD,			// 10-06
-    NF_DATE_DIN_YYMMDD,				DFF_YMD,		// 64-10-06
-    NF_DATE_DIN_YYYYMMDD,			DFF_YYMD,		// 1964-10-06
-
-    NF_NUMERIC_START,				0				// Tabellenende
+    { NF_DATE_SYSTEM_SHORT,         DFF_SSYS },	            // Kurzes Systemdatum
+    { NF_DATE_SYSTEM_LONG,          DFF_LSYS },	            // Langes Systemdatum
+    { NF_DATE_SYS_DDMMYY,           DFF_DMY },              // 06.10.64
+    { NF_DATE_SYS_DDMMYYYY,         DFF_DMYY },	            // 06.10.1964
+    { NF_DATE_SYS_DMMMYY,           DFF_DMMY },	            // 06. Okt 64
+    { NF_DATE_SYS_DMMMYYYY,         4 /*DFF_DMMYY*/ },      // 06. Okt 1964
+    { NF_DATE_DIN_DMMMMYYYY,        5 /*DFF_DMMMYY*/ },     // 06. Oktober 1964
+    { NF_DATE_DIN_DMMMMYYYY,        5 /*DFF_DMMMY*/ },      // 06. Oktober 64
+    { NF_DATE_SYS_NNDMMMMYYYY,      6 /*DFF_DDMMMYY*/ },    // Di, 06. Oktober 1964
+    { NF_DATE_SYS_NNDMMMYY,         6 /*DFF_DDMMY*/ },      // Di, 06. Okt 64
+    { NF_DATE_SYS_NNDMMMMYYYY,      6 /*DFF_DDMMMY*/ },     // Di, 06. Oktober 64
+    { NF_DATE_SYS_NNNNDMMMMYYYY,    7 /*DFF_DDDMMMYY*/ },   // Dienstag, 06. Oktober 1964
+    { NF_DATE_SYS_NNNNDMMMMYYYY,    7 /*DFF_DDDMMMY*/ },    // Dienstag, 06. Oktober 64
+    { NF_DATE_SYS_MMYY,	            2 /*DFF_MY*/ },         // 10.64
+    { NF_DATE_DIN_MMDD,	            DFF_MD },               // 10-06
+    { NF_DATE_DIN_YYMMDD,           DFF_YMD },              // 64-10-06
+    { NF_DATE_DIN_YYYYMMDD,         DFF_YYMD },             // 1964-10-06
+    { NF_NUMERIC_START,	            0 }	                    // Tabellenende
 };
 
 static OldFormats aOldTimeFmt[] =
 {
     // Zeitfelder:
-    NF_TIME_HHMMSS,					TF_SYSTEM,		// Systemzeit
-    NF_TIME_HHMM,					TF_SSMM_24,		// 23:25
-    NF_TIME_HHMMAMPM,				TF_SSMM_12,		// 11:25 PM
-
-    NF_NUMERIC_START,				0				// Tabellenende
+    { NF_TIME_HHMMSS,      TF_SYSTEM },    // Systemzeit
+    { NF_TIME_HHMM,        TF_SSMM_24 },   // 23:25
+    { NF_TIME_HHMMAMPM,    TF_SSMM_12 },   // 11:25 PM
+    { NF_NUMERIC_START,    0 }             // Tabellenende
 };
 
 static OldFormats aOldGetSetExpFmt40[] =
 {
-    NF_TEXT,						VVF_CMD,		// Kommando anzeigen
-    NF_TEXT,						VVF_INVISIBLE,	// unsichtbar
-    NF_PERCENT_INT,					VVF_XXP,		// 1234%
-    NF_PERCENT_DEC2,				VVF_XX_XXP,   	// 1.234,56%
-    NF_TEXT,						VVF_CLEAR,		// ???
-
-    NF_NUMBER_SYSTEM,				VVF_SYS, 		// Zahlenformat aus der
-                                                    // Systemeinstellung
-    NF_NUMBER_INT,					VVF_X,			// 1234
-    NF_NUMBER_DEC2,					VVF_X_X,   		// 1234,5
-    NF_NUMBER_DEC2,					VVF_X_XX,   	// 1245,56
-    NF_NUMBER_1000DEC2,				VVF_XX_XX,   	// 1.234,56
-    NF_NUMBER_1000DEC2,				VVF_XX_X,   	// 1.234,5
-    NF_NUMBER_1000DEC2,				VVF_XX_XXX,		// 1.234,567
-    NF_CURRENCY_1000DEC2,			VVF_SYS_CUR,	// Whrungsformat aus der
-                                                    // Systemeinstellung
-                                                    // (1.234,00 DM)
-    NF_CURRENCY_1000INT,			VVF_X_CUR,		// 1234 DM
-    NF_CURRENCY_1000DEC2,			VVF_XX_XX_CUR,  // 1234,56 DM 1234,00 DM
-    NF_CURRENCY_1000DEC2_DASHED,	VVF_XX_X0_CUR,  // 1234,56 DM 1234,-- DM
-    NF_CURRENCY_1000INT,			VVF_CUR_X,   	// DM 1234
-    NF_CURRENCY_1000DEC2,			VVF_CUR_XX_XX,  // DM 1234,56 DM 1234,00
-    NF_CURRENCY_1000DEC2_DASHED,	VVF_CUR_XX_X0,  // DM 1234,56 DM 1234,--
-
-    NF_NUMERIC_START, 				0				// Tabellenende
+    {NF_TEXT,                        VVF_CMD },	         // Kommando anzeigen
+    {NF_TEXT,                        VVF_INVISIBLE },    // unsichtbar
+    {NF_PERCENT_INT,                 VVF_XXP },          // 1234%
+    {NF_PERCENT_DEC2,                VVF_XX_XXP },       // 1.234,56%
+    {NF_TEXT,                        VVF_CLEAR },        // ???
+    {NF_NUMBER_SYSTEM,               VVF_SYS },          // Zahlenformat aus der
+                                                         // Systemeinstellung
+    {NF_NUMBER_INT,                  VVF_X },            // 1234
+    {NF_NUMBER_DEC2,                 VVF_X_X },          // 1234,5
+    {NF_NUMBER_DEC2,                 VVF_X_XX },         // 1245,56
+    {NF_NUMBER_1000DEC2,             VVF_XX_XX },        // 1.234,56
+    {NF_NUMBER_1000DEC2,             VVF_XX_X },         // 1.234,5
+    {NF_NUMBER_1000DEC2,             VVF_XX_XXX },       // 1.234,567
+    {NF_CURRENCY_1000DEC2,           VVF_SYS_CUR },      // currency format from the
+                                                         // system setup
+                                                         // (1.234,00 DM)
+    {NF_CURRENCY_1000INT,            VVF_X_CUR },        // 1234 DM
+    {NF_CURRENCY_1000DEC2,           VVF_XX_XX_CUR },    // 1234,56 DM 1234,00 DM
+    {NF_CURRENCY_1000DEC2_DASHED,    VVF_XX_X0_CUR },    // 1234,56 DM 1234,-- DM
+    {NF_CURRENCY_1000INT,            VVF_CUR_X },        // DM 1234
+    {NF_CURRENCY_1000DEC2,           VVF_CUR_XX_XX },    // DM 1234,56 DM 1234,00
+    {NF_CURRENCY_1000DEC2_DASHED,    VVF_CUR_XX_X0 },    // DM 1234,56 DM 1234,--
+    {NF_NUMERIC_START,               0 }                 // Tabellenende
 };
 
 static OldFormats aOldGetSetExpFmt30[] =
 {
-    NF_TEXT,						VVF_CMD,		// Kommando anzeigen
-    NF_TEXT,						VVF_INVISIBLE,	// unsichtbar
-    NF_PERCENT_INT,					VVF_XXP,		// 1234%
-    NF_PERCENT_DEC2,				VVF_XX_XXP,   	// 1.234,56%
-    NF_TEXT,						VVF_CLEAR,		// ???
-
-    NF_NUMBER_SYSTEM,				0x0020, 		// Zahlenformat aus der
-                                                    // Systemeinstellung
-    NF_NUMBER_INT,					0x0080,			// 1234
-    NF_NUMBER_1000DEC2,				0x0100,   		// 1.234,56
-    NF_NUMBER_DEC2,					0x0100,   		// 1234,5
-    NF_NUMBER_DEC2,					0x0100,  		// 1245,56
-    NF_NUMBER_1000DEC2,				0x0100,   		// 1.234,5
-    NF_NUMBER_1000DEC2,				0x0100,			// 1.234,567
-    NF_CURRENCY_1000DEC2,			0x0200,			// Whrungsformat aus der
-                                                    // Systemeinstellung
-                                                    // (1.234,00 DM)
-    NF_CURRENCY_1000INT,			0x1000,			// 1234 DM
-    NF_CURRENCY_1000DEC2,			0x1000,  		// 1234,56 DM 1234,00 DM
-    NF_CURRENCY_1000DEC2_DASHED,	0x1000,  		// 1234,56 DM 1234,-- DM
-    NF_CURRENCY_1000INT,			0x1000,   		// DM 1234
-    NF_CURRENCY_1000DEC2,			0x1000,  		// DM 1234,56 DM 1234,00
-    NF_CURRENCY_1000DEC2_DASHED,	0x1000, 		// DM 1234,56 DM 1234,--
-
-    NF_NUMERIC_START, 				0				// Tabellenende
+    {NF_TEXT,                         VVF_CMD },          // Kommando anzeigen
+    {NF_TEXT,                         VVF_INVISIBLE },    // unsichtbar
+    {NF_PERCENT_INT,                  VVF_XXP },          // 1234%
+    {NF_PERCENT_DEC2,                 VVF_XX_XXP },       // 1.234,56%
+    {NF_TEXT,                         VVF_CLEAR },        // ???
+    {NF_NUMBER_SYSTEM,	              0x0020 },           // Zahlenformat aus der
+                                                          // Systemeinstellung
+    { NF_NUMBER_INT,                  0x0080 },           // 1234
+    { NF_NUMBER_1000DEC2,             0x0100 },           // 1.234,56
+    { NF_NUMBER_DEC2,                 0x0100 },           // 1234,5
+    { NF_NUMBER_DEC2,                 0x0100 },           // 1245,56
+    { NF_NUMBER_1000DEC2,             0x0100 },           // 1.234,5
+    { NF_NUMBER_1000DEC2,             0x0100 },           // 1.234,567
+    { NF_CURRENCY_1000DEC2,           0x0200 },           // currency format from
+                                                          // system setup
+                                                          // (1.234,00 DM)
+    { NF_CURRENCY_1000INT,            0x1000 },           // 1234 DM
+    { NF_CURRENCY_1000DEC2,           0x1000 },           // 1234,56 DM 1234,00 DM
+    { NF_CURRENCY_1000DEC2_DASHED,    0x1000 },           // 1234,56 DM 1234,-- DM
+    { NF_CURRENCY_1000INT,            0x1000 },           // DM 1234
+    { NF_CURRENCY_1000DEC2,           0x1000 },           // DM 1234,56 DM 1234,00
+    { NF_CURRENCY_1000DEC2_DASHED,    0x1000 },           // DM 1234,56 DM 1234,--
+    { NF_NUMERIC_START,               0 }                 // Tabellenende
 };
 
 /*N*/ void sw3io_ConvertFromOldField( SwDoc& rDoc, USHORT& rWhich,
@@ -747,7 +740,7 @@ SwAuthorityFieldType* lcl_sw3io_InAuthorityFieldType( Sw3IoImp& rIo )
         pFldType->SetSortByDocument( (cFlags & 0x20) != 0);
     }
 
-    ASSERT( !rIo.pAuthorityMap, "authority map is already existing" );
+    OSL_ENSURE( !rIo.pAuthorityMap, "authority map is already existing" );
     if( nCount > 0 )
         rIo.pAuthorityMap = new SvUShorts;
 
@@ -769,7 +762,7 @@ SwAuthorityFieldType* lcl_sw3io_InAuthorityFieldType( Sw3IoImp& rIo )
         }
 
         USHORT nNewPos = pFldType->AppendField( aEntry );
-        ASSERT( !rIo.bNormal || rIo.bInsert || nNewPos == i,
+        OSL_ENSURE( !rIo.bNormal || rIo.bInsert || nNewPos == i,
                 "unexpected authority entry position" );
         rIo.pAuthorityMap->Insert( nNewPos, rIo.pAuthorityMap->Count() );
 
@@ -1055,7 +1048,7 @@ SwAuthorityFieldType* lcl_sw3io_InAuthorityFieldType( Sw3IoImp& rIo )
 /*N*/ 	}
 /*N*/ }
 
-/*N*/ SwField* lcl_sw3io_InDateField40( Sw3IoImp& rIo, SwFieldType* pType,
+/*N*/ SwField* lcl_sw3io_InDateField40( Sw3IoImp& /*rIo*/, SwFieldType* pType,
 /*N*/ 								  USHORT nSubType, UINT32& )
 /*N*/ { //SW40.SDW  
 /*N*/ 	SwDateTimeField* pFld =
@@ -1065,7 +1058,7 @@ SwAuthorityFieldType* lcl_sw3io_InAuthorityFieldType( Sw3IoImp& rIo )
 /*N*/ 	return pFld;
 /*N*/ }
 
-/*N*/ SwField* lcl_sw3io_InTimeField40( Sw3IoImp& rIo, SwFieldType* pType,
+/*N*/ SwField* lcl_sw3io_InTimeField40( Sw3IoImp& /*rIo*/, SwFieldType* pType,
 /*N*/ 								  USHORT nSubType, UINT32& )
 /*N*/ {
             SwDateTimeField* pFld =
@@ -1538,7 +1531,7 @@ SwAuthorityFieldType* lcl_sw3io_InAuthorityFieldType( Sw3IoImp& rIo )
 /*N*/ 	return new SwDocStatField( (SwDocStatFieldType*)pType, nSubType, rFmt );
 /*N*/ }
 /*N*/ 
-/*N*/ SwField* lcl_sw3io_InDocStatField( Sw3IoImp& rIo, SwFieldType* pType,
+/*N*/ SwField* lcl_sw3io_InDocStatField( Sw3IoImp& /*rIo*/, SwFieldType* pType,
 /*N*/ 								   USHORT nSubType, UINT32& rFmt )
 /*N*/ {
 /*N*/ 	return new SwDocStatField( (SwDocStatFieldType*)pType, nSubType, rFmt );
@@ -1838,7 +1831,7 @@ SwAuthorityFieldType* lcl_sw3io_InAuthorityFieldType( Sw3IoImp& rIo )
 /*N*/ 
 /*N*/ 	if( cFlags & 0x20 )
 /*N*/ 	{
-/*N*/ 		ASSERT( GSE_SEQ & ((SwSetExpFieldType *)pType)->GetType(),
+/*N*/ 		OSL_ENSURE( GSE_SEQ & ((SwSetExpFieldType *)pType)->GetType(),
 /*N*/ 				"Kein Sequence-Number-Feld" );
 /*N*/ 
 /*N*/ 		pFld->SetValue( nSeqVal );
@@ -2001,7 +1994,7 @@ SwAuthorityFieldType* lcl_sw3io_InAuthorityFieldType( Sw3IoImp& rIo )
 /*N*/ 		*rIo.pStrm << ((SwDocInfoField*)pFld)->GetValue();
 /*N*/ }
 
-/*N*/ SwField* lcl_sw3io_InTemplNameField( Sw3IoImp& rIo, SwFieldType* pType,
+/*N*/ SwField* lcl_sw3io_InTemplNameField( Sw3IoImp& /*rIo*/, SwFieldType* pType,
 /*N*/ 									 USHORT, UINT32& rFmt )
 /*N*/ {
 /*N*/ 	return new SwTemplNameField( (SwTemplNameFieldType*)pType, rFmt );
@@ -2206,7 +2199,7 @@ SwAuthorityFieldType* lcl_sw3io_InAuthorityFieldType( Sw3IoImp& rIo )
 
 /*N*/ SwField *lcl_sw3io_InINetField31( Sw3IoImp& rIo, SwFieldType *, USHORT, UINT32& )
 /*N*/ {
-/*N*/ 	ASSERT( !(rIo.pFmtINetFmt || rIo.aINetFldText.Len()),
+/*N*/ 	OSL_ENSURE( !(rIo.pFmtINetFmt || rIo.aINetFldText.Len()),
 /*N*/ 			"Da sind noch Rest-Infos vom INet-Feld!" );
 /*N*/ 
 /*N*/ 	String aURL, aText;
@@ -2307,10 +2300,10 @@ SwAuthorityFieldType* lcl_sw3io_InAuthorityFieldType( Sw3IoImp& rIo )
 
 /*N*/ void lcl_sw3io_OutScriptField40( Sw3IoImp& rIo, SwField* pFld )
 /*N*/ {
-        ASSERT( !rIo.IsSw31Export(),
+        OSL_ENSURE( !rIo.IsSw31Export(),
                 "Wer will denn da ein Script-Feld exportieren" );
 
-        BYTE cFlags = ((SwScriptField*)pFld)->IsCodeURL() ? 0x01 : 0x00;
+        ((SwScriptField*)pFld)->IsCodeURL() ? 0x01 : 0x00;
 
         String aCode;
         if( ((SwScriptField*)pFld)->IsCodeURL() )
@@ -2327,7 +2320,7 @@ SwAuthorityFieldType* lcl_sw3io_InAuthorityFieldType( Sw3IoImp& rIo )
 
 /*N*/ void lcl_sw3io_OutScriptField( Sw3IoImp& rIo, SwField* pFld )
 /*N*/ {
-        ASSERT( !rIo.IsSw31Export(),
+        OSL_ENSURE( !rIo.IsSw31Export(),
                 "Wer will denn da ein Script-Feld exportieren" );
 
         BYTE cFlags = ((SwScriptField*)pFld)->IsCodeURL() ? 0x01 : 0x00;
@@ -2360,7 +2353,7 @@ SwAuthorityFieldType* lcl_sw3io_InAuthorityFieldType( Sw3IoImp& rIo )
 
         SwField *pFld = 0;
         SwFieldType* pType = rIo.pDoc->GetFldType( RES_AUTHORITY, aEmptyStr );
-        ASSERT( pType, "missing authority field type" );
+        OSL_ENSURE( pType, "missing authority field type" );
         if( pType )
         {
             long nHandle = ((SwAuthorityFieldType *)pType)->GetHandle( nPos );
@@ -2476,10 +2469,10 @@ static Sw3InFieldFn aInFieldFnTbl[] =
 
 /*N*/ SwField* Sw3IoImp::InField()
 /*N*/ {
-/*N*/ 	ASSERT( RES_FIELDS_END-RES_FIELDS_BEGIN ==
+/*N*/ 	OSL_ENSURE( RES_FIELDS_END-RES_FIELDS_BEGIN ==
 /*N*/ 						sizeof(aInFieldFnTbl) / sizeof(Sw3InFieldFn),
 /*N*/ 			"Neues Feld? Und tschuess..." );
-/*N*/ 	ASSERT( RES_FIELDS_END-RES_FIELDS_BEGIN ==
+/*N*/ 	OSL_ENSURE( RES_FIELDS_END-RES_FIELDS_BEGIN ==
 /*N*/ 						sizeof(aInFieldFnTbl40) / sizeof(Sw3InFieldFn),
 /*N*/ 			"Neues Feld? Und tschuess..." );
 /*N*/ 
@@ -2528,7 +2521,7 @@ static Sw3InFieldFn aInFieldFnTbl[] =
 /*N*/ 	Sw3InFieldFn pFn =
 /*N*/ 		(nWhich < RES_FIELDS_END) ? pFnTbl[nWhich-RES_FIELDS_BEGIN] : 0;
 /*N*/ 
-/*N*/ 	ASSERT( pFn, "unbekannte Feld-Which-Id" );
+/*N*/ 	OSL_ENSURE( pFn, "unbekannte Feld-Which-Id" );
 /*N*/ 	if( pFn )
 /*N*/ 		pFld = (*pFn)( *this, pType, nSubType, nFldFmt );
 /*N*/ 	else
@@ -2706,15 +2699,15 @@ static Sw3OutFieldFn aOutFieldFnTbl[] =
 
 /*N*/ void Sw3IoImp::OutField( const SwFmtFld& rAttr )
 /*N*/ {
-/*N*/ 	ASSERT( RES_FIELDS_END-RES_FIELDS_BEGIN ==
+/*N*/ 	OSL_ENSURE( RES_FIELDS_END-RES_FIELDS_BEGIN ==
 /*N*/ 						sizeof(aOutFieldFnTbl) / sizeof(Sw3OutFieldFn),
 /*N*/ 			"Neues Feld? Und tschuess..." );
-/*N*/ 	ASSERT( RES_FIELDS_END-RES_FIELDS_BEGIN ==
+/*N*/ 	OSL_ENSURE( RES_FIELDS_END-RES_FIELDS_BEGIN ==
 /*N*/ 						sizeof(aOutFieldFnTbl40) / sizeof(Sw3OutFieldFn),
 /*N*/ 			"Neues Feld? Und tschuess..." );
 /*N*/ 
 /*N*/ 	const SwField* pFld = rAttr.GetFld();
-/*N*/ 	ASSERT( pFld, "SWG-Writer: SwAttrFld-Hint ohne Inhalt!" );
+/*N*/ 	OSL_ENSURE( pFld, "SWG-Writer: SwAttrFld-Hint ohne Inhalt!" );
 /*N*/ 	if( !pFld )
 /*N*/ 		return;
 /*N*/ 
@@ -2950,7 +2943,7 @@ static Sw3OutFieldFn aOutFieldFnTbl[] =
 /*N*/ 											(SwAuthorityFieldType *)&rType );
 /*N*/ 			break;
 /*N*/ 		default:
-/*N*/ 			ASSERT( !this, "Unbekannter Feldtyp" );
+/*N*/ 			OSL_ENSURE( !this, "Unbekannter Feldtyp" );
 /*N*/ 			CloseRec( SWG_FIELDTYPE );
 /*N*/ 			Error();
 /*N*/ 			return FALSE;
