@@ -31,6 +31,8 @@
 #pragma hdrstop
 #endif
 
+#include <bf_svtools/bf_solar.h>
+
 #include "swerror.h"
 
 #include <horiornt.hxx>
@@ -39,7 +41,7 @@
 
 #include <tools/tenccvt.hxx>
 
-#include <errhdl.hxx>
+#include <osl/diagnose.h>
 
 #include <fmtcol.hxx>
 
@@ -426,7 +428,7 @@ void Sw3IoImp::SetDBName()
 /*N*/ 			// Fehlerfall: unbekannte Poolvorlage -> neu anlegen
 /*N*/ 			if( RES_POOLPAGE_BEGIN > nPoolId ||  nPoolId >= RES_POOLPAGE_END )
 /*N*/ 			{
-/*?*/ 				ASSERT( !this, "ungueltige Id" );
+/*?*/ 				OSL_ENSURE( !this, "ungueltige Id" );
 /*?*/ 				nPoolId = IDX_NO_VALUE;
 /*N*/ 			}
 /*N*/ 		}
@@ -564,7 +566,7 @@ void Sw3IoImp::SetDBName()
 /*N*/ 		{
 /*N*/ 			SwPageDesc* pDesc = FindPageDesc( pAttr->GetDescNameIdx() );
 /*N*/ 			pAttr->SetDescNameIdx( IDX_NO_VALUE );
-/*N*/ 			ASSERT( pDesc, "Unbekannte Seitenvorlage fuer PageDesc-Attribut" );
+/*N*/ 			OSL_ENSURE( pDesc, "Unbekannte Seitenvorlage fuer PageDesc-Attribut" );
 /*N*/ 			if( pDesc )
 /*N*/ 			{
 /*N*/ 				pDesc->Add( pAttr );
