@@ -44,7 +44,7 @@
 
 #include <doc.hxx>
 
-#include <errhdl.hxx>
+#include <osl/diagnose.h>
 
 #include <pam.hxx>
 #include <sw3imp.hxx>
@@ -76,9 +76,9 @@ namespace binfilter {
 /*N*/ 
 /*N*/ 	// Der aktuelle NumRange eines 3.1/40-Files muss gerettet werden, falls
 /*N*/ 	// eine Section innerhalb einer Section gelesen wird (z.B. Flys)
-/*N*/ 	SwNumRule* pOld40Rule;
-/*N*/ 	SwPaM* pOld40Range;
-/*N*/ 	BOOL bOldConvertNoNum;
+/*N*/ 	SwNumRule* pOld40Rule = NULL;
+/*N*/ 	SwPaM* pOld40Range =NULL;
+/*N*/ 	BOOL bOldConvertNoNum = 0;
 /*N*/ 	if( !IsVersion(SWG_LONGIDX) )
 /*N*/ 	{
 /*N*/ 		pOld40Rule = pCurNumRule;
@@ -113,7 +113,7 @@ namespace binfilter {
 /*N*/ 
 /*N*/ 	SwTxtNode* pNd = bNode1 ? pStart->GetTxtNode() : NULL;
 /*N*/ 	SwTxtNode* pNd1 = pNd;
-/*N*/ 	ASSERT( !nInsFirstPara || pNd, "Einfuegen in Nicht-Content-Node?" );
+/*N*/ 	OSL_ENSURE( !nInsFirstPara || pNd, "Einfuegen in Nicht-Content-Node?" );
 /*N*/ 	SwPosition *pEndPos = 0;
 /*N*/ 	if( nInsFirstPara && pNd )
 /*N*/ 	{
@@ -242,7 +242,7 @@ namespace binfilter {
 /*?*/ 
 /*?*/ 					if( SwFlyStartNode != pSttNd->GetStartNodeType() )
 /*?*/ 					{
-/*?*/ 						ASSERT( !this,
+/*?*/ 						OSL_ENSURE( !this,
 /*?*/ 								"Verankerung an Frames ist nur fuer Fly-Frames implementiert" );
 /*?*/ 						break;
 /*?*/ 					}
@@ -313,7 +313,7 @@ namespace binfilter {
 /*N*/ 	// auf einem End-Node steht, lassen wir den Code erstmal drinne, aber
 /*N*/ 	// es ist doc recht fraglich, wozu er da ist.
 /*N*/ 	SwEndNode *pEndNd = pDoc->GetNodes()[ rPos ]->GetEndNode();
-/*N*/ 	ASSERT( !pEndNd || !pSectSttNd || pEndNd->FindStartNode()==pSectSttNd,
+/*N*/ 	OSL_ENSURE( !pEndNd || !pSectSttNd || pEndNd->FindStartNode()==pSectSttNd,
 /*N*/ 			"PaM steht auf EndNode, der nicht zur Section gehoert." );
 /*N*/ 	if( pEndNd && !pSectSttNd &&
 /*N*/ 		pEndNd != &pDoc->GetNodes().GetEndOfContent())
@@ -351,14 +351,6 @@ namespace binfilter {
 /*N*/ SwStartNode& Sw3IoImp::InContents()
 /*N*/ {
 /*N*/ 	// Anlegen einer Section mit einem TextNode
-/*N*/ #if 0
-/*N*/ 	SwStartNode* pSttNd = pDoc->GetNodes().MakeTextSection(
-/*N*/ 								pDoc->GetNodes().EndOfAutotext,
-/*N*/ 								(SwStartNodeType)eStartNodeType,
-/*N*/ 								(SwTxtFmtColl*) pDoc->GetDfltTxtFmtColl() );
-/*N*/ 	SwIndex aStart( pSttNd->GetMyIndex() );
-/*N*/ 	InContents( aStart );
-/*N*/ #endif
 /*N*/ // OPT: Section leer anlegen
 /*N*/ 	SwNodeIndex aStart( pDoc->GetNodes().GetEndOfAutotext() );
 /*N*/ 	SwStartNode* pSttNd = pDoc->GetNodes().MakeEmptySection(  aStart,
@@ -417,7 +409,7 @@ namespace binfilter {
 /*N*/ 	// Der Index zeigt auf den Start-Node, also muessen wir einen
 /*N*/ 	// bauen, der auf den naechsten Node zeigt
 /*N*/ 	SwStartNode* pStt = pDoc->GetNodes()[ rStart ]->GetStartNode();
-/*N*/ 	ASSERT( pStt, "StartNode nicht gefunden" );
+/*N*/ 	OSL_ENSURE( pStt, "StartNode nicht gefunden" );
 /*N*/ 	if( pStt )
 /*N*/ 	{
 /*N*/ 		// Hole vom Node und vom letzten Node die Position in der Section
@@ -633,7 +625,7 @@ namespace binfilter {
 /*?*/ 				// kann einfach ignoriert werden
 /*?*/ 				nNodes--; nCurNode++; break;
 /*?*/ 			default:
-/*?*/ 				ASSERT( !this, "Node kann nicht gespeichert werden" );
+/*?*/ 				OSL_ENSURE( !this, "Node kann nicht gespeichert werden" );
 /*?*/ 				Error( ERR_SWG_WRITE_ERROR );
 /*?*/ 				nCurNode = nEndNode;
 /*N*/ 		}
@@ -771,7 +763,7 @@ namespace binfilter {
 /*N*/ {
 /*N*/ 	const SwSection& rSect = rNd.GetSection();
 /*N*/ 
-/*N*/ 	ASSERT( TOX_HEADER_SECTION == rSect.GetType() ||
+/*N*/ 	OSL_ENSURE( TOX_HEADER_SECTION == rSect.GetType() ||
 /*N*/ 			TOX_CONTENT_SECTION == rSect.GetType(),
 /*N*/ 			"Not a TOX section" );
 /*N*/ 
@@ -827,7 +819,7 @@ namespace binfilter {
 /*N*/ 
 /*N*/ 	// The sections start node is counted by OutNodes, but it hasn't been
 /*N*/ 	// written. That for, the number of nodes must be reduced by one.
-/*N*/ 	ASSERT( nNodes > 0, "empty TOX section?" );
+/*N*/ 	OSL_ENSURE( nNodes > 0, "empty TOX section?" );
 /*N*/ 	return nNodes - 1;
 /*N*/ }
 
