@@ -162,10 +162,10 @@ using namespace ::com::sun::star::i18n;
 /*?*/ 			((SwTxtFtn*)pNew)->SetSeqNo( ((SwFmtFtn&)rAttr).GetTxtFtn()->GetSeqRefNo() );
 /*N*/ 		break;
 /*?*/ 	case RES_TXTATR_HARDBLANK:
-            {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*?*/ 		pNew = new SwTxtHardBlank( (SwFmtHardBlank&)rNew, nStt );
+            {DBG_BF_ASSERT(0, "STRIP");}
 /*?*/ 		break;
 /*?*/     case RES_CHRATR_TWO_LINES:
-            {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*?*/ 		pNew = new SwTxt2Lines( (SvxTwoLinesItem&)rNew, nStt, nEnd );
+            {DBG_BF_ASSERT(0, "STRIP");}
 /*?*/ 		break;
 /*N*/ 	case RES_TXTATR_REFMARK:
 /*N*/ 		pNew = nStt == nEnd
@@ -177,13 +177,13 @@ using namespace ::com::sun::star::i18n;
 /*N*/ 		break;
 /*N*/ 	case RES_UNKNOWNATR_CONTAINER:
 /*?*/ 	case RES_TXTATR_UNKNOWN_CONTAINER:
-            {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*?*/ 		pNew = new SwTxtXMLAttrContainer( (SvXMLAttrContainerItem&)rNew,
+            {DBG_BF_ASSERT(0, "STRIP");}
 /*?*/ 		break;
 /*N*/ 	case RES_TXTATR_CJK_RUBY:
 /*N*/ 		pNew = new SwTxtRuby( (SwFmtRuby&)rNew, nStt, nEnd );
 /*N*/ 		break;
 /*N*/ 	}
-/*N*/ 	ASSERT( pNew, "was fuer ein TextAttribut soll hier angelegt werden?" );
+/*N*/ 	OSL_ENSURE( pNew, "was fuer ein TextAttribut soll hier angelegt werden?" );
 /*N*/ 	return pNew;
 /*N*/ }
 
@@ -220,9 +220,9 @@ using namespace ::com::sun::star::i18n;
 /*N*/ 				const SwField* pFld = pAttr->GetFld().GetFld();
 /*N*/
 /*N*/ 				//JP 06-08-95: DDE-Felder bilden eine Ausnahme
-/*N*/ 				ASSERT( RES_DDEFLD == pFld->GetTyp()->Which() ||
+/*N*/ 				OSL_ENSURE( RES_DDEFLD == pFld->GetTyp()->Which() ||
 /*N*/ 						this == ((SwTxtFld*)pAttr)->GetpTxtNode(),
-/*N*/ 						"Wo steht denn dieses Feld?" )
+/*N*/ 						"Wo steht denn dieses Feld?" );
 /*N*/
 /*N*/ 				// bestimmte Felder mussen am Doc das Calculations-Flag updaten
 /*N*/ 				switch( pFld->GetTyp()->Which() )
@@ -288,7 +288,7 @@ using namespace ::com::sun::star::i18n;
 /*N*/ {
 /*N*/ 	BOOL bHiddenPara = FALSE;
 /*N*/
-/*N*/ 	ASSERT( *pAttr->GetStart() <= Len(), "StartIdx hinter Len!" );
+/*N*/ 	OSL_ENSURE( *pAttr->GetStart() <= Len(), "StartIdx hinter Len!" );
 /*N*/
 /*N*/ 	if( !pAttr->GetEnd() )
 /*N*/ 	{
@@ -346,7 +346,7 @@ using namespace ::com::sun::star::i18n;
 /*?*/ 						if( SETATTR_NOTXTATRCHR & nInsMode )
 /*?*/ 						{
 /*?*/ 						// loesche das Zeichen aus dem String !
-/*?*/ 						ASSERT( ( CH_TXTATR_BREAKWORD ==
+/*?*/ 						OSL_ENSURE( ( CH_TXTATR_BREAKWORD ==
 /*?*/ 										aText.GetChar(*pAttr->GetStart() ) ||
 /*?*/ 								  CH_TXTATR_INWORD ==
 /*?*/ 								  		aText.GetChar(*pAttr->GetStart())),
@@ -379,7 +379,7 @@ using namespace ::com::sun::star::i18n;
 /*?*/ 					if( SETATTR_NOTXTATRCHR & nInsMode )
 /*?*/ 					{
 /*?*/ 						// loesche das Zeichen aus dem String !
-/*?*/ 						ASSERT( ( CH_TXTATR_BREAKWORD ==
+/*?*/ 						OSL_ENSURE( ( CH_TXTATR_BREAKWORD ==
 /*?*/ 										aText.GetChar(*pAttr->GetStart() ) ||
 /*?*/ 								  CH_TXTATR_INWORD ==
 /*?*/ 								  		aText.GetChar(*pAttr->GetStart())),
@@ -451,7 +451,7 @@ using namespace ::com::sun::star::i18n;
 /*N*/ #endif
 /*N*/ 						pDoc->GetFtnIdxs().Insert( pTxtFtn );
 /*N*/ #ifdef DBG_UTIL
-/*N*/ 					ASSERT( bSuccess, "FtnIdx nicht eingetragen." );
+/*N*/ 					OSL_ENSURE( bSuccess, "FtnIdx nicht eingetragen." );
 /*N*/ #endif
 /*N*/ 				}
 /*N*/ 				SwNodeIndex aTmpIndex( *this );
@@ -483,7 +483,7 @@ using namespace ::com::sun::star::i18n;
 /*N*/ 	}
 /*N*/ 	else
 /*N*/   {
-/*N*/ 		ASSERT( *pAttr->GetEnd() <= Len(), "EndIdx hinter Len!" );
+/*N*/ 		OSL_ENSURE( *pAttr->GetEnd() <= Len(), "EndIdx hinter Len!" );
 /*N*/   }
 /*N*/
 /*N*/ 	if ( !pSwpHints )
@@ -650,7 +650,7 @@ using namespace ::com::sun::star::i18n;
 /*N*/ 			if( RES_TXTATR_CHARFMT == pItem->Which() &&
 /*N*/ 				GetDoc()->GetDfltCharFmt()==((SwFmtCharFmt*)pItem)->GetCharFmt())
 /*N*/ 			{
-                    DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/ 				SwIndex aIndex( this, nStt );
+                    DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 			}
 /*N*/ 			else
 /*N*/ 			{
@@ -660,7 +660,7 @@ using namespace ::com::sun::star::i18n;
 /*N*/ 					// Attribut ohne Ende, aber Bereich markiert ?
 /*N*/ 					if( nEnd != nStt && !pNew->GetEnd() )
 /*N*/ 					{
-/*?*/ 						ASSERT( !this, "Attribut ohne Ende aber Bereich vorgegeben" );
+/*?*/ 						OSL_ENSURE( !this, "Attribut ohne Ende aber Bereich vorgegeben" );
 /*?*/ 						DestroyAttr( pNew );		// nicht einfuegen
 /*N*/ 					}
 /*N*/ 					else if( Insert( pNew, nMode ))
@@ -722,36 +722,10 @@ using namespace ::com::sun::star::i18n;
 /*N*/ 					rSet.Put( rCFSet.Get( nWhich ) );
 /*N*/ 				nWhich = aIter.NextWhich();
 /*N*/ 			}
-/*N*/ #if 0
-/*N*/ 			SfxItemSet aTmpSet( *rSet.GetPool(), rSet.GetRanges() );
-/*N*/ 			aTmpSet.Set( pFmt->GetAttrSet(), TRUE );
- /*
- ????? JP 31.01.95 ????	wie jetzt ???
-             rSet.MergeValues( aTmpSet );
-
-             // jetzt alle zusammen "mergen"
-             rSet.Differentiate( aTmpSet );
- */
-/*N*/ 			rSet.Put( aTmpSet );
-/*N*/ #endif
 /*N*/ 		}
 /*N*/ 	}
 /*N*/
 /*N*/ 	// aufnehmen als MergeWert (falls noch nicht gesetzt neu setzen!)
-/*N*/ #if 0
- /* wenn mehrere Attribute ueberlappen werden diese gemergt !!
-  z.B
-             1234567890123456789
-               |------------| 		Font1
-                  |------|			Font2
-                     ^  ^
-                     |--|		Abfragebereich: -> uneindeutig
- */
-/*N*/ 	else if( SFX_ITEM_DEFAULT == rSet.GetItemState( rAttr.Which(), FALSE ))
-/*N*/ 		rSet.Put( rAttr );
-/*N*/ 	else
-/*N*/ 		rSet.MergeValue( rAttr );
-/*N*/ #else
  /* wenn mehrere Attribute ueberlappen gewinnt der letze !!
   z.B
              1234567890123456789
@@ -761,7 +735,6 @@ using namespace ::com::sun::star::i18n;
                      |--|		Abfragebereich: -> Gueltig ist Font2
  */
 /*N*/ 		rSet.Put( rAttr );
-/*N*/ #endif
 /*N*/ }
 
 // erfrage die Attribute vom TextNode ueber den Bereich
@@ -950,16 +923,6 @@ using namespace ::com::sun::star::i18n;
 /*N*/
 /*N*/ 	if( pNd == this )
 /*N*/ 	{
-/*?*/ 		if( aThisSet.Count() )
-/*?*/ 		{
-/*?*/ 			SfxItemIter aIter( aThisSet );
-/*?*/ 			const SfxPoolItem* pItem = aIter.GetCurItem();
-/*?*/ 			while( TRUE )
-/*?*/ 			{
-                    DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/ 				if( lcl_IsNewAttrInSet( *pSwpHints, *pItem, GetTxt().Len() ) )
-/*?*/ 			}
-/*?*/ 		}
-/*N*/
 /*N*/ 	}
 /*N*/ 	else
 /*N*/ 	{
@@ -972,20 +935,7 @@ using namespace ::com::sun::star::i18n;
 /*N*/
 /*N*/ 		if( aThisSet.Count() )
 /*N*/ 		{
-/*?*/ 			DBG_BF_ASSERT(0, "STRIP"); //STRIP001 SfxItemIter aIter( aThisSet );
-/*N*/ 		}
-/*N*/
-/*N*/ 		if( aNdSet.Count() )
-/*N*/ 		{
-/*?*/ 			SfxItemIter aIter( aNdSet );
-/*?*/ 			const SfxPoolItem* pItem = aIter.GetCurItem();
-/*?*/ 			while( TRUE )
-/*?*/ 			{
-                    DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/ 				if( lcl_IsNewAttrInSet( *pNd->pSwpHints, *pItem, pNd->GetTxt().Len() ) )
-/*?*/ 			}
-/*?*/
-/*?*/ 			SwFmtChg aTmp1( pNd->GetFmtColl() );
-/*?*/ 			pNd->SwModify::Modify( &aTmp1, &aTmp1 );
+/*?*/ 			DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 		}
 /*N*/ 	}
 /*N*/
@@ -1165,7 +1115,7 @@ using namespace ::com::sun::star::i18n;
 /*N*/             SwTxtAttr *pPrev;
 /*N*/             SwTxtAttr *pNext;
 /*N*/             USHORT nEndIdx = aHtEnd.C40_GETPOS( SwTxtAttr, pAttr );
-/*N*/             ASSERT( USHRT_MAX != nEndIdx, "Missing end index" );
+/*N*/             OSL_ENSURE( USHRT_MAX != nEndIdx, "Missing end index" );
 /*N*/             if( nEndIdx )
 /*N*/             {
 /*N*/                 // If there's a attribute with same start and which-id,
@@ -1460,7 +1410,7 @@ using namespace ::com::sun::star::i18n;
 /*N*/ 									pDoc->InsertFldType( *pFld->GetTyp() );
 /*N*/ 						if( pFldType != pFld->GetTyp() )
 /*N*/ 						{
-/*?*/ 							DBG_BF_ASSERT(0, "STRIP"); //STRIP001 SwFmtFld* pFmtFld = (SwFmtFld*)&((SwTxtFld*)pHint)
+/*?*/ 							DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 						}
 /*N*/ 						pFldType->SetSeqRefNo( *(SwSetExpField*)pFld );
 /*N*/ 					}
@@ -1476,7 +1426,7 @@ using namespace ::com::sun::star::i18n;
 /*N*/ 					break;
 /*N*/ 				}
 /*N*/ 				if( bInsFldType )
-/*?*/ 					{DBG_BF_ASSERT(0, "STRIP");} //STRIP001 pDoc->InsDeletedFldType( *pFld->GetTyp() );
+/*?*/ 					{DBG_BF_ASSERT(0, "STRIP");}
 /*N*/ 			}
 /*N*/ 		}
 /*N*/ 		break;
@@ -1498,7 +1448,7 @@ using namespace ::com::sun::star::i18n;
 /*N*/ 					0 != ( pHtEnd = pHt->GetEnd() ) &&
 /*N*/ 					0 != ( pHintEnd = pHint->GetEnd() ) )
 /*N*/ 				{
-/*?*/ 					DBG_BF_ASSERT(0, "STRIP"); //STRIP001 SwComparePosition eCmp = ::ComparePosition(
+/*?*/ 					DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 				}
 /*N*/ 		}
 /*N*/ 		break;
@@ -1508,7 +1458,7 @@ using namespace ::com::sun::star::i18n;
 /*N*/
 /*N*/ 	case RES_TXTATR_CJK_RUBY:
 /*N*/ 		{
-                DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/ 			((SwTxtRuby*)pHint)->ChgTxtNode( &rNode );
+                DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 		}
 /*N*/ 		break;
 /*N*/ 	}
@@ -1547,7 +1497,7 @@ using namespace ::com::sun::star::i18n;
 /*N*/
 /*N*/ 	if( *pHtEnd < nHtStart )
 /*N*/ 	{
-/*?*/ 		ASSERT( *pHtEnd >= nHtStart,
+/*?*/ 		OSL_ENSURE( *pHtEnd >= nHtStart,
 /*?*/ 					"+SwpHints::Insert: invalid hint, end < start" );
 /*?*/
 /*?*/ 		// Wir drehen den Quatsch einfach um:
@@ -1615,7 +1565,7 @@ using namespace ::com::sun::star::i18n;
 /*N*/ 						{
 /*?*/ 							if( !bOtherFmt )
 /*?*/ 							{
-                                    DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/ 								bOtherFmt = !lcl_Included( pOther->Which(),
+                                    DBG_BF_ASSERT(0, "STRIP");
 /*?*/ 							}
 /*?*/ 							if( bOtherFmt )
 /*?*/ 								nHtEnd = *pOther->GetStart();
@@ -1895,7 +1845,7 @@ using namespace ::com::sun::star::i18n;
 /*N*/ {
 /*N*/ 	// Attr 2.0: SwpHintsArr::Delete( pTxtHt );
 /*N*/ 	const USHORT nPos = GetStartOf( pTxtHt );
-/*N*/ 	ASSERT( USHRT_MAX != nPos, "Attribut nicht im Attribut-Array!" );
+/*N*/ 	OSL_ENSURE( USHRT_MAX != nPos, "Attribut nicht im Attribut-Array!" );
 /*N*/ 	if( USHRT_MAX != nPos )
 /*N*/ 		DeleteAtPos( nPos );
 /*N*/ }
