@@ -35,7 +35,7 @@
 #include <vcl/svapp.hxx>
 #include <rtl/uuid.h>
 
-#include <errhdl.hxx>
+#include <osl/diagnose.h>
 
 #include <unoobj.hxx>
 #include <unomap.hxx>
@@ -64,17 +64,13 @@ using rtl::OUString;
 /******************************************************************
  *
  ******************************************************************/
-/* -----------------------------13.03.00 12:15--------------------------------
 
- ---------------------------------------------------------------------------*/
 const uno::Sequence< sal_Int8 > & SwXFootnote::getUnoTunnelId()
 {
     static uno::Sequence< sal_Int8 > aSeq = ::binfilter::CreateUnoTunnelId();
     return aSeq;
 }
-/* -----------------------------10.03.00 18:04--------------------------------
 
- ---------------------------------------------------------------------------*/
 sal_Int64 SAL_CALL SwXFootnote::getSomething( const uno::Sequence< sal_Int8 >& rId )
     throw(uno::RuntimeException)
 {
@@ -86,16 +82,12 @@ sal_Int64 SAL_CALL SwXFootnote::getSomething( const uno::Sequence< sal_Int8 >& r
     }
     return SwXText::getSomething( rId );
 }
-/* -----------------------------06.04.00 16:36--------------------------------
 
- ---------------------------------------------------------------------------*/
 OUString SwXFootnote::getImplementationName(void) throw( RuntimeException )
 {
     return C2U("SwXFootnote");
 }
-/* -----------------------------06.04.00 16:36--------------------------------
 
- ---------------------------------------------------------------------------*/
 BOOL SwXFootnote::supportsService(const OUString& rServiceName) throw( RuntimeException )
 {
     return  !rServiceName.compareToAscii("com.sun.star.text.Footnote") ||
@@ -104,9 +96,7 @@ BOOL SwXFootnote::supportsService(const OUString& rServiceName) throw( RuntimeEx
             (m_bIsEndnote && !rServiceName.compareToAscii("com.sun.star.text.Endnote"));
 ;
 }
-/* -----------------------------06.04.00 16:36--------------------------------
 
- ---------------------------------------------------------------------------*/
 Sequence< OUString > SwXFootnote::getSupportedServiceNames(void) throw( RuntimeException )
 {
     Sequence< OUString > aRet(m_bIsEndnote ? 4 : 3);
@@ -118,25 +108,21 @@ Sequence< OUString > SwXFootnote::getSupportedServiceNames(void) throw( RuntimeE
         pArray[3] = C2U("com.sun.star.text.Endnote");
     return aRet;
 }
-/*-- 10.12.98 15:31:44---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 TYPEINIT1(SwXFootnote, SwClient);
 
 SwXFootnote::SwXFootnote(sal_Bool bEndnote) :
-    aLstnrCntnr( (text::XTextContent*)this),
     SwXText(0, CURSOR_FOOTNOTE),
+    aLstnrCntnr( (text::XTextContent*)this),
     pFmtFtn(0),
     m_bIsDescriptor(sal_True),
     m_bIsEndnote(bEndnote)
 {
 
 }
-/*-- 10.12.98 15:31:45---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
-SwXFootnote::SwXFootnote(SwDoc* pDoc, const SwFmtFtn& rFmt) :
-    SwXText(pDoc, CURSOR_FOOTNOTE),
+SwXFootnote::SwXFootnote(SwDoc* pInDoc, const SwFmtFtn& rFmt) :
+    SwXText(pInDoc, CURSOR_FOOTNOTE),
     aLstnrCntnr( (text::XTextContent*)this),
     pFmtFtn(&rFmt),
     m_bIsDescriptor(sal_False),
@@ -144,16 +130,12 @@ SwXFootnote::SwXFootnote(SwDoc* pDoc, const SwFmtFtn& rFmt) :
 {
     GetDoc()->GetUnoCallBack()->Add(this);
 }
-/*-- 10.12.98 15:31:45---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwXFootnote::~SwXFootnote()
 {
 
 }
-/* -----------------------------21.03.00 15:39--------------------------------
 
- ---------------------------------------------------------------------------*/
 uno::Sequence< ::com::sun::star::uno::Type > SAL_CALL SwXFootnote::getTypes(  ) throw(uno::RuntimeException)
 {
     uno::Sequence< uno::Type > aFtnTypes = SwXFootnoteBaseClass::getTypes();
@@ -170,9 +152,7 @@ uno::Sequence< ::com::sun::star::uno::Type > SAL_CALL SwXFootnote::getTypes(  )
     return aFtnTypes;
 }
 
-/* -----------------------------21.03.00 15:39--------------------------------
 
- ---------------------------------------------------------------------------*/
 uno::Sequence< sal_Int8 > SAL_CALL SwXFootnote::getImplementationId(  ) throw(uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
@@ -185,9 +165,7 @@ uno::Sequence< sal_Int8 > SAL_CALL SwXFootnote::getImplementationId(  ) throw(un
     }
     return aId;
 }
-/* -----------------------------21.03.00 15:46--------------------------------
 
- ---------------------------------------------------------------------------*/
 uno::Any SAL_CALL SwXFootnote::queryInterface( const uno::Type& aType ) throw(uno::RuntimeException)
 {
     uno::Any aRet = SwXFootnoteBaseClass::queryInterface(aType);
@@ -196,9 +174,7 @@ uno::Any SAL_CALL SwXFootnote::queryInterface( const uno::Type& aType ) throw(un
     return aRet;
 }
 
-/*-- 10.12.98 15:31:47---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 OUString SwXFootnote::getLabel(void) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -212,9 +188,7 @@ OUString SwXFootnote::getLabel(void) throw( uno::RuntimeException )
         throw uno::RuntimeException();
     return sRet;
 }
-/*-- 10.12.98 15:31:48---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXFootnote::setLabel(const OUString& aLabel) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -234,9 +208,7 @@ void SwXFootnote::setLabel(const OUString& aLabel) throw( uno::RuntimeException
         throw uno::RuntimeException();
 
 }
-/* -----------------18.02.99 13:32-------------------
- *
- * --------------------------------------------------*/
+
 void SwXFootnote::attachToRange(const uno::Reference< text::XTextRange > & xTextRange)
             throw( lang::IllegalArgumentException, uno::RuntimeException )
 {
@@ -252,21 +224,21 @@ void SwXFootnote::attachToRange(const uno::Reference< text::XTextRange > & xText
         pCursor = (OTextCursorHelper*)xRangeTunnel->getSomething(
                                 OTextCursorHelper::getUnoTunnelId());
     }
-    SwDoc* pDoc = pRange ? (SwDoc*)pRange->GetDoc() : pCursor ? (SwDoc*)pCursor->GetDoc() : 0;
-    if(pDoc)
+    SwDoc* pLclDoc = pRange ? (SwDoc*)pRange->GetDoc() : pCursor ? (SwDoc*)pCursor->GetDoc() : 0;
+    if(pLclDoc)
     {
-        SwUnoInternalPaM aPam(*pDoc);
+        SwUnoInternalPaM aPam(*pLclDoc);
         //das muss jetzt sal_True liefern
         SwXTextRange::XTextRangeToSwPaM(aPam, xTextRange);
 
-        UnoActionContext aCont(pDoc);
+        UnoActionContext aCont(pLclDoc);
         SwTxtAttr* pTxtAttr = 0;
-        pDoc->DeleteAndJoin(aPam);
+        pLclDoc->DeleteAndJoin(aPam);
         aPam.DeleteMark();
         SwFmtFtn aFootNote(m_bIsEndnote);
         if(m_sLabel.Len())
             aFootNote.SetNumStr(m_sLabel);
-        SfxItemSet  aSet(pDoc->GetAttrPool(), RES_TXTATR_FTN, RES_TXTATR_FTN, 0L);
+        SfxItemSet  aSet(pLclDoc->GetAttrPool(), RES_TXTATR_FTN, RES_TXTATR_FTN, 0L);
         aSet.Put(aFootNote);
         SwXTextCursor::SetCrsrAttr(aPam, aSet, 0);
 
@@ -277,31 +249,27 @@ void SwXFootnote::attachToRange(const uno::Reference< text::XTextRange > & xText
         {
             const SwFmtFtn& rFtn = pTxtAttr->GetFtn();
             pFmtFtn = &rFtn;
-            pDoc->GetUnoCallBack()->Add(this);
+            pLclDoc->GetUnoCallBack()->Add(this);
             //force creation of sequence id - is used for references
-            if(pDoc->IsInReading())
-                ((SwTxtFtn*)pTxtAttr)->SetSeqNo(pDoc->GetFtnIdxs().Count());
+            if(pLclDoc->IsInReading())
+                ((SwTxtFtn*)pTxtAttr)->SetSeqNo(pLclDoc->GetFtnIdxs().Count());
             else
                 ((SwTxtFtn*)pTxtAttr)->SetSeqRefNo();
         }
         m_bIsDescriptor = sal_False;
-        SetDoc(pDoc);
+        SetDoc(pLclDoc);
     }
     else
         throw lang::IllegalArgumentException();
 }
-/*-- 10.12.98 15:31:48---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXFootnote::attach(const uno::Reference< text::XTextRange > & xTextRange)
             throw( lang::IllegalArgumentException, uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
     attachToRange( xTextRange );
 }
-/*-- 10.12.98 15:31:48---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Reference< text::XTextRange >  SwXFootnote::getAnchor(void) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -317,9 +285,7 @@ uno::Reference< text::XTextRange >  SwXFootnote::getAnchor(void) throw( uno::Run
         throw uno::RuntimeException();
     return aRef;
 }
-/*-- 10.12.98 15:31:49---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXFootnote::dispose(void) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -337,26 +303,20 @@ void SwXFootnote::dispose(void) throw( uno::RuntimeException )
         throw uno::RuntimeException();
 
 }
-/*-- 10.12.98 15:31:49---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXFootnote::addEventListener(const uno::Reference< lang::XEventListener > & aListener) throw( uno::RuntimeException )
 {
     if(!GetRegisteredIn())
         throw uno::RuntimeException();
     aLstnrCntnr.AddListener(aListener);
 }
-/*-- 10.12.98 15:31:50---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXFootnote::removeEventListener(const uno::Reference< lang::XEventListener > & aListener) throw( uno::RuntimeException )
 {
     if(!GetRegisteredIn() || !aLstnrCntnr.RemoveListener(aListener))
         throw uno::RuntimeException();
 }
-/* -----------------06.05.99 15:31-------------------
- *
- * --------------------------------------------------*/
+
 const SwStartNode *SwXFootnote::GetStartNode() const
 {
     const SwStartNode *pSttNd = 0;
@@ -374,9 +334,7 @@ uno::Reference< text::XTextCursor >   SwXFootnote::createCursor() throw ( ::com:
 {
     return createTextCursor();
 }
-/*-- 10.12.98 15:31:50---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Reference< text::XTextCursor >  SwXFootnote::createTextCursor(void) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -395,9 +353,7 @@ uno::Reference< text::XTextCursor >  SwXFootnote::createTextCursor(void) throw(
         throw uno::RuntimeException();
     return aRef;
 }
-/*-- 10.12.98 15:31:51---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Reference< text::XTextCursor >  SwXFootnote::createTextCursorByRange(
     const uno::Reference< text::XTextRange > & aTextPosition)
             throw( uno::RuntimeException )
@@ -422,14 +378,11 @@ uno::Reference< text::XTextCursor >  SwXFootnote::createTextCursorByRange(
         throw uno::RuntimeException();
     return aRef;
 }
-/*-- 13.06.00 14:28:23---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 Reference< XEnumeration >  SwXFootnote::createEnumeration() throw( RuntimeException )
 {
     SolarMutexGuard aGuard;
     uno::Reference< container::XEnumeration >  aRef;
-     uno::XInterface* pRet = 0;
     const SwFmtFtn*  pFmt = FindFmt();
     if(pFmt)
     {
@@ -442,23 +395,17 @@ Reference< XEnumeration >  SwXFootnote::createEnumeration() throw( RuntimeExcept
     }
     return aRef;
 }
-/*-- 13.06.00 14:28:24---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 Type SwXFootnote::getElementType(  ) throw(RuntimeException)
 {
     return ::getCppuType((Reference<XTextRange>*)0);
 }
-/*-- 13.06.00 14:28:24---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXFootnote::hasElements(  ) throw(RuntimeException)
 {
     return sal_True;
 }
-/* -----------------------------07.01.00 12:39--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwXFootnote::Invalidate()
 {
     if(GetRegisteredIn())
@@ -469,9 +416,7 @@ void SwXFootnote::Invalidate()
         SetDoc(0);
     }
 }
-/* -----------------18.01.99 09:12-------------------
- *
- * --------------------------------------------------*/
+
 void SwXFootnote::Modify( SfxPoolItem *pOld, SfxPoolItem *pNew)
 {
     switch( pOld ? pOld->Which() : 0 )
@@ -493,9 +438,7 @@ void SwXFootnote::Modify( SfxPoolItem *pOld, SfxPoolItem *pNew)
         break;
     }
 }
-/*-- 11.09.00 13:12:03---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 Reference< XPropertySetInfo > SwXFootnote::getPropertySetInfo(  )
     throw(RuntimeException)
 {
@@ -503,9 +446,7 @@ Reference< XPropertySetInfo > SwXFootnote::getPropertySetInfo(  )
         new SfxItemPropertySetInfo(aSwMapProvider.GetPropertyMap(PROPERTY_MAP_FOOTNOTE));
     return xRef;
 }
-/*-- 11.09.00 13:12:04---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXFootnote::setPropertyValue( const ::rtl::OUString&,
     const Any& )
         throw(UnknownPropertyException, PropertyVetoException,
@@ -514,9 +455,7 @@ void SwXFootnote::setPropertyValue( const ::rtl::OUString&,
     //no values to be set
     throw IllegalArgumentException();
 }
-/*-- 11.09.00 13:12:04---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 Any SwXFootnote::getPropertyValue( const OUString& rPropertyName )
     throw(UnknownPropertyException, WrappedTargetException, RuntimeException)
 {
@@ -550,35 +489,27 @@ Any SwXFootnote::getPropertyValue( const OUString& rPropertyName )
     }
     return aRet;
 }
-/*-- 11.09.00 13:12:04---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
-void SwXFootnote::addPropertyChangeListener( const OUString& aPropertyName,
-    const Reference< XPropertyChangeListener >& xListener )
+void SwXFootnote::addPropertyChangeListener( const OUString& /*aPropertyName*/,
+    const Reference< XPropertyChangeListener >& /*xListener*/ )
         throw(UnknownPropertyException, WrappedTargetException, RuntimeException)
 {
 }
-/*-- 11.09.00 13:12:04---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
-void SwXFootnote::removePropertyChangeListener( const OUString& aPropertyName,
-    const Reference< XPropertyChangeListener >& aListener )
+void SwXFootnote::removePropertyChangeListener( const OUString& /*aPropertyName*/,
+    const Reference< XPropertyChangeListener >& /*aListener*/ )
         throw(UnknownPropertyException, WrappedTargetException, RuntimeException)
 {
 }
-/*-- 11.09.00 13:12:04---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
-void SwXFootnote::addVetoableChangeListener( const OUString& PropertyName,
-    const Reference< XVetoableChangeListener >& aListener )
+void SwXFootnote::addVetoableChangeListener( const OUString& /*PropertyName*/,
+    const Reference< XVetoableChangeListener >& /*aListener*/ )
         throw(UnknownPropertyException, WrappedTargetException, RuntimeException)
 {
 }
-/*-- 11.09.00 13:12:05---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
-void SwXFootnote::removeVetoableChangeListener( const OUString& PropertyName,
-    const Reference< XVetoableChangeListener >& aListener )
+void SwXFootnote::removeVetoableChangeListener( const OUString& /*PropertyName*/,
+    const Reference< XVetoableChangeListener >& /*aListener*/ )
         throw(UnknownPropertyException, WrappedTargetException, RuntimeException)
 {
 }
