@@ -44,7 +44,7 @@
 
 #include <doc.hxx>
 
-#include <errhdl.hxx>
+#include <osl/diagnose.h>
 
 #include <ndtxt.hxx>
 #include <ndnotxt.hxx>
@@ -187,9 +187,7 @@ SwParaSelection::~SwParaSelection()
         pUnoCrsr->MovePara(fnParaCurr, fnParaStart);
     }
 }
-/* -----------------13.05.98 12:15-------------------
- *
- * --------------------------------------------------*/
+
 SwUnoInternalPaM::SwUnoInternalPaM(SwDoc& rDoc) :
     SwPaM(rDoc.GetNodes())
 {
@@ -222,6 +220,7 @@ SwUnoInternalPaM&	SwUnoInternalPaM::operator=(const SwPaM& rPaM)
     }
     return *this;
 }
+
 /****************************************************************************
     ActionContext
 ****************************************************************************/
@@ -232,9 +231,7 @@ UnoActionContext::UnoActionContext(SwDoc* pDc) :
     if(pRootFrm)
         pRootFrm->StartAllAction();
 }
-/*-----------------04.03.98 11:56-------------------
 
---------------------------------------------------*/
 UnoActionContext::~UnoActionContext()
 {
     //das Doc kann hier schon entfernt worden sein
@@ -256,9 +253,7 @@ UnoActionRemoveContext::UnoActionRemoveContext(SwDoc* pDc) :
     if(pRootFrm)
         pRootFrm->UnoRemoveAllActions();
 }
-/* -----------------07.07.98 12:05-------------------
- *
- * --------------------------------------------------*/
+
 UnoActionRemoveContext::~UnoActionRemoveContext()
 {
     SwRootFrm* pRootFrm = pDoc->GetRootFrm();
@@ -267,9 +262,6 @@ UnoActionRemoveContext::~UnoActionRemoveContext()
 
 }
 
-/*-----------------09.03.98 08:29-------------------
-
---------------------------------------------------*/
 void SwXTextCursor::SelectPam(SwPaM& rCrsr, sal_Bool bExpand)
 {
     if(bExpand)
@@ -281,10 +273,8 @@ void SwXTextCursor::SelectPam(SwPaM& rCrsr, sal_Bool bExpand)
         rCrsr.DeleteMark();
 
 }
-/* -----------------20.05.98 14:59-------------------
- *
- * --------------------------------------------------*/
-void SwXTextCursor::getTextFromPam(SwPaM& aCrsr, OUString& rBuffer)
+
+void SwXTextCursor::getTextFromPam(SwPaM& aCrsr, OUString&)
 {
     if(!aCrsr.HasMark())
         return;
@@ -294,46 +284,24 @@ void SwXTextCursor::getTextFromPam(SwPaM& aCrsr, OUString& rBuffer)
 #else
     aStream.SetNumberFormatInt( NUMBERFORMAT_INT_LITTLEENDIAN );
 #endif
-    WriterRef xWrt;
+/* this part is commented out since is not more executable due to the
+   deletion of the Writer class.
+   Investigation needs to be done in order to know if the function can be
+   removed too, or needs to be adapted
+*/
+/*    WriterRef xWrt;
     SwIoSystem::GetWriter( C2S(FILTER_TEXT_DLG), xWrt );
     if( xWrt.Is() )
     {
-        SwWriter aWriter( aStream, aCrsr );
         xWrt->bASCII_NoLastLineEnd = sal_True;
         SwAsciiOptions aOpt = xWrt->GetAsciiOptions();
         aOpt.SetCharSet( RTL_TEXTENCODING_UNICODE );
         xWrt->SetAsciiOptions( aOpt );
         xWrt->bUCS2_WithStartChar = FALSE;
-
-        long lLen;
-        if( !IsError( aWriter.Write( xWrt ) ) &&
-            STRING_MAXLEN > (( lLen  = aStream.GetSize() )
-                                    / sizeof( sal_Unicode )) + 1 )
-        {
-            aStream << (sal_Unicode)'\0';
-
-            String sBuf;
-            const sal_Unicode *p = (sal_Unicode*)aStream.GetBuffer();
-            if( p )
-                sBuf = p;
-            else
-            {
-                long lUniLen = (lLen / sizeof( sal_Unicode ));
-                sal_Unicode* pStrBuf = sBuf.AllocBuffer( xub_StrLen(
-                                lUniLen + 1));
-                aStream.Seek( 0 );
-                aStream.ResetError();
-                aStream.Read( pStrBuf, lLen );
-                pStrBuf[ lUniLen ] = '\0';
-            }
-            rBuffer = OUString( sBuf );
-        }
     }
+*/
 }
 
-/* -----------------06.07.98 07:33-------------------
- *
- * --------------------------------------------------*/
 void lcl_setCharStyle(SwDoc* pDoc, const uno::Any aValue, SfxItemSet& rSet)
      throw (lang::IllegalArgumentException)
 {
@@ -358,9 +326,7 @@ void lcl_setCharStyle(SwDoc* pDoc, const uno::Any aValue, SfxItemSet& rSet)
 
     }
 };
-/* -----------------30.06.98 08:46-------------------
- *
- * --------------------------------------------------*/
+
 void lcl_SetTxtFmtColl(const uno::Any& rAny, SwPaM& rPaM)
     throw (lang::IllegalArgumentException)
 {
@@ -388,9 +354,7 @@ void lcl_SetTxtFmtColl(const uno::Any& rAny, SwPaM& rPaM)
     }
 
 }
-/* -----------------06.07.98 07:38-------------------
- *
- * --------------------------------------------------*/
+
  void lcl_setPageDesc(SwDoc* pDoc, const uno::Any& aValue, SfxItemSet& rSet)
  {
     if(aValue.getValueType() != ::getCppuType((const OUString*)0))
@@ -409,7 +373,7 @@ void lcl_SetTxtFmtColl(const uno::Any& rAny, SwPaM& rPaM)
     SwStyleNameMapper::FillUIName(uDescName, sDescName, GET_POOLID_PAGEDESC, sal_True );
     if(!pNewDesc->GetPageDesc() || pNewDesc->GetPageDesc()->GetName() != sDescName)
     {
-        sal_uInt16 nCount = pDoc->GetPageDescCnt();
+        pDoc->GetPageDescCnt();
         sal_Bool bPut = sal_False;
         if(sDescName.Len())
         {
@@ -434,12 +398,10 @@ void lcl_SetTxtFmtColl(const uno::Any& rAny, SwPaM& rPaM)
     }
     delete pNewDesc;
 }
-/* -----------------30.06.98 10:29-------------------
- *
- * --------------------------------------------------*/
+
 void lcl_SetNodeNumStart( SwPaM& rCrsr, uno::Any aValue )
 {
-    sal_Int16 nTmp;
+    sal_Int16 nTmp(0);
     aValue >>= nTmp;
     sal_uInt16 nStt = (nTmp < 0 ? USHRT_MAX : (sal_uInt16)nTmp);
     SwDoc* pDoc = rCrsr.GetDoc();
@@ -456,9 +418,6 @@ void lcl_SetNodeNumStart( SwPaM& rCrsr, uno::Any aValue )
         pDoc->SetNodeNumStart( *rCrsr.GetPoint(), nStt );
 }
 
-/* -----------------17.09.98 09:44-------------------
- *
- * --------------------------------------------------*/
 class SwTextCursorItemSet_Impl
 {
     SwDoc *pDoc;
@@ -468,7 +427,7 @@ class SwTextCursorItemSet_Impl
 
 public:
     SwTextCursorItemSet_Impl( SwDoc *pD, sal_uInt16 nW ) :
-        pDoc( pD ), nWhich( nW ), pItemSet(0), bGotAttrs( sal_False ) {}
+        pDoc( pD ), pItemSet(0), nWhich( nW ), bGotAttrs( sal_False ) {}
     ~SwTextCursorItemSet_Impl()
         {delete pItemSet;}
 
@@ -541,7 +500,7 @@ sal_Bool lcl_setCrsrPropertyValue(const SfxItemPropertyMap* pMap,
                 {
                     if( FN_UNO_NUM_LEVEL == pMap->nWID)
                     {
-                        sal_Int16 nLevel;
+                        sal_Int16 nLevel(0);
                         aValue >>= nLevel;
                         sal_Int16 nOldLevel = pTxtNd->GetNum()->GetLevel() & ~NO_NUMLEVEL;
                         if(nLevel < MAXLEVEL && nOldLevel != nLevel)
@@ -663,9 +622,6 @@ sal_Bool lcl_setCrsrPropertyValue(const SfxItemPropertyMap* pMap,
 return bRet;
 }
 
-/* -----------------30.06.98 08:39-------------------
- *
- * --------------------------------------------------*/
 SwFmtColl* SwXTextCursor::GetCurTxtFmtColl(SwPaM& rPam, BOOL bConditional)
 {
     static const sal_uInt16 nMaxLookup = 1000;
@@ -714,9 +670,6 @@ SwFmtColl* SwXTextCursor::GetCurTxtFmtColl(SwPaM& rPam, BOOL bConditional)
     return bError ? 0 : pFmt;
 }
 
-/* -----------------26.06.98 16:20-------------------
- * 	Hilfsfunktion fuer PageDesc
- * --------------------------------------------------*/
  SwPageDesc*	GetPageDescByName_Impl(SwDoc& rDoc, const String& rName)
  {
     SwPageDesc* pRet = 0;
@@ -746,6 +699,7 @@ SwFmtColl* SwXTextCursor::GetCurTxtFmtColl(SwPaM& rPam, BOOL bConditional)
 
     return pRet;
  }
+
 /******************************************************************************
  ******************************************************************************
  ******************************************************************************
@@ -755,16 +709,12 @@ SwFmtColl* SwXTextCursor::GetCurTxtFmtColl(SwPaM& rPam, BOOL bConditional)
 /******************************************************************
  * SwXTextCursor
  ******************************************************************/
-/*-- 09.12.98 14:19:19---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 OUString SwXTextCursor::getImplementationName(void) throw( RuntimeException )
 {
     return C2U("SwXTextCursor");
 }
-/*-- 09.12.98 14:19:19---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 BOOL SwXTextCursor::supportsService(const OUString& rServiceName) throw( RuntimeException )
 {
     String sServiceName(rServiceName);
@@ -777,9 +727,7 @@ BOOL SwXTextCursor::supportsService(const OUString& rServiceName) throw( Runtime
         sServiceName.EqualsAscii("com.sun.star.style.ParagraphPropertiesComplex") ||
         sServiceName.EqualsAscii("com.sun.star.text.TextSortable");
 }
-/*-- 09.12.98 14:19:19---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 Sequence< OUString > SwXTextCursor::getSupportedServiceNames(void) throw( RuntimeException )
 {
     Sequence< OUString > aRet(8);
@@ -794,14 +742,12 @@ Sequence< OUString > SwXTextCursor::getSupportedServiceNames(void) throw( Runtim
     pArray[7] = C2U("com.sun.star.text.TextSortable");
     return aRet;
 }
-/*-- 09.12.98 14:19:19---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwXTextCursor::SwXTextCursor(uno::Reference< XText >  xParent, const SwPosition& rPos,
                     CursorType eSet, SwDoc* pDoc, const SwPosition* pMark) :
     aLstnrCntnr(( util::XSortable*)this),
-    xParentText(xParent),
     aPropSet(aSwMapProvider.GetPropertyMap(PROPERTY_MAP_TEXT_CURSOR)),
+    xParentText(xParent),
     pLastSortOptions(0),
     eType(eSet)
 {
@@ -813,14 +759,12 @@ SwXTextCursor::SwXTextCursor(uno::Reference< XText >  xParent, const SwPosition&
     }
     pUnoCrsr->Add(this);
 }
-/* -----------------04.03.99 09:02-------------------
- *
- * --------------------------------------------------*/
+
 SwXTextCursor::SwXTextCursor(uno::Reference< XText >  xParent,
     SwUnoCrsr* pSourceCrsr, CursorType eSet) :
     aLstnrCntnr( (util::XSortable*)this),
-    xParentText(xParent),
     aPropSet(aSwMapProvider.GetPropertyMap(PROPERTY_MAP_TEXT_CURSOR)),
+    xParentText(xParent),
     pLastSortOptions(0),
     eType(eSet)
 {
@@ -833,18 +777,13 @@ SwXTextCursor::SwXTextCursor(uno::Reference< XText >  xParent,
     pUnoCrsr->Add(this);
 }
 
-/*-- 09.12.98 14:19:20---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 SwXTextCursor::~SwXTextCursor()
 {
     SwUnoCrsr* pUnoCrsr = GetCrsr();
     delete pUnoCrsr;
     delete pLastSortOptions;
 }
-/*-- 09.12.98 14:19:18---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXTextCursor::DeleteAndInsert(const String& rText)
 {
     SwUnoCrsr* pUnoCrsr = GetCrsr();
@@ -866,7 +805,7 @@ void SwXTextCursor::DeleteAndInsert(const String& rText)
                 //OPT: GetSystemCharSet
                 if( !pDoc->Insert(*_pStartCrsr, rText) )
                 {
-                    ASSERT( sal_False, "Doc->Insert(Str) failed." )
+                    OSL_FAIL( "Doc->Insert(Str) failed." );
                 }
                 SwXTextCursor::SelectPam(*pUnoCrsr, sal_True);
                 _pStartCrsr->Left(rText.Len(), CRSR_SKIP_CHARS);
@@ -874,17 +813,13 @@ void SwXTextCursor::DeleteAndInsert(const String& rText)
         } while( (_pStartCrsr=(SwCursor*)_pStartCrsr->GetNext()) != pUnoCrsr );
     }
 }
-/* -----------------------------10.03.00 18:02--------------------------------
 
- ---------------------------------------------------------------------------*/
 const uno::Sequence< sal_Int8 > & SwXTextCursor::getUnoTunnelId()
 {
     static uno::Sequence< sal_Int8 > aSeq = ::binfilter::CreateUnoTunnelId();
     return aSeq;
 }
-/* -----------------------------10.03.00 18:04--------------------------------
 
- ---------------------------------------------------------------------------*/
 sal_Int64 SAL_CALL SwXTextCursor::getSomething( const uno::Sequence< sal_Int8 >& rId )
     throw(uno::RuntimeException)
 {
@@ -897,9 +832,6 @@ sal_Int64 SAL_CALL SwXTextCursor::getSomething( const uno::Sequence< sal_Int8 >&
     return OTextCursorHelper::getSomething(rId);
 }
 
-/*-- 09.12.98 14:18:12---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 void SwXTextCursor::collapseToStart(void) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -918,9 +850,7 @@ void SwXTextCursor::collapseToStart(void) throw( uno::RuntimeException )
         throw uno::RuntimeException();
     }
 }
-/*-- 09.12.98 14:18:14---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXTextCursor::collapseToEnd(void) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -939,9 +869,7 @@ void SwXTextCursor::collapseToEnd(void) throw( uno::RuntimeException )
         throw uno::RuntimeException();
     }
 }
-/*-- 09.12.98 14:18:41---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXTextCursor::isCollapsed(void) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -953,9 +881,7 @@ sal_Bool SwXTextCursor::isCollapsed(void) throw( uno::RuntimeException )
     }
     return bRet;
 }
-/*-- 09.12.98 14:18:42---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXTextCursor::goLeft(sal_Int16 nCount, sal_Bool Expand) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -972,9 +898,7 @@ sal_Bool SwXTextCursor::goLeft(sal_Int16 nCount, sal_Bool Expand) throw( uno::Ru
     }
     return bRet;
 }
-/*-- 09.12.98 14:18:42---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXTextCursor::goRight(sal_Int16 nCount, sal_Bool Expand) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -991,9 +915,7 @@ sal_Bool SwXTextCursor::goRight(sal_Int16 nCount, sal_Bool Expand) throw( uno::R
     }
     return bRet;
 }
-/*-- 09.12.98 14:18:43---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXTextCursor::gotoStart(sal_Bool Expand) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1043,9 +965,7 @@ void SwXTextCursor::gotoStart(sal_Bool Expand) throw( uno::RuntimeException )
         throw uno::RuntimeException();
     }
 }
-/*-- 09.12.98 14:18:43---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXTextCursor::gotoEnd(sal_Bool Expand) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1070,9 +990,7 @@ void SwXTextCursor::gotoEnd(sal_Bool Expand) throw( uno::RuntimeException )
         throw uno::RuntimeException();
     }
 }
-/* -----------------05.03.99 07:27-------------------
- *
- * --------------------------------------------------*/
+
 void SwXTextCursor::gotoRange(const uno::Reference< XTextRange > & xRange, sal_Bool bExpand )
                                 throw( uno::RuntimeException )
 {
@@ -1102,8 +1020,7 @@ void SwXTextCursor::gotoRange(const uno::Reference< XTextRange > & xRange, sal_B
         case CURSOR_FOOTNOTE: 	eSearchNodeType = SwFootnoteStartNode; 	break;
         case CURSOR_HEADER:		eSearchNodeType = SwHeaderStartNode;	break;
         case CURSOR_FOOTER:		eSearchNodeType = SwFooterStartNode;	break;
-        //case CURSOR_INVALID:
-        //case CURSOR_BODY:
+        default: break;
     }
     const SwStartNode* pOwnStartNode = pOwnCursor->GetNode()->
                                             FindSttNodeByType(eSearchNodeType);
@@ -1151,9 +1068,9 @@ void SwXTextCursor::gotoRange(const uno::Reference< XTextRange > & xRange, sal_B
         SwPosition* pParamRight;
         if(pCursor)
         {
-            const SwPaM* pTmp = pCursor->GetPaM();
-            pParamLeft = new SwPosition(*pTmp->GetPoint());
-            pParamRight = new SwPosition(pTmp->HasMark() ? *pTmp->GetMark() : *pParamLeft);
+            const SwPaM* pLclTmp = pCursor->GetPaM();
+            pParamLeft = new SwPosition(*pLclTmp->GetPoint());
+            pParamRight = new SwPosition(pLclTmp->HasMark() ? *pLclTmp->GetMark() : *pParamLeft);
         }
         else
         {
@@ -1163,9 +1080,9 @@ void SwXTextCursor::gotoRange(const uno::Reference< XTextRange > & xRange, sal_B
         }
         if(*pParamRight < *pParamLeft)
         {
-            SwPosition* pTmp = pParamLeft;
+            SwPosition* pLclTmp = pParamLeft;
             pParamLeft = pParamRight;
-            pParamRight = pTmp;
+            pParamRight = pLclTmp;
         }
         // jetzt sind vier SwPositions da, zwei davon werden gebraucht, also welche?
         if(aOwnRight < *pParamRight)
@@ -1185,12 +1102,12 @@ void SwXTextCursor::gotoRange(const uno::Reference< XTextRange > & xRange, sal_B
         //der Cursor soll dem uebergebenen Range entsprechen
         if(pCursor)
         {
-            const SwPaM* pTmp = pCursor->GetPaM();
-            *pOwnCursor->GetPoint() = *pTmp->GetPoint();
-            if(pTmp->HasMark())
+            const SwPaM* pLclTmp = pCursor->GetPaM();
+            *pOwnCursor->GetPoint() = *pLclTmp->GetPoint();
+            if(pLclTmp->HasMark())
             {
                 pOwnCursor->SetMark();
-                *pOwnCursor->GetMark() = *pTmp->GetMark();
+                *pOwnCursor->GetMark() = *pLclTmp->GetMark();
             }
             else
                 pOwnCursor->DeleteMark();
@@ -1210,9 +1127,6 @@ void SwXTextCursor::gotoRange(const uno::Reference< XTextRange > & xRange, sal_B
     }
 }
 
-/*-- 09.12.98 14:18:44---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 sal_Bool SwXTextCursor::isStartOfWord(void) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1228,9 +1142,7 @@ sal_Bool SwXTextCursor::isStartOfWord(void) throw( uno::RuntimeException )
     }
     return bRet;
 }
-/*-- 09.12.98 14:18:44---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXTextCursor::isEndOfWord(void) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1246,9 +1158,7 @@ sal_Bool SwXTextCursor::isEndOfWord(void) throw( uno::RuntimeException )
     }
     return bRet;
 }
-/*-- 09.12.98 14:18:44---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXTextCursor::gotoNextWord(sal_Bool Expand) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1276,9 +1186,7 @@ sal_Bool SwXTextCursor::gotoNextWord(sal_Bool Expand) throw( uno::RuntimeExcepti
     }
     return bRet;
 }
-/*-- 09.12.98 14:18:45---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXTextCursor::gotoPreviousWord(sal_Bool Expand) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1304,9 +1212,7 @@ sal_Bool SwXTextCursor::gotoPreviousWord(sal_Bool Expand) throw( uno::RuntimeExc
     }
     return bRet;
 }
-/*-- 09.12.98 14:18:45---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXTextCursor::gotoEndOfWord(sal_Bool Expand) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1326,9 +1232,7 @@ sal_Bool SwXTextCursor::gotoEndOfWord(sal_Bool Expand) throw( uno::RuntimeExcept
     }
     return bRet;
 }
-/*-- 09.12.98 14:18:46---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXTextCursor::gotoStartOfWord(sal_Bool Expand) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1348,9 +1252,7 @@ sal_Bool SwXTextCursor::gotoStartOfWord(sal_Bool Expand) throw( uno::RuntimeExce
     }
     return bRet;
 }
-/*-- 09.12.98 14:18:46---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXTextCursor::isStartOfSentence(void) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1374,9 +1276,7 @@ sal_Bool SwXTextCursor::isStartOfSentence(void) throw( uno::RuntimeException )
         throw uno::RuntimeException();
     return bRet;
 }
-/*-- 09.12.98 14:18:47---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXTextCursor::isEndOfSentence(void) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1400,9 +1300,7 @@ sal_Bool SwXTextCursor::isEndOfSentence(void) throw( uno::RuntimeException )
         throw uno::RuntimeException();
     return bRet;
 }
-/*-- 09.12.98 14:18:47---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXTextCursor::gotoNextSentence(sal_Bool Expand) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1430,9 +1328,7 @@ sal_Bool SwXTextCursor::gotoNextSentence(sal_Bool Expand) throw( uno::RuntimeExc
         throw uno::RuntimeException();
     return bRet;
 }
-/*-- 09.12.98 14:18:47---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXTextCursor::gotoPreviousSentence(sal_Bool Expand) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1457,9 +1353,7 @@ sal_Bool SwXTextCursor::gotoPreviousSentence(sal_Bool Expand) throw( uno::Runtim
         throw uno::RuntimeException();
     return bRet;
 }
-/* -----------------15.10.99 08:24-------------------
 
- --------------------------------------------------*/
 sal_Bool SwXTextCursor::gotoStartOfSentence(sal_Bool Expand) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1479,9 +1373,7 @@ sal_Bool SwXTextCursor::gotoStartOfSentence(sal_Bool Expand) throw( uno::Runtime
         throw uno::RuntimeException();
     return bRet;
 }
-/* -----------------15.10.99 08:24-------------------
 
- --------------------------------------------------*/
 sal_Bool SwXTextCursor::gotoEndOfSentence(sal_Bool Expand) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1504,9 +1396,6 @@ sal_Bool SwXTextCursor::gotoEndOfSentence(sal_Bool Expand) throw( uno::RuntimeEx
     return bRet;
 }
 
-/*-- 09.12.98 14:18:48---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 sal_Bool SwXTextCursor::isStartOfParagraph(void) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1518,9 +1407,7 @@ sal_Bool SwXTextCursor::isStartOfParagraph(void) throw( uno::RuntimeException )
         throw uno::RuntimeException();
     return bRet;
 }
-/*-- 09.12.98 14:18:48---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXTextCursor::isEndOfParagraph(void) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1532,9 +1419,7 @@ sal_Bool SwXTextCursor::isEndOfParagraph(void) throw( uno::RuntimeException )
         throw uno::RuntimeException();
     return bRet;
 }
-/*-- 09.12.98 14:18:49---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXTextCursor::gotoStartOfParagraph(sal_Bool Expand) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1551,9 +1436,7 @@ sal_Bool SwXTextCursor::gotoStartOfParagraph(sal_Bool Expand) throw( uno::Runtim
         throw uno::RuntimeException();
     return bRet;
 }
-/*-- 09.12.98 14:18:49---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXTextCursor::gotoEndOfParagraph(sal_Bool Expand) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1570,9 +1453,7 @@ sal_Bool SwXTextCursor::gotoEndOfParagraph(sal_Bool Expand) throw( uno::RuntimeE
         throw uno::RuntimeException();
     return bRet;
 }
-/*-- 09.12.98 14:18:50---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXTextCursor::gotoNextParagraph(sal_Bool Expand) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1587,9 +1468,7 @@ sal_Bool SwXTextCursor::gotoNextParagraph(sal_Bool Expand) throw( uno::RuntimeEx
         throw uno::RuntimeException();
     return bRet;
 }
-/*-- 09.12.98 14:18:50---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXTextCursor::gotoPreviousParagraph(sal_Bool Expand) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1604,16 +1483,12 @@ sal_Bool SwXTextCursor::gotoPreviousParagraph(sal_Bool Expand) throw( uno::Runti
         throw uno::RuntimeException();
     return bRet;
 }
-/*-- 09.12.98 14:18:50---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Reference< XText >  SwXTextCursor::getText(void) throw( uno::RuntimeException )
 {
     return xParentText;
 }
-/*-- 09.12.98 14:18:50---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Reference< XTextRange >  SwXTextCursor::getStart(void) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1629,9 +1504,7 @@ uno::Reference< XTextRange >  SwXTextCursor::getStart(void) throw( uno::RuntimeE
         throw uno::RuntimeException();
     return xRet;
 }
-/*-- 09.12.98 14:18:51---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Reference< XTextRange >  SwXTextCursor::getEnd(void) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1647,9 +1520,7 @@ uno::Reference< XTextRange >  SwXTextCursor::getEnd(void) throw( uno::RuntimeExc
         throw uno::RuntimeException();
     return xRet;
 }
-/*-- 09.12.98 14:18:51---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 OUString SwXTextCursor::getString(void) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1657,30 +1528,14 @@ OUString SwXTextCursor::getString(void) throw( uno::RuntimeException )
     SwUnoCrsr* pUnoCrsr = ((SwXTextCursor*)this)->GetCrsr();
     if( pUnoCrsr)
     {
-/*		if( pUnoCrsr->GetPoint()->nNode.GetIndex() ==
-            pUnoCrsr->GetMark()->nNode.GetIndex() )
-        {
-            SwTxtNode* pTxtNd = pUnoCrsr->GetNode()->GetTxtNode();
-            if( pTxtNd )
-            {
-                sal_uInt16 nStt = pUnoCrsr->Start()->nContent.GetIndex();
-                aTxt = pTxtNd->GetExpandTxt( nStt,
-                        pUnoCrsr->End()->nContent.GetIndex() - nStt );
-            }
-        }
-        else
-*/		{
             //Text ueber mehrere Absaetze
             SwXTextCursor::getTextFromPam(*pUnoCrsr, aTxt);
-        }
     }
     else
         throw uno::RuntimeException();
     return aTxt;
 }
-/*-- 09.12.98 14:18:52---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXTextCursor::setString(const OUString& aString) throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
@@ -1690,9 +1545,7 @@ void SwXTextCursor::setString(const OUString& aString) throw( uno::RuntimeExcept
 
     DeleteAndInsert(aString);
 }
-/* -----------------------------03.05.00 12:56--------------------------------
 
- ---------------------------------------------------------------------------*/
 Any SwXTextCursor::GetPropertyValue(
     SwPaM& rPaM, const SfxItemPropertySet& rPropSet,
     const OUString& rPropertyName)
@@ -1723,9 +1576,7 @@ Any SwXTextCursor::GetPropertyValue(
 
     return aAny;
 }
-/* -----------------------------03.05.00 12:57--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwXTextCursor::SetPropertyValue(
     SwPaM& rPaM, const SfxItemPropertySet& rPropSet, const OUString& rPropertyName,
     const Any& aValue, const SfxItemPropertyMap* _pMap, USHORT nAttrMode)
@@ -1750,9 +1601,7 @@ void SwXTextCursor::SetPropertyValue(
     else
         throw UnknownPropertyException(OUString ( RTL_CONSTASCII_USTRINGPARAM ( "Unknown property: " ) ) + rPropertyName, static_cast < cppu::OWeakObject * > ( 0 ) );
 }
-/* -----------------------------03.05.00 13:16--------------------------------
 
- ---------------------------------------------------------------------------*/
 Sequence< PropertyState > SwXTextCursor::GetPropertyStates(
             SwPaM& rPaM, SfxItemPropertySet& rPropSet,
             const Sequence< OUString >& PropertyNames,
@@ -1844,9 +1693,7 @@ Sequence< PropertyState > SwXTextCursor::GetPropertyStates(
     delete pSetParent;
     return aRet;
 }
-/* -----------------------------03.05.00 13:17--------------------------------
 
- ---------------------------------------------------------------------------*/
 PropertyState SwXTextCursor::GetPropertyState(
     SwPaM& rPaM, SfxItemPropertySet& rPropSet, const OUString& rPropertyName)
                         throw(UnknownPropertyException, RuntimeException)
@@ -1856,9 +1703,7 @@ PropertyState SwXTextCursor::GetPropertyState(
     Sequence < PropertyState > aSeq = GetPropertyStates( rPaM, rPropSet, aStrings, SW_PROPERTY_STATE_CALLER_SINGLE_VALUE_ONLY );
     return aSeq[0];
 }
-/* -----------------------------03.05.00 13:20--------------------------------
 
- ---------------------------------------------------------------------------*/
 void lcl_SelectParaAndReset ( SwPaM &rPaM, SwDoc* pDoc, const SvUShortsSort* pWhichIds = 0 )
 {
     // if we are reseting paragraph attributes, we need to select the full paragraph first
@@ -1902,9 +1747,7 @@ void SwXTextCursor::SetPropertyToDefault(
     else
         throw UnknownPropertyException(OUString ( RTL_CONSTASCII_USTRINGPARAM ( "Unknown property: " ) ) + rPropertyName, static_cast < cppu::OWeakObject * > ( 0 ) );
 }
-/* -----------------------------03.05.00 13:19--------------------------------
 
- ---------------------------------------------------------------------------*/
 Any SwXTextCursor::GetPropertyDefault(
     SwPaM& rPaM, const SfxItemPropertySet& rPropSet,
     const OUString& rPropertyName)
@@ -1926,9 +1769,7 @@ Any SwXTextCursor::GetPropertyDefault(
         throw UnknownPropertyException(OUString ( RTL_CONSTASCII_USTRINGPARAM ( "Unknown property: " ) ) + rPropertyName, static_cast < cppu::OWeakObject * > ( 0 ) );
     return aRet;
 }
-/*-- 09.12.98 14:18:54---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Reference< beans::XPropertySetInfo >  SwXTextCursor::getPropertySetInfo(void) throw( uno::RuntimeException )
 {
     static uno::Reference< beans::XPropertySetInfo >  xRef;
@@ -1938,7 +1779,7 @@ uno::Reference< beans::XPropertySetInfo >  SwXTextCursor::getPropertySetInfo(voi
         {
             { SW_PROP_NAME(UNO_NAME_IS_SKIP_HIDDEN_TEXT), FN_SKIP_HIDDEN_TEXT, &::getBooleanCppuType(), PROPERTY_NONE,     0},
             { SW_PROP_NAME(UNO_NAME_IS_SKIP_PROTECTED_TEXT), FN_SKIP_PROTECTED_TEXT, &::getBooleanCppuType(), PROPERTY_NONE,     0},
-            {0,0,0,0}
+            {0,0,0,0,0,0}
         };
         uno::Reference< beans::XPropertySetInfo >  xInfo = aPropSet.getPropertySetInfo();
         // PropertySetInfo verlaengern!
@@ -1949,9 +1790,7 @@ uno::Reference< beans::XPropertySetInfo >  SwXTextCursor::getPropertySetInfo(voi
     }
     return xRef;
 }
-/*-- 09.12.98 14:18:54---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXTextCursor::setPropertyValue(const OUString& rPropertyName, const uno::Any& aValue)
         throw( beans::UnknownPropertyException, beans::PropertyVetoException,
              lang::IllegalArgumentException, lang::WrappedTargetException, uno::RuntimeException)
@@ -1978,9 +1817,7 @@ void SwXTextCursor::setPropertyValue(const OUString& rPropertyName, const uno::A
         throw uno::RuntimeException();
 
 }
-/*-- 09.12.98 14:18:55---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 Any SwXTextCursor::getPropertyValue(const OUString& rPropertyName)
     throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
@@ -2007,37 +1844,35 @@ Any SwXTextCursor::getPropertyValue(const OUString& rPropertyName)
     return aAny;
 
 }
-/*-- 09.12.98 14:18:55---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
-void SwXTextCursor::addPropertyChangeListener(const OUString& PropertyName, const uno::Reference< beans::XPropertyChangeListener > & aListener) throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
+void SwXTextCursor::addPropertyChangeListener(
+        const OUString& /*PropertyName*/, const uno::Reference< beans::XPropertyChangeListener > & /*aListener*/) 
+    throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
     DBG_WARNING("not implemented");
 }
-/*-- 09.12.98 14:18:57---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
-void SwXTextCursor::removePropertyChangeListener(const OUString& PropertyName, const uno::Reference< beans::XPropertyChangeListener > & aListener) throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
+void SwXTextCursor::removePropertyChangeListener(
+        const OUString& /*PropertyName*/, const uno::Reference< beans::XPropertyChangeListener > & /*aListener*/) 
+    throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
     DBG_WARNING("not implemented");
 }
-/*-- 09.12.98 14:18:57---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
-void SwXTextCursor::addVetoableChangeListener(const OUString& PropertyName, const uno::Reference< beans::XVetoableChangeListener > & aListener) throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
+void SwXTextCursor::addVetoableChangeListener(
+        const OUString& /*PropertyName*/, const uno::Reference< beans::XVetoableChangeListener > & /*aListener*/) 
+    throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
     DBG_WARNING("not implemented");
 }
-/*-- 09.12.98 14:18:58---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
-void SwXTextCursor::removeVetoableChangeListener(const OUString& PropertyName, const uno::Reference< beans::XVetoableChangeListener > & aListener) throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
+void SwXTextCursor::removeVetoableChangeListener(
+        const OUString& /*PropertyName*/, const uno::Reference< beans::XVetoableChangeListener > & /*aListener*/) 
+    throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
     DBG_WARNING("not implemented");
 }
-/*-- 05.03.99 11:36:11---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 beans::PropertyState SwXTextCursor::getPropertyState(const OUString& rPropertyName)
                         throw( beans::UnknownPropertyException, uno::RuntimeException )
 {
@@ -2052,9 +1887,7 @@ beans::PropertyState SwXTextCursor::getPropertyState(const OUString& rPropertyNa
         throw RuntimeException();
     return eRet;
 }
-/*-- 05.03.99 11:36:11---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Sequence< beans::PropertyState > SwXTextCursor::getPropertyStates(
             const uno::Sequence< OUString >& PropertyNames)
             throw( beans::UnknownPropertyException, uno::RuntimeException )
@@ -2065,18 +1898,14 @@ uno::Sequence< beans::PropertyState > SwXTextCursor::getPropertyStates(
         throw RuntimeException();
     return GetPropertyStates(*pUnoCrsr, aPropSet, PropertyNames);
 }
-/*-- 05.03.99 11:36:12---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXTextCursor::setPropertyToDefault(const OUString& rPropertyName)
     throw( beans::UnknownPropertyException, uno::RuntimeException )
 {
     Sequence < OUString > aSequence ( &rPropertyName, 1 );
     setPropertiesToDefault ( aSequence );
 }
-/*-- 05.03.99 11:36:12---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Any SwXTextCursor::getPropertyDefault(const OUString& rPropertyName)
     throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
