@@ -82,7 +82,9 @@ SV_DECL_PTRARR_SORT( W4WStyleIdTab, W4WStyleIdTabEntryPtr, 0, 1 )
 
 W4WStyleIdTabEntry::W4WStyleIdTabEntry(	SwW4WParser& rParser, USHORT nId,
                                         const sal_Unicode* pName )
-    :  nStyleId( nId ), pColl( 0 ), bSetAttributes( TRUE )
+    : pColl( 0 )
+    , nStyleId( nId )
+    , bSetAttributes( TRUE )
 {
     String aName( pName );
 
@@ -164,7 +166,6 @@ void SwW4WParser::Read_StyleBasedOn()			// (SBO)
     if ( !bStyleDef ) return;
 
     if(   !GetNextName() || nError
-//	if( W4WR_TXTERM != GetNextRecord() || nError
         || W4WR_TXTERM != GetDecimal( nStyNo ) ) return;
 
     TranslateDefaultStyle ( nStyNo, nDocType );
@@ -187,7 +188,7 @@ void SwW4WParser::Read_StyleBasedOn()			// (SBO)
             pColl = (*pStyleTab)[ nPos ]->pColl;
     }
     SwTxtFmtColl* pAktColl = GetAktColl();
-    ASSERT( pAktColl, "StyleId ungueltig" );
+    OSL_ENSURE( pAktColl, "StyleId ungueltig" );
 
     // nicht gefunden -> in Liste aufnehmen
     if( pColl == 0 )
@@ -201,9 +202,6 @@ void SwW4WParser::Read_StyleBasedOn()			// (SBO)
         // Abhaengigkeit merken
         pNewStyle->pColl = pAktColl;
         pStyleBaseTab->Insert( pNewStyle );
-//		const W4WStyleIdTabEntry* &rpNewStyle = pNewStyle;
-//		pStyleBaseTab->Insert( rpNewStyle );
-
     }
     else
     {
@@ -235,8 +233,6 @@ void SwW4WParser::Read_StyleTable()		// (SYT)
         W4WStyleIdTabEntry( *this, nAktStyleId, aCharBuffer );
 
     pStyleTab->Insert( pNewStyle );
-//	const W4WStyleIdTabEntry* &rpNewStyle = pNewStyle;
-//	pStyleTab->Insert( rpNewStyle );
 
 //	NOTE3( "[Style Def: %s, Id: %ld]", aCharBuffer, nAktStyleId );
 
@@ -244,13 +240,11 @@ void SwW4WParser::Read_StyleTable()		// (SYT)
     // ignoriere dabei alle Records nach (SEP)
     BYTE c;
     while( !nError )
-//	while( !nError && !pInput->get(c).eof() && W4WR_RED != c )
     {
         c = ReadChar();
         if ( rInp.IsEof() || W4WR_RED == c )
             break;
         rInp.SeekRel( - 1 );
-//		pInput->putback(c);
         if (EOF==GetNextRecord())
             break;
     }
@@ -264,9 +258,6 @@ void SwW4WParser::Read_StyleTable()		// (SYT)
     bTxtInDoc = bOldTxtInDoc;
 
     SwTxtFmtColl* pAktColl = GetAktColl();
-//	if ( 0 == nAktStyleId )		// 0 : Dieser Style ist der Default
-//		pDoc->SetTxtFmtColl( *pCurPaM, pAktColl, FALSE );//!!!???
-
     if ( pStyleBaseTab ){		// Es sind noch Verbindungen herzustellen
         W4WStyleIdTabEntry aEntry( nAktStyleId );
         W4WStyleIdTabEntry* pTmp =  &aEntry;
@@ -280,12 +271,6 @@ void SwW4WParser::Read_StyleTable()		// (SYT)
             pStyleBaseTab->DeleteAndDestroy( nPos );
         }
     }
-//	if( 0 == pNewStyle->pColl->DerivedFrom() )
-//	{
-        // falls kein SBO kam,
-        // wird der neue Style vom Default abgeleitet
-//		pNewStyle->pColl->SetDerivedFrom( 0 );
-//	}
     nAktStyleId = 0;		// Starte normalen Text mit Default-Style
 }
 
@@ -355,46 +340,6 @@ void SwW4WParser::StyleAnfang()
     // anscheinend nur bei WP richtig quotet. Bei WW stimmt's bei OS/2 nicht,
     // bei AMI stimmt's nie
 
-//JP 11.05.00: UNICODE-CHANGE  - stimmt das noch so ??
-#if 0
-    if ( nDocType == 44 || nDocType == 33 )    // Hier stimmen die Umlaute nicht
-    {
-        rtl_TextEncoding eCS = RTL_TEXTENCODING_IBM_437;  // Wandle Umlaute in ALay - Namen
-        if ( nDocType == 44 )
-            eCS = RTL_TEXTENCODING_MS_1252;  					// WinWord hat Ansi-Charset
-        register BYTE ch, ch2;
-        for ( USHORT i=0; i<nChrCnt; i++ )
-        {
-            ch = aCharBuffer[i];
-            if ( ch < 32 || ch > 127 )
-            {
-                ch2 = String::Convert( ch, eCS, eSysCharSet );
-                aCharBuffer[i] = ( ch2 == 0 ) ? ch : ch2;
-            }
-            else if ( nDocType == 33 && ch == '<'          // AMI-Pro-Umlaute
-                    && aCharBuffer[i+1] == '\\' )
-            {
-                ch = aCharBuffer[i+2];
-                switch ( ch )
-                {
-                case 'd':  ch = 0x84; break;
-                case 'v':  ch = 0x94; break;
-                case '|':  ch = 0x81; break;
-                case '_':  ch = 0xe1; break;
-                case 'D':  ch = 0x8e; break;
-                case 'V':  ch = 0x99; break;
-                case '\\': ch = 0x9a; break;
-                default:   ch = 'X' ; break;
-                }
-                ch2 = String::Convert( ch, eCS, eSysCharSet ); // Umlaut in's System
-                aCharBuffer[i] = ch2;
-                for ( USHORT j=i+1; j+3<nChrCnt; j++ )      // loesche Klammern
-                    aCharBuffer[j] = aCharBuffer[j+3];
-                nChrCnt -= 3;
-            }
-        }
-    }   // Ende Umpopelungen
-#endif
 }
 
 
@@ -421,18 +366,10 @@ void SwW4WParser::Read_StyleOn()        // (STY)
 
         if( !pStyleTab )
         {
-            ASSERT( !this, "+keine StyleTabelle definiert" );
+            OSL_ENSURE( !this, "+keine StyleTabelle definiert" );
         }
         else
         {
-        //    pCtrlStck->StealAttr( RES_PARATR_TABSTOP, W4WR_NODE, pCurPaM->GetPoint() );
-        //    pCtrlStck->StealAttr( RES_FLTR_STYLESHEET, W4WR_NODE, pCurPaM->GetPoint() );
-        //	  const SwPosition& rPos = *pCurPaM->GetPoint();
-        //    pCtrlStck->SetAttr( rPos, RES_LR_SPACE );
-        //    pCtrlStck->SetAttr( rPos, RES_UL_SPACE );
-        //    pCtrlStck->SetAttr( rPos, RES_CHRATR_FONT );
-        //    pCtrlStck->SetAttr( rPos, RES_CHRATR_FONTSIZE );
-
             SetAttr( SwW4WStyle( nAktStyleId ));
 
             bStyleEndRec = FALSE;
@@ -835,7 +772,6 @@ BOOL SwW4WParser::Read_Analyze_FLO_PDT()// analysieren aller PDTs und ggfs.
                     }
                 }
                  // cleverFrames: vertraute Strukturen zu erkennen
-                const BOOL bOnlyFrames = 0 != (W4WFL_FM_onlyFrames & nIniFMFlags);
                 const BOOL bCleverFrames =
                         (0 == (   (   W4WFL_FM_onlyFrames
                                     | W4WFL_FM_neverFrames )
@@ -1074,8 +1010,6 @@ BOOL SwW4WParser::Read_Analyze_FLO_PDT()// analysieren aller PDTs und ggfs.
                         SwRect& rBodyRect = rBodyInfo.aRect;
                         Point& rUpPos = pHdInfo ? pHdInfo->aRect.Pos()
                                                 : rBodyRect.Pos();
-                        Point& rLoPos = pFtInfo ? pFtInfo->aRect.Pos()
-                                                : rBodyRect.Pos();
 
                         nTop  = (USHORT)rUpPos.Y();
                         nLeft = (USHORT)rUpPos.X();
@@ -1088,7 +1022,6 @@ BOOL SwW4WParser::Read_Analyze_FLO_PDT()// analysieren aller PDTs und ggfs.
                         // Header und Footer definieren
                         SwFrmFmt* pHdFmt = 0;
                         SwFrmFmt* pFtFmt = 0;
-                        W4WRectInfo& rRectInfo = *pRDTInfos->Get( rPDTInfo.nHdRectId );
                         if( pHdInfo )
                         {
                             rFrmFmt.SetAttr( SwFmtHeader( TRUE ));
@@ -1380,8 +1313,6 @@ void SwW4WParser::Read_TextRectangelId()				// TRI
                         SwRect& rBodyRect = rBodyInfo.aRect;
                         Point& rUpPos = pHdInfo ? pHdInfo->aRect.Pos()
                                                 : rBodyRect.Pos();
-                        Point& rLoPos = pFtInfo ? pFtInfo->aRect.Pos()
-                                                : rBodyRect.Pos();
 
                         nTop  = (USHORT)rUpPos.Y();
                         nLeft = (USHORT)rUpPos.X();
@@ -1393,7 +1324,6 @@ void SwW4WParser::Read_TextRectangelId()				// TRI
 
                         SwFrmFmt* pHdFmt = 0;
                         SwFrmFmt* pFtFmt = 0;
-                        W4WRectInfo& rRectInfo = *pRDTInfos->Get( pPDTInfo->nHdRectId );
                         if( pHdInfo )
                         {
                             pHdFmt = (SwFrmFmt*)pPageDesc->GetMaster().GetHeader().GetHeaderFmt();
