@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -58,7 +58,7 @@
 #include <bf_xmloff/ProgressBarHelper.hxx>
 #include <bf_xmloff/xmluconv.hxx>
 
-#include <errhdl.hxx>
+#include <osl/diagnose.h>
 
 #include <pam.hxx>
 
@@ -89,7 +89,7 @@
 // for locking SolarMutex: svapp + mutex
 #include <vcl/svapp.hxx>
 #include <osl/mutex.hxx>
-#include <legacysmgr/legacy_binfilters_smgr.hxx>	//STRIP002 
+#include <legacysmgr/legacy_binfilters_smgr.hxx>
 
 #include <bf_svx/xdef.hxx>
 
@@ -123,7 +123,7 @@ void SwXMLExport::SetCurPaM( SwPaM& rPaM, sal_Bool bWhole, sal_Bool bTabOnly )
         *pCurPaM->GetPoint() = *rPaM.Start();
         *pCurPaM->GetMark() = *rPaM.End();
     }
-    
+
     // Set PaM to table/section start node if whole doc should be exported
     if( bWhole )
     {
@@ -151,7 +151,7 @@ void SwXMLExport::SetCurPaM( SwPaM& rPaM, sal_Bool bWhole, sal_Bool bTabOnly )
 // #110680#
 SwXMLExport::SwXMLExport(
     const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory > xServiceFactory,
-    sal_uInt16 nExportFlags) 
+    sal_uInt16 nExportFlags)
 :	SvXMLExport( xServiceFactory, MAP_INCH, XML_TEXT, nExportFlags ),
 #ifdef XML_CORE_API
     pCurPaM( 0 ),
@@ -174,15 +174,15 @@ SwXMLExport::SwXMLExport(
 
 #ifdef XML_CORE_API
 // #110680#
-SwXMLExport::SwXMLExport( 
+SwXMLExport::SwXMLExport(
     const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory > xServiceFactory,
-    const Reference< XModel >& rModel, 
+    const Reference< XModel >& rModel,
     SwPaM& rPaM,
     const OUString& rFileName,
     const Reference< XDocumentHandler > & rHandler,
     const Reference< XGraphicObjectResolver > & rEmbeddedGrfObjs,
     sal_Bool bExpWholeDoc, sal_Bool bExpFirstTableOnly,
-    sal_Bool bShowProg ) 
+    sal_Bool bShowProg )
 :	SvXMLExport( xServiceFactory, rFileName, rHandler, rModel, rEmbeddedGrfObjs,
                  SW_MOD()->GetMetric( rPaM.GetDoc()->IsHTMLMode() ) ),
     pCurPaM( 0 ),
@@ -214,7 +214,7 @@ sal_uInt32 SwXMLExport::exportDoc( enum XMLTokenEnum eClass )
     Reference < XTextDocument > xTextDoc( GetModel(), UNO_QUERY );
     Reference < XText > xText = xTextDoc->getText();
     Reference<XUnoTunnel> xTextTunnel( xText, UNO_QUERY);
-    ASSERT( xTextTunnel.is(), "missing XUnoTunnel for Cursor" );
+    OSL_ENSURE( xTextTunnel.is(), "missing XUnoTunnel for Cursor" );
     if( !xTextTunnel.is() )
         return ERR_SWG_WRITE_ERROR;
 
@@ -223,13 +223,13 @@ sal_uInt32 SwXMLExport::exportDoc( enum XMLTokenEnum eClass )
 
     SwXText *pText = (SwXText *)xTextTunnel->getSomething(
                                         SwXText::getUnoTunnelId() );
-    ASSERT( pText, "SwXText missing" );
+    OSL_ENSURE( pText, "SwXText missing" );
     if( !pText )
         return ERR_SWG_WRITE_ERROR;
 
     SwDoc *pDoc = pText->GetDoc();
 
-    sal_Bool bExtended = sal_False;
+    sal_Bool bLclExtended = sal_False;
     if( (getExportFlags() & (EXPORT_FONTDECLS|EXPORT_STYLES|
                              EXPORT_MASTERSTYLES|EXPORT_CONTENT)) != 0 )
     {
@@ -252,9 +252,9 @@ sal_uInt32 SwXMLExport::exportDoc( enum XMLTokenEnum eClass )
             {
                 if( 0 != (pItem = rPool.GetItem( nWhichId , i ) ) )
                 {
-                    const SvXMLAttrContainerItem *pUnknown = 
+                    const SvXMLAttrContainerItem *pUnknown =
                                 PTR_CAST( SvXMLAttrContainerItem, pItem );
-                    ASSERT( pUnknown, "illegal attribute container item" );
+                    OSL_ENSURE( pUnknown, "illegal attribute container item" );
                     if( pUnknown && (pUnknown->GetAttrCount() > 0) )
                     {
                         sal_uInt16 nIdx = pUnknown->GetFirstNamespaceIndex();
@@ -267,7 +267,7 @@ sal_uInt32 SwXMLExport::exportDoc( enum XMLTokenEnum eClass )
                                                 XML_NAMESPACE_UNKNOWN );
                             nIdx = pUnknown->GetNextNamespaceIndex( nIdx );
                         }
-                        bExtended = sal_True;
+                        bLclExtended = sal_True;
                     }
                 }
             }
@@ -282,7 +282,7 @@ sal_uInt32 SwXMLExport::exportDoc( enum XMLTokenEnum eClass )
         pTwipUnitConv->setXMLMeasureUnit( eUnit );
     }
 
-    SetExtended( bExtended );
+    SetExtended( bLclExtended );
 
     SwDocStat aDocStat( pDoc->GetDocStat() );
     if( (getExportFlags() & EXPORT_META) != 0 )
@@ -315,9 +315,9 @@ sal_uInt32 SwXMLExport::exportDoc( enum XMLTokenEnum eClass )
             if( aDocStat.bModified )
                 pDoc->UpdateDocStat( aDocStat );
 
-            // count each item once, and then multiply by two to reach the 
+            // count each item once, and then multiply by two to reach the
             // figures given above
-            // The styles in pDoc also count the default style that never 
+            // The styles in pDoc also count the default style that never
             // gets exported -> subtract one.
             sal_Int32 nRef = 1;
             nRef += pDoc->GetCharFmts()->Count() - 1;
@@ -356,8 +356,8 @@ sal_uInt32 SwXMLExport::exportDoc( enum XMLTokenEnum eClass )
     if( !GetGraphicResolver().is() )
     {
         pGraphicResolver = SvXMLGraphicHelper::Create( GRAPHICHELPER_MODE_WRITE );
-        Reference< XGraphicObjectResolver > xGraphicResolver( pGraphicResolver );
-        SetGraphicResolver( xGraphicResolver );
+        Reference< XGraphicObjectResolver > xLclGraphicResolver( pGraphicResolver );
+        SetGraphicResolver( xLclGraphicResolver );
     }
 
     SvXMLEmbeddedObjectHelper *pEmbeddedResolver = 0;
@@ -369,14 +369,14 @@ sal_uInt32 SwXMLExport::exportDoc( enum XMLTokenEnum eClass )
             pEmbeddedResolver = SvXMLEmbeddedObjectHelper::Create(
                                             *pPersist,
                                             EMBEDDEDOBJECTHELPER_MODE_WRITE );
-            Reference< XEmbeddedObjectResolver > xEmbeddedResolver( pEmbeddedResolver );
-            SetEmbeddedResolver( xEmbeddedResolver );
+            Reference< XEmbeddedObjectResolver > xLclEmbeddedResolver( pEmbeddedResolver );
+            SetEmbeddedResolver( xLclEmbeddedResolver );
         }
     }
 
     // set redline mode if we export STYLES or CONTENT, unless redline
     // mode is taken care of outside (through info XPropertySet)
-    sal_Bool bSaveRedline = 
+    sal_Bool bSaveRedline =
         ( (getExportFlags() & (EXPORT_CONTENT|EXPORT_STYLES)) != 0 );
     if( bSaveRedline )
     {
@@ -397,7 +397,7 @@ sal_uInt32 SwXMLExport::exportDoc( enum XMLTokenEnum eClass )
     {
         // now save and switch redline mode
         nRedlineMode = pDoc->GetRedlineMode();
-        pDoc->SetRedlineMode( 
+        pDoc->SetRedlineMode(
             ( nRedlineMode & REDLINE_SHOW_MASK ) | REDLINE_INSERT );
     }
 
@@ -408,14 +408,14 @@ sal_uInt32 SwXMLExport::exportDoc( enum XMLTokenEnum eClass )
     {
         pDoc->SetRedlineMode( nRedlineMode );
     }
-    
+
 
     if( pGraphicResolver )
         SvXMLGraphicHelper::Destroy( pGraphicResolver );
     if( pEmbeddedResolver )
         SvXMLEmbeddedObjectHelper::Destroy( pEmbeddedResolver );
 
-    ASSERT( !pTableLines, "there are table columns infos left" );
+    OSL_ENSURE( !pTableLines, "there are table columns infos left" );
 
     return nRet;
 }
@@ -438,7 +438,7 @@ XMLShapeExport* SwXMLExport::CreateShapeExport()
     return pShapeExport;
 }
 
-__EXPORT SwXMLExport::~SwXMLExport()
+SwXMLExport::~SwXMLExport()
 {
     _FinitItemExport();
 }
@@ -455,7 +455,7 @@ void SwXMLExport::GetViewSettings(Sequence<PropertyValue>& aProps)
 {
     Reference< XMultiServiceFactory > xServiceFactory =
             ::legacy_binfilters::getLegacyProcessServiceFactory();
-    ASSERT( xServiceFactory.is(),
+    OSL_ENSURE( xServiceFactory.is(),
             "XMLReader::Read: got no service manager" );
     if( !xServiceFactory.is() )
         return;
@@ -469,19 +469,6 @@ void SwXMLExport::GetViewSettings(Sequence<PropertyValue>& aProps)
             (OUString( RTL_CONSTASCII_USTRINGPARAM ("com.sun.star.document.IndexedPropertyValues") ) ), UNO_QUERY);
     if (xBox.is() )
     {
-#if 0
-        Any aAny;
-        sal_Int32 i=0;
-        for ( SfxViewFrame *pFrame = SfxViewFrame::GetFirst(); 
-                pFrame;
-                i++, pFrame = SfxViewFrame::GetNext(*pFrame ) )
-        {
-            Sequence < PropertyValue > aSequence;
-            pFrame->GetViewShell()->WriteUserDataSequence( aSequence, sal_False );
-            aAny <<= aSequence;
-            xBox->insertByIndex(i, aAny);
-        }
-#endif
         pValue[nIndex].Name = OUString( RTL_CONSTASCII_USTRINGPARAM ( "Views") );
         pValue[nIndex++].Value <<= Reference < XIndexAccess > ( xBox, UNO_QUERY );
     }
@@ -494,12 +481,12 @@ void SwXMLExport::GetViewSettings(Sequence<PropertyValue>& aProps)
         Reference < XTextDocument > xTextDoc( GetModel(), UNO_QUERY );
         xText = xTextDoc->getText();
         Reference<XUnoTunnel> xTextTunnel( xText, UNO_QUERY);
-        ASSERT( xTextTunnel.is(), "missing XUnoTunnel for Cursor" );
+        OSL_ENSURE( xTextTunnel.is(), "missing XUnoTunnel for Cursor" );
         if( xTextTunnel.is() )
         {
             pText = (SwXText *)xTextTunnel->getSomething(
                                                 SwXText::getUnoTunnelId() );
-            ASSERT( pText, "SwXText missing" );
+            OSL_ENSURE( pText, "SwXText missing" );
         }
     }
 
@@ -514,7 +501,7 @@ void SwXMLExport::GetViewSettings(Sequence<PropertyValue>& aProps)
         pDoc->GetDocShell()->SfxInPlaceObject::GetVisArea();
     sal_Bool bTwip = pDoc->GetDocShell()->SfxInPlaceObject::GetMapUnit ( ) == MAP_TWIP;
 
-    ASSERT( bTwip || ( pDoc->GetDocShell()->SfxInPlaceObject::GetMapUnit() == MAP_100TH_MM ),
+    OSL_ENSURE( bTwip || ( pDoc->GetDocShell()->SfxInPlaceObject::GetMapUnit() == MAP_100TH_MM ),
         "Map unit for visible area is neither in TWIPS nor in 100th mm!" );
 
     pValue[nIndex].Name = OUString( RTL_CONSTASCII_USTRINGPARAM ( "ViewAreaTop") );
@@ -572,7 +559,7 @@ void SwXMLExport::GetConfigurationSettings( Sequence < PropertyValue >& rProps)
         Reference< XPropertySet > xProps( xFac->createInstance( OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.document.Settings" ) ) ), UNO_QUERY );
         if( xProps.is() )
             SvXMLUnitConverter::convertPropertySet( rProps, xProps );
-    }	
+    }
 }
 
 void SwXMLExport::_ExportContent()
@@ -588,7 +575,7 @@ void SwXMLExport::_ExportContent()
             // #103597# prevent export of form controls which are embedded in
             // mute sections
             Reference<XIndexAccess> xIAPage( xPage, UNO_QUERY );
-            GetTextParagraphExport()->PreventExportOfControlsInMuteSections( 
+            GetTextParagraphExport()->PreventExportOfControlsInMuteSections(
                 xIAPage, GetFormExport() );
 
             Reference<XFormsSupplier> xFormSupp(xPage, UNO_QUERY);
@@ -610,7 +597,7 @@ void SwXMLExport::_ExportContent()
         Any aAny = xPropSet->getPropertyValue( sTwoDigitYear );
         aAny <<= (sal_Int16)1930;
 
-        sal_Int16 nYear;
+        sal_Int16 nYear(0);
         aAny >>= nYear;
         if (nYear != 1930 )
         {
@@ -679,10 +666,10 @@ Reference< XInterface > SAL_CALL SwXMLExportStyles_createInstance(
     throw( Exception )
 {
     // #110680#
-    //return (cppu::OWeakObject*)new SwXMLExport( 
-    //	EXPORT_STYLES | EXPORT_MASTERSTYLES | EXPORT_AUTOSTYLES | 
+    //return (cppu::OWeakObject*)new SwXMLExport(
+    //	EXPORT_STYLES | EXPORT_MASTERSTYLES | EXPORT_AUTOSTYLES |
     //	EXPORT_FONTDECLS );
-    return (cppu::OWeakObject*)new SwXMLExport( 
+    return (cppu::OWeakObject*)new SwXMLExport(
         rSMgr,
         EXPORT_STYLES | EXPORT_MASTERSTYLES | EXPORT_AUTOSTYLES | EXPORT_FONTDECLS );
 }
@@ -707,11 +694,11 @@ Reference< XInterface > SAL_CALL SwXMLExportContent_createInstance(
 {
     // #110680#
     //return (cppu::OWeakObject*)new SwXMLExport(
-    //	EXPORT_AUTOSTYLES | EXPORT_CONTENT | EXPORT_SCRIPTS | 
+    //	EXPORT_AUTOSTYLES | EXPORT_CONTENT | EXPORT_SCRIPTS |
     //	EXPORT_FONTDECLS );
     return (cppu::OWeakObject*)new SwXMLExport(
         rSMgr,
-        EXPORT_AUTOSTYLES | EXPORT_CONTENT | EXPORT_SCRIPTS | 
+        EXPORT_AUTOSTYLES | EXPORT_CONTENT | EXPORT_SCRIPTS |
         EXPORT_FONTDECLS );
 }
 
@@ -782,7 +769,7 @@ sal_Int64 SAL_CALL SwXMLExport::getSomething( const Sequence< sal_Int8 >& rId )
 
 // XServiceInfo
 // override empty method from parent class
-OUString SAL_CALL SwXMLExport::getImplementationName() 
+OUString SAL_CALL SwXMLExport::getImplementationName()
     throw(RuntimeException)
 {
     switch( getExportFlags() )
@@ -828,11 +815,11 @@ void SwXMLExport::ExportCurPaM( sal_Bool bExportWholePaM )
                                 pCurPaM->GetMark()->nContent.GetIndex() ) )
     {
         SwNode *pNd = pCurPaM->GetNode();
-        
+
         aNextNumInfo.Set( *pNd );
         ExportListChange( aPrevNumInfo, aNextNumInfo );
 
-        ASSERT( !(pNd->IsGrfNode() || pNd->IsOLENode()),
+        OSL_ENSURE( !(pNd->IsGrfNode() || pNd->IsOLENode()),
                 "SwXMLExport::exportCurPaM: grf or OLE node unexpected" );
         if( pNd->IsTxtNode() )
         {
