@@ -75,7 +75,7 @@ void XMLSettingsExportHelper::CallTypeFunction(const uno::Any& rAny,
              * This assertion pops up when exporting values which are set to:
              * PropertyAttribute::MAYBEVOID, and thus are _supposed_ to have
              * a VOID value...so I'm removing it ...mtg
-             * DBG_ERROR("no type");
+             * OSL_FAIL("no type");
              */
         }
         break;
@@ -86,35 +86,35 @@ void XMLSettingsExportHelper::CallTypeFunction(const uno::Any& rAny,
         break;
         case uno::TypeClass_BYTE:
         {
-            sal_Int8 nInt8;
+            sal_Int8 nInt8(0);
             aAny >>= nInt8;
             exportByte(nInt8, rName);
         }
         break;
         case uno::TypeClass_SHORT:
         {
-            sal_Int16 nInt16;
+            sal_Int16 nInt16(0);
             aAny >>= nInt16;
             exportShort(nInt16, rName);
         }
         break;
         case uno::TypeClass_LONG:
         {
-            sal_Int32 nInt32;
+            sal_Int32 nInt32(0);
             aAny >>= nInt32;
             exportInt(nInt32, rName);
         }
         break;
         case uno::TypeClass_HYPER:
         {
-            sal_Int64 nInt64;
+            sal_Int64 nInt64(0);
             aAny >>= nInt64;
             exportLong(nInt64, rName);
         }
         break;
         case uno::TypeClass_DOUBLE:
         {
-            double fDouble;
+            double fDouble(0.0);
             aAny >>= fDouble;
             exportDouble(fDouble, rName);
         }
@@ -172,7 +172,7 @@ void XMLSettingsExportHelper::CallTypeFunction(const uno::Any& rAny,
                 exportSymbolDescriptors(aProps, rName);
             }
             else
-                DBG_ERROR("this type is not implemented now");
+                OSL_FAIL("this type is not implemented now");
         }
         break;
     }
@@ -500,7 +500,7 @@ void lcl_manipulateSetting(
     if( rName.equalsAsciiL( 
             RTL_CONSTASCII_STRINGPARAM( "PrinterIndependentLayout" ) ) )
     {
-        sal_Int16 nTmp;
+        sal_Int16 nTmp = 0;
         if( rAny >>= nTmp )
         {
             if( nTmp == document::PrinterIndependentLayout::LOW_RESOLUTION )
