@@ -91,7 +91,7 @@ using namespace ::binfilter::xmloff::token;
 using rtl::OUString;
 using rtl::OUStringBuffer;
 
-sal_Char __READONLY_DATA sXML_1_0[] = "1.0";
+sal_Char const sXML_1_0[] = "1.0";
 
 #define LOGFILE_AUTHOR "mb93740"
 
@@ -153,7 +153,7 @@ SvXMLExportEventListener::~SvXMLExportEventListener()
 }
 
 // XEventListener
-void SAL_CALL SvXMLExportEventListener::disposing( const lang::EventObject& rEventObject )
+void SAL_CALL SvXMLExportEventListener::disposing( const lang::EventObject& /*rEventObject*/ )
     throw(uno::RuntimeException)
 {
     if (pExport)
@@ -231,25 +231,25 @@ SvXMLExport::SvXMLExport(
 :	pImpl( 0 ), 
     // #110680#
     mxServiceFactory(xServiceFactory),
-    meClass( eClass ),
-    sWS( GetXMLToken(XML_WS) ),
+    pAttrList( new SvXMLAttributeList ),
     pNamespaceMap( new SvXMLNamespaceMap ),
 
     // #110680#
     // pUnitConv( new SvXMLUnitConverter( MAP_100TH_MM, eDfltUnit ) ),
     pUnitConv( new SvXMLUnitConverter( MAP_100TH_MM, eDfltUnit, getServiceFactory() ) ),
     
-    pAttrList( new SvXMLAttributeList ),
-    bExtended( sal_False ),
     pNumExport(0L),
     pProgressBarHelper( NULL ),
     pEventExport( NULL ),
     pImageMapExport( NULL ),
-    pEventListener( NULL ),
     pXMLErrors( NULL ),
-    bSaveLinkedSections(sal_True),
+    pEventListener( NULL ),
+    bExtended( sal_False ),
+    meClass( eClass ),
     mnExportFlags( nExportFlags ),
-    mnErrorFlags( ERROR_NO )
+    mnErrorFlags( ERROR_NO ),
+    sWS( GetXMLToken(XML_WS) ),
+    bSaveLinkedSections(sal_True)
 {
     DBG_ASSERT( mxServiceFactory.is(), "got no service manager" );
     _InitCtor();
@@ -382,7 +382,7 @@ void SAL_CALL SvXMLExport::setSourceDocument( const uno::Reference< lang::XCompo
                     sal_Int32 nIndex;
                     OUString aURL;
 
-                    for( nIndex = 0; nIndex < nCount; nIndex++, *pPrefix++ )
+                    for( nIndex = 0; nIndex < nCount; nIndex++, pPrefix++ )
                     {
                         if( xNamespaceMap->getByName( *pPrefix ) >>= aURL )
                             _GetNamespaceMap().Add( *pPrefix, aURL, XML_NAMESPACE_UNKNOWN );
@@ -503,8 +503,8 @@ sal_Bool SAL_CALL SvXMLExport::filter( const uno::Sequence< beans::PropertyValue
                   aSeq, e.Message, NULL );
     }
 
-    // return true only if no error occured
-    return (GetErrorFlags() & (ERROR_DO_NOTHING|ERROR_ERROR_OCCURED)) == 0;
+    // return true only if no error occurred
+    return (GetErrorFlags() & (ERROR_DO_NOTHING|ERROR_ERROR_OCCURRED)) == 0;
 }
 
 void SAL_CALL SvXMLExport::cancel() throw(uno::RuntimeException)
@@ -520,7 +520,7 @@ void SAL_CALL SvXMLExport::cancel() throw(uno::RuntimeException)
     return sFilterName;
 }
 
-void SAL_CALL SvXMLExport::setName( const ::rtl::OUString& aName )
+void SAL_CALL SvXMLExport::setName( const ::rtl::OUString& /*aName*/ )
     throw (::com::sun::star::uno::RuntimeException)
 {
     // do nothing, because it is not possible to set the FilterName
@@ -549,7 +549,6 @@ uno::Sequence< OUString > SAL_CALL SvXMLExport::getSupportedServiceNames(  )
     throw(uno::RuntimeException)
 {
     uno::Sequence<OUString> aSeq(2);
-    OUString* pSeq = aSeq.getArray();
     aSeq[0] = OUString(
         RTL_CONSTASCII_USTRINGPARAM("com.sun.star.document.ExportFilter"));
     aSeq[1] = OUString(
@@ -661,7 +660,7 @@ void SvXMLExport::ImplExportSettings()
     }
 }
 
-void SvXMLExport::ImplExportStyles( sal_Bool bUsed )
+void SvXMLExport::ImplExportStyles( sal_Bool /*bUsed*/ )
 {
     CheckAttrList();
 
@@ -675,54 +674,22 @@ void SvXMLExport::ImplExportStyles( sal_Bool bUsed )
     }
 }
 
-void SvXMLExport::ImplExportAutoStyles( sal_Bool bUsed )
+void SvXMLExport::ImplExportAutoStyles( sal_Bool /*bUsed*/ )
 {
-//	AddAttributeASCII( XML_NAMESPACE_NONE, XML_ID, XML_AUTO_STYLES_ID );
-    {
-        // <style:automatic-styles>
-        SvXMLElementExport aElem( *this, XML_NAMESPACE_OFFICE,
-                                  XML_AUTOMATIC_STYLES, sal_True, sal_True );
+    // <style:automatic-styles>
+    SvXMLElementExport aElem( *this, XML_NAMESPACE_OFFICE, XML_AUTOMATIC_STYLES,
+       sal_True, sal_True );
 
-#if 0
-        AddAttribute( XML_NAMESPACE_XLINK, XML_TYPE, XML_SIMPLE );
-        AddAttribute( XML_NAMESPACE_XLINK, XML_HREF, XML_STYLES_HREF );
-        AddAttribute( XML_NAMESPACE_XLINK, XML_ACTUATE, XML_ONLOAD );
-        AddAttribute( XML_NAMESPACE_XLINK, XML_ROLE,
-                         pNamespaceMap->GetQNameByKey( XML_NAMESPACE_OFFICE,
-                                               GetXMLToken(XML_STYLESHEET)) );
-        {
-            // <style:use-styles>
-            SvXMLElementExport aElem( *this, XML_NAMESPACE_OFFICE,
-                                      XML_USE_STYLES, sal_True, sal_True );
-        }
-#endif
-        _ExportAutoStyles();
-    }
+    _ExportAutoStyles();
 }
 
-void SvXMLExport::ImplExportMasterStyles( sal_Bool bUsed )
+void SvXMLExport::ImplExportMasterStyles( sal_Bool /*bUsed*/ )
 {
-    {
-        // <style:master-styles>
-        SvXMLElementExport aElem( *this, XML_NAMESPACE_OFFICE, XML_MASTER_STYLES,
-                                sal_True, sal_True );
+    // <style:master-styles>
+    SvXMLElementExport aElem( *this, XML_NAMESPACE_OFFICE, XML_MASTER_STYLES,
+                               sal_True, sal_True );
 
-        _ExportMasterStyles();
-    }
-
-#if 0
-    AddAttribute( XML_NAMESPACE_XLINK, XML_TYPE, XML_SIMPLE );
-    AddAttribute( XML_NAMESPACE_XLINK, XML_HREF, XML_AUTO_STYLES_HREF );
-    AddAttribute( XML_NAMESPACE_XLINK, XML_ACTUATE, XML_ONLOAD );
-    AddAttribute( XML_NAMESPACE_XLINK, XML_ROLE,
-                  pNamespaceMap->GetQNameByKey( XML_NAMESPACE_OFFICE,
-                                                GetXMLToken(XML_STYLESHEET) ) );
-    {
-        // <style:use-styles>
-        SvXMLElementExport aElem( *this, XML_NAMESPACE_OFFICE,
-                                  XML_USE_STYLES, sal_True, sal_True );
-    }
-#endif
+    _ExportMasterStyles();
 }
 
 void SvXMLExport::ImplExportContent()
@@ -954,7 +921,7 @@ void SvXMLExport::_ExportScripts()
     {
         ::rtl::OUString aValue( RTL_CONSTASCII_USTRINGPARAM( "Basic" ) );
         AddAttribute( XML_NAMESPACE_SCRIPT, XML_LANGUAGE, aValue );
-        SvXMLElementExport aElem( *this, XML_NAMESPACE_OFFICE, XML_SCRIPT_DATA, sal_True, sal_True );
+        SvXMLElementExport aLclElem( *this, XML_NAMESPACE_OFFICE, XML_SCRIPT_DATA, sal_True, sal_True );
 
         Reference< document::XExporter > xExporter;
         Reference< lang::XMultiServiceFactory > xMSF( getServiceFactory() );
@@ -995,7 +962,7 @@ void SvXMLExport::_ExportFontDecls()
         mxFontAutoStylePool->exportXML();
 }
 
-void SvXMLExport::_ExportStyles( sal_Bool bUsed )
+void SvXMLExport::_ExportStyles( sal_Bool /*bUsed*/ )
 {
     uno::Reference< lang::XMultiServiceFactory > xFact( GetModel(), uno::UNO_QUERY );
     if( xFact.is())
@@ -1223,15 +1190,15 @@ xmloff::OFormLayerXMLExport* SvXMLExport::CreateFormExport()
     return new xmloff::OFormLayerXMLExport(*this);
 }
 
-void SvXMLExport::GetViewSettings(uno::Sequence<beans::PropertyValue>& aProps)
+void SvXMLExport::GetViewSettings(uno::Sequence<beans::PropertyValue>& /*aProps*/)
 {
 }
 
-void SvXMLExport::GetConfigurationSettings(uno::Sequence<beans::PropertyValue>& aProps)
+void SvXMLExport::GetConfigurationSettings(uno::Sequence<beans::PropertyValue>& /*aProps*/)
 {
 }
 
-void SvXMLExport::addDataStyle(const sal_Int32 nNumberFormat, sal_Bool bTimeFormat )
+void SvXMLExport::addDataStyle(const sal_Int32 nNumberFormat, sal_Bool /*bTimeFormat*/ )
 {
     if(pNumExport)
         pNumExport->SetUsed(nNumberFormat);
@@ -1252,7 +1219,7 @@ void SvXMLExport::exportAutoDataStyles()
         mxFormExport->exportAutoControlNumberStyles();
 }
 
-OUString SvXMLExport::getDataStyleName(const sal_Int32 nNumberFormat, sal_Bool bTimeFormat ) const
+OUString SvXMLExport::getDataStyleName(const sal_Int32 nNumberFormat, sal_Bool /*bTimeFormat*/ ) const
 {
     OUString sTemp;
     if(pNumExport)
@@ -1643,9 +1610,9 @@ void SvXMLExport::SetError(
 
     // maintain error flags
     if ( ( nId & XMLERROR_FLAG_ERROR ) != 0 )
-        mnErrorFlags |= ERROR_ERROR_OCCURED;
+        mnErrorFlags |= ERROR_ERROR_OCCURRED;
     if ( ( nId & XMLERROR_FLAG_WARNING ) != 0 )
-        mnErrorFlags |= ERROR_WARNING_OCCURED;
+        mnErrorFlags |= ERROR_WARNING_OCCURRED;
     if ( ( nId & XMLERROR_FLAG_SEVERE ) != 0 )
         mnErrorFlags |= ERROR_DO_NOTHING;
 
