@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -30,35 +30,20 @@
 
 
 #include <com/sun/star/uno/Reference.h>
-
-
-
 #include <com/sun/star/container/XIndexContainer.hpp>
-
-
-
 #include <com/sun/star/document/XEventsSupplier.hpp>
 
-
-
 #include "xmlimp.hxx"
-
-
 #include "xmlnmspe.hxx"
-
 #include "nmspmap.hxx"
-
 #include "xmluconv.hxx"
-
 #include "xexptran.hxx"
-
 #include "xmlerror.hxx"
-
 #include "XMLEventsImportContext.hxx"
-
 #include "XMLStringBufferImportContext.hxx"
 
 #include <tools/debug.hxx>
+
 namespace binfilter {
 
 
@@ -79,7 +64,7 @@ using ::com::sun::star::drawing::PointSequenceSequence;
 using ::com::sun::star::document::XEventsSupplier;
 
 
-enum XMLImageMapToken 
+enum XMLImageMapToken
 {
     XML_TOK_IMAP_URL,
     XML_TOK_IMAP_DESCRIPTION,
@@ -97,11 +82,11 @@ enum XMLImageMapToken
     XML_TOK_IMAP_TARGET
 };
 
-static __FAR_DATA SvXMLTokenMapEntry aImageMapObjectTokenMap[] =
+static SvXMLTokenMapEntry aImageMapObjectTokenMap[] =
 {
-    { XML_NAMESPACE_XLINK,	XML_HREF,			XML_TOK_IMAP_URL 			},
+    { XML_NAMESPACE_XLINK,	XML_HREF,			XML_TOK_IMAP_URL            },
     { XML_NAMESPACE_OFFICE,	XML_NAME,			XML_TOK_IMAP_NAME			},
-    { XML_NAMESPACE_DRAW,	XML_NOHREF, 		XML_TOK_IMAP_NOHREF			},
+    { XML_NAMESPACE_DRAW,	XML_NOHREF,         XML_TOK_IMAP_NOHREF			},
     { XML_NAMESPACE_SVG,	XML_X,				XML_TOK_IMAP_X				},
     { XML_NAMESPACE_SVG,	XML_Y,				XML_TOK_IMAP_Y				},
     { XML_NAMESPACE_SVG,	XML_CX,			    XML_TOK_IMAP_CENTER_X		},
@@ -157,20 +142,20 @@ public:
             ::com::sun::star::container::XIndexContainer> xMap,
         const sal_Char* pServiceName);
 
-    void StartElement( 
+    void StartElement(
         const ::com::sun::star::uno::Reference<
         ::com::sun::star::xml::sax::XAttributeList >& xAttrList );
 
     void EndElement();
 
-    SvXMLImportContext *CreateChildContext( 
+    SvXMLImportContext *CreateChildContext(
         USHORT nPrefix,
         const ::rtl::OUString& rLocalName,
         const ::com::sun::star::uno::Reference<
             ::com::sun::star::xml::sax::XAttributeList> & xAttrList );
 
 protected:
-    
+
     virtual void ProcessAttribute(
         enum XMLImageMapToken eToken,
         const ::rtl::OUString& rValue);
@@ -184,15 +169,12 @@ protected:
 TYPEINIT1( XMLImageMapObjectContext, SvXMLImportContext );
 
 XMLImageMapObjectContext::XMLImageMapObjectContext(
-    SvXMLImport& rImport,
-    sal_uInt16 nPrefix,
+    SvXMLImport& rInImport,
+    sal_uInt16 nInPrefix,
     const OUString& rLocalName,
     Reference<XIndexContainer> xMap,
     const sal_Char* pServiceName) :
-        SvXMLImportContext(rImport, nPrefix, rLocalName),
-        xImageMap(xMap),
-        bIsActive(sal_True),
-        bValid(sal_False),
+        SvXMLImportContext(rInImport, nInPrefix, rLocalName),
         sBoundary(RTL_CONSTASCII_USTRINGPARAM("Boundary")),
         sCenter(RTL_CONSTASCII_USTRINGPARAM("Center")),
         sDescription(RTL_CONSTASCII_USTRINGPARAM("Description")),
@@ -202,9 +184,12 @@ XMLImageMapObjectContext::XMLImageMapObjectContext(
         sPolygon(RTL_CONSTASCII_USTRINGPARAM("Polygon")),
         sRadius(RTL_CONSTASCII_USTRINGPARAM("Radius")),
         sTarget(RTL_CONSTASCII_USTRINGPARAM("Target")),
-        sURL(RTL_CONSTASCII_USTRINGPARAM("URL"))
+        sURL(RTL_CONSTASCII_USTRINGPARAM("URL")),
+        xImageMap(xMap),
+        bIsActive(sal_True),
+        bValid(sal_False)
 {
-    DBG_ASSERT(NULL != pServiceName, 
+    DBG_ASSERT(NULL != pServiceName,
                "Please supply the image map object service name");
 
     Reference<XMultiServiceFactory> xFactory(GetImport().GetModel(),UNO_QUERY);
@@ -224,7 +209,7 @@ XMLImageMapObjectContext::XMLImageMapObjectContext(
     // else: can't even get factory -> ignore
 }
 
-void XMLImageMapObjectContext::StartElement( 
+void XMLImageMapObjectContext::StartElement(
     const Reference<XAttributeList >& xAttrList )
 {
     SvXMLTokenMap aMap(aImageMapObjectTokenMap);
@@ -233,13 +218,13 @@ void XMLImageMapObjectContext::StartElement(
     for(sal_Int16 nAttr = 0; nAttr < nLength; nAttr++)
     {
         OUString sLocalName;
-        sal_uInt16 nPrefix = GetImport().GetNamespaceMap().
-            GetKeyByAttrName( xAttrList->getNameByIndex(nAttr), 
+        sal_uInt16 nLclPrefix = GetImport().GetNamespaceMap().
+            GetKeyByAttrName( xAttrList->getNameByIndex(nAttr),
                               &sLocalName );
         OUString sValue = xAttrList->getValueByIndex(nAttr);
 
         ProcessAttribute(
-            (enum XMLImageMapToken)aMap.Get(nPrefix, sLocalName), sValue);
+            (enum XMLImageMapToken)aMap.Get(nLclPrefix, sLocalName), sValue);
     }
 }
 
@@ -260,28 +245,27 @@ void XMLImageMapObjectContext::EndElement()
     // else: not valid -> don't create and insert
 }
 
-SvXMLImportContext* XMLImageMapObjectContext::CreateChildContext( 
-    USHORT nPrefix,
+SvXMLImportContext* XMLImageMapObjectContext::CreateChildContext(
+    USHORT nInPrefix,
     const OUString& rLocalName,
     const Reference<XAttributeList> & xAttrList )
 {
-    if ( (XML_NAMESPACE_OFFICE == nPrefix) &&
+    if ( (XML_NAMESPACE_OFFICE == nInPrefix) &&
          IsXMLToken(rLocalName, XML_EVENTS) )
     {
         Reference<XEventsSupplier> xEvents( xMapEntry, UNO_QUERY );
         return new XMLEventsImportContext(
-            GetImport(), nPrefix, rLocalName, xEvents);
+            GetImport(), nInPrefix, rLocalName, xEvents);
     }
-    else if ( (XML_NAMESPACE_SVG == nPrefix) &&
+    else if ( (XML_NAMESPACE_SVG == nInPrefix) &&
               IsXMLToken(rLocalName, XML_DESC) )
     {
         return new XMLStringBufferImportContext(
-            GetImport(), nPrefix, rLocalName, sDescriptionBuffer);
+            GetImport(), nInPrefix, rLocalName, sDescriptionBuffer);
     }
     else
-        return SvXMLImportContext::CreateChildContext(nPrefix, rLocalName, 
+        return SvXMLImportContext::CreateChildContext(nInPrefix, rLocalName,
                                                       xAttrList);
-
 }
 
 void XMLImageMapObjectContext::ProcessAttribute(
@@ -301,10 +285,12 @@ void XMLImageMapObjectContext::ProcessAttribute(
         case XML_TOK_IMAP_NOHREF:
             bIsActive = ! IsXMLToken(rValue, XML_NOHREF);
             break;
-                
+
         case XML_TOK_IMAP_NAME:
             sNam = rValue;
             break;
+        default:
+            break;
     }
 }
 
@@ -312,10 +298,10 @@ void XMLImageMapObjectContext::Prepare(
     Reference<XPropertySet> & rPropertySet)
 {
     Any aAny;
-    
+
     aAny <<= sUrl;
     rPropertySet->setPropertyValue( sURL, aAny );
-    
+
     aAny <<= sDescriptionBuffer.makeStringAndClear();
     rPropertySet->setPropertyValue( sDescription, aAny );
 
@@ -324,7 +310,7 @@ void XMLImageMapObjectContext::Prepare(
 
     aAny.setValue( &bIsActive, ::getBooleanCppuType() );
     rPropertySet->setPropertyValue( sIsActive, aAny );
-    
+
     aAny <<= sNam;
     rPropertySet->setPropertyValue( sName, aAny );
 }
@@ -367,11 +353,11 @@ protected:
 TYPEINIT1(XMLImageMapRectangleContext, XMLImageMapObjectContext);
 
 XMLImageMapRectangleContext::XMLImageMapRectangleContext(
-    SvXMLImport& rImport,
-    sal_uInt16 nPrefix,
+    SvXMLImport& rInImport,
+    sal_uInt16 nInPrefix,
     const OUString& rLocalName,
     Reference<XIndexContainer> xMap) :
-        XMLImageMapObjectContext(rImport, nPrefix, rLocalName, xMap,
+        XMLImageMapObjectContext(rInImport, nInPrefix, rLocalName, xMap,
                                  "com.sun.star.image.ImageMapRectangleObject"),
         bXOK(sal_False),
         bYOK(sal_False),
@@ -392,7 +378,7 @@ void XMLImageMapRectangleContext::ProcessAttribute(
     switch (eToken)
     {
         case XML_TOK_IMAP_X:
-            if (GetImport().GetMM100UnitConverter().convertMeasure(nTmp, 
+            if (GetImport().GetMM100UnitConverter().convertMeasure(nTmp,
                                                                    rValue))
             {
                 aRectangle.X = nTmp;
@@ -400,7 +386,7 @@ void XMLImageMapRectangleContext::ProcessAttribute(
             }
             break;
         case XML_TOK_IMAP_Y:
-            if (GetImport().GetMM100UnitConverter().convertMeasure(nTmp, 
+            if (GetImport().GetMM100UnitConverter().convertMeasure(nTmp,
                                                                    rValue))
             {
                 aRectangle.Y = nTmp;
@@ -408,7 +394,7 @@ void XMLImageMapRectangleContext::ProcessAttribute(
             }
             break;
         case XML_TOK_IMAP_WIDTH:
-            if (GetImport().GetMM100UnitConverter().convertMeasure(nTmp, 
+            if (GetImport().GetMM100UnitConverter().convertMeasure(nTmp,
                                                                    rValue))
             {
                 aRectangle.Width = nTmp;
@@ -416,7 +402,7 @@ void XMLImageMapRectangleContext::ProcessAttribute(
             }
             break;
         case XML_TOK_IMAP_HEIGTH:
-            if (GetImport().GetMM100UnitConverter().convertMeasure(nTmp, 
+            if (GetImport().GetMM100UnitConverter().convertMeasure(nTmp,
                                                                    rValue))
             {
                 aRectangle.Height = nTmp;
@@ -477,11 +463,11 @@ protected:
 TYPEINIT1(XMLImageMapPolygonContext, XMLImageMapObjectContext);
 
 XMLImageMapPolygonContext::XMLImageMapPolygonContext(
-    SvXMLImport& rImport,
-    sal_uInt16 nPrefix,
+    SvXMLImport& rInImport,
+    sal_uInt16 nInPrefix,
     const OUString& rLocalName,
     Reference<XIndexContainer> xMap) :
-        XMLImageMapObjectContext(rImport, nPrefix, rLocalName, xMap,
+        XMLImageMapObjectContext(rInImport, nInPrefix, rLocalName, xMap,
                                  "com.sun.star.image.ImageMapPolygonObject"),
         bViewBoxOK(sal_False),
         bPointsOK(sal_False)
@@ -518,7 +504,7 @@ void XMLImageMapPolygonContext::Prepare(
     Reference<XPropertySet> & rPropertySet)
 {
     // process view box
-    SdXMLImExViewBox aViewBox(sViewBoxString, 
+    SdXMLImExViewBox aViewBox(sViewBoxString,
                               GetImport().GetMM100UnitConverter());
 
     // get polygon sequence
@@ -576,11 +562,11 @@ protected:
 TYPEINIT1(XMLImageMapCircleContext, XMLImageMapObjectContext);
 
 XMLImageMapCircleContext::XMLImageMapCircleContext(
-    SvXMLImport& rImport,
-    sal_uInt16 nPrefix,
+    SvXMLImport& rInImport,
+    sal_uInt16 nInPrefix,
     const OUString& rLocalName,
     Reference<XIndexContainer> xMap) :
-        XMLImageMapObjectContext(rImport, nPrefix, rLocalName, xMap,
+        XMLImageMapObjectContext(rInImport, nInPrefix, rLocalName, xMap,
                                  "com.sun.star.image.ImageMapCircleObject"),
         bXOK(sal_False),
         bYOK(sal_False),
@@ -600,7 +586,7 @@ void XMLImageMapCircleContext::ProcessAttribute(
     switch (eToken)
     {
         case XML_TOK_IMAP_CENTER_X:
-            if (GetImport().GetMM100UnitConverter().convertMeasure(nTmp, 
+            if (GetImport().GetMM100UnitConverter().convertMeasure(nTmp,
                                                                    rValue))
             {
                 aCenter.X = nTmp;
@@ -608,7 +594,7 @@ void XMLImageMapCircleContext::ProcessAttribute(
             }
             break;
         case XML_TOK_IMAP_CENTER_Y:
-            if (GetImport().GetMM100UnitConverter().convertMeasure(nTmp, 
+            if (GetImport().GetMM100UnitConverter().convertMeasure(nTmp,
                                                                    rValue))
             {
                 aCenter.Y = nTmp;
@@ -616,7 +602,7 @@ void XMLImageMapCircleContext::ProcessAttribute(
             }
             break;
         case XML_TOK_IMAP_RADIUS:
-            if (GetImport().GetMM100UnitConverter().convertMeasure(nTmp, 
+            if (GetImport().GetMM100UnitConverter().convertMeasure(nTmp,
                                                                    rValue))
             {
                 nRadius = nTmp;
@@ -648,21 +634,14 @@ void XMLImageMapCircleContext::Prepare(
 
 
 
-
-
-
-
-
-
-
 TYPEINIT1(XMLImageMapContext, SvXMLImportContext);
 
 XMLImageMapContext::XMLImageMapContext(
-    SvXMLImport& rImport,
-    sal_uInt16 nPrefix,
+    SvXMLImport& rInImport,
+    sal_uInt16 nInPrefix,
     const OUString& rLocalName,
     Reference<XPropertySet> & rPropertySet) :
-        SvXMLImportContext(rImport, nPrefix, rLocalName),
+        SvXMLImportContext(rInImport, nInPrefix, rLocalName),
         sImageMap(RTL_CONSTASCII_USTRINGPARAM("ImageMap")),
         xPropertySet(rPropertySet)
 
@@ -674,7 +653,7 @@ XMLImageMapContext::XMLImageMapContext(
     catch( ::com::sun::star::uno::Exception e )
     {
         uno::Sequence<OUString> aSeq(0);
-        rImport.SetError( XMLERROR_FLAG_WARNING | XMLERROR_API, aSeq, e.Message, NULL );
+        rInImport.SetError( XMLERROR_FLAG_WARNING | XMLERROR_API, aSeq, e.Message, NULL );
     }
 }
 
@@ -682,33 +661,33 @@ XMLImageMapContext::~XMLImageMapContext()
 {
 }
 
-SvXMLImportContext *XMLImageMapContext::CreateChildContext( 
-    USHORT nPrefix,
+SvXMLImportContext *XMLImageMapContext::CreateChildContext(
+    USHORT nInPrefix,
     const OUString& rLocalName,
     const Reference<XAttributeList> & xAttrList )
 {
     SvXMLImportContext* pContext = NULL;
 
-    if ( XML_NAMESPACE_DRAW == nPrefix )
+    if ( XML_NAMESPACE_DRAW == nInPrefix )
     {
         if ( IsXMLToken(rLocalName, XML_AREA_RECTANGLE) )
         {
             pContext = new XMLImageMapRectangleContext(
-                GetImport(), nPrefix, rLocalName, xImageMap);
+                GetImport(), nInPrefix, rLocalName, xImageMap);
         }
         else if ( IsXMLToken(rLocalName, XML_AREA_POLYGON) )
         {
             pContext = new XMLImageMapPolygonContext(
-                GetImport(), nPrefix, rLocalName, xImageMap);
+                GetImport(), nInPrefix, rLocalName, xImageMap);
         }
         else if ( IsXMLToken(rLocalName, XML_AREA_CIRCLE) )
         {
             pContext = new XMLImageMapCircleContext(
-                GetImport(), nPrefix, rLocalName, xImageMap);
+                GetImport(), nInPrefix, rLocalName, xImageMap);
         }
     }
     else
-        pContext = SvXMLImportContext::CreateChildContext(nPrefix, rLocalName, 
+        pContext = SvXMLImportContext::CreateChildContext(nInPrefix, rLocalName,
                                                           xAttrList);
 
     return pContext;
