@@ -128,7 +128,7 @@ SvXMLEnumMapEntry aXML_AnimationSpeed_EnumMap[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-AnimationEffect ImplSdXMLgetEffect( XMLEffect eKind, XMLEffectDirection eDirection, sal_Int16 nStartScale, sal_Bool bIn )
+AnimationEffect ImplSdXMLgetEffect( XMLEffect eKind, XMLEffectDirection eDirection, sal_Int16 nStartScale, sal_Bool /*bIn*/ )
 {
     switch( eKind )
     {
@@ -151,6 +151,7 @@ AnimationEffect ImplSdXMLgetEffect( XMLEffect eKind, XMLEffectDirection eDirecti
         case ED_spiral_inward_right:return AnimationEffect_SPIRALIN_RIGHT;
         case ED_spiral_outward_left:return AnimationEffect_SPIRALOUT_LEFT;
         case ED_spiral_outward_right:return AnimationEffect_SPIRALOUT_RIGHT;
+        default: break;
         }
         return AnimationEffect_FADE_FROM_LEFT;
     case EK_move:
@@ -184,6 +185,7 @@ AnimationEffect ImplSdXMLgetEffect( XMLEffect eKind, XMLEffectDirection eDirecti
             case ED_to_upperright:		return AnimationEffect_MOVE_TO_UPPERRIGHT;
             case ED_to_lowerright:		return AnimationEffect_MOVE_TO_LOWERRIGHT;
             case ED_to_lowerleft:		return AnimationEffect_MOVE_TO_LOWERLEFT;
+            default: break;
             }
             return AnimationEffect_ZOOM_IN;
         }
@@ -201,6 +203,7 @@ AnimationEffect ImplSdXMLgetEffect( XMLEffect eKind, XMLEffectDirection eDirecti
             case ED_from_lowerright:	return AnimationEffect_ZOOM_OUT_FROM_LOWERRIGHT;
             case ED_from_center:		return AnimationEffect_ZOOM_OUT_FROM_CENTER;
             case ED_spiral_inward_left:	return AnimationEffect_ZOOM_OUT_SPIRAL;
+            default: break;
             }
             return AnimationEffect_ZOOM_OUT;
         }
@@ -224,6 +227,7 @@ AnimationEffect ImplSdXMLgetEffect( XMLEffect eKind, XMLEffectDirection eDirecti
             case ED_to_upperright:		return AnimationEffect_MOVE_TO_UPPERRIGHT;
             case ED_to_lowerright:		return AnimationEffect_MOVE_TO_LOWERRIGHT;
             case ED_to_lowerleft:		return AnimationEffect_MOVE_TO_LOWERLEFT;
+            default: break;
             }
         }
         return AnimationEffect_MOVE_FROM_LEFT;
@@ -251,6 +255,7 @@ AnimationEffect ImplSdXMLgetEffect( XMLEffect eKind, XMLEffectDirection eDirecti
         case ED_from_top:			return AnimationEffect_WAVYLINE_FROM_TOP;
         case ED_from_right:			return AnimationEffect_WAVYLINE_FROM_RIGHT;
         case ED_from_bottom:		return AnimationEffect_WAVYLINE_FROM_BOTTOM;
+        default: break;
         }
         return AnimationEffect_WAVYLINE_FROM_LEFT;
     case EK_random:
@@ -271,6 +276,7 @@ AnimationEffect ImplSdXMLgetEffect( XMLEffect eKind, XMLEffectDirection eDirecti
         case ED_from_upperright:	return AnimationEffect_LASER_FROM_UPPERRIGHT;
         case ED_from_lowerleft:		return AnimationEffect_LASER_FROM_LOWERLEFT;
         case ED_from_lowerright:	return AnimationEffect_LASER_FROM_LOWERRIGHT;
+        default: break;
         }
         return AnimationEffect_LASER_FROM_LEFT;
     case EK_appear:
@@ -296,6 +302,7 @@ AnimationEffect ImplSdXMLgetEffect( XMLEffect eKind, XMLEffectDirection eDirecti
         case ED_to_lowerright:		return AnimationEffect_MOVE_SHORT_TO_LOWERRIGHT;
         case ED_to_bottom:			return AnimationEffect_MOVE_SHORT_TO_BOTTOM;
         case ED_to_lowerleft:		return AnimationEffect_MOVE_SHORT_TO_LOWERLEFT;
+        default: break;
         }
         return AnimationEffect_MOVE_SHORT_FROM_LEFT;
     case EK_checkerboard:
@@ -321,8 +328,11 @@ AnimationEffect ImplSdXMLgetEffect( XMLEffect eKind, XMLEffectDirection eDirecti
         case ED_from_lowerright:	return AnimationEffect_STRETCH_FROM_LOWERRIGHT;
         case ED_vertical:			return AnimationEffect_VERTICAL_STRETCH;
         case ED_horizontal:			return AnimationEffect_HORIZONTAL_STRETCH;
+        default: break;
         }
         return AnimationEffect_STRETCH_FROM_LEFT;
+    default:
+        break;
     }
 
     return AnimationEffect_NONE;
@@ -402,7 +412,7 @@ public:
 public:
     TYPEINFO();
 
-    XMLAnimationsEffectContext( SvXMLImport& rImport,
+    XMLAnimationsEffectContext( SvXMLImport& rInImport,
         sal_uInt16 nPrfx,
         const OUString& rLocalName,
         const Reference< XAttributeList >& xAttrList,
@@ -411,7 +421,7 @@ public:
 
     virtual void EndElement();
 
-    virtual SvXMLImportContext * CreateChildContext( USHORT nPrefix, const OUString& rLocalName,
+    virtual SvXMLImportContext * CreateChildContext( USHORT nInPrefix, const OUString& rLocalName,
         const Reference< XAttributeList >& xAttrList );
 };
 
@@ -422,14 +432,14 @@ class XMLAnimationsSoundContext : public SvXMLImportContext
 public:
     TYPEINFO();
 
-    XMLAnimationsSoundContext( SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList, XMLAnimationsEffectContext* pParent );
+    XMLAnimationsSoundContext( SvXMLImport& rInImport, sal_uInt16 nPrfx, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList, XMLAnimationsEffectContext* pParent );
     virtual ~XMLAnimationsSoundContext();
 };
 
 TYPEINIT1( XMLAnimationsSoundContext, SvXMLImportContext );
 
-XMLAnimationsSoundContext::XMLAnimationsSoundContext( SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList, XMLAnimationsEffectContext* pParent )
-: SvXMLImportContext( rImport, nPrfx, rLocalName ), mpParent( pParent )
+XMLAnimationsSoundContext::XMLAnimationsSoundContext( SvXMLImport& rInImport, sal_uInt16 nPrfx, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList, XMLAnimationsEffectContext* pParent )
+: SvXMLImportContext( rInImport, nPrfx, rLocalName ), mpParent( pParent )
 {
     if( mpParent && nPrfx == XML_NAMESPACE_PRESENTATION && IsXMLToken( rLocalName, XML_SOUND ) )
     {
@@ -437,20 +447,20 @@ XMLAnimationsSoundContext::XMLAnimationsSoundContext( SvXMLImport& rImport, sal_
         for(sal_Int16 i=0; i < nAttrCount; i++)
         {
             OUString sAttrName = xAttrList->getNameByIndex( i );
-            OUString aLocalName;
-            sal_uInt16 nPrefix = GetImport().GetNamespaceMap().GetKeyByAttrName( sAttrName, &aLocalName );
+            OUString aLclLocalName;
+            sal_uInt16 nLclPrefix = GetImport().GetNamespaceMap().GetKeyByAttrName( sAttrName, &aLclLocalName );
             OUString sValue = xAttrList->getValueByIndex( i );
 
-            switch( nPrefix )
+            switch( nLclPrefix )
             {
             case XML_NAMESPACE_XLINK:
-                if( IsXMLToken( aLocalName, XML_HREF ) )
+                if( IsXMLToken( aLclLocalName, XML_HREF ) )
                 {
-                    mpParent->maSoundURL = rImport.GetAbsoluteReference(sValue);
+                    mpParent->maSoundURL = rInImport.GetAbsoluteReference(sValue);
                 }
                 break;
             case XML_NAMESPACE_PRESENTATION:
-                if( IsXMLToken( aLocalName, XML_PLAY_FULL ) )
+                if( IsXMLToken( aLclLocalName, XML_PLAY_FULL ) )
                 {
                     mpParent->mbPlayFull = IsXMLToken( sValue, XML_TRUE );
                 }
@@ -466,12 +476,13 @@ XMLAnimationsSoundContext::~XMLAnimationsSoundContext()
 
 TYPEINIT1( XMLAnimationsEffectContext, SvXMLImportContext );
 
-XMLAnimationsEffectContext::XMLAnimationsEffectContext( SvXMLImport& rImport,  sal_uInt16 nPrfx, const OUString& rLocalName,  const Reference< XAttributeList >& xAttrList, AnimImpImpl* pImpl )
-:	SvXMLImportContext(rImport, nPrfx, rLocalName),
+XMLAnimationsEffectContext::XMLAnimationsEffectContext( SvXMLImport& rInImport,  sal_uInt16 nPrfx, const OUString& rLocalName,  const Reference< XAttributeList >& xAttrList, AnimImpImpl* pImpl )
+:	SvXMLImportContext(rInImport, nPrfx, rLocalName),
     mpImpl( pImpl ),
-    meKind( XMLE_SHOW ), mbTextEffect( sal_False ), mnShapeId( -1 ), mnPathShapeId( -1 ),
+    meKind( XMLE_SHOW ), mbTextEffect( sal_False ), mnShapeId( -1 ),
     meEffect( EK_none ), meDirection( ED_none ), mnStartScale( 100 ),
-    meSpeed( AnimationSpeed_MEDIUM ), maDimColor(0), mbPlayFull( sal_False )
+    meSpeed( AnimationSpeed_MEDIUM ), maDimColor(0), mbPlayFull( sal_False ),
+    mnPathShapeId( -1 )
 {
     if( IsXMLToken( rLocalName, XML_SHOW_SHAPE ) )
     {
@@ -510,49 +521,49 @@ XMLAnimationsEffectContext::XMLAnimationsEffectContext( SvXMLImport& rImport,  s
     for(sal_Int16 i=0; i < nAttrCount; i++)
     {
         OUString sAttrName = xAttrList->getNameByIndex( i );
-        OUString aLocalName;
-        sal_uInt16 nPrefix = GetImport().GetNamespaceMap().GetKeyByAttrName( sAttrName, &aLocalName );
+        OUString aLclLocalName;
+        sal_uInt16 nLclPrefix = GetImport().GetNamespaceMap().GetKeyByAttrName( sAttrName, &aLclLocalName );
         OUString sValue = xAttrList->getValueByIndex( i );
 
-        switch( nPrefix )
+        switch( nLclPrefix )
         {
         case XML_NAMESPACE_DRAW:
-            if( IsXMLToken( aLocalName, XML_SHAPE_ID ) )
+            if( IsXMLToken( aLclLocalName, XML_SHAPE_ID ) )
             {
                 SvXMLUnitConverter::convertNumber(mnShapeId, sValue);
             }
-            else if( IsXMLToken( aLocalName, XML_COLOR ) )
+            else if( IsXMLToken( aLclLocalName, XML_COLOR ) )
             {
                 SvXMLUnitConverter::convertColor(maDimColor, sValue);
             }
             break;
 
         case XML_NAMESPACE_PRESENTATION:
-            if( IsXMLToken( aLocalName, XML_EFFECT ) )
+            if( IsXMLToken( aLclLocalName, XML_EFFECT ) )
             {
                 USHORT eEnum;
                 if( SvXMLUnitConverter::convertEnum( eEnum, sValue, aXML_AnimationEffect_EnumMap ) )
                     meEffect = (XMLEffect)eEnum;
             }
-            else if( IsXMLToken(aLocalName, XML_DIRECTION ) )
+            else if( IsXMLToken(aLclLocalName, XML_DIRECTION ) )
             {
                 USHORT eEnum;
                 if( SvXMLUnitConverter::convertEnum( eEnum, sValue, aXML_AnimationDirection_EnumMap ) )
                     meDirection = (XMLEffectDirection)eEnum;
             }
-            else if( IsXMLToken( aLocalName, XML_START_SCALE ) )
+            else if( IsXMLToken( aLclLocalName, XML_START_SCALE ) )
             {
                 sal_Int32 nScale;
                 if( SvXMLUnitConverter::convertPercent( nScale, sValue ) )
                     mnStartScale = (sal_Int16)nScale;
             }
-            else if( IsXMLToken( aLocalName, XML_SPEED ) )
+            else if( IsXMLToken( aLclLocalName, XML_SPEED ) )
             {
                 USHORT eEnum;
                 if( SvXMLUnitConverter::convertEnum( eEnum, sValue, aXML_AnimationSpeed_EnumMap ) )
                     meSpeed = (AnimationSpeed)eEnum;
             }
-            else if( IsXMLToken( aLocalName, XML_PATH_ID ) )
+            else if( IsXMLToken( aLclLocalName, XML_PATH_ID ) )
             {
                 SvXMLUnitConverter::convertNumber(mnPathShapeId, sValue);
             }
@@ -565,9 +576,9 @@ XMLAnimationsEffectContext::~XMLAnimationsEffectContext()
 {
 }
 
-SvXMLImportContext * XMLAnimationsEffectContext::CreateChildContext( USHORT nPrefix, const OUString& rLocalName, const Reference< XAttributeList>& xAttrList )
+SvXMLImportContext * XMLAnimationsEffectContext::CreateChildContext( USHORT nInPrefix, const OUString& rLocalName, const Reference< XAttributeList>& xAttrList )
 {
-    return new XMLAnimationsSoundContext( GetImport(), nPrefix, rLocalName, xAttrList, this );
+    return new XMLAnimationsSoundContext( GetImport(), nInPrefix, rLocalName, xAttrList, this );
 }
 
 void XMLAnimationsEffectContext::EndElement()
@@ -669,7 +680,7 @@ void XMLAnimationsEffectContext::EndElement()
     }
     catch( Exception e )
     {
-        DBG_ERROR( "exception catched while importing animation information!" );
+        OSL_FAIL( "exception catched while importing animation information!" );
     }
 }
 
@@ -677,9 +688,9 @@ void XMLAnimationsEffectContext::EndElement()
 
 TYPEINIT1( XMLAnimationsContext, SvXMLImportContext );
 
-XMLAnimationsContext::XMLAnimationsContext( SvXMLImport& rImport, sal_uInt16 nPrfx,	const ::rtl::OUString& rLocalName,
-        const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList>& xAttrList)
-: SvXMLImportContext(rImport, nPrfx, rLocalName)
+XMLAnimationsContext::XMLAnimationsContext( SvXMLImport& rInImport, sal_uInt16 nPrfx,	const ::rtl::OUString& rLocalName,
+        const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList>& /*xAttrList*/)
+: SvXMLImportContext(rInImport, nPrfx, rLocalName)
 {
     mpImpl = new AnimImpImpl();
 }
@@ -689,10 +700,10 @@ XMLAnimationsContext::~XMLAnimationsContext()
     delete mpImpl;
 }
 
-SvXMLImportContext * XMLAnimationsContext::CreateChildContext( USHORT nPrefix, const ::rtl::OUString& rLocalName,
+SvXMLImportContext * XMLAnimationsContext::CreateChildContext( USHORT nInPrefix, const ::rtl::OUString& rLocalName,
         const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList>& xAttrList )
 {
-    return new XMLAnimationsEffectContext( GetImport(), nPrefix, rLocalName,  xAttrList, mpImpl );
+    return new XMLAnimationsEffectContext( GetImport(), nInPrefix, rLocalName,  xAttrList, mpImpl );
 }
 }//end of namespace binfilter
 
