@@ -61,7 +61,7 @@ struct SvXMLNumFmtEntry
 };
 
 typedef SvXMLNumFmtEntry* SvXMLNumFmtEntryPtr;
-SV_DECL_PTRARR_DEL( SvXMLNumFmtEntryArr, SvXMLNumFmtEntryPtr, 4, 4 )//STRIP007;
+SV_DECL_PTRARR_DEL( SvXMLNumFmtEntryArr, SvXMLNumFmtEntryPtr, 4, 4 )
 
 struct SvXMLEmbeddedElement
 {
@@ -77,7 +77,7 @@ struct SvXMLEmbeddedElement
 };
 
 typedef SvXMLEmbeddedElement* SvXMLEmbeddedElementPtr;
-SV_DECL_PTRARR_SORT_DEL( SvXMLEmbeddedElementArr, SvXMLEmbeddedElementPtr, 0, 4 )//STRIP007 ;
+SV_DECL_PTRARR_SORT_DEL( SvXMLEmbeddedElementArr, SvXMLEmbeddedElementPtr, 0, 4 )
 
 //-------------------------------------------------------------------------
 
@@ -320,7 +320,7 @@ static ColorData aNumFmtStdColors[XML_NUMF_COLORCOUNT] =
 //	token maps
 //
 
-static __FAR_DATA SvXMLTokenMapEntry aStylesElemMap[] =
+static SvXMLTokenMapEntry aStylesElemMap[] =
 {
     //	style elements
     { XML_NAMESPACE_NUMBER, XML_NUMBER_STYLE, 	   XML_TOK_STYLES_NUMBER_STYLE		},
@@ -333,7 +333,7 @@ static __FAR_DATA SvXMLTokenMapEntry aStylesElemMap[] =
     XML_TOKEN_MAP_END
 };
 
-static __FAR_DATA SvXMLTokenMapEntry aStyleElemMap[] =
+static SvXMLTokenMapEntry aStyleElemMap[] =
 {
     //	elements in a style
     { XML_NAMESPACE_NUMBER, XML_TEXT,				XML_TOK_STYLE_TEXT				},
@@ -359,7 +359,7 @@ static __FAR_DATA SvXMLTokenMapEntry aStyleElemMap[] =
     XML_TOKEN_MAP_END
 };
 
-static __FAR_DATA SvXMLTokenMapEntry aStyleAttrMap[] =
+static SvXMLTokenMapEntry aStyleAttrMap[] =
 {
     //	attributes for a style
     { XML_NAMESPACE_STYLE,  XML_NAME,			 	   XML_TOK_STYLE_ATTR_NAME					},
@@ -377,7 +377,7 @@ static __FAR_DATA SvXMLTokenMapEntry aStyleAttrMap[] =
     XML_TOKEN_MAP_END
 };
 
-static __FAR_DATA SvXMLTokenMapEntry aStyleElemAttrMap[] =
+static SvXMLTokenMapEntry aStyleElemAttrMap[] =
 {
     //	attributes for an element within a style
     { XML_NAMESPACE_NUMBER, XML_DECIMAL_PLACES,		     XML_TOK_ELEM_ATTR_DECIMAL_PLACES		},
@@ -398,14 +398,14 @@ static __FAR_DATA SvXMLTokenMapEntry aStyleElemAttrMap[] =
 
 // maps for SvXMLUnitConverter::convertEnum
 
-static __FAR_DATA SvXMLEnumMapEntry aStyleValueMap[] =
+static SvXMLEnumMapEntry aStyleValueMap[] =
 {
     { XML_SHORT,            sal_False	},
     { XML_LONG,             sal_True	},
     { XML_TOKEN_INVALID,    0 }
 };
 
-static __FAR_DATA SvXMLEnumMapEntry aFormatSourceMap[] =
+static SvXMLEnumMapEntry aFormatSourceMap[] =
 {
     { XML_FIXED,	        sal_False },
     { XML_LANGUAGE,         sal_True  },
@@ -427,7 +427,7 @@ struct SvXMLDefaultDateFormat
     sal_Bool					bSystem;
 };
 
-static __FAR_DATA SvXMLDefaultDateFormat aDefaultDateFormats[] =
+static SvXMLDefaultDateFormat aDefaultDateFormats[] =
 {
     // format							day-of-week		day				month				year			hours			minutes			seconds			format-source
 
@@ -807,7 +807,7 @@ void lcl_EnquoteIfNecessary( ::rtl::OUStringBuffer& rContent, sal_uInt16 nFormat
     else if ( nFormatType == XML_TOK_STYLES_PERCENTAGE_STYLE && nLength > 1 )
     {
         //	the percent character in percentage styles must be left out of quoting
-        //	(one occurence is enough even if there are several percent characters in the string)
+        //	(one occurrence is enough even if there are several percent characters in the string)
 
         ::rtl::OUString aString( rContent.getStr() );
         sal_Int32 nPos = aString.indexOf( (sal_Unicode) '%' );
@@ -853,7 +853,7 @@ void lcl_EnquoteIfNecessary( ::rtl::OUStringBuffer& rContent, sal_uInt16 nFormat
         {
             // A quote is turned into "\"" - a quote to end quoted text, an escaped quote,
             // and a quote to resume quoting.
-            rtl::OUString aInsert( rtl::OUString::createFromAscii( "\"\\\"" ) );
+            rtl::OUString aInsert( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "\"\\\"" )) );
 
             sal_Int32 nPos = 0;
             while ( nPos < rContent.getLength() )
@@ -1100,11 +1100,6 @@ void SvXMLNumFmtElementContext::EndElement()
             break;
         case XML_TOK_STYLE_ERA:
             rParent.UpdateCalendar( sCalendar );
-#if 0
-//! I18N doesn't provide SYSTEM or extended date information yet
-            if ( rParent.IsFromSystem() )
-                bEffLong = SvXMLNumFmtDefaults::IsSystemLongEra( rParent.GetInternational(), bLong );
-#endif
             rParent.AddNfKeyword( bEffLong ? NF_KEY_GGG : NF_KEY_G );
             //	HasEra flag is set
             break;
@@ -1166,14 +1161,14 @@ void SvXMLNumFmtElementContext::EndElement()
             {
                 rParent.AddNumber( aNumInfo );		// simple number
 
-                rParent.AddToCode( OUString::createFromAscii( "E+" ) );
+                rParent.AddToCode( OUString( RTL_CONSTASCII_USTRINGPARAM( "E+" )) );
                 for (sal_Int32 i=0; i<aNumInfo.nExpDigits; i++)
                     rParent.AddToCode( OUString::valueOf((sal_Unicode)'0') );
             }
             break;
 
         default:
-            DBG_ERROR("invalid element ID");
+            OSL_FAIL("invalid element ID");
     }
 }
 
@@ -1508,7 +1503,7 @@ void SvXMLNumFormatContext::CreateAndInsert(sal_Bool bOverwrite)
         SvNumberFormatter* pFormatter = pData->GetNumberFormatter();
         if (!pFormatter)
         {
-            DBG_ERROR("no number formatter");
+            OSL_FAIL("no number formatter");
             return;
         }
 
@@ -1601,58 +1596,6 @@ void SvXMLNumFormatContext::CreateAndInsert(sal_Bool bOverwrite)
             }
         }
 
-#if 0
-//! I18N doesn't provide SYSTEM or extended date information yet
-        if ( nIndex != NUMBERFORMAT_ENTRY_NOT_FOUND && !bFromSystem )
-        {
-            //	instead of automatic date format, use fixed formats if bFromSystem is not set
-            //!	prevent use of automatic formats in other cases, force user-defined format?
-
-            sal_uInt32 nNewIndex = nIndex;
-
-            NfIndexTableOffset eOffset = pFormatter->GetIndexTableOffset( nIndex );
-            if ( eOffset == NF_DATE_SYSTEM_SHORT )
-            {
-                const International& rInt = pData->GetInternational( nFormatLang );
-                if ( rInt.IsDateDayLeadingZero() && rInt.IsDateMonthLeadingZero() )
-                {
-                    if ( rInt.IsDateCentury() )
-                        nNewIndex = pFormatter->GetFormatIndex( NF_DATE_SYS_DDMMYYYY, nFormatLang );
-                    else
-                        nNewIndex = pFormatter->GetFormatIndex( NF_DATE_SYS_DDMMYY, nFormatLang );
-                }
-            }
-            else if ( eOffset == NF_DATE_SYSTEM_LONG )
-            {
-                const International& rInt = pData->GetInternational( nFormatLang );
-                if ( !rInt.IsLongDateDayLeadingZero() )
-                {
-                    sal_Bool bCentury = rInt.IsLongDateCentury();
-                    MonthFormat eMonth = rInt.GetLongDateMonthFormat();
-                    if ( eMonth == MONTH_LONG && bCentury )
-                    {
-                        if ( rInt.GetLongDateDayOfWeekFormat() == DAYOFWEEK_LONG )
-                            nNewIndex = pFormatter->GetFormatIndex( NF_DATE_SYS_NNNNDMMMMYYYY, nFormatLang );
-                        else
-                            nNewIndex = pFormatter->GetFormatIndex( NF_DATE_SYS_NNDMMMMYYYY, nFormatLang );
-                    }
-                    else if ( eMonth == MONTH_SHORT && !bCentury )
-                        nNewIndex = pFormatter->GetFormatIndex( NF_DATE_SYS_NNDMMMYY, nFormatLang );
-                }
-            }
-
-            if ( nNewIndex != nIndex )
-            {
-                //	verify the fixed format really matches the format string
-                //	(not the case with some formats from locale data)
-
-                const SvNumberformat* pFixedFormat = pFormatter->GetEntry( nNewIndex );
-                if ( pFixedFormat && pFixedFormat->GetFormatstring() == String(sFormat) )
-                    nIndex = nNewIndex;
-            }
-        }
-#endif
-
         if ( nIndex != NUMBERFORMAT_ENTRY_NOT_FOUND && !bAutoOrder )
         {
             //	use fixed-order formats instead of SYS... if bAutoOrder is false
@@ -1689,7 +1632,7 @@ void SvXMLNumFormatContext::CreateAndInsert(sal_Bool bOverwrite)
 
         if ( nIndex == NUMBERFORMAT_ENTRY_NOT_FOUND )
         {
-            DBG_ERROR("invalid number format");
+            OSL_FAIL("invalid number format");
             nIndex = pFormatter->GetStandardIndex( nFormatLang );
         }
 
@@ -1703,17 +1646,6 @@ void SvXMLNumFormatContext::CreateAndInsert(sal_Bool bOverwrite)
 
         if (!bRemoveAfterUse)
             GetImport().AddNumberStyle( nKey, GetName() );
-
-    #if 0
-        ByteString aByte( String(sFormatName), gsl_getSystemTextEncoding() );
-        aByte.Append( " | " );
-        aByte.Append(ByteString( String(sFormat), gsl_getSystemTextEncoding() ));
-        aByte.Append( " | " );
-        aByte.Append(ByteString::CreateFromInt32( nIndex ));
-
-    //	DBG_ERROR(aByte.GetBuffer());
-        int xxx=42;
-    #endif
     }
 }
 
@@ -2039,7 +1971,7 @@ void SvXMLNumFormatContext::AddCondition( const sal_Int32 nIndex )
     ::rtl::OUString rCondition = aMyConditions[nIndex].sCondition;
     SvNumberFormatter* pFormatter = pData->GetNumberFormatter();
     sal_uInt32 nKey = pData->GetKeyForName( rApplyName );
-    OUString sValue = OUString::createFromAscii( "value()" );		//! define constant
+    OUString sValue( RTL_CONSTASCII_USTRINGPARAM( "value()" ));		//! define constant
     sal_Int32 nValLen = sValue.getLength();
 
     if ( pFormatter && nKey != NUMBERFORMAT_ENTRY_NOT_FOUND &&
@@ -2089,7 +2021,7 @@ void SvXMLNumFormatContext::AddCondition( const sal_Int32 nIndex )
 void SvXMLNumFormatContext::AddCondition( const sal_Int32 nIndex, const ::rtl::OUString& rFormat, const LocaleDataWrapper& rData )
 {
     ::rtl::OUString rCondition = aMyConditions[nIndex].sCondition;
-    OUString sValue = OUString::createFromAscii( "value()" );		//! define constant
+    OUString sValue( RTL_CONSTASCII_USTRINGPARAM( "value()" ));		//! define constant
     sal_Int32 nValLen = sValue.getLength();
 
     if ( rCondition.copy( 0, nValLen ) == sValue )
