@@ -697,11 +697,11 @@ namespace dxcanvas
             mpWindow->SetParentClipMode(0x0002);
             
             // the system child window must not clear its background
-            mpWindow->EnableEraseBackground( FALSE );
+            mpWindow->EnableEraseBackground( sal_False );
 
             mpWindow->SetControlForeground();
             mpWindow->SetControlBackground();
-            mpWindow->EnablePaint(FALSE);
+            mpWindow->EnablePaint(sal_False);
 
             const SystemEnvData *pData = mpWindow->GetSystemData();
             const HWND hwnd(reinterpret_cast<HWND>(pData->hWnd));
@@ -1183,8 +1183,7 @@ namespace dxcanvas
                 }
 
                 default:
-                    OSL_ENSURE(false, 
-                               "DXRenderModule::pushVertex(): unexpected primitive type");
+                    OSL_FAIL("DXRenderModule::pushVertex(): unexpected primitive type");
                     break;
             }
         }
