@@ -167,8 +167,7 @@ namespace vclcanvas
 #ifndef QUARTZ
                     if( aMask.GetBitCount() != 1 )
                     {
-                        OSL_ENSURE(false,
-                                   "CanvasCustomSprite::redraw(): Mask bitmap is not "
+                        OSL_FAIL("CanvasCustomSprite::redraw(): Mask bitmap is not "
                                    "monochrome (performance!)");
                         aMask.MakeMono(255);
                     }
@@ -342,21 +341,8 @@ namespace vclcanvas
                         else
 #endif
                         {
-                            // redraw is direcly on the front buffer,
-                            // or using alpha blending - cannot use
-                            // XOR, thus, employing the still somewhat
-                            // speedier triangle clip method
-                            ::basegfx::B2DPolygon aTriangulatedClip(::basegfx::triangulator::triangulate(aClipPoly)); 
-
-                            // restrict the clipping area to the visible portion of the output device.
-                            Size aSize(rTargetSurface.GetOutputSizePixel());
-                            ::basegfx::B2DRange aOutputRect(::basegfx::B2DPoint(0,0),::basegfx::B2DPoint(aSize.Width(),aSize.Height()));
-                            ::basegfx::B2DPolygon aClippedClip(::basegfx::tools::clipTriangleListOnRange(aTriangulatedClip,aOutputRect));
-
-                            // #i76339#
-                            const Polygon aPoly(aClippedClip);
-                            const PolyPolygon aPolyPoly(aPoly);
-                            rTargetSurface.SetTriangleClipRegion(aPolyPoly);
+                            Region aClipRegion( aClipPoly );
+                            rTargetSurface.SetClipRegion( aClipRegion );
                         }
                     }
                 }
@@ -377,7 +363,7 @@ namespace vclcanvas
                         // here
 
                         // draw semi-transparent
-                        BYTE nColor( static_cast<UINT8>( ::basegfx::fround( 255.0*(1.0 - fAlpha) + .5) ) );
+                        sal_uInt8 nColor( static_cast<sal_uInt8>( ::basegfx::fround( 255.0*(1.0 - fAlpha) + .5) ) );
                         AlphaMask aAlpha( maContent->GetSizePixel(), 
                                           &nColor );
             
@@ -409,7 +395,7 @@ namespace vclcanvas
 
                     for( int i=0; i<aMarkerPoly.Count(); ++i )
                     {
-                        rTargetSurface.DrawPolyLine( aMarkerPoly.GetObject((USHORT)i) );
+                        rTargetSurface.DrawPolyLine( aMarkerPoly.GetObject((sal_uInt16)i) );
                     }
 
                     // paint sprite prio
