@@ -45,7 +45,7 @@
 #include "DiagramHelper.hxx"
 #include "macros.hxx"
 #include "chartview/DrawModelWrapper.hxx"
-#include "chartview/NumberFormatterWrapper.hxx"
+#include "NumberFormatterWrapper.hxx"
 #include "ViewElementListProvider.hxx"
 #include "MultipleChartConverters.hxx"
 #include "ControllerLockGuard.hxx"
@@ -122,8 +122,8 @@ void ChartController::executeDispatch_InsertAxes()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, ::rtl::OUString( String( SchResId( STR_OBJECT_AXES )))),
-        m_xUndoManager, getModel() );
+            ActionDescriptionProvider::INSERT, String( SchResId( STR_OBJECT_AXES ))),
+        m_xUndoManager );
 
     try
     {
@@ -147,7 +147,7 @@ void ChartController::executeDispatch_InsertAxes()
                 , aDialogInput.aExistenceList, aDialogOutput.aExistenceList, m_xCC
                 , mpRefSizeProvider.get() );
             if( bChanged )
-                aUndoGuard.commitAction();
+                aUndoGuard.commit();
         }
     }
     catch( uno::RuntimeException& e)
@@ -160,8 +160,8 @@ void ChartController::executeDispatch_InsertGrid()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, ::rtl::OUString( String( SchResId( STR_OBJECT_GRIDS )))),
-        m_xUndoManager, getModel() );
+            ActionDescriptionProvider::INSERT, String( SchResId( STR_OBJECT_GRIDS ))),
+        m_xUndoManager );
 
     try
     {
@@ -181,7 +181,7 @@ void ChartController::executeDispatch_InsertGrid()
             bool bChanged = AxisHelper::changeVisibilityOfGrids( xDiagram
                 , aDialogInput.aExistenceList, aDialogOutput.aExistenceList, m_xCC );
             if( bChanged )
-                aUndoGuard.commitAction();
+                aUndoGuard.commit();
         }
     }
     catch( uno::RuntimeException& e)
@@ -197,8 +197,8 @@ void ChartController::executeDispatch_InsertTitles()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, ::rtl::OUString( String( SchResId( STR_OBJECT_TITLES )))),
-        m_xUndoManager, getModel() );
+            ActionDescriptionProvider::INSERT, String( SchResId( STR_OBJECT_TITLES ))),
+        m_xUndoManager );
 
     try
     {
@@ -215,7 +215,7 @@ void ChartController::executeDispatch_InsertTitles()
             aDlg.getResult( aDialogOutput );
             bool bChanged = aDialogOutput.writeDifferenceToModel( getModel(), m_xCC, &aDialogInput );
             if( bChanged )
-                aUndoGuard.commitAction();
+                aUndoGuard.commit();
         }
     }
     catch( uno::RuntimeException& e)
@@ -228,30 +228,30 @@ void ChartController::executeDispatch_DeleteLegend()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::DELETE, ::rtl::OUString( String( SchResId( STR_OBJECT_LEGEND )))),
-        m_xUndoManager, getModel() );
+            ActionDescriptionProvider::DELETE, String( SchResId( STR_OBJECT_LEGEND ))),
+        m_xUndoManager );
 
     LegendHelper::hideLegend( getModel() );
-    aUndoGuard.commitAction();
+    aUndoGuard.commit();
 }
 
 void ChartController::executeDispatch_InsertLegend()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, ::rtl::OUString( String( SchResId( STR_OBJECT_LEGEND )))),
-        m_xUndoManager, getModel() );
+            ActionDescriptionProvider::INSERT, String( SchResId( STR_OBJECT_LEGEND ))),
+        m_xUndoManager );
 
     Reference< chart2::XLegend > xLegend = LegendHelper::showLegend( getModel(), m_xCC );
-    aUndoGuard.commitAction();
+    aUndoGuard.commit();
 }
 
 void ChartController::executeDispatch_OpenLegendDialog()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, ::rtl::OUString( String( SchResId( STR_OBJECT_LEGEND )))),
-        m_xUndoManager, getModel() );
+            ActionDescriptionProvider::INSERT, String( SchResId( STR_OBJECT_LEGEND ))),
+        m_xUndoManager );
 
     try
     {
@@ -265,7 +265,7 @@ void ChartController::executeDispatch_OpenLegendDialog()
             ControllerLockGuard aCLGuard( getModel() );
             bool bChanged = aDlg.writeToModel( getModel() );
             if( bChanged )
-                aUndoGuard.commitAction();
+                aUndoGuard.commit();
         }
     }
     catch( uno::RuntimeException& e)
@@ -281,8 +281,8 @@ void ChartController::executeDispatch_InsertMenu_DataLabels()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, ::rtl::OUString( String( SchResId( STR_OBJECT_DATALABELS )))),
-        m_xUndoManager, getModel() );
+            ActionDescriptionProvider::INSERT, String( SchResId( STR_OBJECT_DATALABELS ))),
+        m_xUndoManager );
 
     //if a series is selected insert labels for that series only:
     uno::Reference< chart2::XDataSeries > xSeries(
@@ -299,7 +299,7 @@ void ChartController::executeDispatch_InsertMenu_DataLabels()
 
         bool bSuccess = ChartController::executeDlg_ObjectProperties_withoutUndoGuard( aObjectCID, true );
         if( bSuccess ) 
-            aUndoGuard.commitAction();
+            aUndoGuard.commit();
         return;
     }
 
@@ -331,7 +331,7 @@ void ChartController::executeDispatch_InsertMenu_DataLabels()
             ControllerLockGuard aCLGuard( getModel() );
             bool bChanged = aItemConverter.ApplyItemSet( aOutItemSet );//model should be changed now
             if( bChanged )
-                aUndoGuard.commitAction();
+                aUndoGuard.commit();
         }
     }
     catch( uno::RuntimeException& e)
@@ -355,7 +355,7 @@ void ChartController::executeDispatch_InsertMenu_YErrorBars()
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
             ActionDescriptionProvider::INSERT, ObjectNameProvider::getName_ObjectForAllSeries( OBJECTTYPE_DATA_ERRORS ) ),
-        m_xUndoManager, getModel() );
+        m_xUndoManager );
 
     try
     {
@@ -381,7 +381,7 @@ void ChartController::executeDispatch_InsertMenu_YErrorBars()
             ControllerLockGuard aCLGuard( getModel() );
             bool bChanged = aItemConverter.ApplyItemSet( aOutItemSet );//model should be changed now
             if( bChanged )
-                aUndoGuard.commitAction();
+                aUndoGuard.commit();
         }
     }
     catch( uno::RuntimeException& e)
@@ -394,19 +394,19 @@ void ChartController::executeDispatch_InsertMeanValue()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, ::rtl::OUString( String( SchResId( STR_OBJECT_AVERAGE_LINE )))),
-        m_xUndoManager, getModel() );
+            ActionDescriptionProvider::INSERT, String( SchResId( STR_OBJECT_AVERAGE_LINE ))),
+        m_xUndoManager );
     lcl_InsertMeanValueLine( m_xCC ).operator()(
         ObjectIdentifier::getDataSeriesForCID( m_aSelection.getSelectedCID(), getModel() ));
-    aUndoGuard.commitAction();
+    aUndoGuard.commit();
 }
 
 void ChartController::executeDispatch_InsertMenu_MeanValues()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, ::rtl::OUString( String( SchResId( STR_OBJECT_AVERAGE_LINE )))),
-        m_xUndoManager, getModel() );
+            ActionDescriptionProvider::INSERT, String( SchResId( STR_OBJECT_AVERAGE_LINE ))),
+        m_xUndoManager );
 
     uno::Reference< chart2::XDataSeries > xSeries(
         ObjectIdentifier::getDataSeriesForCID( m_aSelection.getSelectedCID(), getModel() ), uno::UNO_QUERY );
@@ -421,7 +421,7 @@ void ChartController::executeDispatch_InsertMenu_MeanValues()
             DiagramHelper::getDataSeriesFromDiagram( ChartModelHelper::findDiagram( getModel() )));
         ::std::for_each( aSeries.begin(), aSeries.end(), lcl_InsertMeanValueLine( m_xCC ));
     }
-    aUndoGuard.commitAction();
+    aUndoGuard.commit();
 }
 
 void ChartController::executeDispatch_InsertMenu_Trendlines()
@@ -438,7 +438,7 @@ void ChartController::executeDispatch_InsertMenu_Trendlines()
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
             ActionDescriptionProvider::INSERT, ObjectNameProvider::getName_ObjectForAllSeries( OBJECTTYPE_DATA_CURVE ) ),
-        m_xUndoManager, getModel() );
+        m_xUndoManager );
 
     try
     {
@@ -461,7 +461,7 @@ void ChartController::executeDispatch_InsertMenu_Trendlines()
             ControllerLockGuard aCLGuard( getModel() );
             bool bChanged = aItemConverter.ApplyItemSet( aOutItemSet );//model should be changed now
             if( bChanged )
-                aUndoGuard.commitAction();
+                aUndoGuard.commit();
         }
     }
     catch( uno::RuntimeException& e)
@@ -478,8 +478,8 @@ void ChartController::executeDispatch_InsertTrendline()
     {
         UndoLiveUpdateGuard aUndoGuard(
             ActionDescriptionProvider::createDescription(
-                ActionDescriptionProvider::INSERT, ::rtl::OUString( String( SchResId( STR_OBJECT_CURVE )))),
-            m_xUndoManager, getModel() );
+                ActionDescriptionProvider::INSERT, String( SchResId( STR_OBJECT_CURVE ))),
+            m_xUndoManager );
 
         // add a linear curve
         RegressionCurveHelper::addRegressionCurve(
@@ -519,7 +519,7 @@ void ChartController::executeDispatch_InsertTrendline()
                 ControllerLockGuard aCLGuard( getModel() );
                 aItemConverter.ApplyItemSet( *pOutItemSet );
             }
-            aUndoGuard.commitAction();
+            aUndoGuard.commit();
         }
     }
 }
@@ -532,8 +532,8 @@ void ChartController::executeDispatch_InsertYErrorBars()
     {
         UndoLiveUpdateGuard aUndoGuard(
             ActionDescriptionProvider::createDescription(
-                ActionDescriptionProvider::INSERT, ::rtl::OUString( String( SchResId( STR_OBJECT_ERROR_BARS )))),
-            m_xUndoManager, getModel() );
+                ActionDescriptionProvider::INSERT, String( SchResId( STR_OBJECT_ERROR_BARS ))),
+            m_xUndoManager );
 
         // add error bars with standard deviation
         uno::Reference< beans::XPropertySet > xErrorBarProp(
@@ -569,7 +569,7 @@ void ChartController::executeDispatch_InsertYErrorBars()
                 ControllerLockGuard aCLGuard( getModel() );
                 aItemConverter.ApplyItemSet( *pOutItemSet );
             }
-            aUndoGuard.commitAction();
+            aUndoGuard.commit();
         }
     }
 }
@@ -592,11 +592,11 @@ void ChartController::executeDispatch_InsertTrendlineEquation( bool bInsertR2 )
             // using assignment for broken gcc 3.3
             UndoGuard aUndoGuard = UndoGuard(
                 ActionDescriptionProvider::createDescription(
-                    ActionDescriptionProvider::INSERT, ::rtl::OUString( String( SchResId( STR_OBJECT_CURVE_EQUATION )))),
-                m_xUndoManager, getModel() );
+                    ActionDescriptionProvider::INSERT, String( SchResId( STR_OBJECT_CURVE_EQUATION ))),
+                m_xUndoManager );
             xEqProp->setPropertyValue( C2U("ShowEquation"), uno::makeAny( true ));
             xEqProp->setPropertyValue( C2U("ShowCorrelationCoefficient"), uno::makeAny( bInsertR2 ));
-            aUndoGuard.commitAction();
+            aUndoGuard.commit();
         }
     }
 }
@@ -609,10 +609,10 @@ void ChartController::executeDispatch_InsertR2Value()
     {
         UndoGuard aUndoGuard = UndoGuard(
             ActionDescriptionProvider::createDescription(
-                ActionDescriptionProvider::INSERT, ::rtl::OUString( String( SchResId( STR_OBJECT_CURVE_EQUATION )))),
-            m_xUndoManager, getModel() );
+                ActionDescriptionProvider::INSERT, String( SchResId( STR_OBJECT_CURVE_EQUATION ))),
+            m_xUndoManager );
         xEqProp->setPropertyValue( C2U("ShowCorrelationCoefficient"), uno::makeAny( true ));
-        aUndoGuard.commitAction();
+        aUndoGuard.commit();
     }
 }
 
@@ -624,10 +624,10 @@ void ChartController::executeDispatch_DeleteR2Value()
     {
         UndoGuard aUndoGuard = UndoGuard(
             ActionDescriptionProvider::createDescription(
-                ActionDescriptionProvider::INSERT, ::rtl::OUString( String( SchResId( STR_OBJECT_CURVE_EQUATION )))),
-            m_xUndoManager, getModel() );
+                ActionDescriptionProvider::INSERT, String( SchResId( STR_OBJECT_CURVE_EQUATION ))),
+            m_xUndoManager );
         xEqProp->setPropertyValue( C2U("ShowCorrelationCoefficient"), uno::makeAny( false ));
-        aUndoGuard.commitAction();
+        aUndoGuard.commit();
     }
 }
 
@@ -639,10 +639,10 @@ void ChartController::executeDispatch_DeleteMeanValue()
     {
         UndoGuard aUndoGuard(
             ActionDescriptionProvider::createDescription(
-                ActionDescriptionProvider::DELETE, ::rtl::OUString( String( SchResId( STR_OBJECT_AVERAGE_LINE )))),
-            m_xUndoManager, getModel() );
+                ActionDescriptionProvider::DELETE, String( SchResId( STR_OBJECT_AVERAGE_LINE ))),
+            m_xUndoManager );
         RegressionCurveHelper::removeMeanValueLine( xRegCurveCnt );
-        aUndoGuard.commitAction();
+        aUndoGuard.commit();
     }
 }
 
@@ -654,10 +654,10 @@ void ChartController::executeDispatch_DeleteTrendline()
     {
         UndoGuard aUndoGuard(
             ActionDescriptionProvider::createDescription(
-                ActionDescriptionProvider::DELETE, ::rtl::OUString( String( SchResId( STR_OBJECT_CURVE )))),
-            m_xUndoManager, getModel() );
+                ActionDescriptionProvider::DELETE, String( SchResId( STR_OBJECT_CURVE ))),
+            m_xUndoManager );
         RegressionCurveHelper::removeAllExceptMeanValueLine( xRegCurveCnt );
-        aUndoGuard.commitAction();
+        aUndoGuard.commit();
     }
 }
 
@@ -669,10 +669,10 @@ void ChartController::executeDispatch_DeleteTrendlineEquation()
     {
         UndoGuard aUndoGuard(
             ActionDescriptionProvider::createDescription(
-                ActionDescriptionProvider::DELETE, ::rtl::OUString( String( SchResId( STR_OBJECT_CURVE_EQUATION )))),
-            m_xUndoManager, getModel() );
+                ActionDescriptionProvider::DELETE, String( SchResId( STR_OBJECT_CURVE_EQUATION ))),
+            m_xUndoManager );
         RegressionCurveHelper::removeEquations( xRegCurveCnt );
-        aUndoGuard.commitAction();
+        aUndoGuard.commit();
     }
 }
 
@@ -684,10 +684,10 @@ void ChartController::executeDispatch_DeleteYErrorBars()
     {
         UndoGuard aUndoGuard(
             ActionDescriptionProvider::createDescription(
-                ActionDescriptionProvider::DELETE, ::rtl::OUString( String( SchResId( STR_OBJECT_CURVE )))),
-            m_xUndoManager, getModel() );
+                ActionDescriptionProvider::DELETE, String( SchResId( STR_OBJECT_CURVE ))),
+            m_xUndoManager );
         StatisticsHelper::removeErrorBars( xDataSeries );
-        aUndoGuard.commitAction();
+        aUndoGuard.commit();
     }
 }
 
@@ -698,20 +698,20 @@ void ChartController::executeDispatch_InsertDataLabels()
     if( xSeries.is() )
     {
         UndoGuard aUndoGuard = UndoGuard( ActionDescriptionProvider::createDescription( ActionDescriptionProvider::INSERT,
-            ::rtl::OUString( String( SchResId( STR_OBJECT_DATALABELS )))),
-            m_xUndoManager, getModel() );
+            String( SchResId( STR_OBJECT_DATALABELS ))),
+            m_xUndoManager );
         DataSeriesHelper::insertDataLabelsToSeriesAndAllPoints( xSeries );
-        aUndoGuard.commitAction();
+        aUndoGuard.commit();
     }
 }
 
 void ChartController::executeDispatch_InsertDataLabel()
 {
     UndoGuard aUndoGuard = UndoGuard( ActionDescriptionProvider::createDescription( ActionDescriptionProvider::INSERT, 
-        ::rtl::OUString( String( SchResId( STR_OBJECT_LABEL )))),
-        m_xUndoManager, getModel() );
+        String( SchResId( STR_OBJECT_LABEL ))),
+        m_xUndoManager );
     DataSeriesHelper::insertDataLabelToPoint( ObjectIdentifier::getObjectPropertySet( m_aSelection.getSelectedCID(), getModel() ) );
-    aUndoGuard.commitAction();
+    aUndoGuard.commit();
 }
 
 void ChartController::executeDispatch_DeleteDataLabels()
@@ -721,44 +721,44 @@ void ChartController::executeDispatch_DeleteDataLabels()
     if( xSeries.is() )
     {
         UndoGuard aUndoGuard( ActionDescriptionProvider::createDescription( ActionDescriptionProvider::DELETE,
-            ::rtl::OUString( String( SchResId( STR_OBJECT_DATALABELS )))),
-            m_xUndoManager, getModel() );
+            String( SchResId( STR_OBJECT_DATALABELS ))),
+            m_xUndoManager );
         DataSeriesHelper::deleteDataLabelsFromSeriesAndAllPoints( xSeries );
-        aUndoGuard.commitAction();
+        aUndoGuard.commit();
     }
 }
 
 void ChartController::executeDispatch_DeleteDataLabel()
 {
     UndoGuard aUndoGuard( ActionDescriptionProvider::createDescription( ActionDescriptionProvider::DELETE,
-        ::rtl::OUString( String( SchResId( STR_OBJECT_LABEL )))),
-        m_xUndoManager, getModel() );
+        String( SchResId( STR_OBJECT_LABEL ))),
+        m_xUndoManager );
     DataSeriesHelper::deleteDataLabelsFromPoint( ObjectIdentifier::getObjectPropertySet( m_aSelection.getSelectedCID(), getModel() ) );
-    aUndoGuard.commitAction();
+    aUndoGuard.commit();
 }
 
 void ChartController::executeDispatch_ResetAllDataPoints()
 {
     UndoGuard aUndoGuard( ActionDescriptionProvider::createDescription( ActionDescriptionProvider::FORMAT,
-        ::rtl::OUString( String( SchResId( STR_OBJECT_DATAPOINTS )))),
-        m_xUndoManager, getModel() );
+        String( SchResId( STR_OBJECT_DATAPOINTS ))),
+        m_xUndoManager );
     uno::Reference< chart2::XDataSeries > xSeries( ObjectIdentifier::getDataSeriesForCID( m_aSelection.getSelectedCID(), getModel() ), uno::UNO_QUERY );
     if( xSeries.is() )
         xSeries->resetAllDataPoints();
-    aUndoGuard.commitAction();
+    aUndoGuard.commit();
 }
 void ChartController::executeDispatch_ResetDataPoint()
 {
     UndoGuard aUndoGuard( ActionDescriptionProvider::createDescription( ActionDescriptionProvider::FORMAT,
-        ::rtl::OUString( String( SchResId( STR_OBJECT_DATAPOINT )))),
-        m_xUndoManager, getModel() );
+        String( SchResId( STR_OBJECT_DATAPOINT ))),
+        m_xUndoManager );
     uno::Reference< chart2::XDataSeries > xSeries( ObjectIdentifier::getDataSeriesForCID( m_aSelection.getSelectedCID(), getModel() ), uno::UNO_QUERY );
     if( xSeries.is() )
     {
         sal_Int32 nPointIndex = ObjectIdentifier::getIndexFromParticleOrCID( m_aSelection.getSelectedCID() );
         xSeries->resetDataPoint( nPointIndex );
     }    
-    aUndoGuard.commitAction();
+    aUndoGuard.commit();
 }
 
 void ChartController::executeDispatch_InsertAxisTitle()
@@ -769,8 +769,8 @@ void ChartController::executeDispatch_InsertAxisTitle()
         {
             UndoGuard aUndoGuard(
             ActionDescriptionProvider::createDescription(
-                ActionDescriptionProvider::INSERT, ::rtl::OUString( String( SchResId( STR_OBJECT_TITLE )))),
-            m_xUndoManager, getModel() );
+                ActionDescriptionProvider::INSERT, String( SchResId( STR_OBJECT_TITLE ))),
+            m_xUndoManager );
 
             Reference< XAxis > xAxis = ObjectIdentifier::getAxisForCID( m_aSelection.getSelectedCID(), getModel() );
             sal_Int32 nDimensionIndex = -1;
@@ -788,17 +788,8 @@ void ChartController::executeDispatch_InsertAxisTitle()
 
             ::std::auto_ptr< ReferenceSizeProvider > apRefSizeProvider( impl_createReferenceSizeProvider());
             xTitle = TitleHelper::createTitle( eTitleType, ObjectNameProvider::getTitleNameByType(eTitleType), getModel(), m_xCC, apRefSizeProvider.get() );
-            aUndoGuard.commitAction();
+            aUndoGuard.commit();
         }
-
-        /*
-        if( xTitle.is() )
-        {
-            OUString aTitleCID = ObjectIdentifier::createClassifiedIdentifierForObject( xTitle, getModel() );
-            select( uno::makeAny(aTitleCID) );
-            executeDispatch_EditText();
-        }
-        */
     }
     catch( uno::RuntimeException& e)
     {
@@ -810,8 +801,8 @@ void ChartController::executeDispatch_InsertAxis()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, ::rtl::OUString( String( SchResId( STR_OBJECT_AXIS )))),
-        m_xUndoManager, getModel() );
+            ActionDescriptionProvider::INSERT, String( SchResId( STR_OBJECT_AXIS ))),
+        m_xUndoManager );
 
     try
     {
@@ -819,7 +810,7 @@ void ChartController::executeDispatch_InsertAxis()
         if( xAxis.is() )
         {
             AxisHelper::makeAxisVisible( xAxis );
-            aUndoGuard.commitAction();
+            aUndoGuard.commit();
         }
     }
     catch( uno::RuntimeException& e)
@@ -832,8 +823,8 @@ void ChartController::executeDispatch_DeleteAxis()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::DELETE, ::rtl::OUString( String( SchResId( STR_OBJECT_AXIS )))),
-        m_xUndoManager, getModel() );
+            ActionDescriptionProvider::DELETE, String( SchResId( STR_OBJECT_AXIS ))),
+        m_xUndoManager );
 
     try
     {
@@ -841,7 +832,7 @@ void ChartController::executeDispatch_DeleteAxis()
         if( xAxis.is() )
         {
             AxisHelper::makeAxisInvisible( xAxis );
-            aUndoGuard.commitAction();
+            aUndoGuard.commit();
         }
     }
     catch( uno::RuntimeException& e)
@@ -854,8 +845,8 @@ void ChartController::executeDispatch_InsertMajorGrid()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, ::rtl::OUString( String( SchResId( STR_OBJECT_GRID )))),
-        m_xUndoManager, getModel() );
+            ActionDescriptionProvider::INSERT, String( SchResId( STR_OBJECT_GRID ))),
+        m_xUndoManager );
 
     try
     {
@@ -863,7 +854,7 @@ void ChartController::executeDispatch_InsertMajorGrid()
         if( xAxis.is() )
         {
             AxisHelper::makeGridVisible( xAxis->getGridProperties() );
-            aUndoGuard.commitAction();
+            aUndoGuard.commit();
         }
     }
     catch( uno::RuntimeException& e)
@@ -876,8 +867,8 @@ void ChartController::executeDispatch_DeleteMajorGrid()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::DELETE, ::rtl::OUString( String( SchResId( STR_OBJECT_GRID )))),
-        m_xUndoManager, getModel() );
+            ActionDescriptionProvider::DELETE, String( SchResId( STR_OBJECT_GRID ))),
+        m_xUndoManager );
 
     try
     {
@@ -885,7 +876,7 @@ void ChartController::executeDispatch_DeleteMajorGrid()
         if( xAxis.is() )
         {
             AxisHelper::makeGridInvisible( xAxis->getGridProperties() );
-            aUndoGuard.commitAction();
+            aUndoGuard.commit();
         }
     }
     catch( uno::RuntimeException& e)
@@ -898,8 +889,8 @@ void ChartController::executeDispatch_InsertMinorGrid()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, ::rtl::OUString( String( SchResId( STR_OBJECT_GRID )))),
-        m_xUndoManager, getModel() );
+            ActionDescriptionProvider::INSERT, String( SchResId( STR_OBJECT_GRID ))),
+        m_xUndoManager );
 
     try
     {
@@ -909,7 +900,7 @@ void ChartController::executeDispatch_InsertMinorGrid()
             Sequence< Reference< beans::XPropertySet > > aSubGrids( xAxis->getSubGridProperties() );
             for( sal_Int32 nN=0; nN<aSubGrids.getLength(); nN++)
                 AxisHelper::makeGridVisible( aSubGrids[nN] );
-            aUndoGuard.commitAction();
+            aUndoGuard.commit();
         }
     }
     catch( uno::RuntimeException& e)
@@ -922,8 +913,8 @@ void ChartController::executeDispatch_DeleteMinorGrid()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::DELETE, ::rtl::OUString( String( SchResId( STR_OBJECT_GRID )))),
-        m_xUndoManager, getModel() );
+            ActionDescriptionProvider::DELETE, String( SchResId( STR_OBJECT_GRID ))),
+        m_xUndoManager );
 
     try
     {
@@ -933,7 +924,7 @@ void ChartController::executeDispatch_DeleteMinorGrid()
             Sequence< Reference< beans::XPropertySet > > aSubGrids( xAxis->getSubGridProperties() );
             for( sal_Int32 nN=0; nN<aSubGrids.getLength(); nN++)
                 AxisHelper::makeGridInvisible( aSubGrids[nN] );
-            aUndoGuard.commitAction();
+            aUndoGuard.commit();
         }
     }
     catch( uno::RuntimeException& e)
