@@ -32,6 +32,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <osl/diagnose.h>
+#include "diagnose_ex.h"
 #include "odbc/OPreparedStatement.hxx"
 #include "odbc/OBoundParam.hxx"
 #include <com/sun/star/sdbc/DataType.hpp>
@@ -596,6 +597,7 @@ void SAL_CALL OPreparedStatement::clearParameters(  ) throw(SQLException, Runtim
     OSL_ENSURE(m_aStatementHandle,"StatementHandle is null!");
     SQLRETURN nRet = N3SQLFreeStmt (m_aStatementHandle, SQL_RESET_PARAMS);
     nRet = N3SQLFreeStmt (m_aStatementHandle, SQL_UNBIND);
+    OSL_UNUSED(nRet);
 }
 // -------------------------------------------------------------------------
 void SAL_CALL OPreparedStatement::clearBatch(  ) throw(SQLException, RuntimeException)
