@@ -36,7 +36,7 @@
 #include <osl/diagnose.h>
 #include <osl/mutex.hxx>
 
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 
 #include <com/sun/star/lang/XEventListener.hpp>
 
@@ -47,10 +47,6 @@ using namespace com::sun::star::lang;
 
 namespace cppu
 {
-
-//===================================================================
-//===================================================================
-//===================================================================
 /**
  * Reallocate the sequence.
  */
@@ -80,17 +76,10 @@ static void sequenceRemoveElementAt( Sequence< Reference< XInterface > > & rSeq,
     rSeq = aDestSeq;
 }
 
-
-//-----------------------------------------------------------------------------
-//-----------------------------------------------------------------------------
-
 #ifdef _MSC_VER
 #pragma warning( disable: 4786 )
 #endif
 
-//===================================================================
-//===================================================================
-//===================================================================
 OInterfaceIteratorHelper::OInterfaceIteratorHelper( OInterfaceContainerHelper & rCont_ )
     SAL_THROW( () )
     : rCont( rCont_ )
@@ -171,11 +160,6 @@ void OInterfaceIteratorHelper::remove() SAL_THROW( () )
     }
 }
 
-//===================================================================
-//===================================================================
-//===================================================================
-
-
 OInterfaceContainerHelper::OInterfaceContainerHelper( Mutex & rMutex_ ) SAL_THROW( () )
     : rMutex( rMutex_ )
     , bInUse( sal_False )
@@ -367,10 +351,6 @@ void OInterfaceContainerHelper::clear() SAL_THROW( () )
     aGuard.clear();
 }
 
-//##################################################################################################
-//##################################################################################################
-//##################################################################################################
-
 // specialized class for type
 
 typedef ::std::vector< std::pair < Type , void* > > t_type2ptr;
@@ -539,11 +519,6 @@ void OMultiTypeInterfaceContainerHelper::clear()
     }
 }
 
-
-//##################################################################################################
-//##################################################################################################
-//##################################################################################################
-
 // specialized class for long
 
 typedef ::std::vector< std::pair < sal_Int32 , void* > > t_long2ptr;
