@@ -26,9 +26,6 @@
  *
  ************************************************************************/
 
-// MARKER(update_precomp.py): autogen include statement, do not remove
-#include "precompiled_cui.hxx"
-
 //svdraw.hxx
 #define _SVDRAW_HXX
 #define _SDR_NOITEMS
@@ -69,6 +66,7 @@
 #include <svx/svxdlg.hxx>
 #include <dialmgr.hxx>
 #include "sfx2/opengrf.hxx"
+#include "paragrph.hrc"
 
 #define DLGWIN this->GetParent()->GetParent()
 
@@ -117,8 +115,6 @@ SvxBitmapTabPage::SvxBitmapTabPage
     aXFillAttr          ( pXPool ),
     rXFSet              ( aXFillAttr.GetItemSet() )
 {
-    aBtnLoad.SetModeImage( Image( CUI_RES( RID_SVXIMG_LOAD_H ) ), BMP_COLOR_HIGHCONTRAST );
-    aBtnSave.SetModeImage( Image( CUI_RES( RID_SVXIMG_SAVE_H ) ), BMP_COLOR_HIGHCONTRAST );
     FreeResource();
 
     // diese Page braucht ExchangeSupport
@@ -127,7 +123,6 @@ SvxBitmapTabPage::SvxBitmapTabPage
     // Setzen des Output-Devices
     rXFSet.Put( aXFStyleItem );
     rXFSet.Put( aXBitmapItem );
-    //aCtlPreview.SetAttributes( aXFillAttr );
 
     aBtnAdd.SetClickHdl( LINK( this, SvxBitmapTabPage, ClickAddHdl_Impl ) );
     aBtnImport.SetClickHdl(
@@ -146,6 +141,16 @@ SvxBitmapTabPage::SvxBitmapTabPage
     aLbBackgroundColor.SetSelectHdl(
         LINK( this, SvxBitmapTabPage, ChangeBackgrndColorHdl_Impl ) );
 
+    String accName = String(SVX_RES(STR_EXAMPLE)); 
+    aCtlPreview.SetAccessibleName(accName); 
+    aCtlPixel.SetAccessibleRelationMemberOf( &aFlProp );
+    aCtlPixel.SetAccessibleRelationLabeledBy( &aFtPixelEdit );
+    aLbBitmaps.SetAccessibleRelationLabeledBy(&aLbBitmaps);
+    aBtnAdd.SetAccessibleRelationMemberOf( &aFlProp );
+    aBtnModify.SetAccessibleRelationMemberOf( &aFlProp );
+    aBtnImport.SetAccessibleRelationMemberOf( &aFlProp );
+    aBtnDelete.SetAccessibleRelationMemberOf( &aFlProp );	
+
 }
 
 // -----------------------------------------------------------------------
@@ -164,12 +169,12 @@ void SvxBitmapTabPage::Construct()
 
 void SvxBitmapTabPage::ActivatePage( const SfxItemSet&  )
 {
-    USHORT nPos;
-    USHORT nCount;
+    sal_uInt16 nPos;
+    sal_uInt16 nCount;
 
     if( *pDlgType == 0 ) // Flaechen-Dialog
     {
-        *pbAreaTP = FALSE;
+        *pbAreaTP = sal_False;
 
         if( pColorTab )
         {
@@ -252,9 +257,9 @@ int SvxBitmapTabPage::DeactivatePage( SfxItemSet* _pSet)
 
 // -----------------------------------------------------------------------
 
-BOOL SvxBitmapTabPage::FillItemSet( SfxItemSet& _rOutAttrs )
+sal_Bool SvxBitmapTabPage::FillItemSet( SfxItemSet& _rOutAttrs )
 {
-    if( *pDlgType == 0 && *pbAreaTP == FALSE ) // Flaechen-Dialog
+    if( *pDlgType == 0 && *pbAreaTP == sal_False ) // Flaechen-Dialog
     {
         if( *pPageType == PT_BITMAP )
         {
@@ -262,7 +267,7 @@ BOOL SvxBitmapTabPage::FillItemSet( SfxItemSet& _rOutAttrs )
 
             XOBitmap aXOBitmap;
             String aString;
-            USHORT nPos = aLbBitmaps.GetSelectEntryPos();
+            sal_uInt16 nPos = aLbBitmaps.GetSelectEntryPos();
             if( nPos != LISTBOX_ENTRY_NOTFOUND )
             {
                 aXOBitmap = pBitmapList->GetBitmap( nPos )->GetXBitmap();
@@ -282,7 +287,7 @@ BOOL SvxBitmapTabPage::FillItemSet( SfxItemSet& _rOutAttrs )
             _rOutAttrs.Put( XFillBitmapItem( aString, aXOBitmap ) );
         }
     }
-    return TRUE;
+    return sal_True;
 }
 
 // -----------------------------------------------------------------------
@@ -340,11 +345,11 @@ IMPL_LINK( SvxBitmapTabPage, ChangeBitmapHdl_Impl, void *, EMPTYARG )
     else
     {
         const SfxPoolItem* pPoolItem = NULL;
-        if( SFX_ITEM_SET == rOutAttrs.GetItemState( GetWhich( XATTR_FILLSTYLE ), TRUE, &pPoolItem ) )
+        if( SFX_ITEM_SET == rOutAttrs.GetItemState( GetWhich( XATTR_FILLSTYLE ), sal_True, &pPoolItem ) )
         {
             XFillStyle eXFS = (XFillStyle) ( ( const XFillStyleItem* ) pPoolItem )->GetValue();
             if( ( XFILL_BITMAP == eXFS ) &&
-                ( SFX_ITEM_SET == rOutAttrs.GetItemState( GetWhich( XATTR_FILLBITMAP ), TRUE, &pPoolItem ) ) )
+                ( SFX_ITEM_SET == rOutAttrs.GetItemState( GetWhich( XATTR_FILLBITMAP ), sal_True, &pPoolItem ) ) )
             {
                 pXOBitmap = new XOBitmap( ( ( const XFillBitmapItem* ) pPoolItem )->GetBitmapValue() );
             }
@@ -359,14 +364,6 @@ IMPL_LINK( SvxBitmapTabPage, ChangeBitmapHdl_Impl, void *, EMPTYARG )
     }
     if( pXOBitmap )
     {
-        //WorkWindow		aTmpWW( DLGWIN );
-        //VirtualDevice	aVD( aTmpWW );
-        //USHORT	nLines = aCtlPixel.GetLineCount();
-        //Color	aPixelColor, aBackColor;
-        //BOOL	bPixelColor = FALSE;
-        //USHORT	nWidth  = pBitmap->GetSizePixel().Width();
-        //USHORT	nHeight = pBitmap->GetSizePixel().Height();
-
         // #85339# try to convert bitmapped item to array item.
         if(pXOBitmap->GetBitmapType() == XBITMAP_IMPORT)
         {
@@ -379,7 +376,7 @@ IMPL_LINK( SvxBitmapTabPage, ChangeBitmapHdl_Impl, void *, EMPTYARG )
                 sal_uInt32 nCol1(0xffffffff); // background
                 sal_uInt32 nCol2(0xffffffff); // pixel
                 BitmapReadAccess* pAccess = aBitmap.AcquireReadAccess();
-                sal_Bool bValid(TRUE);
+                sal_Bool bValid(sal_True);
 
                 if(pAccess)
                 {
@@ -412,7 +409,7 @@ IMPL_LINK( SvxBitmapTabPage, ChangeBitmapHdl_Impl, void *, EMPTYARG )
                                     else
                                     {
                                         // Third color detected
-                                        bValid = FALSE;
+                                        bValid = sal_False;
                                     }
                                 }
                                 else
@@ -435,7 +432,7 @@ IMPL_LINK( SvxBitmapTabPage, ChangeBitmapHdl_Impl, void *, EMPTYARG )
                 else
                 {
                     // no access -> no success
-                    bValid = FALSE;
+                    bValid = sal_False;
                 }
 
                 if(bValid)
@@ -468,7 +465,7 @@ IMPL_LINK( SvxBitmapTabPage, ChangeBitmapHdl_Impl, void *, EMPTYARG )
         if( pXOBitmap->GetBitmapType() == XBITMAP_IMPORT )
         {
             aCtlPixel.Reset();
-            aCtlPixel.SetPaintable( FALSE );
+            aCtlPixel.SetPaintable( sal_False );
             aCtlPixel.Disable();
             aFtPixelEdit.Disable();
             aFtColor.Disable();
@@ -480,7 +477,7 @@ IMPL_LINK( SvxBitmapTabPage, ChangeBitmapHdl_Impl, void *, EMPTYARG )
         }
         else if( pXOBitmap->GetBitmapType() == XBITMAP_8X8 )
         {
-            aCtlPixel.SetPaintable( TRUE );
+            aCtlPixel.SetPaintable( sal_True );
             aCtlPixel.Enable();
             aFtPixelEdit.Enable();
             aFtColor.Enable();
@@ -529,7 +526,7 @@ IMPL_LINK( SvxBitmapTabPage, ChangeBitmapHdl_Impl, void *, EMPTYARG )
         aCtlPreview.SetAttributes( aXFillAttr.GetItemSet() );
         aCtlPreview.Invalidate();
 
-        bBmpChanged = FALSE;
+        bBmpChanged = sal_False;
         delete pXOBitmap;
     }
     return 0L;
@@ -539,7 +536,7 @@ IMPL_LINK( SvxBitmapTabPage, ChangeBitmapHdl_Impl, void *, EMPTYARG )
 
 long SvxBitmapTabPage::CheckChanges_Impl()
 {
-    USHORT nPos = aLbBitmaps.GetSelectEntryPos();
+    sal_uInt16 nPos = aLbBitmaps.GetSelectEntryPos();
     if( nPos != LISTBOX_ENTRY_NOTFOUND )
     {
         String aString = aLbBitmaps.GetSelectEntry();
@@ -578,9 +575,7 @@ long SvxBitmapTabPage::CheckChanges_Impl()
                 break;
 
                 case RET_CANCEL:
-                    // return( -1L );
                 break;
-                // return( TRUE ); // Abbruch
             }
             delete aMessDlg;
         }
@@ -602,18 +597,18 @@ IMPL_LINK( SvxBitmapTabPage, ClickAddHdl_Impl, void *, EMPTYARG )
 
     long nCount = pBitmapList->Count();
     long j = 1;
-    BOOL bDifferent = FALSE;
+    sal_Bool bDifferent = sal_False;
 
     while( !bDifferent )
     {
         aName  = aNewName;
         aName += sal_Unicode(' ');
         aName += UniString::CreateFromInt32( j++ );
-        bDifferent = TRUE;
+        bDifferent = sal_True;
 
         for( long i = 0; i < nCount && bDifferent; i++ )
             if( aName == pBitmapList->GetBitmap( i )->GetName() )
-                bDifferent = FALSE;
+                bDifferent = sal_False;
     }
 
     SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
@@ -621,17 +616,17 @@ IMPL_LINK( SvxBitmapTabPage, ClickAddHdl_Impl, void *, EMPTYARG )
     AbstractSvxNameDialog* pDlg = pFact->CreateSvxNameDialog( DLGWIN, aName, aDesc );
     DBG_ASSERT(pDlg, "Dialogdiet fail!");
     WarningBox*    pWarnBox = NULL;
-    USHORT         nError   = RID_SVXSTR_WARN_NAME_DUPLICATE;
+    sal_uInt16         nError   = RID_SVXSTR_WARN_NAME_DUPLICATE;
 
     while( pDlg->Execute() == RET_OK )
     {
         pDlg->GetName( aName );
 
-        bDifferent = TRUE;
+        bDifferent = sal_True;
 
         for( long i = 0; i < nCount && bDifferent; i++ )
             if( aName == pBitmapList->GetBitmap( i )->GetName() )
-                bDifferent = FALSE;
+                bDifferent = sal_False;
 
         if( bDifferent ) {
             nError = 0;
@@ -649,7 +644,6 @@ IMPL_LINK( SvxBitmapTabPage, ClickAddHdl_Impl, void *, EMPTYARG )
         if( pWarnBox->Execute() != RET_OK )
             break;
     }
-    //Rectangle aDlgRect( pDlg->GetPosPixel(), pDlg->GetSizePixel() );
     delete pDlg;
     delete pWarnBox;
 
@@ -669,7 +663,7 @@ IMPL_LINK( SvxBitmapTabPage, ClickAddHdl_Impl, void *, EMPTYARG )
         else // Es muss sich um eine nicht vorhandene importierte Bitmap handeln
         {
             const SfxPoolItem* pPoolItem = NULL;
-            if( SFX_ITEM_SET == rOutAttrs.GetItemState( XATTR_FILLBITMAP, TRUE, &pPoolItem ) )
+            if( SFX_ITEM_SET == rOutAttrs.GetItemState( XATTR_FILLBITMAP, sal_True, &pPoolItem ) )
             {
                 XOBitmap aXOBitmap( ( ( const XFillBitmapItem* ) pPoolItem )->GetBitmapValue() );
                 pEntry = new XBitmapEntry( aXOBitmap, aName );
@@ -688,7 +682,7 @@ IMPL_LINK( SvxBitmapTabPage, ClickAddHdl_Impl, void *, EMPTYARG )
 #ifdef WNT
             // hack: #31355# W.P.
             Rectangle aRect( aLbBitmaps.GetPosPixel(), aLbBitmaps.GetSizePixel() );
-            if( TRUE ) {				// ??? overlapped with pDlg
+            if( sal_True ) {				// ??? overlapped with pDlg
                                         // and srolling
                 Invalidate( aRect );
                 //aLbBitmaps.Invalidate();
@@ -756,12 +750,12 @@ IMPL_LINK( SvxBitmapTabPage, ClickImportHdl_Impl, void *, EMPTYARG )
             {
                 pDlg->GetName( aName );
 
-                BOOL bDifferent = TRUE;
+                sal_Bool bDifferent = sal_True;
                 long nCount     = pBitmapList->Count();
 
                 for( long i = 0; i < nCount && bDifferent; i++ )
                     if( aName == pBitmapList->GetBitmap( i )->GetName() )
-                        bDifferent = FALSE;
+                        bDifferent = sal_False;
 
                 if( bDifferent ) {
                     nError = 0;
@@ -780,7 +774,6 @@ IMPL_LINK( SvxBitmapTabPage, ClickImportHdl_Impl, void *, EMPTYARG )
                 if( pWarnBox->Execute() != RET_OK )
                     break;
             }
-            //Rectangle aDlgRect( pDlg->GetPosPixel(), pDlg->GetSizePixel() );
             delete pDlg;
             delete pWarnBox;
 
@@ -797,10 +790,9 @@ IMPL_LINK( SvxBitmapTabPage, ClickImportHdl_Impl, void *, EMPTYARG )
 #ifdef WNT
                 // hack: #31355# W.P.
                 Rectangle aRect( aLbBitmaps.GetPosPixel(), aLbBitmaps.GetSizePixel() );
-                if( TRUE ) {				// ??? overlapped with pDlg
+                if( sal_True ) {				// ??? overlapped with pDlg
                                             // and srolling
                     Invalidate( aRect );
-                    //aLbBitmaps.Invalidate();
                 }
 #endif
 
@@ -828,7 +820,7 @@ IMPL_LINK( SvxBitmapTabPage, ClickImportHdl_Impl, void *, EMPTYARG )
 
 IMPL_LINK( SvxBitmapTabPage, ClickModifyHdl_Impl, void *, EMPTYARG )
 {
-    USHORT nPos = aLbBitmaps.GetSelectEntryPos();
+    sal_uInt16 nPos = aLbBitmaps.GetSelectEntryPos();
 
     if ( nPos != LISTBOX_ENTRY_NOTFOUND )
     {
@@ -844,24 +836,24 @@ IMPL_LINK( SvxBitmapTabPage, ClickModifyHdl_Impl, void *, EMPTYARG )
         DBG_ASSERT(pDlg, "Dialogdiet fail!");
 
         long nCount = pBitmapList->Count();
-        BOOL bDifferent = FALSE;
-        BOOL bLoop = TRUE;
+        sal_Bool bDifferent = sal_False;
+        sal_Bool bLoop = sal_True;
 
         while( bLoop && pDlg->Execute() == RET_OK )
         {
             pDlg->GetName( aName );
-            bDifferent = TRUE;
+            bDifferent = sal_True;
 
             for( long i = 0; i < nCount && bDifferent; i++ )
             {
                 if( aName == pBitmapList->GetBitmap( i )->GetName() &&
                     aName != aOldName )
-                    bDifferent = FALSE;
+                    bDifferent = sal_False;
             }
 
             if( bDifferent )
             {
-                bLoop = FALSE;
+                bLoop = sal_False;
                 XBitmapEntry* pEntry = pBitmapList->GetBitmap( nPos );
 
                 pEntry->SetName( aName );
@@ -880,7 +872,7 @@ IMPL_LINK( SvxBitmapTabPage, ClickModifyHdl_Impl, void *, EMPTYARG )
                 // Flag fuer modifiziert setzen
                 *pnBitmapListState |= CT_MODIFIED;
 
-                bBmpChanged = FALSE;
+                bBmpChanged = sal_False;
             }
             else
             {
@@ -898,7 +890,7 @@ IMPL_LINK( SvxBitmapTabPage, ClickModifyHdl_Impl, void *, EMPTYARG )
 
 IMPL_LINK( SvxBitmapTabPage, ClickDeleteHdl_Impl, void *, EMPTYARG )
 {
-    USHORT nPos = aLbBitmaps.GetSelectEntryPos();
+    sal_uInt16 nPos = aLbBitmaps.GetSelectEntryPos();
 
     if( nPos != LISTBOX_ENTRY_NOTFOUND )
     {
@@ -934,7 +926,7 @@ IMPL_LINK( SvxBitmapTabPage, ClickDeleteHdl_Impl, void *, EMPTYARG )
 
 IMPL_LINK( SvxBitmapTabPage, ClickLoadHdl_Impl, void *, EMPTYARG )
 {
-    USHORT nReturn = RET_YES;
+    sal_uInt16 nReturn = RET_YES;
     ResMgr& rMgr = CUI_MGR();
 
     if ( *pnBitmapListState & CT_MODIFIED )
@@ -970,39 +962,36 @@ IMPL_LINK( SvxBitmapTabPage, ClickLoadHdl_Impl, void *, EMPTYARG )
             pBmpList->SetName( aURL.getName() );
             if( pBmpList->Load() )
             {
-                if( pBmpList )
+                // Pruefen, ob Tabelle geloescht werden darf:
+                if( pBitmapList != ( (SvxAreaTabDialog*) DLGWIN )->GetBitmapList() )
+                    delete pBitmapList;
+
+                pBitmapList = pBmpList;
+                ( (SvxAreaTabDialog*) DLGWIN )->SetNewBitmapList( pBitmapList );
+
+                aLbBitmaps.Clear();
+                aLbBitmaps.Fill( pBitmapList );
+                Reset( rOutAttrs );
+
+                pBitmapList->SetName( aURL.getName() );
+
+                // Ermitteln (evtl. abschneiden) des Namens und in
+                // der GroupBox darstellen
+                String aString( ResId( RID_SVXSTR_TABLE, rMgr ) );
+                aString.AppendAscii( RTL_CONSTASCII_STRINGPARAM( ": " ) );
+
+                if ( aURL.getBase().getLength() > 18 )
                 {
-                    // Pruefen, ob Tabelle geloescht werden darf:
-                    if( pBitmapList != ( (SvxAreaTabDialog*) DLGWIN )->GetBitmapList() )
-                        delete pBitmapList;
-
-                    pBitmapList = pBmpList;
-                    ( (SvxAreaTabDialog*) DLGWIN )->SetNewBitmapList( pBitmapList );
-
-                    aLbBitmaps.Clear();
-                    aLbBitmaps.Fill( pBitmapList );
-                    Reset( rOutAttrs );
-
-                    pBitmapList->SetName( aURL.getName() );
-
-                    // Ermitteln (evtl. abschneiden) des Namens und in
-                    // der GroupBox darstellen
-                    String aString( ResId( RID_SVXSTR_TABLE, rMgr ) );
-                    aString.AppendAscii( RTL_CONSTASCII_STRINGPARAM( ": " ) );
-
-                    if ( aURL.getBase().getLength() > 18 )
-                    {
-                        aString += String(aURL.getBase()).Copy( 0, 15 );
-                        aString.AppendAscii( RTL_CONSTASCII_STRINGPARAM( "..." ) );
-                    }
-                    else
-                        aString += String(aURL.getBase());
-
-                    // Flag fuer gewechselt setzen
-                    *pnBitmapListState |= CT_CHANGED;
-                    // Flag fuer modifiziert entfernen
-                    *pnBitmapListState &= ~CT_MODIFIED;
+                    aString += String(aURL.getBase()).Copy( 0, 15 );
+                    aString.AppendAscii( RTL_CONSTASCII_STRINGPARAM( "..." ) );
                 }
+                else
+                    aString += String(aURL.getBase());
+
+                // Flag fuer gewechselt setzen
+                *pnBitmapListState |= CT_CHANGED;
+                // Flag fuer modifiziert entfernen
+                *pnBitmapListState &= ~CT_MODIFIED;
                 LeaveWait();
             }
             else
@@ -1106,7 +1095,7 @@ IMPL_LINK( SvxBitmapTabPage, ChangePixelColorHdl_Impl, void *, EMPTYARG )
     aCtlPreview.SetAttributes( aXFillAttr.GetItemSet() );
     aCtlPreview.Invalidate();
 
-    bBmpChanged = TRUE;
+    bBmpChanged = sal_True;
 
     return 0L;
 }
@@ -1125,7 +1114,7 @@ IMPL_LINK( SvxBitmapTabPage, ChangeBackgrndColorHdl_Impl, void *, EMPTYARG )
     aCtlPreview.SetAttributes( aXFillAttr.GetItemSet() );
     aCtlPreview.Invalidate();
 
-    bBmpChanged = TRUE;
+    bBmpChanged = sal_True;
 
     return 0L;
 }
@@ -1143,7 +1132,7 @@ void SvxBitmapTabPage::PointChanged( Window* pWindow, RECT_POINT )
         aCtlPreview.SetAttributes( aXFillAttr.GetItemSet() );
         aCtlPreview.Invalidate();
 
-        bBmpChanged = TRUE;
+        bBmpChanged = sal_True;
     }
 }
 
