@@ -214,10 +214,10 @@ namespace dbmm
     }
 
     //--------------------------------------------------------------------
-    BOOL MacroMigrationDialog::Close()
+    sal_Bool MacroMigrationDialog::Close()
     {
         if ( m_pData->bMigrationIsRunning )
-            return FALSE;
+            return sal_False;
         return MacroMigrationDialog_Base::Close();
     }
 
@@ -271,7 +271,7 @@ namespace dbmm
             break;
 
         default:
-            OSL_ENSURE( false, "MacroMigrationDialog::enterState: unhandled state!" );
+            OSL_FAIL( "MacroMigrationDialog::enterState: unhandled state!" );
         }
     }
 
@@ -296,7 +296,7 @@ namespace dbmm
         case STATE_SUMMARY:
             break;
         default:
-            OSL_ENSURE( false, "MacroMigrationDialog::prepareLeaveCurrentState: unhandled state!" );
+            OSL_FAIL( "MacroMigrationDialog::prepareLeaveCurrentState: unhandled state!" );
         }
 
         return sal_True;
@@ -535,7 +535,7 @@ namespace dbmm
                 if ( !xController->suspend( sal_True ) )
                 {   // ouch. There shouldn't be any modal dialogs and such, so there
                     // really is no reason why suspending shouldn't work.
-                    OSL_ENSURE( false, "MacroMigrationDialog::impl_reloadDocument_nothrow: could not suspend a controller!" );
+                    OSL_FAIL( "MacroMigrationDialog::impl_reloadDocument_nothrow: could not suspend a controller!" );
                     // ignoring this would be at the cost of a crash (potentially)
                     // so, we cannot continue here.
                     throw CloseVetoException();
