@@ -96,8 +96,6 @@ using namespace ::com::sun::star::sdbc;
 using namespace ::com::sun::star::sdb;
 using namespace ::com::sun::star::ui::dialogs;
 using namespace ::com::sun::star::util;
-//	using namespace ::com::sun::star::sdbcx;
-//	using namespace ::connectivity;
 using namespace ::dbtools;
 using namespace ::dbaui;
 using namespace ::comphelper;
@@ -112,13 +110,13 @@ using namespace ::osl;
 //------------------------------------------------------------------------------
 ::rtl::OUString ORelationController::getImplementationName_Static() throw( RuntimeException )
 {
-    return ::rtl::OUString::createFromAscii("org.openoffice.comp.dbu.ORelationDesign");
+    return ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("org.openoffice.comp.dbu.ORelationDesign"));
 }
 //------------------------------------------------------------------------------
 Sequence< ::rtl::OUString> ORelationController::getSupportedServiceNames_Static(void) throw( RuntimeException )
 {
     Sequence< ::rtl::OUString> aSupported(1);
-    aSupported.getArray()[0] = ::rtl::OUString::createFromAscii("com.sun.star.sdb.RelationDesign");
+    aSupported.getArray()[0] = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.sdb.RelationDesign"));
     return aSupported;
 }
 //-------------------------------------------------------------------------
@@ -348,7 +346,7 @@ namespace
                 {
                     ::comphelper::disposeComponent(xResult);
                     loadTableData(m_xTables->getByName(*pIter));
-                } // if ( xResult.is() && xResult->next() )
+                }
             }
             catch( const Exception& )
             {
@@ -367,12 +365,10 @@ namespace
         Reference<XPropertySet> xTableProp(_aTable,UNO_QUERY);
         const ::rtl::OUString sSourceName = ::dbtools::composeTableName( m_xMetaData, xTableProp, ::dbtools::eInTableDefinitions, false, false, false );
         TTableDataHelper::iterator aFind = m_aTableData.find(sSourceName);
-        bool bNotFound = true, bAdded = false;
         if ( aFind == m_aTableData.end() )
         {
             aFind = m_aTableData.insert(TTableDataHelper::value_type(sSourceName,::boost::shared_ptr<OTableWindowData>(new OTableWindowData(xTableProp,sSourceName, sSourceName)))).first;
-            aFind->second->ShowAll(FALSE);
-            bAdded = true;
+            aFind->second->ShowAll(sal_False);
         }
         TTableWindowData::value_type pReferencingTable = aFind->second;
         Reference<XIndexAccess> xKeys = pReferencingTable->getKeys();
@@ -394,7 +390,6 @@ namespace
                 xKey->getPropertyValue(PROPERTY_TYPE) >>= nKeyType;
                 if ( KeyType::FOREIGN == nKeyType )
                 {
-                    bNotFound = false;
                     ::rtl::OUString sReferencedTable;
                     xKey->getPropertyValue(PROPERTY_REFERENCEDTABLE) >>= sReferencedTable;
                     //////////////////////////////////////////////////////////////////////
@@ -406,11 +401,11 @@ namespace
                         {
                             Reference<XPropertySet>  xReferencedTable(m_xTables->getByName(sReferencedTable),UNO_QUERY);
                             aRefFind = m_aTableData.insert(TTableDataHelper::value_type(sReferencedTable,::boost::shared_ptr<OTableWindowData>(new OTableWindowData(xReferencedTable,sReferencedTable, sReferencedTable)))).first;
-                            aRefFind->second->ShowAll(FALSE);
+                            aRefFind->second->ShowAll(sal_False);
                         }
                         else
                             continue; // table name could not be found so we do not show this table releation
-                    } // if ( aFind == m_aTableData.end() )
+                    }
                     TTableWindowData::value_type pReferencedTable = aRefFind->second;
 
                     ::rtl::OUString sKeyName;
@@ -454,7 +449,7 @@ namespace
                     pTabConnData->SetCardinality();
                 }
             }
-        } // if ( xKeys.is() )
+        }
     }
 }
 
@@ -478,7 +473,7 @@ void ORelationController::mergeData(const TTableConnectionData& _aConnectionData
         {
             m_vTableData.push_back((*aConnDataIter)->getReferencedTable());
         }
-    } // for(;aConnDataIter != aConnDataEnd;++aConnDataIter)
+    }
     if ( m_nThreadEvent )
     {
         --m_nThreadEvent;
@@ -495,7 +490,7 @@ IMPL_LINK( ORelationController, OnThreadFinished, void*, /*NOTINTERESTEDIN*/ )
     {
         getView()->initialize();	// show the windows and fill with our informations
         getView()->Invalidate(INVALIDATE_NOERASE);
-        getUndoMgr()->Clear();		// clear all undo redo things
+        ClearUndoManager();
         setModified(sal_False);		// and we are not modified yet
         
         if(m_vTableData.empty())
@@ -535,8 +530,8 @@ void ORelationController::loadData()
                 nStart = nEnd;
                 nEnd += nMaxElements;
                 nEnd = ::std::min(nEnd,nCount);
-            } // for(;pIter != pEnd;++pIter)
-        } // if ( aMeta.supportsThreads() )
+            }
+        }
         else
         {
             RelationLoader* pThread = new RelationLoader(this,xMetaData,m_xTables,aNames,0,nCount);
