@@ -77,11 +77,12 @@ Entry_Impl::Entry_Impl( const uno::Reference< deployment::XPackage > &xPackage,
         m_sTitle = xPackage->getDisplayName();
         m_sVersion = xPackage->getVersion();
         m_sDescription = xPackage->getDescription();
+    m_sLicenseText = xPackage->getLicenseText();
 
         beans::StringPair aInfo( m_xPackage->getPublisherInfo() );
         m_sPublisher = aInfo.First;
         m_sPublisherURL = aInfo.Second;
-
+    
         // get the icons for the package if there are any
         uno::Reference< graphic::XGraphic > xGraphic = xPackage->getIcon( false );
         if ( xGraphic.is() )
@@ -184,13 +185,9 @@ ExtensionBox_Impl::ExtensionBox_Impl( Dialog* pParent, TheExtensionManager *pMan
     m_nActiveHeight( 0 ),
     m_nExtraHeight( 2 ),
     m_aSharedImage( DialogHelper::getResId( RID_IMG_SHARED ) ),
-    m_aSharedImageHC( DialogHelper::getResId( RID_IMG_SHARED_HC ) ),
     m_aLockedImage( DialogHelper::getResId( RID_IMG_LOCKED ) ),
-    m_aLockedImageHC( DialogHelper::getResId( RID_IMG_LOCKED_HC ) ),
     m_aWarningImage( DialogHelper::getResId( RID_IMG_WARNING ) ),
-    m_aWarningImageHC( DialogHelper::getResId( RID_IMG_WARNING_HC ) ),
     m_aDefaultImage( DialogHelper::getResId( RID_IMG_EXTENSION ) ),
-    m_aDefaultImageHC( DialogHelper::getResId( RID_IMG_EXTENSION_HC ) ),
     m_pScrollBar( NULL ),
     m_pManager( pManager )
 {
@@ -334,7 +331,7 @@ void ExtensionBox_Impl::select( sal_Int32 nIndex )
 {
     const ::osl::MutexGuard aGuard( m_entriesMutex );
     checkIndex( nIndex );
-    selectEntry( nIndex );   
+    selectEntry( nIndex );
 }
 
 //------------------------------------------------------------------------------
@@ -354,7 +351,6 @@ void ExtensionBox_Impl::select( const rtl::OUString & sName )
     }
 }
 
-//------------------------------------------------------------------------------
 //------------------------------------------------------------------------------
 // Title + description
 void ExtensionBox_Impl::CalcActiveHeight( const long nPos )
@@ -455,10 +451,10 @@ void ExtensionBox_Impl::DeleteRemoved()
 void ExtensionBox_Impl::selectEntry( const long nPos )
 {
     //ToDo whe should not use the guard at such a big scope here.
-    //Currently it is used to gard m_vEntries and m_nActive. m_nActive will be 
+    //Currently it is used to gard m_vEntries and m_nActive. m_nActive will be
     //modified in this function.
     //It would be probably best to always use a copy of m_vEntries
-    //and some other state variables from ExtensionBox_Impl for 
+    //and some other state variables from ExtensionBox_Impl for
     //the whole painting operation. See issue i86993
     ::osl::ClearableMutexGuard guard(m_entriesMutex);
 
@@ -531,9 +527,9 @@ void ExtensionBox_Impl::DrawRow( const Rectangle& rRect, const TEntry_Impl pEntr
     aPos += Point( TOP_OFFSET, TOP_OFFSET );
     Image aImage;
     if ( ! pEntry->m_aIcon )
-        aImage = isHCMode() ? m_aDefaultImageHC : m_aDefaultImage;
+        aImage = m_aDefaultImage;
     else
-        aImage = isHCMode() ? pEntry->m_aIconHC : pEntry->m_aIcon;
+        aImage = pEntry->m_aIcon;
     Size aImageSize = aImage.GetSizePixel();
     if ( ( aImageSize.Width() <= ICON_WIDTH ) && ( aImageSize.Height() <= ICON_HEIGHT ) )
         DrawImage( Point( aPos.X()+((ICON_WIDTH-aImageSize.Width())/2), aPos.Y()+((ICON_HEIGHT-aImageSize.Height())/2) ), aImage );
@@ -639,16 +635,16 @@ void ExtensionBox_Impl::DrawRow( const Rectangle& rRect, const TEntry_Impl pEntr
     {
         aPos = rRect.TopRight() + Point( -(RIGHT_ICON_OFFSET + SMALL_ICON_SIZE), TOP_OFFSET );
         if ( pEntry->m_bLocked )
-            DrawImage( aPos, Size( SMALL_ICON_SIZE, SMALL_ICON_SIZE ), isHCMode() ? m_aLockedImageHC : m_aLockedImage );
+            DrawImage( aPos, Size( SMALL_ICON_SIZE, SMALL_ICON_SIZE ), m_aLockedImage );
         else
-            DrawImage( aPos, Size( SMALL_ICON_SIZE, SMALL_ICON_SIZE ), isHCMode() ? m_aSharedImageHC : m_aSharedImage );
+            DrawImage( aPos, Size( SMALL_ICON_SIZE, SMALL_ICON_SIZE ), m_aSharedImage );
     }
     if ( ( pEntry->m_eState == AMBIGUOUS ) || pEntry->m_bMissingDeps || pEntry->m_bMissingLic )
     {
         aPos = rRect.TopRight() + Point( -(RIGHT_ICON_OFFSET + SPACE_BETWEEN + 2*SMALL_ICON_SIZE), TOP_OFFSET );
-        DrawImage( aPos, Size( SMALL_ICON_SIZE, SMALL_ICON_SIZE ), isHCMode() ? m_aWarningImageHC : m_aWarningImage );
+        DrawImage( aPos, Size( SMALL_ICON_SIZE, SMALL_ICON_SIZE ), m_aWarningImage );
     }
-    
+
     SetLineColor( Color( COL_LIGHTGRAY ) );
     DrawLine( rRect.BottomLeft(), rRect.BottomRight() );
 }
@@ -711,7 +707,7 @@ bool ExtensionBox_Impl::HandleTabKey( bool )
 }
 
 // -----------------------------------------------------------------------
-bool ExtensionBox_Impl::HandleCursorKey( USHORT nKeyCode )
+bool ExtensionBox_Impl::HandleCursorKey( sal_uInt16 nKeyCode )
 {
     if ( m_vEntries.empty() )
         return true;
@@ -876,7 +872,7 @@ long ExtensionBox_Impl::Notify( NotifyEvent& rNEvt )
     {
         const KeyEvent* pKEvt = rNEvt.GetKeyEvent();
         KeyCode         aKeyCode = pKEvt->GetKeyCode();
-        USHORT          nKeyCode = aKeyCode.GetCode();
+        sal_uInt16          nKeyCode = aKeyCode.GetCode();
 
         if ( nKeyCode == KEY_TAB )
             bHandled = HandleTabKey( aKeyCode.IsShift() );
@@ -989,7 +985,7 @@ long ExtensionBox_Impl::addEntry( const uno::Reference< deployment::XPackage > &
         }
         else if ( !m_bInCheckMode )
         {
-            OSL_ENSURE( 0, "ExtensionBox_Impl::addEntry(): Will not add duplicate entries"  );
+            OSL_FAIL( "ExtensionBox_Impl::addEntry(): Will not add duplicate entries"  );
         }
     }
 
@@ -1062,7 +1058,7 @@ void ExtensionBox_Impl::removeEntry( const uno::Reference< deployment::XPackage
                 long nPos = iIndex - m_vEntries.begin();
 
                 // Entries mustn't removed here, because they contain a hyperlink control
-                // which can only be deleted when the thread has the solar mutex. Therefor 
+                // which can only be deleted when the thread has the solar mutex. Therefor
                 // the entry will be moved into the m_vRemovedEntries list which will be
                 // cleared on the next paint event
                 m_vRemovedEntries.push_back( *iIndex );
@@ -1154,7 +1150,7 @@ void ExtensionBox_Impl::checkEntries()
                     nNewPos = nPos;
                 if ( nPos <= m_nActive )
                     m_nActive += 1;
-                iIndex++;
+                ++iIndex;
             }
             else
             {   // remove entry from list
@@ -1168,7 +1164,7 @@ void ExtensionBox_Impl::checkEntries()
             }
         }
         else
-            iIndex++;
+            ++iIndex;
     }
     guard.clear();
 
@@ -1184,11 +1180,6 @@ void ExtensionBox_Impl::checkEntries()
             Invalidate();
     }
 }
-//------------------------------------------------------------------------------
-bool ExtensionBox_Impl::isHCMode()
-{
-    return (bool)GetSettings().GetStyleSettings().GetHighContrastMode();
-}
 
 //------------------------------------------------------------------------------
 void ExtensionBox_Impl::SetScrollHdl( const Link& rLink )
