@@ -111,17 +111,17 @@ namespace dbp
         if (!xColumnFactory.is() || !xColumnContainer.is())
             return;
 
-        static const ::rtl::OUString s_sDataFieldProperty	= ::rtl::OUString::createFromAscii("DataField");
-        static const ::rtl::OUString s_sLabelProperty		= ::rtl::OUString::createFromAscii("Label");
-        static const ::rtl::OUString s_sWidthProperty		= ::rtl::OUString::createFromAscii("Width");
-        static const ::rtl::OUString s_sMouseWheelBehavior  = ::rtl::OUString::createFromAscii("MouseWheelBehavior");
+        static const ::rtl::OUString s_sDataFieldProperty	(RTL_CONSTASCII_USTRINGPARAM("DataField"));
+        static const ::rtl::OUString s_sLabelProperty		(RTL_CONSTASCII_USTRINGPARAM("Label"));
+        static const ::rtl::OUString s_sWidthProperty		(RTL_CONSTASCII_USTRINGPARAM("Width"));
+        static const ::rtl::OUString s_sMouseWheelBehavior (RTL_CONSTASCII_USTRINGPARAM("MouseWheelBehavior"));
         static const ::rtl::OUString s_sEmptyString;
 
         // collect "descriptors" for the to-be-created (grid)columns
-        DECLARE_STL_VECTOR( ::rtl::OUString, StringArray );
-        StringArray aColumnServiceNames;	// service names to be used with the XGridColumnFactory
-        StringArray aColumnLabelPostfixes;	// postfixes to append to the column labels
-        StringArray aFormFieldNames;		// data field names
+        DECLARE_STL_VECTOR( ::rtl::OUString, OUStringArray );
+        OUStringArray aColumnServiceNames;	// service names to be used with the XGridColumnFactory
+        OUStringArray aColumnLabelPostfixes;	// postfixes to append to the column labels
+        OUStringArray aFormFieldNames;		// data field names
 
         aColumnServiceNames.reserve(getSettings().aSelectedFields.getLength());
         aColumnLabelPostfixes.reserve(getSettings().aSelectedFields.getLength());
@@ -143,14 +143,14 @@ namespace dbp
             {
                 case DataType::BIT:
                 case DataType::BOOLEAN:
-                    aColumnServiceNames.push_back(::rtl::OUString::createFromAscii("CheckBox"));
+                    aColumnServiceNames.push_back(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("CheckBox")));
                     aColumnLabelPostfixes.push_back(s_sEmptyString);
                     break;
 
                 case DataType::TINYINT:
                 case DataType::SMALLINT:
                 case DataType::INTEGER:
-                    aColumnServiceNames.push_back(::rtl::OUString::createFromAscii("NumericField"));
+                    aColumnServiceNames.push_back(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("NumericField")));
                     aColumnLabelPostfixes.push_back(s_sEmptyString);
                     break;
 
@@ -159,31 +159,31 @@ namespace dbp
                 case DataType::DOUBLE:
                 case DataType::NUMERIC:
                 case DataType::DECIMAL:
-                    aColumnServiceNames.push_back(::rtl::OUString::createFromAscii("FormattedField"));
+                    aColumnServiceNames.push_back(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("FormattedField")));
                     aColumnLabelPostfixes.push_back(s_sEmptyString);
                     break;
 
                 case DataType::DATE:
-                    aColumnServiceNames.push_back(::rtl::OUString::createFromAscii("DateField"));
+                    aColumnServiceNames.push_back(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("DateField")));
                     aColumnLabelPostfixes.push_back(s_sEmptyString);
                     break;
 
                 case DataType::TIME:
-                    aColumnServiceNames.push_back(::rtl::OUString::createFromAscii("TimeField"));
+                    aColumnServiceNames.push_back(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("TimeField")));
                     aColumnLabelPostfixes.push_back(s_sEmptyString);
                     break;
 
                 case DataType::TIMESTAMP:
-                    aColumnServiceNames.push_back(::rtl::OUString::createFromAscii("DateField"));
+                    aColumnServiceNames.push_back(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("DateField")));
                     aColumnLabelPostfixes.push_back(String(ModuleRes(RID_STR_DATEPOSTFIX)));
 
                     aFormFieldNames.push_back(*pSelectedFields);
-                    aColumnServiceNames.push_back(::rtl::OUString::createFromAscii("TimeField"));
+                    aColumnServiceNames.push_back(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("TimeField")));
                     aColumnLabelPostfixes.push_back(String(ModuleRes(RID_STR_TIMEPOSTFIX)));
                     break;
 
                 default:
-                    aColumnServiceNames.push_back(::rtl::OUString::createFromAscii("TextField"));
+                    aColumnServiceNames.push_back(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("TextField")));
                     aColumnLabelPostfixes.push_back(s_sEmptyString);
             }
         }
@@ -196,10 +196,10 @@ namespace dbp
         {
             Reference< XNameAccess > xExistenceChecker(xColumnContainer.get());
 
-            ConstStringArrayIterator pColumnServiceName = aColumnServiceNames.begin();
-            ConstStringArrayIterator pColumnLabelPostfix = aColumnLabelPostfixes.begin();
-            ConstStringArrayIterator pFormFieldName = aFormFieldNames.begin();
-            ConstStringArrayIterator pColumnServiceNameEnd = aColumnServiceNames.end();
+            ConstOUStringArrayIterator pColumnServiceName = aColumnServiceNames.begin();
+            ConstOUStringArrayIterator pColumnLabelPostfix = aColumnLabelPostfixes.begin();
+            ConstOUStringArrayIterator pFormFieldName = aFormFieldNames.begin();
+            ConstOUStringArrayIterator pColumnServiceNameEnd = aColumnServiceNames.end();
 
             for (;pColumnServiceName < pColumnServiceNameEnd; ++pColumnServiceName, ++pColumnLabelPostfix, ++pFormFieldName)
             {
@@ -227,9 +227,9 @@ namespace dbp
                 }
                 catch(Exception&)
                 {
-                    DBG_ERROR(	::rtl::OString("OGridWizard::implApplySettings: unexpected exception while creating the grid column for field ")
-                            +=	::rtl::OString(pFormFieldName->getStr(), pFormFieldName->getLength(), gsl_getSystemTextEncoding())
-                            +=	::rtl::OString("!"));
+                    OSL_FAIL( ( ::rtl::OString("OGridWizard::implApplySettings: unexpected exception while creating the grid column for field ")
+                            += ::rtl::OString(pFormFieldName->getStr(), pFormFieldName->getLength(), gsl_getSystemTextEncoding())
+                            += ::rtl::OString("!") ).getStr() );
                 }
             }
         }
@@ -373,12 +373,12 @@ namespace dbp
             return sal_False;
 
         OGridSettings& rSettings = getSettings();
-        USHORT nSelected = m_aSelFields.GetEntryCount();
+        sal_uInt16 nSelected = m_aSelFields.GetEntryCount();
 
         rSettings.aSelectedFields.realloc(nSelected);
         ::rtl::OUString* pSelected = rSettings.aSelectedFields.getArray();
 
-        for (USHORT i=0; i<nSelected; ++i, ++pSelected)
+        for (sal_uInt16 i=0; i<nSelected; ++i, ++pSelected)
             *pSelected = m_aSelFields.GetEntry(i);
 
         return sal_True;
@@ -420,11 +420,11 @@ namespace dbp
         ListBox& rMoveTo = bMoveRight ? m_aSelFields : m_aExistFields;
 
         // the index of the selected entry
-        USHORT nSelected = bMoveRight ? m_aExistFields.GetSelectEntryPos() : m_aSelFields.GetSelectEntryPos();
+        sal_uInt16 nSelected = bMoveRight ? m_aExistFields.GetSelectEntryPos() : m_aSelFields.GetSelectEntryPos();
         // the (original) relative position of the entry
         sal_IntPtr nRelativeIndex = reinterpret_cast<sal_IntPtr>(bMoveRight ? m_aExistFields.GetEntryData(nSelected) : m_aSelFields.GetEntryData(nSelected));
 
-        USHORT nInsertPos = LISTBOX_APPEND;
+        sal_uInt16 nInsertPos = LISTBOX_APPEND;
         if (!bMoveRight)
         {	// need to determine an insert pos which reflects the original
             nInsertPos = 0;
@@ -447,7 +447,7 @@ namespace dbp
         // remove the entry from it's old list
         if (bMoveRight)
         {
-            USHORT nSelectPos = m_aExistFields.GetSelectEntryPos();
+            sal_uInt16 nSelectPos = m_aExistFields.GetSelectEntryPos();
             m_aExistFields.RemoveEntry(nSelected);
             if ((LISTBOX_ENTRY_NOTFOUND != nSelectPos) && (nSelectPos < m_aExistFields.GetEntryCount()))
                 m_aExistFields.SelectEntryPos(nSelectPos);
@@ -456,7 +456,7 @@ namespace dbp
         }
         else
         {
-            USHORT nSelectPos = m_aSelFields.GetSelectEntryPos();
+            sal_uInt16 nSelectPos = m_aSelFields.GetSelectEntryPos();
             m_aSelFields.RemoveEntry(nSelected);
             if ((LISTBOX_ENTRY_NOTFOUND != nSelectPos) && (nSelectPos < m_aSelFields.GetEntryCount()))
                 m_aSelFields.SelectEntryPos(nSelectPos);
