@@ -375,7 +375,7 @@ namespace pcr
         ::osl::MutexGuard aGuard( m_aMutex );
 
         if (_rxFrame.is() && haveView())
-            throw RuntimeException(::rtl::OUString::createFromAscii("Unable to attach to a second frame."),*this);
+            throw RuntimeException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Unable to attach to a second frame.")),*this);
 
         // revoke as focus listener from the old container window
         stopContainerWindowListening();
@@ -391,7 +391,7 @@ namespace pcr
         VCLXWindow*	pContainerWindow = VCLXWindow::GetImplementation(xContainerWindow);
         Window* pParentWin = pContainerWindow ? pContainerWindow->GetWindow() : NULL;
         if (!pParentWin)
-            throw RuntimeException(::rtl::OUString::createFromAscii("The frame is invalid. Unable to extract the container window."),*this);
+            throw RuntimeException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("The frame is invalid. Unable to extract the container window.")),*this);
 
         if ( Construct( pParentWin ) )
         {
@@ -401,7 +401,7 @@ namespace pcr
             }
             catch( const Exception& )
             {
-                OSL_ENSURE( sal_False, "OPropertyBrowserController::attachFrame: caught an exception!" );
+                OSL_FAIL( "OPropertyBrowserController::attachFrame: caught an exception!" );
             }
         }
 
@@ -470,7 +470,7 @@ namespace pcr
             }
             catch( const Exception& )
             {
-                OSL_ENSURE( sal_False, "OPropertyBrowserController::suspendPropertyHandlers_nothrow: caught an exception!" );
+                OSL_FAIL( "OPropertyBrowserController::suspendPropertyHandlers_nothrow: caught an exception!" );
             }
         }
         return sal_True;
@@ -597,14 +597,14 @@ namespace pcr
     //------------------------------------------------------------------------
     ::rtl::OUString OPropertyBrowserController::getImplementationName_static(  ) throw(RuntimeException)
     {
-        return ::rtl::OUString::createFromAscii("org.openoffice.comp.extensions.ObjectInspector");
+        return ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("org.openoffice.comp.extensions.ObjectInspector"));
     }
 
     //------------------------------------------------------------------------
     Sequence< ::rtl::OUString > OPropertyBrowserController::getSupportedServiceNames_static(  ) throw(RuntimeException)
     {
         Sequence< ::rtl::OUString > aSupported(1);
-        aSupported[0] = ::rtl::OUString::createFromAscii( "com.sun.star.inspection.ObjectInspector" );
+        aSupported[0] = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.inspection.ObjectInspector"));
         return aSupported;
     }
 
@@ -748,7 +748,7 @@ namespace pcr
     {
         if ( _rEvent.Source == m_xModel )
         {
-            if ( _rEvent.PropertyName.equalsAscii( "IsReadOnly" ) )
+            if ( _rEvent.PropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "IsReadOnly" ) ) )
                 impl_updateReadOnlyView_nothrow();
             return;
         }
@@ -990,7 +990,7 @@ namespace pcr
 
         catch(Exception&)
         {
-            DBG_ERROR("OPropertyBrowserController::impl_rebindToInspectee_nothrow: caught an exception !");
+            OSL_FAIL("OPropertyBrowserController::impl_rebindToInspectee_nothrow: caught an exception !");
         }
     }
 
@@ -1121,7 +1121,7 @@ namespace pcr
         }
         catch(Exception&)
         {
-            DBG_ERROR("OPropertyBrowserController::doInspection : caught an exception !");
+            OSL_FAIL("OPropertyBrowserController::doInspection : caught an exception !");
         }
     }
 
@@ -1192,7 +1192,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "OPropertyBrowserController::describePropertyLine: caught an exception!" );
+            OSL_FAIL( "OPropertyBrowserController::describePropertyLine: caught an exception!" );
         }
     }
 
@@ -1257,7 +1257,7 @@ namespace pcr
                     ::rtl::OString sMessage( "OPropertyBrowserController::UpdateUI: empty category provided for property '" );
                     sMessage += ::rtl::OString( property->second.Name.getStr(), property->second.Name.getLength(), osl_getThreadTextEncoding() );
                     sMessage += "'!";
-                    OSL_ENSURE( false, sMessage );
+                    OSL_FAIL( sMessage );
                 }
             #endif
                 // finally insert this property control
@@ -1267,7 +1267,7 @@ namespace pcr
                     // this category does not yet exist. This is allowed, as an inspector model might be lazy, and not provide
                     // any category information of its own. In this case, we have a fallback ...
                     m_aPageIds[ aDescriptor.Category ] =
-                        getPropertyBox().AppendPage( aDescriptor.Category, SmartId() );
+                    getPropertyBox().AppendPage( aDescriptor.Category, rtl::OString() );
                     nTargetPageId = impl_getPageIdForCategory_nothrow( aDescriptor.Category );
                 }
 
@@ -1365,7 +1365,7 @@ namespace pcr
                 // also okay, we expect that the handler has disabled the UI as necessary
                 break;
             default:
-                OSL_ENSURE( false, "OPropertyBrowserController::Clicked: unknown result value!" );
+                OSL_FAIL( "OPropertyBrowserController::Clicked: unknown result value!" );
                 break;
             }
         }
@@ -1441,7 +1441,7 @@ namespace pcr
         }
         catch(Exception&)
         {
-            DBG_ERROR("OPropertyBrowserController::Commit : caught an exception !");
+            OSL_FAIL("OPropertyBrowserController::Commit : caught an exception !");
         }
 
         m_sCommittingProperty = ::rtl::OUString();
@@ -1590,7 +1590,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "OPropertyBrowserController::rebuildPropertyUI: caught an exception!" );
+            OSL_FAIL( "OPropertyBrowserController::rebuildPropertyUI: caught an exception!" );
         }
 
         getPropertyBox().ChangeEntry( aDescriptor );
