@@ -579,9 +579,9 @@ const CCIHuffmanTableEntry CCIUncompTableSave[CCIUncompTableSize]={
 //=========================================================================
 
 
-CCIDecompressor::CCIDecompressor( ULONG nOpts, UINT32 nImageWidth ) :
-    bTableBad	( FALSE ),
-    bStatus		( FALSE ),
+CCIDecompressor::CCIDecompressor( sal_uLong nOpts, sal_uInt32 nImageWidth ) :
+    bTableBad	( sal_False ),
+    bStatus		( sal_False ),
     pByteSwap	( NULL ),
     nWidth		( nImageWidth ),
     nOptions	( nOpts ),
@@ -589,10 +589,10 @@ CCIDecompressor::CCIDecompressor( ULONG nOpts, UINT32 nImageWidth ) :
 {
     if ( nOpts & CCI_OPTION_INVERSEBITORDER )
     {
-        pByteSwap = new BYTE[ 256 ];
+        pByteSwap = new sal_uInt8[ 256 ];
         for ( int i = 0; i < 256; i++ )
         {
-            pByteSwap[ i ] = sal::static_int_cast< BYTE >(
+            pByteSwap[ i ] = sal::static_int_cast< sal_uInt8 >(
                 ( i << 7 ) | ( ( i & 2 ) << 5 ) | ( ( i & 4 ) << 3 ) | ( ( i & 8 ) << 1 ) |
                 ( ( i & 16 ) >> 1 ) | ( ( i & 32 ) >> 3 ) | ( ( i & 64 ) >> 5 ) | ( ( i & 128 ) >> 7 ));
         }
@@ -625,26 +625,26 @@ void CCIDecompressor::StartDecompression( SvStream & rIStream )
 {
     pIStream = &rIStream;
     nInputBitsBufSize = 0;
-    bFirstEOL = TRUE;
-    bStatus = TRUE;
+    bFirstEOL = sal_True;
+    bStatus = sal_True;
     nEOLCount = 0;
 
-    if ( bTableBad == TRUE )
+    if ( bTableBad == sal_True )
         return;
 }
 
 
-BOOL CCIDecompressor::DecompressScanline( BYTE * pTarget, ULONG nTargetBits )
+sal_Bool CCIDecompressor::DecompressScanline( sal_uInt8 * pTarget, sal_uLong nTargetBits )
 {
-    USHORT i;
-    BYTE * pSrc,* pDst;
-    BOOL b2D;
+    sal_uInt16 i;
+    sal_uInt8 * pSrc,* pDst;
+    sal_Bool b2D;
 
     if ( nEOLCount >= 5 )	// RTC( Return To Controller )
-        return TRUE;
+        return sal_True;
 
-    if ( bStatus == FALSE )
-        return FALSE;
+    if ( bStatus == sal_False )
+        return sal_False;
 
     // Wenn EOL-Codes vorhanden sind, steht der EOL-Code auch vor der ersten Zeile.
     // (und ich dachte EOL heisst 'End Of Line'...)
@@ -653,21 +653,21 @@ BOOL CCIDecompressor::DecompressScanline( BYTE * pTarget, ULONG nTargetBits )
     {
         if ( bFirstEOL )
         {
-            UINT32 nCurPos = pIStream->Tell();
-            UINT16 nOldInputBitsBufSize = nInputBitsBufSize;
-            UINT32 nOldInputBitsBuf = nInputBitsBuf;
-            if ( ReadEOL( 32 ) == FALSE )
+            sal_uInt32 nCurPos = pIStream->Tell();
+            sal_uInt16 nOldInputBitsBufSize = nInputBitsBufSize;
+            sal_uInt32 nOldInputBitsBuf = nInputBitsBuf;
+            if ( ReadEOL( 32 ) == sal_False )
             {
                 nInputBitsBufSize = nOldInputBitsBufSize;
                 nInputBitsBuf = nOldInputBitsBuf;
                 pIStream->Seek( nCurPos );
                 nOptions &=~ CCI_OPTION_EOL;				// CCITT Group 3 - Compression Type 2
             }
-            bFirstEOL = FALSE;
+            bFirstEOL = sal_False;
         }
         else
         {
-            if ( ReadEOL( nTargetBits ) == FALSE )
+            if ( ReadEOL( nTargetBits ) == sal_False )
             {
                 return bStatus;
             }
@@ -675,7 +675,7 @@ BOOL CCIDecompressor::DecompressScanline( BYTE * pTarget, ULONG nTargetBits )
     }
 
     if ( nEOLCount >= 5 )	// RTC( Return To Controller )
-        return TRUE;
+        return sal_True;
 
     // ggf. eine weisse vorherige Zeile herstellen fuer 2D:
     if ( nOptions & CCI_OPTION_2D )
@@ -685,7 +685,7 @@ BOOL CCIDecompressor::DecompressScanline( BYTE * pTarget, ULONG nTargetBits )
             if ( pLastLine == NULL )
                 delete[] pLastLine;
             nLastLineSize = ( nTargetBits + 7 ) >> 3;
-            pLastLine = new BYTE[ nLastLineSize ];
+            pLastLine = new sal_uInt8[ nLastLineSize ];
             pDst = pLastLine;
             for ( i = 0; i < nLastLineSize; i++ ) *( pDst++ ) = 0x00;
         }
@@ -700,19 +700,19 @@ BOOL CCIDecompressor::DecompressScanline( BYTE * pTarget, ULONG nTargetBits )
         if ( nOptions & CCI_OPTION_EOL )
             b2D = Read2DTag();
         else
-            b2D = TRUE;
+            b2D = sal_True;
     }
     else
-        b2D = FALSE;
+        b2D = sal_False;
 
     // Zeile einlesen:
     if ( b2D )
-        Read2DScanlineData( pTarget, (USHORT)nTargetBits );
+        Read2DScanlineData( pTarget, (sal_uInt16)nTargetBits );
     else
-        Read1DScanlineData( pTarget, (USHORT)nTargetBits );
+        Read1DScanlineData( pTarget, (sal_uInt16)nTargetBits );
 
     // Wenn wir im 2D-Modus sind, muessen wir uns die Zeile merken:
-    if ( nOptions & CCI_OPTION_2D && bStatus == TRUE )
+    if ( nOptions & CCI_OPTION_2D && bStatus == sal_True )
     {
         pSrc = pTarget;
         pDst = pLastLine;
@@ -720,7 +720,7 @@ BOOL CCIDecompressor::DecompressScanline( BYTE * pTarget, ULONG nTargetBits )
     }
 
     if ( pIStream->GetError() )
-        bStatus = FALSE;
+        bStatus = sal_False;
 
     return bStatus;
 }
@@ -729,12 +729,12 @@ BOOL CCIDecompressor::DecompressScanline( BYTE * pTarget, ULONG nTargetBits )
 void CCIDecompressor::MakeLookUp(const CCIHuffmanTableEntry * pHufTab,
                                  const CCIHuffmanTableEntry * pHufTabSave,
                                  CCILookUpTableEntry * pLookUp,
-                                 USHORT nHuffmanTableSize,
-                                 USHORT nMaxCodeBits)
+                                 sal_uInt16 nHuffmanTableSize,
+                                 sal_uInt16 nMaxCodeBits)
 {
-    USHORT i,j,nMinCode,nMaxCode,nLookUpSize,nMask;
+    sal_uInt16 i,j,nMinCode,nMaxCode,nLookUpSize,nMask;
 
-    if (bTableBad==TRUE) return;
+    if (bTableBad==sal_True) return;
 
     nLookUpSize=1<<nMaxCodeBits;
 
@@ -748,14 +748,14 @@ void CCIDecompressor::MakeLookUp(const CCIHuffmanTableEntry * pHufTab,
              pHufTab[i].nCodeBits==0 ||
              pHufTab[i].nCodeBits>nMaxCodeBits )
         {
-            bTableBad=TRUE;
+            bTableBad=sal_True;
             return;
         }
         nMinCode = nMask & (pHufTab[i].nCode << (nMaxCodeBits-pHufTab[i].nCodeBits));
         nMaxCode = nMinCode | (nMask >> pHufTab[i].nCodeBits);
         for (j=nMinCode; j<=nMaxCode; j++) {
             if (pLookUp[j].nCodeBits!=0) {
-                bTableBad=TRUE;
+                bTableBad=sal_True;
                 return;
             }
             pLookUp[j].nValue=pHufTab[i].nValue;
@@ -765,10 +765,10 @@ void CCIDecompressor::MakeLookUp(const CCIHuffmanTableEntry * pHufTab,
 }
 
 
-BOOL CCIDecompressor::ReadEOL( UINT32 /*nMaxFillBits*/ )
+sal_Bool CCIDecompressor::ReadEOL( sal_uInt32 /*nMaxFillBits*/ )
 {
-    USHORT	nCode;
-    BYTE	nByte;
+    sal_uInt16	nCode;
+    sal_uInt8	nByte;
 
     // if (nOptions&CCI_OPTION_BYTEALIGNEOL) nMaxFillBits=7; else nMaxFillBits=0;
     // Buuuh: Entweder wird die Option in itiff.cxx nicht richtig gesetzt (-> Fehler in Doku)
@@ -778,7 +778,7 @@ BOOL CCIDecompressor::ReadEOL( UINT32 /*nMaxFillBits*/ )
     // bis zu 32-Bloedsinn-Bits vor dem EOL-Code:
     // und ich habe eine Datei gefunden in der bis zu ??? Bloedsinn Bits stehen, zudem ist dort die Bit Reihenfolge verdreht (SJ);
 
-    UINT32 nMaxPos = pIStream->Tell();
+    sal_uInt32 nMaxPos = pIStream->Tell();
     nMaxPos += nWidth >> 3;
 
     for ( ;; )
@@ -787,16 +787,16 @@ BOOL CCIDecompressor::ReadEOL( UINT32 /*nMaxFillBits*/ )
         {
             *pIStream >> nByte;
             if ( pIStream->IsEof() )
-                return FALSE;
+                return sal_False;
             if ( pIStream->Tell() > nMaxPos )
-                return FALSE;
+                return sal_False;
 
             if ( nOptions & CCI_OPTION_INVERSEBITORDER )
                 nByte = pByteSwap[ nByte ];
-            nInputBitsBuf=(nInputBitsBuf<<8) | (ULONG)nByte;
+            nInputBitsBuf=(nInputBitsBuf<<8) | (sal_uLong)nByte;
             nInputBitsBufSize += 8;
         }
-        nCode = (USHORT)( ( nInputBitsBuf >> ( nInputBitsBufSize - 12 ) ) & 0x0fff );
+        nCode = (sal_uInt16)( ( nInputBitsBuf >> ( nInputBitsBufSize - 12 ) ) & 0x0fff );
         if ( nCode == 0x0001 )
         {
             nEOLCount++;
@@ -806,38 +806,38 @@ BOOL CCIDecompressor::ReadEOL( UINT32 /*nMaxFillBits*/ )
         else
             nInputBitsBufSize--;
     }
-    return TRUE;
+    return sal_True;
 }
 
 
-BOOL CCIDecompressor::Read2DTag()
+sal_Bool CCIDecompressor::Read2DTag()
 {
-    BYTE nByte;
+    sal_uInt8 nByte;
 
-    // Ein Bit einlesen und TRUE liefern, wenn es 0 ist, sonst FALSE
+    // Ein Bit einlesen und sal_True liefern, wenn es 0 ist, sonst sal_False
     if (nInputBitsBufSize==0) {
         *pIStream >> nByte;
         if ( nOptions & CCI_OPTION_INVERSEBITORDER )
             nByte = pByteSwap[ nByte ];
-        nInputBitsBuf=(ULONG)nByte;
+        nInputBitsBuf=(sal_uLong)nByte;
         nInputBitsBufSize=8;
     }
     nInputBitsBufSize--;
-    if ( ((nInputBitsBuf>>nInputBitsBufSize)&0x0001) ) return FALSE;
-    else return TRUE;
+    if ( ((nInputBitsBuf>>nInputBitsBufSize)&0x0001) ) return sal_False;
+    else return sal_True;
 }
 
 
-BYTE CCIDecompressor::ReadBlackOrWhite()
+sal_uInt8 CCIDecompressor::ReadBlackOrWhite()
 {
-    BYTE nByte;
+    sal_uInt8 nByte;
 
     // Ein Bit einlesen und 0x00 liefern, wenn es 0 ist, sonst 0xff
     if (nInputBitsBufSize==0) {
         *pIStream >> nByte;
         if ( nOptions & CCI_OPTION_INVERSEBITORDER )
             nByte = pByteSwap[ nByte ];
-        nInputBitsBuf=(ULONG)nByte;
+        nInputBitsBuf=(sal_uLong)nByte;
         nInputBitsBufSize=8;
     }
     nInputBitsBufSize--;
@@ -846,32 +846,32 @@ BYTE CCIDecompressor::ReadBlackOrWhite()
 }
 
 
-USHORT CCIDecompressor::ReadCodeAndDecode(const CCILookUpTableEntry * pLookUp,
-                                          USHORT nMaxCodeBits)
+sal_uInt16 CCIDecompressor::ReadCodeAndDecode(const CCILookUpTableEntry * pLookUp,
+                                          sal_uInt16 nMaxCodeBits)
 {
-    USHORT nCode,nCodeBits;
-    BYTE nByte;
+    sal_uInt16 nCode,nCodeBits;
+    sal_uInt8 nByte;
 
     // Einen Huffman-Code einlesen und dekodieren:
     while (nInputBitsBufSize<nMaxCodeBits) {
         *pIStream >> nByte;
         if ( nOptions  & CCI_OPTION_INVERSEBITORDER )
             nByte = pByteSwap[ nByte ];
-        nInputBitsBuf=(nInputBitsBuf<<8) | (ULONG)nByte;
+        nInputBitsBuf=(nInputBitsBuf<<8) | (sal_uLong)nByte;
         nInputBitsBufSize+=8;
     }
-    nCode=(USHORT)((nInputBitsBuf>>(nInputBitsBufSize-nMaxCodeBits))
+    nCode=(sal_uInt16)((nInputBitsBuf>>(nInputBitsBufSize-nMaxCodeBits))
                    &(0xffff>>(16-nMaxCodeBits)));
     nCodeBits=pLookUp[nCode].nCodeBits;
-    if (nCodeBits==0) bStatus=FALSE;
+    if (nCodeBits==0) bStatus=sal_False;
     nInputBitsBufSize = nInputBitsBufSize - nCodeBits;
     return pLookUp[nCode].nValue;
 }
 
 
-void CCIDecompressor::FillBits(BYTE * pTarget, USHORT nTargetBits,
-                               USHORT nBitPos, USHORT nNumBits,
-                               BYTE nBlackOrWhite)
+void CCIDecompressor::FillBits(sal_uInt8 * pTarget, sal_uInt16 nTargetBits,
+                               sal_uInt16 nBitPos, sal_uInt16 nNumBits,
+                               sal_uInt8 nBlackOrWhite)
 {
     if ( nBitPos >= nTargetBits )
         return;
@@ -894,11 +894,11 @@ void CCIDecompressor::FillBits(BYTE * pTarget, USHORT nTargetBits,
 }
 
 
-USHORT CCIDecompressor::CountBits(const BYTE * pData, USHORT nDataSizeBits,
-                                  USHORT nBitPos, BYTE nBlackOrWhite)
+sal_uInt16 CCIDecompressor::CountBits(const sal_uInt8 * pData, sal_uInt16 nDataSizeBits,
+                                  sal_uInt16 nBitPos, sal_uInt8 nBlackOrWhite)
 {
-    USHORT nPos,nLo;
-    BYTE nData;
+    sal_uInt16 nPos,nLo;
+    sal_uInt8 nData;
 
     // Hier wird die Anzahl der zusammenhaengenden Bits gezaehlt, die
     // ab Position nBitPos in pTarget alle die Farbe nBlackOrWhite
@@ -923,12 +923,12 @@ USHORT CCIDecompressor::CountBits(const BYTE * pData, USHORT nDataSizeBits,
 }
 
 
-void CCIDecompressor::Read1DScanlineData(BYTE * pTarget, USHORT nTargetBits)
+void CCIDecompressor::Read1DScanlineData(sal_uInt8 * pTarget, sal_uInt16 nTargetBits)
 {
-    USHORT nCode,nCodeBits,nDataBits,nTgtFreeByteBits;
-    BYTE nByte;
-    BYTE nBlackOrWhite; // ist 0xff fuer Black oder 0x00 fuer White
-    BOOL bTerminatingCode;
+    sal_uInt16 nCode,nCodeBits,nDataBits,nTgtFreeByteBits;
+    sal_uInt8 nByte;
+    sal_uInt8 nBlackOrWhite; // ist 0xff fuer Black oder 0x00 fuer White
+    sal_Bool bTerminatingCode;
 
     // Der erste Code ist immer eine "White-Code":
     nBlackOrWhite=0x00;
@@ -945,10 +945,10 @@ void CCIDecompressor::Read1DScanlineData(BYTE * pTarget, USHORT nTargetBits)
             *pIStream >> nByte;
             if ( nOptions & CCI_OPTION_INVERSEBITORDER )
                 nByte = pByteSwap[ nByte ];
-            nInputBitsBuf=(nInputBitsBuf<<8) | (ULONG)nByte;
+            nInputBitsBuf=(nInputBitsBuf<<8) | (sal_uLong)nByte;
             nInputBitsBufSize+=8;
         }
-        nCode=(USHORT)((nInputBitsBuf>>(nInputBitsBufSize-13))&0x1fff);
+        nCode=(sal_uInt16)((nInputBitsBuf>>(nInputBitsBufSize-13))&0x1fff);
 
         // Anzahl der DatenBits und Anzahl der CodeBits ermitteln:
         if (nBlackOrWhite) {
@@ -977,7 +977,7 @@ void CCIDecompressor::Read1DScanlineData(BYTE * pTarget, USHORT nTargetBits)
         }
 
         // Ist es ein 'Terminating-Code' ?
-        if (nDataBits<64) bTerminatingCode=TRUE; else bTerminatingCode=FALSE;
+        if (nDataBits<64) bTerminatingCode=sal_True; else bTerminatingCode=sal_False;
 
         // Die gelesenen Bits aus dem Eingabe-Buffer entfernen:
         nInputBitsBufSize = nInputBitsBufSize - nCodeBits;
@@ -1010,25 +1010,25 @@ void CCIDecompressor::Read1DScanlineData(BYTE * pTarget, USHORT nTargetBits)
         }
 
         // ggf. Umschaltung Black <-> White:
-        if (bTerminatingCode==TRUE) nBlackOrWhite=~nBlackOrWhite;
+        if (bTerminatingCode==sal_True) nBlackOrWhite=~nBlackOrWhite;
 
-    } while (nTargetBits>0 || bTerminatingCode==FALSE);
+    } while (nTargetBits>0 || bTerminatingCode==sal_False);
 }
 
 
 
-void CCIDecompressor::Read2DScanlineData(BYTE * pTarget, USHORT nTargetBits)
+void CCIDecompressor::Read2DScanlineData(sal_uInt8 * pTarget, sal_uInt16 nTargetBits)
 {
-    USHORT n2DMode,nBitPos,nUncomp,nRun,nRun2,nt;
-    BYTE nBlackOrWhite;
+    sal_uInt16 n2DMode,nBitPos,nUncomp,nRun,nRun2,nt;
+    sal_uInt8 nBlackOrWhite;
 
     nBlackOrWhite=0x00;
     nBitPos=0;
 
-    while (nBitPos<nTargetBits && bStatus==TRUE) {
+    while (nBitPos<nTargetBits && bStatus==sal_True) {
 
         n2DMode=ReadCodeAndDecode(p2DModeLookUp,10);
-        if (bStatus==FALSE) return;
+        if (bStatus==sal_False) return;
 
         if (n2DMode==CCI2DMODE_UNCOMP) {
             for (;;) {
