@@ -38,6 +38,8 @@
 
 #include "properties.h"
 
+#include "helper/mischelper.hxx"
+
 //_________________________________________________________________________________________________________________
 //	interface includes
 //_________________________________________________________________________________________________________________
@@ -62,7 +64,6 @@
 //_________________________________________________________________________________________________________________
 //	Defines
 //_________________________________________________________________________________________________________________
-//
 
 using namespace com::sun::star::uno;
 using namespace com::sun::star::lang;
@@ -73,7 +74,6 @@ using namespace ::com::sun::star::frame;
 //_________________________________________________________________________________________________________________
 //	Namespace
 //_________________________________________________________________________________________________________________
-//
 
 struct ModuleToCommands
 {
@@ -143,6 +143,8 @@ class ConfigurationAccess_UICommand : // Order is neccessary for right initializ
         virtual void SAL_CALL disposing( const EventObject& aEvent ) throw(RuntimeException);
 
     protected:
+        virtual ::com::sun::star::uno::Any SAL_CALL getByNameImpl( const ::rtl::OUString& aName );
+
         struct CmdToInfoMap
         {
             CmdToInfoMap() : bPopup( false ),
@@ -170,7 +172,7 @@ class ConfigurationAccess_UICommand : // Order is neccessary for right initializ
                                                 std::vector< ::rtl::OUString >& aImageMirrorVector);
 
     private:
-        typedef ::std::hash_map< ::rtl::OUString,
+        typedef ::boost::unordered_map< ::rtl::OUString,
                                  CmdToInfoMap,
                                  OUStringHashCode,
                                  ::std::equal_to< ::rtl::OUString > > CommandToInfoCache;
@@ -193,9 +195,10 @@ class ConfigurationAccess_UICommand : // Order is neccessary for right initializ
         Reference< XNameAccess >          m_xGenericUICommands;
         Reference< XMultiServiceFactory > m_xServiceManager;
         Reference< XMultiServiceFactory > m_xConfigProvider;
-        //Reference< XMultiServiceFactory > m_xConfigProviderPopups;
         Reference< XNameAccess >          m_xConfigAccess;
+        Reference< XContainerListener >   m_xConfigListener;
         Reference< XNameAccess >          m_xConfigAccessPopups;
+        Reference< XContainerListener >   m_xConfigAccessListener;
         Sequence< rtl::OUString >         m_aCommandImageList;
         Sequence< rtl::OUString >         m_aCommandRotateImageList;
         Sequence< rtl::OUString >         m_aCommandMirrorImageList;
@@ -233,7 +236,6 @@ ConfigurationAccess_UICommand::ConfigurationAccess_UICommand( const rtl::OUStrin
 
     m_aConfigPopupAccess += aModuleName;
     m_aConfigPopupAccess += rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( CONFIGURATION_POP_ELEMENT_ACCESS ));
-    //m_xConfigProviderPopups = Reference< XMultiServiceFactory >( rServiceManager->createInstance(SERVICENAME_CFGPROVIDER),UNO_QUERY );
 
     rtl::OUString aTmp;
     ::utl::ConfigManager::GetDirectConfigProperty( ::utl::ConfigManager::PRODUCTNAME ) >>= aTmp;
@@ -246,15 +248,15 @@ ConfigurationAccess_UICommand::~ConfigurationAccess_UICommand()
     ResetableGuard aLock( m_aLock );
     Reference< XContainer > xContainer( m_xConfigAccess, UNO_QUERY );
     if ( xContainer.is() )
-        xContainer->removeContainerListener( this );
+        xContainer->removeContainerListener(m_xConfigListener);
     xContainer = Reference< XContainer >( m_xConfigAccessPopups, UNO_QUERY );
     if ( xContainer.is() )
-        xContainer->removeContainerListener( this );
+        xContainer->removeContainerListener(m_xConfigAccessListener);
 }
 
+
 // XNameAccess
-Any SAL_CALL ConfigurationAccess_UICommand::getByName( const ::rtl::OUString& rCommandURL )
-throw ( NoSuchElementException, WrappedTargetException, RuntimeException)
+Any SAL_CALL ConfigurationAccess_UICommand::getByNameImpl( const ::rtl::OUString& rCommandURL )
 {
     static sal_Int32 nRequests  = 0;
 
@@ -279,21 +281,26 @@ throw ( NoSuchElementException, WrappedTargetException, RuntimeException)
         else if ( rCommandURL.equalsIgnoreAsciiCaseAscii( UICOMMANDDESCRIPTION_NAMEACCESS_COMMANDMIRRORIMAGELIST ))
             return makeAny( m_aCommandMirrorImageList );
         else
-            throw NoSuchElementException();
+            return Any();
     }
     else
     {
         // SAFE
         ++nRequests;
-        Any a = getInfoFromCommand( rCommandURL );
-
-        if ( !a.hasValue() )
-            throw NoSuchElementException();
-
-        return a;
+        return getInfoFromCommand( rCommandURL );
     }
 }
 
+Any SAL_CALL ConfigurationAccess_UICommand::getByName( const ::rtl::OUString& rCommandURL )
+throw ( NoSuchElementException, WrappedTargetException, RuntimeException)
+{
+    Any aRet( getByNameImpl( rCommandURL ) );
+    if( !aRet.hasValue() )
+        throw NoSuchElementException();
+
+    return aRet;
+}
+
 Sequence< ::rtl::OUString > SAL_CALL ConfigurationAccess_UICommand::getElementNames()
 throw ( RuntimeException )
 {
@@ -303,7 +310,7 @@ throw ( RuntimeException )
 sal_Bool SAL_CALL ConfigurationAccess_UICommand::hasByName( const ::rtl::OUString& rCommandURL )
 throw (::com::sun::star::uno::RuntimeException)
 {
-    return getByName( rCommandURL ).hasValue();
+    return getByNameImpl( rCommandURL ).hasValue();
 }
 
 // XElementAccess
@@ -394,7 +401,7 @@ void ConfigurationAccess_UICommand::impl_fill(const Reference< XNameAccess >& _x
             {
             }
         }
-    } // if ( m_xConfigAccessPopups.is() )
+    }
 }
 sal_Bool ConfigurationAccess_UICommand::fillCache()
 {
@@ -469,7 +476,7 @@ Any ConfigurationAccess_UICommand::getInfoFromCommand( const rtl::OUString& rCom
         {
             // First try to ask our global commands configuration access. It also caches maybe
             // we find the entry in its cache first.
-            if ( m_xGenericUICommands.is() )
+            if ( m_xGenericUICommands.is() && m_xGenericUICommands->hasByName( rCommandURL ) )
             {
                 try
                 {
@@ -558,7 +565,10 @@ sal_Bool ConfigurationAccess_UICommand::initializeConfigAccess()
             // Add as container listener
             Reference< XContainer > xContainer( m_xConfigAccess, UNO_QUERY );
             if ( xContainer.is() )
-                xContainer->addContainerListener( this );
+            {
+                m_xConfigListener = new WeakContainerListener(this);
+                xContainer->addContainerListener(m_xConfigListener);
+            }
         }
 
         aPropValue.Value <<= m_aConfigPopupAccess;
@@ -569,7 +579,10 @@ sal_Bool ConfigurationAccess_UICommand::initializeConfigAccess()
             // Add as container listener
             Reference< XContainer > xContainer( m_xConfigAccessPopups, UNO_QUERY );
             if ( xContainer.is() )
-                xContainer->addContainerListener( this );
+            {
+                m_xConfigAccessListener = new WeakContainerListener(this);
+                xContainer->addContainerListener(m_xConfigAccessListener);
+            }
         }
 
         return sal_True;
@@ -643,7 +656,7 @@ UICommandDescription::UICommandDescription( const Reference< XMultiServiceFactor
 {
     RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "framework", "Ocke.Janssen@sun.com", "UICommandDescription::UICommandDescription" );
     Reference< XNameAccess > xEmpty;
-    rtl::OUString aGenericUICommand( ::rtl::OUString::createFromAscii( "GenericCommands" ));
+    rtl::OUString aGenericUICommand( RTL_CONSTASCII_USTRINGPARAM("GenericCommands") );
     m_xGenericUICommands = new ConfigurationAccess_UICommand( aGenericUICommand, xEmpty, xServiceManager );
 
     impl_fillElements("ooSetupFactoryCommandConfigRef");
