@@ -27,46 +27,40 @@
  ************************************************************************/
 
 #include "oox/xls/numberformatsbuffer.hxx"
+
 #include <com/sun/star/container/XNameAccess.hpp>
-#include <com/sun/star/lang/XMultiServiceFactory.hpp>
-#include <com/sun/star/util/XNumberFormatsSupplier.hpp>
-#include <com/sun/star/util/XNumberFormats.hpp>
-#include <com/sun/star/util/XNumberFormatTypes.hpp>
 #include <com/sun/star/i18n/NumberFormatIndex.hpp>
-#include <osl/thread.h>
-#include <rtl/string.hxx>
+#include <com/sun/star/lang/XMultiServiceFactory.hpp>
+#include <com/sun/star/util/XNumberFormatTypes.hpp>
+#include <com/sun/star/util/XNumberFormats.hpp>
+#include <com/sun/star/util/XNumberFormatsSupplier.hpp>
 #include <rtl/strbuf.hxx>
+#include <rtl/string.hxx>
+#include <osl/thread.h>
 #include <rtl/ustrbuf.hxx>
-#include "properties.hxx"
+#include "oox/core/filterbase.hxx"
 #include "oox/helper/attributelist.hxx"
 #include "oox/helper/propertymap.hxx"
-#include "oox/helper/recordinputstream.hxx"
-#include "oox/core/filterbase.hxx"
 #include "oox/xls/biffinputstream.hxx"
 
-using ::rtl::OString;
-using ::rtl::OStringBuffer;
-using ::rtl::OUString;
-using ::rtl::OUStringBuffer;
-using ::rtl::OStringToOUString;
-using ::com::sun::star::uno::Any;
-using ::com::sun::star::uno::Reference;
-using ::com::sun::star::uno::Sequence;
-using ::com::sun::star::uno::Exception;
-using ::com::sun::star::uno::UNO_QUERY;
-using ::com::sun::star::uno::UNO_QUERY_THROW;
-using ::com::sun::star::container::XNameAccess;
-using ::com::sun::star::lang::Locale;
-using ::com::sun::star::lang::XMultiServiceFactory;
-using ::com::sun::star::util::XNumberFormatsSupplier;
-using ::com::sun::star::util::XNumberFormats;
-using ::com::sun::star::util::XNumberFormatTypes;
-
 namespace oox {
 namespace xls {
 
 // ============================================================================
 
+using namespace ::com::sun::star::container;
+using namespace ::com::sun::star::lang;
+using namespace ::com::sun::star::uno;
+using namespace ::com::sun::star::util;
+
+using ::rtl::OString;
+using ::rtl::OStringBuffer;
+using ::rtl::OStringToOUString;
+using ::rtl::OUString;
+using ::rtl::OUStringBuffer;
+
+// ============================================================================
+
 namespace {
 
 /** Stores the number format used in Calc for an Excel built-in number format. */
@@ -1840,8 +1834,7 @@ sal_Int32 lclCreatePredefinedFormat( const Reference< XNumberFormats >& rxNumFmt
     }
     catch( Exception& )
     {
-        OSL_ENSURE( false,
-            OStringBuffer( "lclCreatePredefinedFormat - cannot create predefined number format " ).
+        OSL_FAIL( OStringBuffer( "lclCreatePredefinedFormat - cannot create predefined number format " ).
             append( OString::valueOf( static_cast< sal_Int32 >( nPredefId ) ) ).getStr() );
     }
     return nIndex;
@@ -1865,8 +1858,7 @@ sal_Int32 lclCreateFormat( const Reference< XNumberFormats >& rxNumFmts,
         }
         else
         {
-            OSL_ENSURE( false,
-                OStringBuffer( "lclCreateFormat - cannot create number format '" ).
+            OSL_FAIL( OStringBuffer( "lclCreateFormat - cannot create number format '" ).
                 append( OUStringToOString( rFmtCode, osl_getThreadTextEncoding() ) ).
                 append( '\'' ).getStr() );
         }
@@ -1978,7 +1970,7 @@ NumberFormatsBuffer::NumberFormatsBuffer( const WorkbookHelper& rHelper ) :
     }
     catch( Exception& )
     {
-        OSL_ENSURE( false, "NumberFormatsBuffer::NumberFormatsBuffer - cannot get system locale" );
+        OSL_FAIL( "NumberFormatsBuffer::NumberFormatsBuffer - cannot get system locale" );
     }
 
     // create built-in formats for current locale
@@ -2004,10 +1996,10 @@ NumberFormatRef NumberFormatsBuffer::importNumFmt( const AttributeList& rAttribs
     return createNumFmt( nNumFmtId, aFmtCode );
 }
 
-void NumberFormatsBuffer::importNumFmt( RecordInputStream& rStrm )
+void NumberFormatsBuffer::importNumFmt( SequenceInputStream& rStrm )
 {
     sal_Int32 nNumFmtId = rStrm.readuInt16();
-    OUString aFmtCode = rStrm.readString();
+    OUString aFmtCode = BiffHelper::readString( rStrm );
     createNumFmt( nNumFmtId, aFmtCode );
 }
 
