@@ -216,7 +216,8 @@ FileHandle_Impl::Allocator::~Allocator()
 void FileHandle_Impl::Allocator::allocate (sal_uInt8 ** ppBuffer, size_t * pnSize)
 {
     OSL_PRECOND((0 != ppBuffer) && (0 != pnSize), "FileHandle_Impl::Allocator::allocate(): contract violation");
-    *ppBuffer = static_cast< sal_uInt8* >(rtl_cache_alloc(m_cache)), *pnSize = m_bufsiz;
+    if ((0 != ppBuffer) && (0 != pnSize))
+        *ppBuffer = static_cast< sal_uInt8* >(rtl_cache_alloc(m_cache)), *pnSize = m_bufsiz;
 }
 void FileHandle_Impl::Allocator::deallocate (sal_uInt8 * pBuffer)
 {
@@ -273,7 +274,7 @@ void FileHandle_Impl::operator delete (void * p, size_t)
 size_t FileHandle_Impl::getpagesize()
 {
 #if defined(FREEBSD) || defined(NETBSD) || defined(MACOSX) || \
-	defined(OPENBSD)
+    defined(OPENBSD) || defined(DRAGONFLY)
     return sal::static_int_cast< size_t >(::getpagesize());
 #else /* POSIX */
     return sal::static_int_cast< size_t >(::sysconf(_SC_PAGESIZE));
