@@ -51,9 +51,10 @@
 
 #include <osl/thread.hxx>
 
-// using namespace osl;
-using namespace rtl;
-
+using ::rtl::OUString;
+using ::rtl::OUStringBuffer;
+using ::rtl::OUStringToOString;
+using ::rtl::OString;
 #define TESTSHL2_INI "testshl2"
 #define PSEUDO_INI   "pseudo"
 
@@ -62,7 +63,7 @@ using namespace rtl;
 inline void printUString( const ::rtl::OUString & str, const sal_Char * msg = "" )
 {
 
-    if (strlen(msg) > 0)
+    if (msg && msg[0] != 0)
     {
         t_print("%s: ", msg );
     }
@@ -77,7 +78,7 @@ bool t_fileExist(rtl::OUString const& _sFilename)
 {
     ::osl::FileBase::RC   nError1;
     ::osl::File aTestFile( _sFilename );
-    nError1 = aTestFile.open ( OpenFlag_Read );
+    nError1 = aTestFile.open ( osl_File_OpenFlag_Read );
     if ( ( ::osl::FileBase::E_NOENT != nError1 ) && ( ::osl::FileBase::E_ACCES != nError1 ) )
     {
         aTestFile.close( );
@@ -95,7 +96,7 @@ inline ::rtl::OUString getModulePath( void )
 
     suDirPath = suDirPath.copy( 0, suDirPath.lastIndexOf('/') );
     suDirPath = suDirPath.copy( 0, suDirPath.lastIndexOf('/') + 1);
-    suDirPath += rtl::OUString::createFromAscii("bin");
+    suDirPath += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("bin"));
     return suDirPath;
 }
 
@@ -122,32 +123,14 @@ inline rtl::OUString t_getSourcePath(rtl::OString const& _sFilename)
 {
 
      rtl::OUString aDirURL(getExecutableDirectory());
-     aDirURL += OUString::createFromAscii( "/");
+     aDirURL += OUString(RTL_CONSTASCII_USTRINGPARAM("/"));
      aDirURL += OUString::createFromAscii( _sFilename.getStr() );
 #if defined(WNT) || defined(OS2)
-    aDirURL += rtl::OUString::createFromAscii(".ini");
+    aDirURL += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(".ini"));
 #else
-    aDirURL += rtl::OUString::createFromAscii("rc");
+    aDirURL += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("rc"));
 #endif
     return aDirURL;
-
-// LLA: does not right work on my personal laptop, SRC_ROOT does not show where the source is :-(.
-/*
-  sal_Char *  pStr = getenv("SRC_ROOT");
-  rtl::OUString suPath;
-  if (filename != "")
-  {
-  suPath = rtl::OUString::createFromAscii(pStr) + rtl::OUString::createFromAscii( "/sal/qa/rtl/bootstrap/" )
-  + rtl::OUString::createFromAscii( filename );
-  }
-  else
-  {
-  suPath = rtl::OUString::createFromAscii(pStr) + rtl::OUString::createFromAscii( "/sal/qa/rtl/bootstrap" );
-  }
-  rtl::OUString suURL;
-  ::osl::FileBase::getFileURLFromSystemPath( suPath, suURL );
-  return suURL;
-*/
 }
 
 void thread_sleep_tenth_sec(sal_Int32 _nTenthSec)
@@ -185,7 +168,7 @@ namespace rtl_Bootstrap
                 rtl::OUString suIniname = t_getSourcePath(TESTSHL2_INI);
                 printUString( suIniname );
                 Bootstrap aBootstrap( suIniname );
-                rtl::OUString suGetname; // = rtl::OUString::createFromAscii("");
+                rtl::OUString suGetname; // = rtl::OUString();
                 aBootstrap.getIniName( suGetname );
                 printUString( suGetname );
 
@@ -230,7 +213,7 @@ namespace rtl_Bootstrap
             {
                 Bootstrap aBootstrap;
                 rtl::OUString suValue;
-                rtl::OUString suValuename = rtl::OUString::createFromAscii( "SOLAR_JAVA" );
+                rtl::OUString suValuename (RTL_CONSTASCII_USTRINGPARAM("SOLAR_JAVA"));
                 //aBootstrap.getFrom( suValuename, suValue );
                 aBootstrap.getFrom( suValuename, suValue );
                 sal_Char *  pStr = getenv("SOLAR_JAVA");
@@ -242,7 +225,7 @@ namespace rtl_Bootstrap
            {
            Bootstrap aBootstrap;
            rtl::OUString suValue;
-           rtl::OUString suValuename = rtl::OUString::createFromAscii( "SRC_ROOT" );
+           rtl::OUString suValuename (RTL_CONSTASCII_USTRINGPARAM("SRC_ROOT"));
            //aBootstrap.getFrom( suValuename, suValue );
            aBootstrap.getFrom( suValuename, suValue );
            sal_Char *  pStr = getenv("SRC_ROOT");
@@ -263,7 +246,7 @@ namespace rtl_Bootstrap
                 rtl::OUString suIniname = t_getSourcePath(TESTSHL2_INI);
                 Bootstrap aBootstrap( suIniname );
                 rtl::OUString suGetname;
-                rtl::OUString suValuename = rtl::OUString::createFromAscii( "INHERITED_VALUE" );
+                rtl::OUString suValuename (RTL_CONSTASCII_USTRINGPARAM("INHERITED_VALUE"));
                 aBootstrap.getFrom( suValuename, suGetname );
                 printUString( suGetname );
                 CPPUNIT_ASSERT_MESSAGE("get the value of a variable in ini file.", suGetname.getLength() != 0 );
@@ -275,10 +258,9 @@ namespace rtl_Bootstrap
                 rtl::OUString suIniname = t_getSourcePath(TESTSHL2_INI);
                 Bootstrap aBootstrap( suIniname );
                 rtl::OUString suGetname;
-                rtl::OUString suValuename = rtl::OUString::createFromAscii( "MY_VALUE" );
-                rtl::OUString myDefault = rtl::OUString::createFromAscii( "2" );
+                rtl::OUString suValuename(RTL_CONSTASCII_USTRINGPARAM("MY_VALUE"));
+                rtl::OUString myDefault(RTL_CONSTASCII_USTRINGPARAM("2"));
                 aBootstrap.getFrom( suValuename, suGetname, myDefault );
-                //printUString( suGetname );
                 CPPUNIT_ASSERT_MESSAGE("getFrom use default.", suGetname.compareTo( myDefault ) == 0 );
             }
 
@@ -294,29 +276,26 @@ namespace rtl_Bootstrap
                 aBootstrap.getIniName( suGetIniName );
 
                 printUString(suGetIniName, "Current bootstrap file");
-                sal_Int32 nIndex = suGetIniName.indexOf(rtl::OUString::createFromAscii( "pseudo" ));
+                sal_Int32 nIndex = suGetIniName.indexOf(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("pseudo")));
                 CPPUNIT_ASSERT_MESSAGE("ini name must have 'pseudo' in name.", nIndex > 0);
 
-                // rtlBootstrapHandle bsHandle = aBootstrap.getHandle();
-                // CPPUNIT_ASSERT_MESSAGE("getHandle return NULL!", bsHandle != 0);
-
                 rtl::OUString suValue;
-                rtl::OUString suKeyName = rtl::OUString::createFromAscii( "FILE" );
+                rtl::OUString suKeyName(RTL_CONSTASCII_USTRINGPARAM("FILE"));
                 aBootstrap.getFrom( suKeyName, suValue );
                 printUString( suValue );
-                sal_Int32 nCompare = suValue.compareTo( rtl::OUString::createFromAscii("pseudo file") );
+                sal_Int32 nCompare = suValue.compareTo( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("pseudo file")) );
 
                 CPPUNIT_ASSERT_MESSAGE("<Bootstrap('pseudo')>.getFrom('FILE', ...) result is unexpected.",  nCompare == 0);
             }
         void getFrom_004_1()
             {
                 // get the same key out of the default context
-                rtl::OUString suKeyName = rtl::OUString::createFromAscii( "FILE" );
+                rtl::OUString suKeyName(RTL_CONSTASCII_USTRINGPARAM("FILE"));
                 rtl::OUString suGetValue;
                 Bootstrap::get( suKeyName, suGetValue );
                 printUString( suGetValue );
 
-                CPPUNIT_ASSERT_MESSAGE("Bootstrap::get('FILE', ...)", suGetValue.compareTo( rtl::OUString::createFromAscii("testshl2 file") ) == 0 );
+                CPPUNIT_ASSERT_MESSAGE("Bootstrap::get('FILE', ...)", suGetValue.compareTo( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("testshl2 file")) ) == 0 );
             }
 
     /** helper function: return the child process's ret value( typedef sal_uInt32 oslProcessExitCode;)
@@ -327,17 +306,16 @@ namespace rtl_Bootstrap
          rtl::OUString suCWD = getModulePath();
             oslProcess hProcess = NULL;
            rtl::OUString suFileURL = suCWD;
-            suFileURL += rtl::OUString::createFromAscii("/") +  rtl::OUString::createFromAscii(process_name) ;
+            suFileURL += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/")) +  rtl::OUString::createFromAscii(process_name) ;
 #if defined(WNT) || defined(OS2)
-        suFileURL += rtl::OUString::createFromAscii(".exe");
+        suFileURL += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(".exe"));
 #endif
             const int nParameterCount = 3;
             rtl_uString* pParameters[ nParameterCount ];
             OUString suFlag( OUString::createFromAscii(flag) );
-        OUString suEnv1( OUString::createFromAscii("-env:UNO_SERVICES=service.rdb"));
+        OUString suEnv1( RTL_CONSTASCII_USTRINGPARAM("-env:UNO_SERVICES=service.rdb") );
         OUString suIniname = t_getSourcePath("rtl");
         printUString( suIniname, "rtl path:");
-        //OUString suEnv2( OUString::createFromAscii("-env:MYENV=bootstrap_process"));
 
             pParameters[0] = suFlag.pData;
             pParameters[1] = suEnv1.pData;
@@ -452,7 +430,6 @@ namespace rtl_Bootstrap
                 rtl::OUString suGetIniname;
                 aBootstrap.getIniName( suGetIniname );
                 //which should be .....testshl2rc
-                //printUString( suGetIniname );
 
                 rtl::OUString suIniname = t_getSourcePath(PSEUDO_INI);
                 Bootstrap::setIniFilename( suIniname );
@@ -468,13 +445,10 @@ namespace rtl_Bootstrap
         void setIniFilename_002()
             {
                 rtl::OUString suIniname = t_getSourcePath(TESTSHL2_INI);
-                // CPPUNIT_ASSERT_MESSAGE("test failed, Bootstrap ini does not exist.", t_fileExist(suIniname ) == true);
 
                 Bootstrap::setIniFilename( suIniname );
-                //rtl_bootstrap_args_open( suIniname.pData );
                 rtl::OUString suGetname;
-                rtl::OUString suValuename = rtl::OUString::createFromAscii( "INHERITED_VALUE" );
-                //aBootstrap.getFrom( suValuename, suGetname  );
+                rtl::OUString suValuename(RTL_CONSTASCII_USTRINGPARAM("INHERITED_VALUE"));
                 Bootstrap::get( suValuename, suGetname  );
                 printUString( suGetname );
                 CPPUNIT_ASSERT_MESSAGE("setIniFilename and get value of the argument.", suGetname.getLength() != 0 );
@@ -513,18 +487,12 @@ namespace rtl_Bootstrap
                 rtlBootstrapHandle bsHandle = aBootstrap.getHandle();
                 CPPUNIT_ASSERT_MESSAGE("getHandle return NULL!", bsHandle != 0);
 
-                //rtl::OUString iniName;
-                //rtl_bootstrap_get_iniName_from_handle( bsHandle, &iniName.pData );
-
                 rtl::OUString suValue;
-                rtl::OUString suKeyName = rtl::OUString::createFromAscii( "PSEUDOFILE" );
+                rtl::OUString suKeyName(RTL_CONSTASCII_USTRINGPARAM("PSEUDOFILE"));
                 rtl_bootstrap_get_from_handle(bsHandle, suKeyName.pData, &suValue.pData, NULL);
                 printUString( suValue);
 
-                CPPUNIT_ASSERT_MESSAGE("Can not use the handle which is returned by getHandle!", suValue.equals( rtl::OUString::createFromAscii("be pseudo") ) == sal_True );
-
-                // CPPUNIT_ASSERT_MESSAGE("Can not use the handle which is returned by getHandle!",
-                //      suGetname.equalsIgnoreAsciiCase( iniName ) == sal_True );
+                CPPUNIT_ASSERT_MESSAGE("Can not use the handle which is returned by getHandle!", suValue.equals( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("be pseudo")) ) == sal_True );
             }
 
         CPPUNIT_TEST_SUITE(getHandle);
@@ -550,8 +518,8 @@ namespace rtl_Bootstrap
                 //in ini fle, INHERITED_VALUE=inherited_value
                 rtl::OUString suIniname = t_getSourcePath(TESTSHL2_INI);
                 Bootstrap aBootstrap( suIniname);
-                rtl::OUString suName = rtl::OUString::createFromAscii( "INHERITED_VALUE" );
-                rtl::OUString suValue = rtl::OUString::createFromAscii( "ok" );
+                rtl::OUString suName(RTL_CONSTASCII_USTRINGPARAM("INHERITED_VALUE"));
+                rtl::OUString suValue(RTL_CONSTASCII_USTRINGPARAM("ok"));
                 // set to another value
                 Bootstrap::set( suName, suValue );
                 rtl::OUString suGetValue;
@@ -562,13 +530,13 @@ namespace rtl_Bootstrap
             {
                 rtl::OUString suIniname = t_getSourcePath(TESTSHL2_INI);
                 Bootstrap myBootstrap( suIniname);
-                rtl::OUString suName = rtl::OUString::createFromAscii( "INHERITED_VALUE" );
+                rtl::OUString suName(RTL_CONSTASCII_USTRINGPARAM("INHERITED_VALUE"));
                 rtl::OUString suGetOrientValue;
                 Bootstrap::get( suName, suGetOrientValue);
                 // ??  INHERITED_VALUE = ok now, which is set in set_001
                 printUString( suGetOrientValue );
 
-                rtl::OUString suValue = rtl::OUString::createFromAscii( TESTSHL2_INI );
+                rtl::OUString suValue(RTL_CONSTASCII_USTRINGPARAM( TESTSHL2_INI ));
                 // set to another value
                 Bootstrap::set( suName, suValue );
                 rtl::OUString suGetValue;
@@ -596,12 +564,10 @@ namespace rtl_Bootstrap
             {
                 rtl::OUString suIniname = t_getSourcePath(TESTSHL2_INI);
                 Bootstrap aBootstrap( suIniname);
-                rtl::OUString suMacro = rtl::OUString::createFromAscii( "$MYVAR/expand1" );
-                //printUString( suMacro );
+                rtl::OUString suMacro(RTL_CONSTASCII_USTRINGPARAM("$MYVAR/expand1"));
                 //expandMacro now
                 aBootstrap.expandMacrosFrom( suMacro );
-                rtl::OUString suExpectedMacro = rtl::OUString::createFromAscii( "src680_test/expand1" );
-                //printUString( suMacro );
+                rtl::OUString suExpectedMacro(RTL_CONSTASCII_USTRINGPARAM("src680_test/expand1"));
                 CPPUNIT_ASSERT_MESSAGE("expandMacrosFrom failed.", suMacro.compareTo(suExpectedMacro) == 0 );
             }
 
@@ -619,27 +585,26 @@ namespace rtl_Bootstrap
                 t_print("inifile is:");
                 printUString( suIniname );
                 Bootstrap aBootstrap( suIniname) ;
-                  rtl::OUString suMacro = rtl::OUString::createFromAscii( "${" );         //rtlrc:Bootstrap:RTLVALUE}");
+                  rtl::OUString suMacro(RTL_CONSTASCII_USTRINGPARAM("${"));         //rtlrc:Bootstrap:RTLVALUE}");
 
-     rtl::OUString aDirURL = OUString::createFromAscii( "$ORIGIN");
-     aDirURL += OUString::createFromAscii( "/");
-     aDirURL += OUString::createFromAscii( "rtl" );
+     rtl::OUString aDirURL(RTL_CONSTASCII_USTRINGPARAM("$ORIGIN"));
+     aDirURL += OUString(RTL_CONSTASCII_USTRINGPARAM("/"));
+     aDirURL += OUString(RTL_CONSTASCII_USTRINGPARAM("rtl"));
 #if defined(WNT) || defined(OS2)
-    aDirURL += rtl::OUString::createFromAscii(".ini");
+    aDirURL += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(".ini"));
 #else
-    aDirURL += rtl::OUString::createFromAscii("rc");
+    aDirURL += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("rc"));
 #endif
 
                 suMacro += aDirURL;//t_getSourcePath("rtl");
-                suMacro += rtl::OUString::createFromAscii( "::RTLVALUE}");
+                suMacro += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("::RTLVALUE}"));
 
                 t_print("created macro is: ");
                 printUString( suMacro );
-                //expandMacro now
                 aBootstrap.expandMacrosFrom( suMacro );
                 t_print("expanded macro is:");
                 printUString( suMacro );
-                rtl::OUString suExpectedMacro = rtl::OUString::createFromAscii( "qadev17" );
+                rtl::OUString suExpectedMacro(RTL_CONSTASCII_USTRINGPARAM("qadev17"));
                 CPPUNIT_ASSERT_MESSAGE("failed, can't expand '${file:///.../" SAL_CONFIGFILE("rtl") "::RTLVALUE}' to 'qadev17'", suMacro.compareTo(suExpectedMacro) == 0 );
             }
         void expandMacrosFrom_002_1()
@@ -651,22 +616,19 @@ namespace rtl_Bootstrap
 
                 rtl::OUString suMacro;
                 // just a simple test, if this really work.
-                aBootstrap.getFrom(rtl::OUString::createFromAscii( "SOFROMVALUE2" ), suMacro );
+                aBootstrap.getFrom(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("SOFROMVALUE2")), suMacro );
                 t_print("SOFROMVALUE2:");
                 printUString( suMacro );
                 CPPUNIT_ASSERT_MESSAGE("'SOFROMVALUE2' seems to do not exist.", suMacro.getLength() > 0 );
 
-                aBootstrap.getFrom(rtl::OUString::createFromAscii( "SOFROMVALUE" ), suMacro );
+                aBootstrap.getFrom(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("SOFROMVALUE")), suMacro );
 
                 t_print("SOFROMVALUE:");
                 printUString( suMacro );
 
                 //expandMacro now
                 // seems to be, that getFrom() already expand the string
-                // t_print("expanded macro is:");
-                // aBootstrap.expandMacrosFrom( suMacro );
-                // printUString( suMacro );
-                rtl::OUString suExpectedMacro = rtl::OUString::createFromAscii( "src680_qadev" );
+                rtl::OUString suExpectedMacro(RTL_CONSTASCII_USTRINGPARAM("src680_qadev"));
                 CPPUNIT_ASSERT_MESSAGE("failed, can't expand '${" SAL_CONFIGFILE("rtl") "::SOVALUE}' to 'src680_qadev'", suMacro.compareTo(suExpectedMacro) == 0 );
             }
         void expandMacrosFrom_002_2()
@@ -680,67 +642,35 @@ namespace rtl_Bootstrap
                 Bootstrap aBootstrap( suIniname);
 
                 rtl::OUString suMacro;
-                aBootstrap.getFrom(rtl::OUString::createFromAscii( "SOFROMVALUE3" ), suMacro );
+                aBootstrap.getFrom(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("SOFROMVALUE3")), suMacro );
 
                 t_print("SOFROMVALUE3:");
                 printUString( suMacro );
 
-                if (suMacro.equals(rtl::OUString::createFromAscii("testshl2_file") ) == sal_True)
+                if (suMacro.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("testshl2_file")) ) == sal_True)
                 {
                     CPPUNIT_ASSERT_MESSAGE("Value 'SOFROMVALUE3' is read from the wrong ini file.", 0 );
                 }
                 else
                 {
-                    CPPUNIT_ASSERT_MESSAGE("SOFROMVALUE3 should contain 'rtlfile'.", suMacro.equals(rtl::OUString::createFromAscii("rtlfile") ) == sal_True );
+                    CPPUNIT_ASSERT_MESSAGE("SOFROMVALUE3 should contain 'rtlfile'.", suMacro.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("rtlfile")) ) == sal_True );
                 }
             }
-//? I don't know if this is a right test.
-//         void expandMacrosFrom_002_3()
-//             {
-//                 // test, to read and expand SOFROMVALUE4
-//                 // SOFROMVALUE4 is 'rtl(.ini|rc):Other_Section:TESTSHL_SOVALUE' which should expand to '' if all is ok.
-//
-//                 rtl::OUString suIniname = t_getSourcePath(TESTSHL2_INI);
-//                 t_print("inifile is:");
-//     	        printUString( suIniname );
-//                 Bootstrap aBootstrap( suIniname);
-//
-//                 rtl::OUString suMacro;
-//                 aBootstrap.getFrom(rtl::OUString::createFromAscii( "SOFROMVALUE4" ), suMacro );
-//
-//                 t_print("SOFROMVALUE4:");
-//                 printUString( suMacro );
-//
-//                 if (suMacro.equals(rtl::OUString::createFromAscii("testshl2_file") ) == sal_True)
-//                 {
-//                     CPPUNIT_ASSERT_MESSAGE("Value 'SOFROMVALUE4' is read from the wrong section out of the wrong ini file.", 0 );
-//                 }
-//                 else if (suMacro.equals(rtl::OUString::createFromAscii("testshl2_file_other") ) == sal_True)
-//                 {
-//                     CPPUNIT_ASSERT_MESSAGE("Value 'SOFROMVALUE4' is read from the wrong ini file.", 0 );
-//                 }
-//                 else
-//                 {
-//                     CPPUNIT_ASSERT_MESSAGE("Value 'SOFROMVALUE4' should contain 'rtlfile_other'.", suMacro.equals(rtl::OUString::createFromAscii("rtlfile_other") ) == sal_True );
-//                 }
-//             }
         void expandMacrosFrom_003()
             {
                 rtl::OUString suIniname = t_getSourcePath(TESTSHL2_INI);
                 Bootstrap aBootstrap( suIniname);
                 rtl::OUString suMacro[4];
-                suMacro[0] = rtl::OUString::createFromAscii( "$SYSUSERCONFIG" );
-                suMacro[1] = rtl::OUString::createFromAscii( "$SYSUSERHOME" );
-                suMacro[2] = rtl::OUString::createFromAscii( "$SYSBINDIR" );
-                suMacro[3] = rtl::OUString::createFromAscii( "$ORIGIN" );
+                suMacro[0] = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("$SYSUSERCONFIG"));
+                suMacro[1] = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("$SYSUSERHOME"));
+                suMacro[2] = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("$SYSBINDIR"));
+                suMacro[3] = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("$ORIGIN"));
 
                 for ( int i = 0; i < 4; i++ )
                 {
                     aBootstrap.expandMacrosFrom( suMacro[i] );
                     printUString(suMacro[i]);
                 }
-                // printUString( t_getSourcePath("") );
-                // CPPUNIT_ASSERT_MESSAGE("some integral variables.", suMacro[3].equalsIgnoreAsciiCase(t_getSourcePath("")) == sal_True );
                 CPPUNIT_ASSERT_MESSAGE("some integral variables.", suMacro[0].getLength() > 0 &&
                                        suMacro[1].getLength() > 0 &&
                                        suMacro[2].getLength() > 0 &&
@@ -818,7 +748,6 @@ namespace rtl_Bootstrap
         CPPUNIT_TEST(expandMacrosFrom_002);
         CPPUNIT_TEST(expandMacrosFrom_002_1);
         CPPUNIT_TEST(expandMacrosFrom_002_2);
-//?        CPPUNIT_TEST(expandMacrosFrom_002_3);
         CPPUNIT_TEST(expandMacrosFrom_003);
         CPPUNIT_TEST(testRecursion);
         CPPUNIT_TEST(testLink);
@@ -844,13 +773,13 @@ namespace rtl_Bootstrap
             {
                 rtl::OUString suIniname = t_getSourcePath(TESTSHL2_INI);
                 Bootstrap aBootstrap( suIniname) ;
-                rtl::OUString suMacro = rtl::OUString::createFromAscii( "$INHERITED_VALUE/well" );
+                rtl::OUString suMacro(RTL_CONSTASCII_USTRINGPARAM("$INHERITED_VALUE/well"));
                 Bootstrap::expandMacros( suMacro );
 
-        rtl::OUString suName = rtl::OUString::createFromAscii( "INHERITED_VALUE" );
+        rtl::OUString suName(RTL_CONSTASCII_USTRINGPARAM("INHERITED_VALUE"));
                 OUString suGetValue;
                 Bootstrap::get( suName, suGetValue );
-                suGetValue += OUString::createFromAscii( "/well" );
+                suGetValue += OUString(RTL_CONSTASCII_USTRINGPARAM("/well"));
                 CPPUNIT_ASSERT_MESSAGE("expandMacros failed.", suGetValue.compareTo(suMacro) == 0 );
             }
 
@@ -872,38 +801,17 @@ namespace rtl_Bootstrap
 
 // -----------------------------------------------------------------------------
 
-// this macro creates an empty function, which will called by the RegisterAllFunctions()
-// to let the user the possibility to also register some functions by hand.
-// NOADDITIONAL;
-
-
-// Here are some helpers, which create a new file 'rtlrc' at the executable path position
-// and fill the file with some information.
-// static rtl::OUString getExecutableDirectory()
-// {
-//     rtl::OUString fileName;
-//     osl_getExecutableFile(&fileName.pData);
-//
-//     sal_Int32 nDirEnd = fileName.lastIndexOf('/');
-//
-//     OSL_ENSURE(nDirEnd >= 0, "Cannot locate executable directory");
-//
-//     rtl::OUString aDirURL = fileName.copy(0, nDirEnd);
-//     return aDirURL;
-// }
-
 static void removeAndCreateFile(rtl::OUString const& _suFileURL, rtl::OString const& _sContent)
 {
     osl::File::remove(_suFileURL);
 
     ::std::auto_ptr<osl::File> pFile( new osl::File( _suFileURL ) );
-    ::osl::FileBase::RC nError = pFile->open( OpenFlag_Write | OpenFlag_Create );
+    ::osl::FileBase::RC nError = pFile->open( osl_File_OpenFlag_Write | osl_File_OpenFlag_Create );
     if ( ::osl::FileBase::E_None == nError || ::osl::FileBase::E_EXIST == nError )
     {
         t_print(T_VERBOSE, "%s\n" , OString(_suFileURL, _suFileURL.getLength(), RTL_TEXTENCODING_ASCII_US).getStr());
         sal_uInt64 nWritenBytes;
         pFile->write(_sContent.getStr(), _sContent.getLength(), nWritenBytes);
-        // t_print("nBytes: %ld\n", nBytes);
 
         rtl::OString sError = "can't write enough bytes to file";
         sError += OString(_suFileURL, _suFileURL.getLength(), RTL_TEXTENCODING_ASCII_US);
@@ -929,9 +837,9 @@ static void create_rtlrc()
 {
     rtl::OUString aFileURL(getExecutableDirectory());
 #if defined(WNT) || defined(OS2)
-    aFileURL += rtl::OUString::createFromAscii("/rtl.ini");
+    aFileURL += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/rtl.ini"));
 #else
-    aFileURL += rtl::OUString::createFromAscii("/rtlrc");
+    aFileURL += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/rtlrc"));
 #endif
 
     rtl::OString sLines;
@@ -952,9 +860,9 @@ static void create_testshl2rc()
 {
     rtl::OUString aFileURL(getExecutableDirectory());
 #if defined(WNT) || defined(OS2)
-    aFileURL += rtl::OUString::createFromAscii("/testshl2.ini");
+    aFileURL += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/testshl2.ini"));
 #else
-    aFileURL += rtl::OUString::createFromAscii("/testshl2rc");
+    aFileURL += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/testshl2rc"));
 #endif
     rtl::OString sLines;
     sLines += "[Bootstrap]\n";
@@ -967,7 +875,6 @@ static void create_testshl2rc()
     sLines += "SOFROMVALUE2=test\n";
     sLines += "SOFROMVALUE3=${$ORIGIN/" SAL_CONFIGFILE("rtl") "::TESTSHL_SOVALUE}\n";
     sLines += "TESTSHL_SOVALUE=testshl2_file\n";
-    //? sLines += "SOFROMVALUE4=${" SAL_CONFIGFILE("rtl") ":Other_Section:TESTSHL_SOVALUE}\n";
     sLines += "ILLEGAL VALUE=test\n";
     sLines += "ILLEGAL.DOT=test\n";
     sLines += "ILLEGAL;SEMICOLON=test\n";
@@ -978,7 +885,6 @@ static void create_testshl2rc()
     sLines += "[Other_Section]\n";
     sLines += "FILE=testshl2 file other\n";
     sLines += "EXPAND=$FILE\n";
-    //? sLines += "TESTSHL_SOVALUE=testshl2_file_other\n";
 
     removeAndCreateFile(aFileURL, sLines);
 
@@ -994,9 +900,9 @@ static void create_pseudorc()
 {
     rtl::OUString aFileURL(getExecutableDirectory());
 #if defined(WNT) || defined(OS2)
-    aFileURL += rtl::OUString::createFromAscii("/pseudo.ini");
+    aFileURL += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/pseudo.ini"));
 #else
-    aFileURL += rtl::OUString::createFromAscii("/pseudorc");
+    aFileURL += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/pseudorc"));
 #endif
     rtl::OString sLines;
     sLines += "[Bootstrap]\n";
@@ -1011,9 +917,9 @@ void create_bootstrap_processrc()
 {
     rtl::OUString aDirURL(getModulePath());
 #if defined(WNT) || defined(OS2)
-    aDirURL += rtl::OUString::createFromAscii("/bootstrap_process.ini");
+    aDirURL += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/bootstrap_process.ini"));
 #else
-    aDirURL += rtl::OUString::createFromAscii("/bootstrap_processrc");
+    aDirURL += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/bootstrap_processrc"));
 #endif
     rtl::OString sLines;
     sLines += "[Bootstrap]\n";
