@@ -54,8 +54,8 @@
 #include <com/sun/star/sheet/DataPilotFieldFilter.hpp>
 
 #include <vector>
-#include <hash_set>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
+#include <boost/unordered_set.hpp>
 
 using namespace ::com::sun::star;
 using ::com::sun::star::uno::Any;
@@ -67,13 +67,11 @@ using ::rtl::OUString;
 using ::rtl::OUStringHash;
 
 using ::std::vector;
-using ::std::hash_set;
-using ::std::hash_map;
 using ::boost::shared_ptr;
 
 #define D_TIMEFACTOR              86400.0
 
-const USHORT SC_DP_LEAPYEAR = 1648;     // arbitrary leap year for date calculations
+const sal_uInt16 SC_DP_LEAPYEAR = 1648;     // arbitrary leap year for date calculations
 
 // part values for the extra "<" and ">" entries (same for all parts)
 const sal_Int32 SC_DP_DATE_FIRST = -1;
@@ -82,10 +80,10 @@ const sal_Int32 SC_DP_DATE_LAST = 10000;
 // ============================================================================
 namespace 
 {  
-    BOOL lcl_Search( SCCOL nSourceDim, ScDPTableDataCache* pCache , const std::vector< SCROW >& vIdx, SCROW nNew , SCROW& rIndex)
+    sal_Bool lcl_Search( SCCOL nSourceDim, const ScDPCache* pCache , const std::vector< SCROW >& vIdx, SCROW nNew , SCROW& rIndex)
     {
         rIndex = vIdx.size();
-        BOOL bFound = FALSE;
+        sal_Bool bFound = false;
         SCROW nLo = 0;
         SCROW nHi = vIdx.size() - 1;
         SCROW nIndex;
@@ -105,7 +103,7 @@ namespace
                 nHi = nIndex - 1;
                 if (nCompare == 0)
                 {
-                    bFound = TRUE;
+                    bFound = sal_True;
                     nLo = nIndex;
                 }
             }
@@ -114,7 +112,7 @@ namespace
         return bFound;
     }
 
-    void  lcl_Insert( SCCOL nSourceDim, ScDPTableDataCache* pCache ,  std::vector< SCROW >& vIdx, SCROW nNew )
+    void  lcl_Insert( SCCOL nSourceDim, const ScDPCache* pCache ,  std::vector< SCROW >& vIdx, SCROW nNew )
     {
         SCROW nIndex = 0;                
         if ( !lcl_Search( nSourceDim, pCache, vIdx, nNew ,nIndex ) ) 
@@ -122,18 +120,18 @@ namespace
     }
 
     template<bool bUpdateData>
-    SCROW lcl_InsertValue( SCCOL nSourceDim, ScDPTableDataCache* pCache ,  std::vector< SCROW >& vIdx, const ScDPItemData & rData );
+    SCROW lcl_InsertValue(SCCOL nSourceDim, const ScDPCache* pCache, std::vector<SCROW>& vIdx, const ScDPItemData & rData);
 
     template<>
-    SCROW lcl_InsertValue<false>( SCCOL nSourceDim, ScDPTableDataCache* pCache ,  std::vector< SCROW >& vIdx, const ScDPItemData & rData )
+    SCROW lcl_InsertValue<false>(SCCOL nSourceDim, const ScDPCache* pCache, std::vector<SCROW>& vIdx, const ScDPItemData & rData)
     {
-        SCROW nNewID = pCache->GetAdditionalItemID( rData );
-        lcl_Insert( nSourceDim, pCache, vIdx, nNewID );
+        SCROW nNewID = pCache->GetAdditionalItemID(rData);
+        lcl_Insert(nSourceDim, pCache, vIdx, nNewID);
         return nNewID;
     }
 
     template<>
-    SCROW lcl_InsertValue<true>( SCCOL nSourceDim, ScDPTableDataCache* pCache ,  std::vector< SCROW >& vIdx, const ScDPItemData & rData )
+    SCROW lcl_InsertValue<true>(SCCOL nSourceDim, const ScDPCache* pCache, std::vector<SCROW>& vIdx, const ScDPItemData & rData)
     {
         SCROW nItemId = lcl_InsertValue<false>( nSourceDim, pCache, vIdx, rData );
 
@@ -144,20 +142,20 @@ namespace
     }
 
     template<bool bUpdateData>
-    void lcl_InsertValue ( SCCOL nSourceDim, ScDPTableDataCache* pCache ,  std::vector< SCROW >& vIdx, const String&  rString, const double& fValue )
+    void lcl_InsertValue ( SCCOL nSourceDim, const ScDPCache* pCache,  std::vector< SCROW >& vIdx, const String&  rString, const double& fValue )
     {
-        lcl_InsertValue<bUpdateData>( nSourceDim, pCache, vIdx, ScDPItemData( rString, fValue, TRUE ) );
+        lcl_InsertValue<bUpdateData>( nSourceDim, pCache, vIdx, ScDPItemData( rString, fValue, sal_True ) );
     }
 
     template<bool bUpdateData>
-    void lcl_InsertValue ( SCCOL nSourceDim, ScDPTableDataCache* pCache ,  std::vector< SCROW >& vIdx, const String&  rString, const double& fValue, sal_Int32 nDatePart )
+    void lcl_InsertValue ( SCCOL nSourceDim, const ScDPCache* pCache, std::vector< SCROW >& vIdx, const String&  rString, const double& fValue, sal_Int32 nDatePart )
     {
         lcl_InsertValue<bUpdateData>( nSourceDim, pCache, vIdx, ScDPItemData( nDatePart, rString, fValue, ScDPItemData::MK_DATA|ScDPItemData::MK_VAL|ScDPItemData::MK_DATEPART ) );
     }
 
     void lcl_AppendDateStr( rtl::OUStringBuffer& rBuffer, double fValue, SvNumberFormatter* pFormatter )
     {
-        ULONG nFormat = pFormatter->GetStandardFormat( NUMBERFORMAT_DATE, ScGlobal::eLnge );
+        sal_uLong nFormat = pFormatter->GetStandardFormat( NUMBERFORMAT_DATE, ScGlobal::eLnge );
         String aString;
         pFormatter->GetInputLineString( fValue, nFormat, aString );
         rBuffer.append( aString );
@@ -283,10 +281,7 @@ public:
     ScDPGroupDateFilter(double fMatchValue, sal_Int32 nDatePart, 
                         const Date* pNullDate, const ScDPNumGroupInfo* pNumInfo);
 
-    // Wang Xu Ming -- 2009-8-17
-    // DataPilot Migration - Cache&&Performance
     virtual bool match(const ScDPItemData & rCellData) const;
-    // End Comments
 
 private:
     ScDPGroupDateFilter(); // disabled
@@ -306,8 +301,7 @@ ScDPGroupDateFilter::ScDPGroupDateFilter(double fMatchValue, sal_Int32 nDatePart
     mfMatchValue(fMatchValue),
     mnDatePart(nDatePart)
 {
-//  fprintf(stdout, "ScDPCacheTable:DateGroupFilter::DateGroupFilter: match value = %g; date part = %ld\n",
-//          mfMatchValue, mnDatePart);
+
 }
 bool ScDPGroupDateFilter::match( const ScDPItemData & rCellData ) const
 {
@@ -317,7 +311,7 @@ bool ScDPGroupDateFilter::match( const ScDPItemData & rCellData ) const
 
     if ( !rCellData.IsValue() )
         return false;
-//	ScDPCacheCell rCell( rCellData.fValue );
+
     if (!mpNumInfo)
         return false;
 
@@ -360,7 +354,7 @@ bool ScDPGroupDateFilter::match( const ScDPItemData & rCellData ) const
                 return sec == matchSec;
             }
             default:
-                DBG_ERROR("invalid time part");
+                OSL_FAIL("invalid time part");
         }
         return false;
     }
@@ -399,7 +393,7 @@ bool ScDPGroupDateFilter::match( const ScDPItemData & rCellData ) const
             return days == matchDays;
         }
         default:
-            DBG_ERROR("invalid date part");
+            OSL_FAIL("invalid date part");
     }
 
     return false;
@@ -448,7 +442,7 @@ String lcl_GetDateGroupName( sal_Int32 nDatePart, sal_Int32 nValue, SvNumberForm
                 Date aNullDate = *(pFormatter->GetNullDate());
                 long nDays = aDate - aNullDate;
 
-                ULONG nFormat = pFormatter->GetFormatIndex( NF_DATE_SYS_DDMMM, ScGlobal::eLnge );
+                sal_uLong nFormat = pFormatter->GetFormatIndex( NF_DATE_SYS_DDMMM, ScGlobal::eLnge );
                 Color* pColor;
                 pFormatter->GetOutputString( nDays, nFormat, aRet, &pColor );
             }
@@ -463,7 +457,7 @@ String lcl_GetDateGroupName( sal_Int32 nDatePart, sal_Int32 nValue, SvNumberForm
             aRet.Append( lcl_GetTwoDigitString( nValue ) );
             break;
         default:
-            DBG_ERROR("invalid date part");
+            OSL_FAIL("invalid date part");
     }
     return aRet;
 }
@@ -533,14 +527,14 @@ sal_Int32 lcl_GetDatePartValue( double fValue, sal_Int32 nDatePart, SvNumberForm
                 }
                 break;
             default:
-                DBG_ERROR("invalid date part");
+                OSL_FAIL("invalid date part");
         }
     }
 
     return nResult;
 }
 
-BOOL lcl_DateContained( sal_Int32 nGroupPart, const ScDPItemData& rGroupData,
+sal_Bool lcl_DateContained( sal_Int32 nGroupPart, const ScDPItemData& rGroupData,
                         sal_Int32 nBasePart, const ScDPItemData& rBaseData )
 {
     if ( !rGroupData.IsValue() || !rBaseData.IsValue() )
@@ -550,11 +544,8 @@ BOOL lcl_DateContained( sal_Int32 nGroupPart, const ScDPItemData& rGroupData,
     }
 
     // no approxFloor needed, values were created from integers
-// Wang Xu Ming -- 2009-8-17
-// DataPilot Migration - Cache&&Performance
     sal_Int32 nGroupValue = (sal_Int32) rGroupData.GetValue();
     sal_Int32 nBaseValue = (sal_Int32) rBaseData.GetValue();
-// End Comments
     if ( nBasePart > nGroupPart )
     {
         // switch, so the base part is the smaller (inner) part
@@ -570,7 +561,7 @@ BOOL lcl_DateContained( sal_Int32 nGroupPart, const ScDPItemData& rGroupData,
         return ( nGroupValue == nBaseValue );
     }
 
-    BOOL bContained = TRUE;
+    sal_Bool bContained = sal_True;
     switch ( nBasePart )        // inner part
     {
         case com::sun::star::sheet::DataPilotFieldGroupBy::MONTHS:
@@ -609,7 +600,8 @@ String lcl_GetSpecialDateName( double fValue, bool bFirst, SvNumberFormatter* pF
     return aBuffer.makeStringAndClear();
 }
 
-void ScDPDateGroupHelper::FillColumnEntries( SCCOL nSourceDim, ScDPTableDataCache* pCache, std::vector< SCROW >& rEntries, const std::vector< SCROW >& rOriginal  ) const
+void ScDPDateGroupHelper::FillColumnEntries(
+    SCCOL nSourceDim, const ScDPCache* pCache, std::vector<SCROW>& rEntries, const std::vector<SCROW>& rOriginal) const
 {
     // auto min/max is only used for "Years" part, but the loop is always needed
     double fSourceMin = 0.0;
@@ -669,7 +661,7 @@ void ScDPDateGroupHelper::FillColumnEntries( SCCOL nSourceDim, ScDPTableDataCach
         case com::sun::star::sheet::DataPilotFieldGroupBy::MINUTES:  nStart = 0; nEnd = 59;  break;
         case com::sun::star::sheet::DataPilotFieldGroupBy::SECONDS:  nStart = 0; nEnd = 59;  break;
         default:
-            DBG_ERROR("invalid date part");
+            OSL_FAIL("invalid date part");
     }
 
     for ( sal_Int32 nValue = nStart; nValue <= nEnd; nValue++ )
@@ -724,10 +716,7 @@ void ScDPGroupItem::FillGroupFilter( ScDPCacheTable::GroupFilter& rFilter ) cons
 {
     ScDPItemDataVec::const_iterator itrEnd = aElements.end();
     for (ScDPItemDataVec::const_iterator itr = aElements.begin(); itr != itrEnd; ++itr)
-// Wang Xu Ming -- 2009-8-17
-// DataPilot Migration - Cache&&Performance
         rFilter.addMatchItem(itr->GetString(), itr->GetValue(), itr->IsValue());
-// End Comments
 }
 
 // -----------------------------------------------------------------------
@@ -736,8 +725,7 @@ ScDPGroupDimension::ScDPGroupDimension( long nSource, const String& rNewName ) :
     nSourceDim( nSource ),
     nGroupDim( -1 ),
     aGroupName( rNewName ),
-    pDateHelper( NULL )/*,
-    pCollection( NULL )*/
+    pDateHelper( NULL )
 {
 }
 
@@ -789,21 +777,19 @@ void ScDPGroupDimension::SetGroupDim( long nDim )
 {
     nGroupDim = nDim;
 }
-// Wang Xu Ming -- 2009-9-2
-// DataPilot Migration - Cache&&Performance
 const std::vector< SCROW >&  ScDPGroupDimension::GetColumnEntries( const ScDPCacheTable&  rCacheTable, const std::vector< SCROW >& rOriginal  )  const
 {
     if ( maMemberEntries.empty() )
     {
         if ( pDateHelper ) 
         { 
-            pDateHelper->FillColumnEntries(  (SCCOL)GetSourceDim(), rCacheTable.GetCache(), maMemberEntries,  rOriginal  );
+            pDateHelper->FillColumnEntries(  (SCCOL)GetSourceDim(), rCacheTable.getCache(), maMemberEntries,  rOriginal  );
         }
         else
         {
             for (size_t  i =0; i < rOriginal.size( );  i ++)
             {
-                const  ScDPItemData* pItemData = rCacheTable.GetCache()->GetItemDataById( (SCCOL)GetSourceDim(), rOriginal[i] );
+                const  ScDPItemData* pItemData = rCacheTable.getCache()->GetItemDataById( (SCCOL)GetSourceDim(), rOriginal[i] );
                 if ( !pItemData || !GetGroupForData( *pItemData ) )
                 {
                     // not in any group -> add as its own group
@@ -814,15 +800,14 @@ const std::vector< SCROW >&  ScDPGroupDimension::GetColumnEntries( const ScDPCac
             long nCount = aItems.size();
             for (long i=0; i<nCount; i++)
             {
-                SCROW nNew = rCacheTable.GetCache()->GetAdditionalItemID(  aItems[i].GetName() );
-                lcl_Insert ( (SCCOL)GetSourceDim(), rCacheTable.GetCache(), maMemberEntries, nNew  );
+                SCROW nNew = rCacheTable.getCache()->GetAdditionalItemID(  aItems[i].GetName() );
+                lcl_Insert ( (SCCOL)GetSourceDim(), rCacheTable.getCache(), maMemberEntries, nNew  );
             }
         }
     }
     return maMemberEntries;
 }
 
-// End Comments
 
 
 const ScDPGroupItem* ScDPGroupDimension::GetGroupForData( const ScDPItemData& rData ) const
@@ -916,8 +901,8 @@ void ScDPNumGroupDimension::MakeDateHelper( const ScDPNumGroupInfo& rInfo, sal_I
     aGroupInfo.Enable = sal_True;   //! or query both?
 }
 
-const std::vector< SCROW >& ScDPNumGroupDimension::GetNumEntries( SCCOL nSourceDim, ScDPTableDataCache* pCache,
-                    const std::vector< SCROW >& rOriginal  ) const
+const std::vector<SCROW>& ScDPNumGroupDimension::GetNumEntries(
+    SCCOL nSourceDim, const ScDPCache* pCache, const std::vector<SCROW>& rOriginal) const
 {
     if ( maMemberEntries.empty() )
     {
@@ -1024,7 +1009,7 @@ const std::vector< SCROW >& ScDPNumGroupDimension::GetNumEntries( SCCOL nSourceD
 }
 
 ScDPGroupTableData::ScDPGroupTableData( const shared_ptr<ScDPTableData>& pSource, ScDocument* pDocument ) :
-    ScDPTableData(pDocument, pSource->GetCacheId() ),
+    ScDPTableData(pDocument),
     pSourceData( pSource ),
     pDoc( pDocument )
 {
@@ -1086,7 +1071,6 @@ void ScDPGroupTableData::GetNumGroupInfo( long nDimension, ScDPNumGroupInfo& rIn
         rDecimal    = pNumGroups[nDimension].GetDecSeparator();
     }
 }
-// Wang Xu Ming - DataPilot migration
 long  ScDPGroupTableData::GetMembersCount( long nDim )
 {
     const std::vector< SCROW >&  members = GetColumnEntries( nDim );
@@ -1112,7 +1096,7 @@ const std::vector< SCROW >& ScDPGroupTableData::GetColumnEntries( long  nColumn
     {
         // dimension number is unchanged for numerical groups
         const  std::vector< SCROW >& rOriginal = pSourceData->GetColumnEntries( nColumn );
-        return pNumGroups[nColumn].GetNumEntries( (SCCOL)nColumn,  GetCacheTable().GetCache(), rOriginal );
+        return pNumGroups[nColumn].GetNumEntries( (SCCOL)nColumn, GetCacheTable().getCache(), rOriginal );
     }
 
     return pSourceData->GetColumnEntries( nColumn );
@@ -1146,13 +1130,13 @@ String ScDPGroupTableData::getDimensionName(long nColumn)
     return pSourceData->getDimensionName( nColumn );
 }
 
-BOOL ScDPGroupTableData::getIsDataLayoutDimension(long nColumn)
+sal_Bool ScDPGroupTableData::getIsDataLayoutDimension(long nColumn)
 {
     // position of data layout dimension is moved from source data
     return ( nColumn == sal::static_int_cast<long>( nSourceCount + aGroups.size() ) );    // data layout dimension?
 }
 
-BOOL ScDPGroupTableData::IsDateDimension(long nDim)
+sal_Bool ScDPGroupTableData::IsDateDimension(long nDim)
 {
     if ( nDim >= nSourceCount )
     {
@@ -1165,7 +1149,7 @@ BOOL ScDPGroupTableData::IsDateDimension(long nDim)
     return pSourceData->IsDateDimension( nDim );
 }
 
-ULONG ScDPGroupTableData::GetNumberFormat(long nDim)
+sal_uLong ScDPGroupTableData::GetNumberFormat(long nDim)
 {
     if ( nDim >= nSourceCount )
     {
@@ -1189,7 +1173,7 @@ void ScDPGroupTableData::DisposeData()
     pSourceData->DisposeData();
 }
 
-void ScDPGroupTableData::SetEmptyFlags( BOOL bIgnoreEmptyRows, BOOL bRepeatIfEmpty )
+void ScDPGroupTableData::SetEmptyFlags( sal_Bool bIgnoreEmptyRows, sal_Bool bRepeatIfEmpty )
 {
     pSourceData->SetEmptyFlags( bIgnoreEmptyRows, bRepeatIfEmpty );
 }
@@ -1206,12 +1190,12 @@ void ScDPGroupTableData::CreateCacheTable()
 
 void ScDPGroupTableData::ModifyFilterCriteria(vector<ScDPCacheTable::Criterion>& rCriteria)
 {
-    typedef hash_map<long, const ScDPGroupDimension*> GroupFieldMapType;
+    typedef boost::unordered_map<long, const ScDPGroupDimension*> GroupFieldMapType;
     GroupFieldMapType aGroupFieldIds;
     {
         ScDPGroupDimensionVec::const_iterator itr = aGroups.begin(), itrEnd = aGroups.end();
         for (; itr != itrEnd; ++itr)
-            aGroupFieldIds.insert( hash_map<long, const ScDPGroupDimension*>::value_type(itr->GetGroupDim(), &(*itr)) );
+            aGroupFieldIds.insert( boost::unordered_map<long, const ScDPGroupDimension*>::value_type(itr->GetGroupDim(), &(*itr)) );
     }
 
     vector<ScDPCacheTable::Criterion> aNewCriteria;
@@ -1284,13 +1268,8 @@ void ScDPGroupTableData::ModifyFilterCriteria(vector<ScDPCacheTable::Criterion>&
                 for (size_t i = 0; i < nGroupItemCount; ++i)
                 {
                     const ScDPGroupItem* pGrpItem = pGrpDim->GetGroupByIndex(i);
-                    // Wang Xu Ming -- 2009-6-9
-                    // DataPilot Migration
                     ScDPItemData aName( pFilter->getMatchString(),pFilter->getMatchValue(),pFilter->hasValue()) ;
-                    /*aName.aString   = pFilter->getMatchString();
-                    aName.fValue    = pFilter->getMatchValue();
-                    aName.bHasValue = pFilter->hasValue();*/
-                    // End Comments
+
                                        if (!pGrpItem || !pGrpItem->GetName().IsCaseInsEqual(aName))
                         continue;
     
@@ -1309,14 +1288,14 @@ void ScDPGroupTableData::ModifyFilterCriteria(vector<ScDPCacheTable::Criterion>&
     rCriteria.swap(aNewCriteria);
 }
 
-void ScDPGroupTableData::FilterCacheTable(const vector<ScDPCacheTable::Criterion>& rCriteria, const hash_set<sal_Int32>& rCatDims)
+void ScDPGroupTableData::FilterCacheTable(const vector<ScDPCacheTable::Criterion>& rCriteria, const boost::unordered_set<sal_Int32>& rCatDims)
 {
     vector<ScDPCacheTable::Criterion> aNewCriteria(rCriteria);
     ModifyFilterCriteria(aNewCriteria);
     pSourceData->FilterCacheTable(aNewCriteria, rCatDims);
 }
 
-void ScDPGroupTableData::GetDrillDownData(const vector<ScDPCacheTable::Criterion>& rCriteria, const hash_set<sal_Int32>& rCatDims, Sequence< Sequence<Any> >& rData)
+void ScDPGroupTableData::GetDrillDownData(const vector<ScDPCacheTable::Criterion>& rCriteria, const boost::unordered_set<sal_Int32>& rCatDims, Sequence< Sequence<Any> >& rData)
 {
     vector<ScDPCacheTable::Criterion> aNewCriteria(rCriteria);
     ModifyFilterCriteria(aNewCriteria);
@@ -1359,7 +1338,7 @@ void ScDPGroupTableData::FillGroupValues( /*ScDPItemData* pItemData*/ SCROW* pIt
 {
     long nGroupedColumns = aGroups.size();
 
-    ScDPTableDataCache* pCache = GetCacheTable().GetCache();
+    const ScDPCache* pCache = GetCacheTable().getCache();
     for (long nDim=0; nDim<nCount; nDim++)
     {
         const ScDPDateGroupHelper* pDateHelper = NULL;
@@ -1393,7 +1372,7 @@ void ScDPGroupTableData::FillGroupValues( /*ScDPItemData* pItemData*/ SCROW* pIt
                     double fGroupValue;
                     String aGroupName = lcl_GetNumGroupForValue( pData->GetValue(),
                              aNumInfo, bHasNonInteger, cDecSeparator, fGroupValue, pDoc );
-                    ScDPItemData  aItemData ( aGroupName, fGroupValue, TRUE ) ;
+                    ScDPItemData  aItemData ( aGroupName, fGroupValue, sal_True ) ;
                     pItemDataIndex[nDim] = pCache->GetAdditionalItemID( aItemData  );
                 }
                 // else (textual) keep original value
@@ -1402,33 +1381,29 @@ void ScDPGroupTableData::FillGroupValues( /*ScDPItemData* pItemData*/ SCROW* pIt
 
         if ( pDateHelper )
         { 
-            const ScDPItemData* pData  = GetCacheTable().GetCache()->GetItemDataById( (SCCOL)nSourceDim, pItemDataIndex[nDim]);
+            const ScDPItemData* pData  = GetCacheTable().getCache()->GetItemDataById( (SCCOL)nSourceDim, pItemDataIndex[nDim]);
               if ( pData ->IsValue() )
             {
                 sal_Int32 nPartValue = lcl_GetDatePartValue(
                     pData->GetValue(), pDateHelper->GetDatePart(), pDoc->GetFormatTable(),
                     &pDateHelper->GetNumInfo() );
-// Wang Xu Ming -- 2009-9-7
-// DataPilot Migration - Cache&&Performance
-                //String aName = lcl_GetDateGroupName( pDateHelper, nPartValue, pDoc->GetFormatTable() ); 
                 ScDPItemData  aItemData( pDateHelper->GetDatePart(), String(), nPartValue, ScDPItemData::MK_DATA|ScDPItemData::MK_VAL|ScDPItemData::MK_DATEPART );
-                pItemDataIndex[nDim] = GetCacheTable().GetCache()->GetAdditionalItemID( aItemData );
-// End Comments
+                pItemDataIndex[nDim] = GetCacheTable().getCache()->GetAdditionalItemID( aItemData );
             }
         }
     }
 }
 
-BOOL ScDPGroupTableData::IsBaseForGroup(long nDim) const
+sal_Bool ScDPGroupTableData::IsBaseForGroup(long nDim) const
 {
     for ( ScDPGroupDimensionVec::const_iterator aIter(aGroups.begin()); aIter != aGroups.end(); aIter++ )
     {
         const ScDPGroupDimension& rDim = *aIter;
         if ( rDim.GetSourceDim() == nDim )
-            return TRUE;
+            return sal_True;
     }
 
-    return FALSE;
+    return false;
 }
 
 long ScDPGroupTableData::GetGroupBase(long nGroupDim) const
@@ -1443,7 +1418,7 @@ long ScDPGroupTableData::GetGroupBase(long nGroupDim) const
     return -1;      // none
 }
 
-BOOL ScDPGroupTableData::IsNumOrDateGroup(long nDimension) const
+sal_Bool ScDPGroupTableData::IsNumOrDateGroup(long nDimension) const
 {
     // Virtual method from ScDPTableData, used in result data to force text labels.
 
@@ -1460,10 +1435,10 @@ BOOL ScDPGroupTableData::IsNumOrDateGroup(long nDimension) const
             return ( rDim.GetDateHelper() != NULL );
     }
 
-    return FALSE;
+    return false;
 }
 
-BOOL ScDPGroupTableData::IsInGroup( const ScDPItemData& rGroupData, long nGroupIndex,
+sal_Bool ScDPGroupTableData::IsInGroup( const ScDPItemData& rGroupData, long nGroupIndex,
                                     const ScDPItemData& rBaseData, long nBaseIndex ) const
 {
     for ( ScDPGroupDimensionVec::const_iterator aIter(aGroups.begin()); aIter != aGroups.end(); aIter++ )
@@ -1486,8 +1461,8 @@ BOOL ScDPGroupTableData::IsInGroup( const ScDPItemData& rGroupData, long nGroupI
                 // date group information, too.
                 if ( !pBaseDateHelper )
                 {
-                    DBG_ERROR( "mix of date and non-date groups" );
-                    return TRUE;
+                    OSL_FAIL( "mix of date and non-date groups" );
+                    return true;
                 }
 
                 sal_Int32 nGroupPart = pGroupDateHelper->GetDatePart();
@@ -1506,11 +1481,11 @@ BOOL ScDPGroupTableData::IsInGroup( const ScDPItemData& rGroupData, long nGroupI
         }
     }
 
-    DBG_ERROR("IsInGroup: no group dimension found");
-    return TRUE;
+    OSL_FAIL("IsInGroup: no group dimension found");
+    return true;
 }
 
-BOOL ScDPGroupTableData::HasCommonElement( const ScDPItemData& rFirstData, long nFirstIndex,
+sal_Bool ScDPGroupTableData::HasCommonElement( const ScDPItemData& rFirstData, long nFirstIndex,
                                          const ScDPItemData& rSecondData, long nSecondIndex ) const
 {
     const ScDPGroupDimension* pFirstDim = NULL;
@@ -1532,8 +1507,8 @@ BOOL ScDPGroupTableData::HasCommonElement( const ScDPItemData& rFirstData, long
             // If one is a date group dimension, the other one must be, too.
             if ( !pFirstDateHelper || !pSecondDateHelper )
             {
-                DBG_ERROR( "mix of date and non-date groups" );
-                return TRUE;
+                OSL_FAIL( "mix of date and non-date groups" );
+                return true;
             }
 
             sal_Int32 nFirstPart = pFirstDateHelper->GetDatePart();
@@ -1545,7 +1520,7 @@ BOOL ScDPGroupTableData::HasCommonElement( const ScDPItemData& rFirstData, long
         const ScDPGroupItem* pSecondItem = pSecondDim->GetGroupForName( rSecondData );
         if ( pFirstItem && pSecondItem )
         {
-            // two existing groups -> TRUE if they have a common element
+            // two existing groups -> sal_True if they have a common element
             return pFirstItem->HasCommonElement( *pSecondItem );
         }
         else if ( pFirstItem )
@@ -1560,13 +1535,13 @@ BOOL ScDPGroupTableData::HasCommonElement( const ScDPItemData& rFirstData, long
         }
         else
         {
-            // no groups -> TRUE if equal
+            // no groups -> sal_True if equal
             return rFirstData.IsCaseInsEqual( rSecondData );
         }
     }
 
-    DBG_ERROR("HasCommonElement: no group dimension found");
-    return TRUE;
+    OSL_FAIL("HasCommonElement: no group dimension found");
+    return true;
 }
 
 long ScDPGroupTableData::GetSourceDim( long nDim )
