@@ -56,6 +56,9 @@
 #undef _FILTDLG_CXX
 #include <vcl/msgbox.hxx>
 
+using ::rtl::OUString;
+using ::rtl::OUStringBuffer;
+
 // DEFINE --------------------------------------------------------------------
 
 #define ERRORBOX(rid)	ErrorBox( this, WinBits( WB_OK|WB_DEF_OK), \
@@ -115,38 +118,98 @@ ScFilterDlg::ScFilterDlg( SfxBindings* pB, SfxChildWindow* pCW, Window* pParent,
         pDoc			( NULL ),
         nSrcTab			( 0 ),
         nFieldCount		( 0 ),
-        bRefInputMode	( FALSE ),
+        bRefInputMode	( false ),
         pTimer			( NULL )
 {
-    for (USHORT i=0; i<=MAXCOL; i++)
+    for (sal_uInt16 i=0; i<=MAXCOL; i++)
         pEntryLists[i] = NULL;
     for (SCSIZE i=0;i<MAXQUERY;i++)
     {
-         bRefreshExceptQuery[i]=FALSE; 
+         bRefreshExceptQuery[i]=false; 
     }
     aBtnMore.SetMoreText( String(ScResId( SCSTR_MOREBTN_MOREOPTIONS )) );
     aBtnMore.SetLessText( String(ScResId( SCSTR_MOREBTN_FEWEROPTIONS )) );
     Init( rArgSet );
     FreeResource();
 
-    // Hack: RefInput-Kontrolle
+    // Hack: RefInput control
     pTimer = new Timer;
-    pTimer->SetTimeout( 50 ); // 50ms warten
+    pTimer->SetTimeout( 50 ); // Wait 50ms
     pTimer->SetTimeoutHdl( LINK( this, ScFilterDlg, TimeOutHdl ) );
+
+    OUStringBuffer aBuf;
+
+    OUString sAccName = ResId::toString(ScResId(RID_FILTER_OPERATOR));
+    aBuf.append(sAccName);
+    aBuf.appendAscii(RTL_CONSTASCII_STRINGPARAM (" 1"));
+    aLbConnect1.SetAccessibleName(aBuf.makeStringAndClear());
+    aBuf.append(sAccName);
+    aBuf.appendAscii(RTL_CONSTASCII_STRINGPARAM (" 2"));
+    aLbConnect2.SetAccessibleName(aBuf.makeStringAndClear());
+
+    sAccName = ResId::toString(ScResId(RID_FILTER_FIELDNAME));
+    aBuf.append(sAccName);
+    aBuf.appendAscii(RTL_CONSTASCII_STRINGPARAM (" 1"));
+    aLbField1.SetAccessibleName(aBuf.makeStringAndClear());
+    aBuf.append(sAccName);
+    aBuf.appendAscii(RTL_CONSTASCII_STRINGPARAM (" 2"));
+    aLbField2.SetAccessibleName(aBuf.makeStringAndClear());
+    aBuf.append(sAccName);
+    aBuf.appendAscii(RTL_CONSTASCII_STRINGPARAM (" 3"));
+    aLbField3.SetAccessibleName(aBuf.makeStringAndClear());
+
+    sAccName = ResId::toString(ScResId(RID_FILTER_CONDITION));
+    aBuf.append(sAccName);
+    aBuf.appendAscii(RTL_CONSTASCII_STRINGPARAM (" 1"));
+    aLbCond1.SetAccessibleName(aBuf.makeStringAndClear());
+    aBuf.append(sAccName);
+    aBuf.appendAscii(RTL_CONSTASCII_STRINGPARAM (" 2"));
+    aLbCond2.SetAccessibleName(aBuf.makeStringAndClear());
+    aBuf.append(sAccName);
+    aBuf.appendAscii(RTL_CONSTASCII_STRINGPARAM (" 3"));
+    aLbCond3.SetAccessibleName(aBuf.makeStringAndClear());
+    
+    sAccName = ResId::toString(ScResId(RID_FILTER_VALUE));
+    aBuf.append(sAccName);
+    aBuf.appendAscii(RTL_CONSTASCII_STRINGPARAM (" 1"));
+    aEdVal1.SetAccessibleName(aBuf.makeStringAndClear());
+    aBuf.append(sAccName);
+    aBuf.appendAscii(RTL_CONSTASCII_STRINGPARAM (" 2"));
+    aEdVal2.SetAccessibleName(aBuf.makeStringAndClear());
+    aBuf.append(sAccName);
+    aBuf.appendAscii(RTL_CONSTASCII_STRINGPARAM (" 3"));
+    aEdVal3.SetAccessibleName(aBuf.makeStringAndClear());
+
+    aLbCopyArea.SetAccessibleName(ScResId(STR_COPY_AREA_TO));
+    aEdCopyArea.SetAccessibleName(ScResId(STR_COPY_AREA_TO));
+    aLbCopyArea.SetAccessibleRelationLabeledBy(&aBtnCopyResult);
+    aEdCopyArea.SetAccessibleRelationLabeledBy(&aBtnCopyResult);
+    
+    aLbConnect1.SetAccessibleRelationLabeledBy(&aFtConnect);
+    aLbConnect2.SetAccessibleRelationLabeledBy(&aFtConnect);
+    aLbField1.SetAccessibleRelationLabeledBy(&aFtField);
+    aLbField2.SetAccessibleRelationLabeledBy(&aFtField);
+    aLbField3.SetAccessibleRelationLabeledBy(&aFtField);
+    aLbCond1.SetAccessibleRelationLabeledBy(&aFtCond);
+    aLbCond2.SetAccessibleRelationLabeledBy(&aFtCond);
+    aLbCond3.SetAccessibleRelationLabeledBy(&aFtCond);
+    aEdVal1.SetAccessibleRelationLabeledBy(&aFtVal);
+    aEdVal2.SetAccessibleRelationLabeledBy(&aFtVal);
+    aEdVal3.SetAccessibleRelationLabeledBy(&aFtVal);
 }
 
 
 //----------------------------------------------------------------------------
 
-__EXPORT ScFilterDlg::~ScFilterDlg()
+ScFilterDlg::~ScFilterDlg()
 {
-    for (USHORT i=0; i<=MAXCOL; i++)
+    for (sal_uInt16 i=0; i<=MAXCOL; i++)
         delete pEntryLists[i];
 
     delete pOptionsMgr;
     delete pOutItem;
 
-    // Hack: RefInput-Kontrolle
+    // Hack: RefInput control
     pTimer->Stop();
     delete pTimer;
 }
@@ -154,7 +217,7 @@ __EXPORT ScFilterDlg::~ScFilterDlg()
 
 //----------------------------------------------------------------------------
 
-void __EXPORT ScFilterDlg::Init( const SfxItemSet& rArgSet )
+void ScFilterDlg::Init( const SfxItemSet& rArgSet )
 {
     const ScQueryItem& rQueryItem = (const ScQueryItem&)
                                     rArgSet.Get( nWhichQuery );
@@ -183,7 +246,7 @@ void __EXPORT ScFilterDlg::Init( const SfxItemSet& rArgSet )
     pDoc	  	= pViewData ? pViewData->GetDocument() : NULL;
     nSrcTab		= pViewData ? pViewData->GetTabNo() : static_cast<SCTAB>(0);
 
-    // fuer leichteren Zugriff:
+    // for easier access:
     aFieldLbArr	 [0] = &aLbField1;
     aFieldLbArr	 [1] = &aLbField2;
     aFieldLbArr	 [2] = &aLbField3;
@@ -201,7 +264,7 @@ void __EXPORT ScFilterDlg::Init( const SfxItemSet& rArgSet )
     aConnLbArr   [2] = &aLbConnect3;
     aConnLbArr   [3] = &aLbConnect4;
 
-    // Optionen initialisieren lassen:
+    // Option initialization:
 
     pOptionsMgr	 = new ScFilterOptionsMgr(
                             this,
@@ -223,20 +286,20 @@ void __EXPORT ScFilterDlg::Init( const SfxItemSet& rArgSet )
                             aStrNoName,
                             aStrUndefined );
 
-    // Feldlisten einlesen und Eintraege selektieren:
+    // Read in field lists and select entries
 
     FillFieldLists();
 
     for ( SCSIZE i=0; i<4; i++ )
     {
         String	aValStr;
-        USHORT	nCondPos	 = 0;
-        USHORT	nFieldSelPos = 0;
+        sal_uInt16	nCondPos	 = 0;
+        sal_uInt16	nFieldSelPos = 0;
 
         ScQueryEntry& rEntry = theQueryData.GetEntry(i);
         if ( rEntry.bDoQuery )
         {
-            nCondPos	 = (USHORT)rEntry.eOp;
+            nCondPos	 = (sal_uInt16)rEntry.eOp;
             nFieldSelPos = GetFieldSelPos( static_cast<SCCOL>(rEntry.nField) );
             if ( rEntry.nVal == SC_EMPTYFIELDS && !rEntry.bQueryByString && *rEntry.pStr == EMPTY_STRING )
             {
@@ -256,16 +319,16 @@ void __EXPORT ScFilterDlg::Init( const SfxItemSet& rArgSet )
             nFieldSelPos = GetFieldSelPos( pViewData->GetCurX() );
             rEntry.nField = nFieldSelPos ? (theQueryData.nCol1 +
                 static_cast<SCCOL>(nFieldSelPos) - 1) : static_cast<SCCOL>(0);
-            rEntry.bDoQuery=TRUE;
-            bRefreshExceptQuery[i]=TRUE;
+            rEntry.bDoQuery=sal_True;
+            bRefreshExceptQuery[i]=sal_True;
 
         }
         aFieldLbArr[i]->SelectEntryPos( nFieldSelPos );
         aCondLbArr [i]->SelectEntryPos( nCondPos );
         aValueEdArr[i]->SetText( aValStr );
-        aValueEdArr[i]->EnableAutocomplete( FALSE );
+        aValueEdArr[i]->EnableAutocomplete( sal_False );
         aValueEdArr[i]->SetModifyHdl( LINK( this, ScFilterDlg, ValModifyHdl ) );
-        UpdateValueList( static_cast<USHORT>(i+1) );
+        UpdateValueList( static_cast<sal_uInt16>(i+1) );
     }
 
     aScrollBar.SetEndScrollHdl( LINK( this, ScFilterDlg, ScrollHdl ) );
@@ -274,21 +337,21 @@ void __EXPORT ScFilterDlg::Init( const SfxItemSet& rArgSet )
     aScrollBar.SetRange( Range( 0, 4 ) );
     aScrollBar.SetLineSize( 1 );
     aLbConnect1.Hide(); 
-    // Disable/Enable Logik:
+    // Disable/Enable Logic:
 
        (aLbField1.GetSelectEntryPos() != 0)
     && (aLbField2.GetSelectEntryPos() != 0)
-        ? aLbConnect2.SelectEntryPos( (USHORT)theQueryData.GetEntry(1).eConnect )  
+        ? aLbConnect2.SelectEntryPos( (sal_uInt16)theQueryData.GetEntry(1).eConnect )  
         : aLbConnect2.SetNoSelection();
 
        (aLbField2.GetSelectEntryPos() != 0)
     && (aLbField3.GetSelectEntryPos() != 0)
-        ? aLbConnect3.SelectEntryPos( (USHORT)theQueryData.GetEntry(2).eConnect )  
+        ? aLbConnect3.SelectEntryPos( (sal_uInt16)theQueryData.GetEntry(2).eConnect )  
         : aLbConnect3.SetNoSelection();
 
        (aLbField3.GetSelectEntryPos() != 0)
     && (aLbField4.GetSelectEntryPos() != 0)
-        ? aLbConnect4.SelectEntryPos( (USHORT)theQueryData.GetEntry(3).eConnect )  
+        ? aLbConnect4.SelectEntryPos( (sal_uInt16)theQueryData.GetEntry(3).eConnect )  
         : aLbConnect4.SetNoSelection();
     if ( aLbField1.GetSelectEntryPos() == 0 )
     {
@@ -333,16 +396,16 @@ void __EXPORT ScFilterDlg::Init( const SfxItemSet& rArgSet )
 
     if(pDoc!=NULL &&
         pDoc->GetChangeTrack()!=NULL) aBtnCopyResult.Disable();
-    // Modal-Modus einschalten
-//	SetDispatcherLock( TRUE );
-    //@BugID 54702 Enablen/Disablen nur noch in Basisklasse
-//	SFX_APPWINDOW->Disable(FALSE);		//! allgemeine Methode im ScAnyRefDlg
+    // Switch on modal mode
+//	SetDispatcherLock( sal_True );
+    //@BugID 54702 Enable/disable only in Basic class
+//	SFX_APPWINDOW->Disable(sal_False);		//! general method in ScAnyRefDlg
 }
 
 
 //----------------------------------------------------------------------------
 
-BOOL __EXPORT ScFilterDlg::Close()
+sal_Bool ScFilterDlg::Close()
 {
     if (pViewData)
         pViewData->GetDocShell()->CancelAutoDBRange();
@@ -352,12 +415,12 @@ BOOL __EXPORT ScFilterDlg::Close()
 
 
 //----------------------------------------------------------------------------
-// Uebergabe eines mit der Maus selektierten Tabellenbereiches, der dann als
-// neue Selektion im Referenz-Edit angezeigt wird.
+// Mouse-selected cell area becomes the new selection and is shown in the
+// reference text box
 
 void ScFilterDlg::SetReference( const ScRange& rRef, ScDocument* pDocP )
 {
-    if ( bRefInputMode )	// Nur moeglich, wenn im Referenz-Editmodus
+    if ( bRefInputMode )	// Only possible if in reference edit mode
     {
         if ( rRef.aStart != rRef.aEnd )
             RefInputStart( &aEdCopyArea );
@@ -405,7 +468,7 @@ void ScFilterDlg::FillFieldLists()
         SCROW	nFirstRow	= theQueryData.nRow1;
         SCCOL	nMaxCol		= theQueryData.nCol2;
         SCCOL	col = 0;
-        USHORT	i=1;
+        sal_uInt16	i=1;
 
         for ( col=nFirstCol; col<=nMaxCol; col++ )
         {
@@ -429,13 +492,13 @@ void ScFilterDlg::FillFieldLists()
 
 //----------------------------------------------------------------------------
 
-void ScFilterDlg::UpdateValueList( USHORT nList )
+void ScFilterDlg::UpdateValueList( sal_uInt16 nList )
 {
     if ( pDoc && nList>0 && nList<=4 )
     {
         ComboBox*	pValList		= aValueEdArr[nList-1];
-        USHORT		nFieldSelPos	= aFieldLbArr[nList-1]->GetSelectEntryPos();
-        USHORT		nListPos		= 0;
+        sal_uInt16		nFieldSelPos	= aFieldLbArr[nList-1]->GetSelectEntryPos();
+        sal_uInt16		nListPos		= 0;
         String		aCurValue  		= pValList->GetText();
 
         pValList->Clear();
@@ -445,26 +508,26 @@ void ScFilterDlg::UpdateValueList( USHORT nList )
 
         if ( nFieldSelPos )
         {
-            WaitObject aWaiter( this );		// auch wenn nur die ListBox gefuellt wird
+            WaitObject aWaiter( this );		// even if only the list box has content
 
             SCCOL nColumn = theQueryData.nCol1 + static_cast<SCCOL>(nFieldSelPos) - 1;
             if (!pEntryLists[nColumn])
             {
-                USHORT nOffset = GetSliderPos();
+                sal_uInt16 nOffset = GetSliderPos();
                 SCTAB nTab		 = nSrcTab;
                 SCROW nFirstRow = theQueryData.nRow1;
-                SCROW nLastRow   = theQueryData.bUseDynamicRange ? theQueryData.nDynamicEndRow : theQueryData.nRow2;
+                SCROW nLastRow   = theQueryData.nRow2;
                 mbHasDates[nOffset+nList-1] = false;
 
-                //	erstmal ohne die erste Zeile
+                // first without the first line
 
                 pEntryLists[nColumn] = new TypedScStrCollection( 128, 128 );
                 pEntryLists[nColumn]->SetCaseSensitive( aBtnCase.IsChecked() );
                 pDoc->GetFilterEntriesArea( nColumn, nFirstRow+1, nLastRow,
                                             nTab, *pEntryLists[nColumn], mbHasDates[nOffset+nList-1] );
 
-                //	Eintrag fuer die erste Zeile
-                //!	Eintrag (pHdrEntry) ohne Collection erzeugen?
+                // Entry for the first line
+                //! Entry (pHdrEntry) doesn't generate collection?
 
                 nHeaderPos[nColumn] = USHRT_MAX;
                 TypedScStrCollection aHdrColl( 1, 1 );
@@ -482,15 +545,15 @@ void ScFilterDlg::UpdateValueList( USHORT nList )
                                     "Header-Eintrag nicht wiedergefunden" );
                     }
                     else
-                        delete pNewEntry;			// war schon drin
+                        delete pNewEntry;			// was already there
                 }
             }
 
             TypedScStrCollection* pColl = pEntryLists[nColumn];
-            USHORT nValueCount = pColl->GetCount();
+            sal_uInt16 nValueCount = pColl->GetCount();
             if ( nValueCount > 0 )
             {
-                for ( USHORT i=0; i<nValueCount; i++ )
+                for ( sal_uInt16 i=0; i<nValueCount; i++ )
                 {
                     pValList->InsertEntry( (*pColl)[i]->GetString(), nListPos );
                     nListPos++;
@@ -504,37 +567,37 @@ void ScFilterDlg::UpdateValueList( USHORT nList )
     UpdateHdrInValueList( nList );
 }
 
-void ScFilterDlg::UpdateHdrInValueList( USHORT nList )
+void ScFilterDlg::UpdateHdrInValueList( sal_uInt16 nList )
 {
     //!	GetText / SetText ??
 
     if ( pDoc && nList>0 && nList<=4 )
     {
-        USHORT nFieldSelPos = aFieldLbArr[nList-1]->GetSelectEntryPos();
+        sal_uInt16 nFieldSelPos = aFieldLbArr[nList-1]->GetSelectEntryPos();
         if ( nFieldSelPos )
         {
             SCCOL nColumn = theQueryData.nCol1 + static_cast<SCCOL>(nFieldSelPos) - 1;
             if ( pEntryLists[nColumn] )
             {
-                USHORT nPos = nHeaderPos[nColumn];
+                sal_uInt16 nPos = nHeaderPos[nColumn];
                 if ( nPos != USHRT_MAX )
                 {
                     ComboBox* pValList = aValueEdArr[nList-1];
-                    USHORT nListPos = nPos + 2;					// nach "leer" und "nicht leer"
+                    sal_uInt16 nListPos = nPos + 2;					// for "empty" and "non-empty"
 
                     TypedStrData* pHdrEntry = (*pEntryLists[nColumn])[nPos];
                     if ( pHdrEntry )
                     {
                         String aHdrStr = pHdrEntry->GetString();
-                        BOOL bWasThere = ( pValList->GetEntry(nListPos) == aHdrStr );
-                        BOOL bInclude = !aBtnHeader.IsChecked();
+                        sal_Bool bWasThere = ( pValList->GetEntry(nListPos) == aHdrStr );
+                        sal_Bool bInclude = !aBtnHeader.IsChecked();
 
-                        if (bInclude)			// Eintrag aufnehmen
+                        if (bInclude)			// Include entry
                         {
                             if (!bWasThere)
                                 pValList->InsertEntry(aHdrStr, nListPos);
                         }
-                        else					// Eintrag weglassen
+                        else					// Omit entry
                         {
                             if (bWasThere)
                                 pValList->RemoveEntry(nListPos);
@@ -542,13 +605,13 @@ void ScFilterDlg::UpdateHdrInValueList( USHORT nList )
                     }
                     else
                     {
-                        DBG_ERROR("Eintag in Liste nicht gefunden");
+                        OSL_FAIL("Eintag in Liste nicht gefunden");
                     }
                 }
             }
             else
             {
-                DBG_ERROR("Spalte noch nicht initialisiert");
+                OSL_FAIL("Spalte noch nicht initialisiert");
             }
         }
     }
@@ -556,7 +619,7 @@ void ScFilterDlg::UpdateHdrInValueList( USHORT nList )
 
 //----------------------------------------------------------------------------
 
-void ScFilterDlg::ClearValueList( USHORT nList )
+void ScFilterDlg::ClearValueList( sal_uInt16 nList )
 {
     if ( nList>0 && nList<=4 )
     {
@@ -571,10 +634,10 @@ void ScFilterDlg::ClearValueList( USHORT nList )
 
 //----------------------------------------------------------------------------
 
-USHORT ScFilterDlg::GetFieldSelPos( SCCOL nField )
+sal_uInt16 ScFilterDlg::GetFieldSelPos( SCCOL nField )
 {
     if ( nField >= theQueryData.nCol1 && nField <= theQueryData.nCol2 )
-        return static_cast<USHORT>(nField - theQueryData.nCol1 + 1);
+        return static_cast<sal_uInt16>(nField - theQueryData.nCol1 + 1);
     else
         return 0;
 }
@@ -585,7 +648,7 @@ ScQueryItem* ScFilterDlg::GetOutputItem()
 {
     ScAddress		theCopyPos;
     ScQueryParam 	theParam( theQueryData );
-    BOOL            bCopyPosOk = FALSE;
+    sal_Bool            bCopyPosOk = false;
 
     if ( aBtnCopyResult.IsChecked() )
     {
@@ -595,33 +658,33 @@ ScQueryItem* ScFilterDlg::GetOutputItem()
         if ( STRING_NOTFOUND != nColonPos )
             theCopyStr.Erase( nColonPos );
 
-        USHORT nResult = theCopyPos.Parse( theCopyStr, pDoc, pDoc->GetAddressConvention() );
+        sal_uInt16 nResult = theCopyPos.Parse( theCopyStr, pDoc, pDoc->GetAddressConvention() );
         bCopyPosOk = ( SCA_VALID == (nResult & SCA_VALID) );
     }
 
     if ( aBtnCopyResult.IsChecked() && bCopyPosOk )
     {
-        theParam.bInplace   = FALSE;
+        theParam.bInplace   = false;
         theParam.nDestTab	= theCopyPos.Tab();
         theParam.nDestCol	= theCopyPos.Col();
         theParam.nDestRow	= theCopyPos.Row();
     }
     else
     {
-        theParam.bInplace   = TRUE;
+        theParam.bInplace   = sal_True;
         theParam.nDestTab	= 0;
         theParam.nDestCol	= 0;
         theParam.nDestRow	= 0;
     }
 
     theParam.bHasHeader		= aBtnHeader.IsChecked();
-    theParam.bByRow			= TRUE;
+    theParam.bByRow			= sal_True;
     theParam.bDuplicate		= !aBtnUnique.IsChecked();
     theParam.bCaseSens 		= aBtnCase.IsChecked();
     theParam.bRegExp		= aBtnRegExp.IsChecked();
     theParam.bDestPers		= aBtnDestPers.IsChecked();
 
-    //	nur die drei eingestellten - alles andere zuruecksetzen
+    // only set the three - reset everything else
 
     DELETEZ( pOutItem );
     pOutItem = new ScQueryItem( nWhichQuery, &theParam );
@@ -632,7 +695,7 @@ ScQueryItem* ScFilterDlg::GetOutputItem()
 
 //----------------------------------------------------------------------------
 
-BOOL ScFilterDlg::IsRefInputMode() const
+sal_Bool ScFilterDlg::IsRefInputMode() const
 {
     return bRefInputMode;
 }
@@ -646,24 +709,24 @@ IMPL_LINK( ScFilterDlg, EndDlgHdl, Button*, pBtn )
 {
     if ( pBtn == &aBtnOk )
     {
-        BOOL bAreaInputOk = TRUE;
+        sal_Bool bAreaInputOk = sal_True;
 
         if ( aBtnCopyResult.IsChecked() )
         {
             if ( !pOptionsMgr->VerifyPosStr( aEdCopyArea.GetText() ) )
             {
                 if ( !aBtnMore.GetState() )
-                    aBtnMore.SetState( TRUE );
+                    aBtnMore.SetState( sal_True );
 
                 ERRORBOX( STR_INVALID_TABREF );
                 aEdCopyArea.GrabFocus();
-                bAreaInputOk = FALSE;
+                bAreaInputOk = false;
             }
         }
 
         if ( bAreaInputOk )
         {
-            SetDispatcherLock( FALSE );
+            SetDispatcherLock( false );
             SwitchToDocument();
             GetBindings().GetDispatcher()->Execute( FID_FILTER_OK,
                                       SFX_CALLMODE_SLOT | SFX_CALLMODE_RECORD,
@@ -689,9 +752,9 @@ IMPL_LINK( ScFilterDlg, MoreClickHdl, MoreButton*, EMPTYARG )
     else
     {
         pTimer->Stop();
-        bRefInputMode = FALSE;
-        //@BugID 54702 Enablen/Disablen nur noch in Basisklasse
-        //SFX_APPWINDOW->Disable(FALSE);		//! allgemeine Methode im ScAnyRefDlg
+        bRefInputMode = false;
+        //@BugID 54702 Enable/disable only in Basic class
+        //SFX_APPWINDOW->Disable(FALSE);		//! general method in ScAnyRefDlg
     }
     return 0;
 }
@@ -701,7 +764,7 @@ IMPL_LINK( ScFilterDlg, MoreClickHdl, MoreButton*, EMPTYARG )
 
 IMPL_LINK( ScFilterDlg, TimeOutHdl, Timer*, _pTimer )
 {
-    // alle 50ms nachschauen, ob RefInputMode noch stimmt
+    // Check if RefInputMode is still true every 50ms
 
     if( _pTimer == pTimer && IsActive() )
         bRefInputMode = (aEdCopyArea.HasFocus() || aRbCopyArea.HasFocus());
@@ -718,10 +781,9 @@ IMPL_LINK( ScFilterDlg, TimeOutHdl, Timer*, _pTimer )
 IMPL_LINK( ScFilterDlg, LbSelectHdl, ListBox*, pLb )
 {
     /*
-     * Behandlung der Enable/Disable-Logik,
-     * abhaengig davon, welche ListBox angefasst wurde:
+     * Handle enable/disable logic depending on which ListBox was selected
      */
-    USHORT nOffset = GetSliderPos();
+    sal_uInt16 nOffset = GetSliderPos();
 
     if ( pLb == &aLbConnect1 )
     {
@@ -729,10 +791,10 @@ IMPL_LINK( ScFilterDlg, LbSelectHdl, ListBox*, pLb )
         aLbCond1.Enable();
         aEdVal1.Enable();
 
-        USHORT 	nConnect1 = aLbConnect1.GetSelectEntryPos();
-        USHORT nQE = nOffset;
+        sal_uInt16 	nConnect1 = aLbConnect1.GetSelectEntryPos();
+        sal_uInt16 nQE = nOffset;
         theQueryData.GetEntry(nQE).eConnect =(ScQueryConnect)nConnect1;
-        bRefreshExceptQuery[nQE]=TRUE;
+        bRefreshExceptQuery[nQE]=sal_True;
     }
 
     else if ( pLb == &aLbConnect2 )
@@ -741,10 +803,10 @@ IMPL_LINK( ScFilterDlg, LbSelectHdl, ListBox*, pLb )
         aLbCond2.Enable();
         aEdVal2.Enable();
 
-        USHORT 	nConnect2 = aLbConnect2.GetSelectEntryPos();
-        USHORT nQE = 1+nOffset;
+        sal_uInt16 	nConnect2 = aLbConnect2.GetSelectEntryPos();
+        sal_uInt16 nQE = 1+nOffset;
         theQueryData.GetEntry(nQE).eConnect =(ScQueryConnect)nConnect2;
-         bRefreshExceptQuery[nQE]=TRUE;
+         bRefreshExceptQuery[nQE]=sal_True;
     }
     else if ( pLb == &aLbConnect3 )
     {
@@ -752,10 +814,10 @@ IMPL_LINK( ScFilterDlg, LbSelectHdl, ListBox*, pLb )
         aLbCond3.Enable();
         aEdVal3.Enable();
 
-        USHORT 	nConnect3 = aLbConnect3.GetSelectEntryPos();
-        USHORT nQE = 2+nOffset;
+        sal_uInt16 	nConnect3 = aLbConnect3.GetSelectEntryPos();
+        sal_uInt16 nQE = 2+nOffset;
         theQueryData.GetEntry(nQE).eConnect = (ScQueryConnect)nConnect3;
-        bRefreshExceptQuery[nQE]=TRUE;
+        bRefreshExceptQuery[nQE]=sal_True;
 
     }
     else if ( pLb == &aLbConnect4 )
@@ -764,10 +826,10 @@ IMPL_LINK( ScFilterDlg, LbSelectHdl, ListBox*, pLb )
         aLbCond4.Enable();
         aEdVal4.Enable();
 
-        USHORT 	nConnect4 = aLbConnect4.GetSelectEntryPos();
-        USHORT nQE = 3+nOffset;
+        sal_uInt16 	nConnect4 = aLbConnect4.GetSelectEntryPos();
+        sal_uInt16 nQE = 3+nOffset;
         theQueryData.GetEntry(nQE).eConnect = (ScQueryConnect)nConnect4;
-        bRefreshExceptQuery[nQE]=TRUE;
+        bRefreshExceptQuery[nQE]=sal_True;
 
     }
     else if ( pLb == &aLbField1 )
@@ -800,13 +862,13 @@ IMPL_LINK( ScFilterDlg, LbSelectHdl, ListBox*, pLb )
             aEdVal2.Disable();
             aEdVal3.Disable();
             aEdVal4.Disable();
-            for (USHORT i= nOffset; i< MAXQUERY; i++)
+            for (sal_uInt16 i= nOffset; i< MAXQUERY; i++)
             {
-                theQueryData.GetEntry(i).bDoQuery = FALSE;
-                bRefreshExceptQuery[i]=FALSE; 
+                theQueryData.GetEntry(i).bDoQuery = false;
+                bRefreshExceptQuery[i]=false; 
                 theQueryData.GetEntry(i).nField =  static_cast<SCCOL>(0);
             }
-            bRefreshExceptQuery[nOffset] =TRUE;
+            bRefreshExceptQuery[nOffset] =sal_True;
         }
         else
         {
@@ -815,8 +877,8 @@ IMPL_LINK( ScFilterDlg, LbSelectHdl, ListBox*, pLb )
             {
                 aLbConnect2.Enable();
             }
-            theQueryData.GetEntry(nOffset).bDoQuery = TRUE;
-            USHORT 	nField	= pLb->GetSelectEntryPos();
+            theQueryData.GetEntry(nOffset).bDoQuery = sal_True;
+            sal_uInt16 	nField	= pLb->GetSelectEntryPos();
             theQueryData.GetEntry(nOffset).nField = theQueryData.nCol1 + static_cast<SCCOL>(nField) - 1 ;
         }
     }
@@ -843,14 +905,14 @@ IMPL_LINK( ScFilterDlg, LbSelectHdl, ListBox*, pLb )
             aEdVal3.Disable();
             aEdVal4.Disable();
 
-            USHORT nTemp=nOffset+1;
-            for (USHORT i= nTemp; i< MAXQUERY; i++)
+            sal_uInt16 nTemp=nOffset+1;
+            for (sal_uInt16 i= nTemp; i< MAXQUERY; i++)
             {
-                theQueryData.GetEntry(i).bDoQuery = FALSE;
-                bRefreshExceptQuery[i]=FALSE; 
+                theQueryData.GetEntry(i).bDoQuery = false;
+                bRefreshExceptQuery[i]=false; 
                 theQueryData.GetEntry(i).nField =  static_cast<SCCOL>(0);
             }
-            bRefreshExceptQuery[nTemp]=TRUE; 
+            bRefreshExceptQuery[nTemp]=sal_True; 
         }
         else
         {
@@ -859,9 +921,9 @@ IMPL_LINK( ScFilterDlg, LbSelectHdl, ListBox*, pLb )
             {
                 aLbConnect3.Enable();
             }
-            USHORT 	nField	= pLb->GetSelectEntryPos();
-            USHORT nQ=1+nOffset;
-            theQueryData.GetEntry(nQ).bDoQuery = TRUE;
+            sal_uInt16 	nField	= pLb->GetSelectEntryPos();
+            sal_uInt16 nQ=1+nOffset;
+            theQueryData.GetEntry(nQ).bDoQuery = sal_True;
             theQueryData.GetEntry(nQ).nField = theQueryData.nCol1 + static_cast<SCCOL>(nField) - 1 ;
         }
     }
@@ -880,14 +942,14 @@ IMPL_LINK( ScFilterDlg, LbSelectHdl, ListBox*, pLb )
             aLbCond4.Disable();
             aEdVal4.Disable();
 
-            USHORT nTemp=nOffset+2;
-            for (USHORT i= nTemp; i< MAXQUERY; i++)
+            sal_uInt16 nTemp=nOffset+2;
+            for (sal_uInt16 i= nTemp; i< MAXQUERY; i++)
             {
-                theQueryData.GetEntry(i).bDoQuery = FALSE;
-                bRefreshExceptQuery[i]=FALSE;  
+                theQueryData.GetEntry(i).bDoQuery = false;
+                bRefreshExceptQuery[i]=false;  
                 theQueryData.GetEntry(i).nField =  static_cast<SCCOL>(0);
             }
-            bRefreshExceptQuery[nTemp]=TRUE; 
+            bRefreshExceptQuery[nTemp]=sal_True; 
         }
         else
         {
@@ -897,9 +959,9 @@ IMPL_LINK( ScFilterDlg, LbSelectHdl, ListBox*, pLb )
                 aLbConnect4.Enable();
             }
             
-            USHORT 	nField	= pLb->GetSelectEntryPos();
-            USHORT nQ=2+nOffset;
-            theQueryData.GetEntry(nQ).bDoQuery = TRUE;
+            sal_uInt16 	nField	= pLb->GetSelectEntryPos();
+            sal_uInt16 nQ=2+nOffset;
+            theQueryData.GetEntry(nQ).bDoQuery = sal_True;
             theQueryData.GetEntry(nQ).nField = theQueryData.nCol1 + static_cast<SCCOL>(nField) - 1 ;
 
         }
@@ -909,21 +971,21 @@ IMPL_LINK( ScFilterDlg, LbSelectHdl, ListBox*, pLb )
         if ( aLbField4.GetSelectEntryPos() == 0 )
         {
             ClearValueList( 4 );
-            USHORT nTemp=nOffset+3;
-            for (USHORT i= nTemp; i< MAXQUERY; i++)
+            sal_uInt16 nTemp=nOffset+3;
+            for (sal_uInt16 i= nTemp; i< MAXQUERY; i++)
             {
-                theQueryData.GetEntry(i).bDoQuery = FALSE;
-                bRefreshExceptQuery[i]=FALSE; 
+                theQueryData.GetEntry(i).bDoQuery = false;
+                bRefreshExceptQuery[i]=false; 
                 theQueryData.GetEntry(i).nField =  static_cast<SCCOL>(0);
             }
-            bRefreshExceptQuery[nTemp]=TRUE; 
+            bRefreshExceptQuery[nTemp]=sal_True; 
         }
         else
         {
             UpdateValueList( 4 );
-            USHORT 	nField	= pLb->GetSelectEntryPos();
-            USHORT nQ=3+nOffset;
-            theQueryData.GetEntry(nQ).bDoQuery = TRUE;
+            sal_uInt16 	nField	= pLb->GetSelectEntryPos();
+            sal_uInt16 nQ=3+nOffset;
+            theQueryData.GetEntry(nQ).bDoQuery = sal_True;
             theQueryData.GetEntry(nQ).nField = theQueryData.nCol1 + static_cast<SCCOL>(nField) - 1 ;
         }
 
@@ -934,17 +996,17 @@ IMPL_LINK( ScFilterDlg, LbSelectHdl, ListBox*, pLb )
     }
     else if ( pLb == &aLbCond2)
     {
-        USHORT nQ=1+nOffset;
+        sal_uInt16 nQ=1+nOffset;
         theQueryData.GetEntry(nQ).eOp=(ScQueryOp)pLb->GetSelectEntryPos();
     }
     else if ( pLb == &aLbCond3)
     {
-        USHORT nQ=2+nOffset;
+        sal_uInt16 nQ=2+nOffset;
         theQueryData.GetEntry(nQ).eOp=(ScQueryOp)pLb->GetSelectEntryPos();
     }
     else 
     {
-        USHORT nQ=3+nOffset;
+        sal_uInt16 nQ=3+nOffset;
         theQueryData.GetEntry(nQ).eOp=(ScQueryOp)pLb->GetSelectEntryPos();
     }
 
@@ -956,18 +1018,18 @@ IMPL_LINK( ScFilterDlg, LbSelectHdl, ListBox*, pLb )
 
 IMPL_LINK( ScFilterDlg, CheckBoxHdl, CheckBox*, pBox )
 {
-    //	Spaltenkoepfe:
-    //		FeldListen: Spaltexx <-> Spaltenkopf-String
-    //		WertListen: Spaltenkopf-Wert entfaellt.
-    //	Gross-/Kleinschreibung:
-    //		WertListen: komplett neu
+    //	Column headers:
+    //		Field list: Columnxx <-> column header string
+    //		Value list: Column header value not applicable.
+    //	Upper/lower case:
+    //		Value list: completely new
 
-    if ( pBox == &aBtnHeader )				// Feldlisten und Wertlisten
+    if ( pBox == &aBtnHeader )				// Field list and value list
     {
-        USHORT nCurSel1 = aLbField1.GetSelectEntryPos();
-        USHORT nCurSel2 = aLbField2.GetSelectEntryPos();
-        USHORT nCurSel3 = aLbField3.GetSelectEntryPos();
-        USHORT nCurSel4 = aLbField4.GetSelectEntryPos();
+        sal_uInt16 nCurSel1 = aLbField1.GetSelectEntryPos();
+        sal_uInt16 nCurSel2 = aLbField2.GetSelectEntryPos();
+        sal_uInt16 nCurSel3 = aLbField3.GetSelectEntryPos();
+        sal_uInt16 nCurSel4 = aLbField4.GetSelectEntryPos();
         FillFieldLists();
         aLbField1.SelectEntryPos( nCurSel1 );
         aLbField2.SelectEntryPos( nCurSel2 );
@@ -980,12 +1042,12 @@ IMPL_LINK( ScFilterDlg, CheckBoxHdl, CheckBox*, pBox )
         UpdateHdrInValueList( 4 );
     }
 
-    if ( pBox == &aBtnCase )			// Wertlisten komplett
+    if ( pBox == &aBtnCase )			// Complete value list
     {
-        for (USHORT i=0; i<=MAXCOL; i++)
+        for (sal_uInt16 i=0; i<=MAXCOL; i++)
             DELETEZ( pEntryLists[i] );
 
-        UpdateValueList( 1 );		// aktueller Text wird gemerkt
+        UpdateValueList( 1 );		// current text is recorded
         UpdateValueList( 2 );
         UpdateValueList( 3 );
         UpdateValueList( 4 );
@@ -999,9 +1061,9 @@ IMPL_LINK( ScFilterDlg, CheckBoxHdl, CheckBox*, pBox )
 
 IMPL_LINK( ScFilterDlg, ValModifyHdl, ComboBox*, pEd )
 {
-    USHORT   nOffset = GetSliderPos();
-    USHORT   i=0;
-    USHORT   nQE =i + nOffset;
+    sal_uInt16   nOffset = GetSliderPos();
+    sal_uInt16   i=0;
+    sal_uInt16   nQE =i + nOffset;
     if ( pEd )
     {
         String    aStrVal	= pEd->GetText();
@@ -1038,7 +1100,7 @@ IMPL_LINK( ScFilterDlg, ValModifyHdl, ComboBox*, pEd )
             pLbCond->Enable();
 
         ScQueryEntry& rEntry = theQueryData.GetEntry( nQE );
-        BOOL bDoThis = (pLbField->GetSelectEntryPos() != 0);
+        sal_Bool bDoThis = (pLbField->GetSelectEntryPos() != 0);
         rEntry.bDoQuery = bDoThis;
 
         if ( rEntry.bDoQuery || bRefreshExceptQuery[nQE] )
@@ -1047,22 +1109,22 @@ IMPL_LINK( ScFilterDlg, ValModifyHdl, ComboBox*, pEd )
             {
                 rEntry.pStr->Erase();
                 rEntry.nVal = SC_EMPTYFIELDS;
-                rEntry.bQueryByString = FALSE;
+                rEntry.bQueryByString = false;
             }
             else if ( aStrVal == aStrNotEmpty )
             {
                 rEntry.pStr->Erase();
                 rEntry.nVal = SC_NONEMPTYFIELDS;
-                rEntry.bQueryByString = FALSE;
+                rEntry.bQueryByString = false;
             }
             else
             {
                 *rEntry.pStr		  = aStrVal;
                 rEntry.nVal			  = 0;
-                rEntry.bQueryByString = TRUE;
+                rEntry.bQueryByString = sal_True;
             }
 
-            USHORT 	nField	= pLbField->GetSelectEntryPos();
+            sal_uInt16 	nField	= pLbField->GetSelectEntryPos();
             rEntry.nField = nField ? (theQueryData.nCol1 +
                 static_cast<SCCOL>(nField) - 1) : static_cast<SCCOL>(0);
            
@@ -1084,31 +1146,31 @@ IMPL_LINK( ScFilterDlg, ScrollHdl, ScrollBar*, EMPTYARG )
 
 void ScFilterDlg::SliderMoved()
 {
-    USHORT nOffset = GetSliderPos();
+    sal_uInt16 nOffset = GetSliderPos();
     RefreshEditRow( nOffset);
 }
-USHORT ScFilterDlg::GetSliderPos()
+sal_uInt16 ScFilterDlg::GetSliderPos()
 {
-    return (USHORT) aScrollBar.GetThumbPos();
+    return (sal_uInt16) aScrollBar.GetThumbPos();
 }
-void ScFilterDlg::RefreshEditRow( USHORT nOffset )
+void ScFilterDlg::RefreshEditRow( sal_uInt16 nOffset )
 {		
     if (nOffset==0) 
         aConnLbArr[0]->Hide();
     else
         aConnLbArr[0]->Show();	
 
-    for ( USHORT i=0; i<4; i++ )
+    for ( sal_uInt16 i=0; i<4; i++ )
     {
         String	aValStr;
-        USHORT	nCondPos	 = 0;
-        USHORT	nFieldSelPos = 0;
-        USHORT  nQE = i+nOffset;
+        sal_uInt16	nCondPos	 = 0;
+        sal_uInt16	nFieldSelPos = 0;
+        sal_uInt16  nQE = i+nOffset;
 
         ScQueryEntry& rEntry = theQueryData.GetEntry( nQE);
         if ( rEntry.bDoQuery || bRefreshExceptQuery[nQE] )
         {
-            nCondPos	 = (USHORT)rEntry.eOp;
+            nCondPos	 = (sal_uInt16)rEntry.eOp;
             if(rEntry.bDoQuery)
                nFieldSelPos = GetFieldSelPos( static_cast<SCCOL>(rEntry.nField) );
 
@@ -1138,9 +1200,9 @@ void ScFilterDlg::RefreshEditRow( USHORT nOffset )
                         aConnLbArr[i+1]->Enable();
                     else
                         aConnLbArr[i+1]->Disable();
-                    USHORT nQENext = nQE+1;
+                    sal_uInt16 nQENext = nQE+1;
                     if(theQueryData.GetEntry(nQENext).bDoQuery || bRefreshExceptQuery[nQENext])
-                        aConnLbArr[i+1]->SelectEntryPos( (USHORT) theQueryData.GetEntry(nQENext).eConnect );
+                        aConnLbArr[i+1]->SelectEntryPos( (sal_uInt16) theQueryData.GetEntry(nQENext).eConnect );
                     else
                         aConnLbArr[i+1]->SetNoSelection();
                 }
@@ -1153,7 +1215,7 @@ void ScFilterDlg::RefreshEditRow( USHORT nOffset )
                     aConnLbArr[i]->Disable();
 
                 if(rEntry.bDoQuery || bRefreshExceptQuery[nQE])
-                    aConnLbArr[i]->SelectEntryPos( (USHORT) rEntry.eConnect );
+                    aConnLbArr[i]->SelectEntryPos( (sal_uInt16) rEntry.eConnect );
                 else
                     aConnLbArr[i]->SetNoSelection();
             }
@@ -1184,7 +1246,7 @@ void ScFilterDlg::RefreshEditRow( USHORT nOffset )
         aFieldLbArr[i]->SelectEntryPos( nFieldSelPos );
         aCondLbArr [i]->SelectEntryPos( nCondPos );
         aValueEdArr[i]->SetText( aValStr );
-        UpdateValueList( static_cast<USHORT>(i+1) );
+        UpdateValueList( static_cast<sal_uInt16>(i+1) );
     }
 }
 
