@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -77,7 +77,6 @@ static const xub_StrLen SCNAV_COLLETTERS = ::ScColToAlpha(SCNAV_MAXCOL).Len();
 
 //------------------------------------------------------------------------
 
-//	static
 void ScNavigatorDlg::ReleaseFocus()
 {
     SfxViewShell* pCurSh = SfxViewShell::Current();
@@ -105,17 +104,17 @@ ColumnEdit::ColumnEdit( ScNavigatorDlg* pParent, const ResId& rResId )
 
 //------------------------------------------------------------------------
 
-__EXPORT ColumnEdit::~ColumnEdit()
+ColumnEdit::~ColumnEdit()
 {
 }
 
 //------------------------------------------------------------------------
 
-long __EXPORT ColumnEdit::Notify( NotifyEvent& rNEvt )
+long ColumnEdit::Notify( NotifyEvent& rNEvt )
 {
     long nHandled = SpinField::Notify( rNEvt );
 
-    USHORT nType = rNEvt.GetType();
+    sal_uInt16 nType = rNEvt.GetType();
     if ( nType == EVENT_KEYINPUT )
     {
         const KeyEvent* pKEvt = rNEvt.GetKeyEvent();
@@ -143,7 +142,7 @@ long __EXPORT ColumnEdit::Notify( NotifyEvent& rNEvt )
 
 //------------------------------------------------------------------------
 
-void __EXPORT ColumnEdit::LoseFocus()
+void ColumnEdit::LoseFocus()
 {
     EvalText();
 }
@@ -151,7 +150,7 @@ void __EXPORT ColumnEdit::LoseFocus()
 
 //------------------------------------------------------------------------
 
-void __EXPORT ColumnEdit::Up()
+void ColumnEdit::Up()
 {
     nCol++;
 
@@ -168,7 +167,7 @@ void __EXPORT ColumnEdit::Up()
 
 //------------------------------------------------------------------------
 
-void __EXPORT ColumnEdit::Down()
+void ColumnEdit::Down()
 {
     if ( nCol>1 )
         SetCol( nCol-1 );
@@ -180,7 +179,7 @@ void __EXPORT ColumnEdit::Down()
 
 //------------------------------------------------------------------------
 
-void __EXPORT ColumnEdit::First()
+void ColumnEdit::First()
 {
     nCol = 1;
     SetText( 'A' );
@@ -188,7 +187,7 @@ void __EXPORT ColumnEdit::First()
 
 //------------------------------------------------------------------------
 
-void __EXPORT ColumnEdit::Last()
+void ColumnEdit::Last()
 {
     String aStr;
     nCol = NumToAlpha( SCNAV_MAXCOL, aStr );
@@ -316,13 +315,13 @@ RowEdit::RowEdit( ScNavigatorDlg* pParent, const ResId& rResId )
 
 //------------------------------------------------------------------------
 
-__EXPORT RowEdit::~RowEdit()
+RowEdit::~RowEdit()
 {
 }
 
 //------------------------------------------------------------------------
 
-long __EXPORT RowEdit::Notify( NotifyEvent& rNEvt )
+long RowEdit::Notify( NotifyEvent& rNEvt )
 {
     long nHandled = NumericField::Notify( rNEvt );
 
@@ -343,7 +342,7 @@ long __EXPORT RowEdit::Notify( NotifyEvent& rNEvt )
 
 //------------------------------------------------------------------------
 
-void __EXPORT RowEdit::LoseFocus()
+void RowEdit::LoseFocus()
 {
 }
 
@@ -370,13 +369,13 @@ ScDocListBox::ScDocListBox( ScNavigatorDlg* pParent, const ResId& rResId )
 
 //------------------------------------------------------------------------
 
-__EXPORT ScDocListBox::~ScDocListBox()
+ScDocListBox::~ScDocListBox()
 {
 }
 
 //------------------------------------------------------------------------
 
-void __EXPORT ScDocListBox::Select()
+void ScDocListBox::Select()
 {
     ScNavigatorDlg::ReleaseFocus();
 
@@ -397,19 +396,17 @@ CommandToolBox::CommandToolBox( ScNavigatorDlg* pParent, const ResId& rResId )
     SetSizePixel( CalcWindowSizePixel() );
     SetDropdownClickHdl( LINK(this, CommandToolBox, ToolBoxDropdownClickHdl) );
     SetItemBits( IID_DROPMODE, GetItemBits( IID_DROPMODE ) | TIB_DROPDOWNONLY );
-//	EnableItem( IID_UP, FALSE );
-//	EnableItem( IID_DOWN, FALSE );
 }
 
 //------------------------------------------------------------------------
 
-__EXPORT CommandToolBox::~CommandToolBox()
+CommandToolBox::~CommandToolBox()
 {
 }
 
 //------------------------------------------------------------------------
 
-void CommandToolBox::Select( USHORT nSelId )
+void CommandToolBox::Select( sal_uInt16 nSelId )
 {
     //	Modus umschalten ?
 
@@ -447,7 +444,6 @@ void CommandToolBox::Select( USHORT nSelId )
             case IID_DOWN:
                 rDlg.EndOfDataArea();
                 break;
-            // IID_DROPMODE ist in Click
             case IID_CHANGEROOT:
                 rDlg.aLbEntries.ToggleRoot();
                 UpdateButtons();
@@ -455,14 +451,14 @@ void CommandToolBox::Select( USHORT nSelId )
         }
 }
 
-void __EXPORT CommandToolBox::Select()
+void CommandToolBox::Select()
 {
     Select( GetCurItemId() );
 }
 
 //------------------------------------------------------------------------
 
-void __EXPORT CommandToolBox::Click()
+void CommandToolBox::Click()
 {
 }
 
@@ -478,14 +474,14 @@ IMPL_LINK( CommandToolBox, ToolBoxDropdownClickHdl, ToolBox*, EMPTYARG )
         ScPopupMenu aPop( ScResId( RID_POPUP_DROPMODE ) );
         aPop.CheckItem( RID_DROPMODE_URL + rDlg.GetDropMode() );
         aPop.Execute( this, GetItemRect(IID_DROPMODE), POPUPMENU_EXECUTE_DOWN );
-        USHORT nId = aPop.GetSelected();
+        sal_uInt16 nId = aPop.GetSelected();
 
         EndSelection();		// vor SetDropMode (SetDropMode ruft SetItemImage)
 
         if ( nId >= RID_DROPMODE_URL && nId <= RID_DROPMODE_COPY )
             rDlg.SetDropMode( nId - RID_DROPMODE_URL );
 
-        //	#49956# den gehighlighteten Button aufheben
+        //	den gehighlighteten Button aufheben
         Point aPoint;
         MouseEvent aLeave( aPoint, 0, MOUSE_LEAVEWINDOW | MOUSE_SYNTHETIC );
         MouseMove( aLeave );
@@ -505,38 +501,34 @@ void CommandToolBox::UpdateButtons()
     //	Umschalten-Button:
     if ( eMode == NAV_LMODE_SCENARIOS || eMode == NAV_LMODE_NONE )
     {
-        EnableItem( IID_CHANGEROOT,	FALSE );
-        CheckItem( IID_CHANGEROOT, FALSE );
+        EnableItem( IID_CHANGEROOT,	false );
+        CheckItem( IID_CHANGEROOT, false );
     }
     else
     {
-        EnableItem( IID_CHANGEROOT,	TRUE );
-        BOOL bRootSet = rDlg.aLbEntries.GetRootType() != SC_CONTENT_ROOT;
+        EnableItem( IID_CHANGEROOT,	sal_True );
+        sal_Bool bRootSet = rDlg.aLbEntries.GetRootType() != SC_CONTENT_ROOT;
         CheckItem( IID_CHANGEROOT, bRootSet );
     }
 
-    BOOL bHC = GetSettings().GetStyleSettings().GetHighContrastMode();
-
-    USHORT nImageId = 0;
+    sal_uInt16 nImageId = 0;
     switch ( rDlg.nDropMode )
     {
-        case SC_DROPMODE_URL:	nImageId = bHC ? RID_IMG_H_DROP_URL  : RID_IMG_DROP_URL;  break;
-        case SC_DROPMODE_LINK:	nImageId = bHC ? RID_IMG_H_DROP_LINK : RID_IMG_DROP_LINK; break;
-        case SC_DROPMODE_COPY:	nImageId = bHC ? RID_IMG_H_DROP_COPY : RID_IMG_DROP_COPY; break;
+        case SC_DROPMODE_URL:	nImageId = RID_IMG_DROP_URL;  break;
+        case SC_DROPMODE_LINK:	nImageId = RID_IMG_DROP_LINK; break;
+        case SC_DROPMODE_COPY:	nImageId = RID_IMG_DROP_COPY; break;
     }
     SetItemImage( IID_DROPMODE, Image(ScResId(nImageId)) );
 }
 
 void CommandToolBox::InitImageList()
 {
-    BOOL bHC = GetSettings().GetStyleSettings().GetHighContrastMode();
+    ImageList& rImgLst = rDlg.aCmdImageList;
 
-    ImageList& rImgLst = bHC ? rDlg.aCmdImageListH : rDlg.aCmdImageList;
-
-    USHORT nCount = GetItemCount();
-    for (USHORT i = 0; i < nCount; i++)
+    sal_uInt16 nCount = GetItemCount();
+    for (sal_uInt16 i = 0; i < nCount; i++)
     {
-        USHORT nId = GetItemId(i);
+        sal_uInt16 nId = GetItemId(i);
         SetItemImage( nId, rImgLst.GetImage( nId ) );
     }
 }
@@ -559,7 +551,7 @@ void CommandToolBox::DataChanged( const DataChangedEvent& rDCEvt )
 //==================================================================
 
 ScNavigatorSettings::ScNavigatorSettings() :
-    maExpandedVec( SC_CONTENT_COUNT, FALSE ),
+    maExpandedVec( SC_CONTENT_COUNT, false ),
     mnRootSelected( SC_CONTENT_ROOT ),
     mnChildSelected( SC_CONTENT_NOCHILD )
 {
@@ -575,7 +567,7 @@ SFX_IMPL_CHILDWINDOWCONTEXT( ScNavigatorDialogWrapper, SID_NAVIGATOR )
 
 ScNavigatorDialogWrapper::ScNavigatorDialogWrapper(
                                     Window*			 pParent,
-                                    USHORT			 nId,
+                                    sal_uInt16			 nId,
                                     SfxBindings*	 pBind,
                                     SfxChildWinInfo* /* pInfo */ ) :
         SfxChildWindowContext( nId )
@@ -597,7 +589,7 @@ ScNavigatorDialogWrapper::ScNavigatorDialogWrapper(
     //	deshalb muessen in Abhaengigkeit von der momentanen Groesse die
     //	Inhalte eingeblendet werden oder nicht
 
-    BOOL bSmall = ( aInfoSize.Height() <= pNavigator->aInitSize.Height() + SCNAV_MINTOL );
+    sal_Bool bSmall = ( aInfoSize.Height() <= pNavigator->aInitSize.Height() + SCNAV_MINTOL );
     NavListMode eNavMode = NAV_LMODE_NONE;
     if (!bSmall)
     {
@@ -611,12 +603,12 @@ ScNavigatorDialogWrapper::ScNavigatorDialogWrapper(
             eNavMode = NAV_LMODE_AREAS;
     }
 
-    //	Die Groesse des Floats nicht neu setzen (FALSE bei SetListMode), damit der
+    //	Die Groesse des Floats nicht neu setzen (sal_False bei SetListMode), damit der
     //	Navigator nicht aufgeklappt wird, wenn er minimiert war (#38872#).
 
-    pNavigator->SetListMode( eNavMode, FALSE );		// FALSE: Groesse des Float nicht setzen
+    pNavigator->SetListMode( eNavMode, false );		// FALSE: Groesse des Float nicht setzen
 
-    USHORT nCmdId;
+    sal_uInt16 nCmdId;
     switch (eNavMode)
     {
         case NAV_LMODE_DOCS:		nCmdId = IID_DOCS; 		break;
@@ -632,17 +624,9 @@ ScNavigatorDialogWrapper::ScNavigatorDialogWrapper(
     }
 
     pNavigator->bFirstBig = ( nCmdId == 0 );	// dann spaeter
-
-/*???
-    FloatingWindow* pFloat = GetFloatingWindow();
-    if ( pFloat )
-        pFloat->SetMinOutputSizePixel( pNavigator->GetMinOutputSizePixel() );
-*/
-
-//!?	pNavigator->Show();
 }
 
-void __EXPORT ScNavigatorDialogWrapper::Resizing( Size& rSize )
+void ScNavigatorDialogWrapper::Resizing( Size& rSize )
 {
     ((ScNavigatorDlg*)GetWindow())->Resizing(rSize);
 }
@@ -660,7 +644,6 @@ ScNavigatorDlg::ScNavigatorDlg( SfxBindings* pB, SfxChildWindowContext* pCW, Win
         Window( pParent, ScResId(RID_SCDLG_NAVIGATOR) ),
         rBindings	( *pB ),								// is used in CommandToolBox ctor
         aCmdImageList( ScResId( IL_CMD ) ),
-        aCmdImageListH( ScResId( ILH_CMD ) ),
         aFtCol		( this, ScResId( FT_COL ) ),
         aEdCol		( this, ScResId( ED_COL ) ),
         aFtRow		( this, ScResId( FT_ROW ) ),
@@ -682,7 +665,7 @@ ScNavigatorDlg::ScNavigatorDlg( SfxBindings* pB, SfxChildWindowContext* pCW, Win
         nCurCol		( 0 ),
         nCurRow		( 0 ),
         nCurTab		( 0 ),
-        bFirstBig	( FALSE )
+        bFirstBig	( false )
 {
     ScNavipiCfg& rCfg = SC_MOD()->GetNavipiCfg();
     nDropMode = rCfg.GetDragMode();
@@ -716,12 +699,6 @@ ScNavigatorDlg::ScNavigatorDlg( SfxBindings* pB, SfxChildWindowContext* pCW, Win
     nListModeHeight	=  aInitSize.Height()
                      + nInitListHeight;
 
-    //	kein Resize, eh der ganze Kontext-Kram initialisiert ist!
-//	SetOutputSizePixel( aInitSize );		//???
-/*!	FloatingWindow* pFloat = pContextWin->GetFloatingWindow();
-    if ( pFloat)
-        pFloat->SetMinOutputSizePixel( aInitSize );
-*/
     ppBoundItems = new ScNavigatorControllerItem* [CTRL_ITEMS];
 
     rBindings.ENTERREGISTRATIONS();
@@ -738,7 +715,7 @@ ScNavigatorDlg::ScNavigatorDlg( SfxBindings* pB, SfxChildWindowContext* pCW, Win
 
     aLbDocuments.Hide();		// bei NAV_LMODE_NONE gibts die nicht
 
-    aLbEntries.InitWindowBits(TRUE);
+    aLbEntries.InitWindowBits(sal_True);
 
     aLbEntries.SetSpaceBetweenEntries(0);
     aLbEntries.SetSelectionMode( SINGLE_SELECTION );
@@ -747,7 +724,7 @@ ScNavigatorDlg::ScNavigatorDlg( SfxBindings* pB, SfxChildWindowContext* pCW, Win
                                     SV_DRAGDROP_ENABLE_TOP );
 
     //	war eine Kategorie als Root ausgewaehlt?
-    USHORT nLastRoot = rCfg.GetRootType();
+    sal_uInt16 nLastRoot = rCfg.GetRootType();
     if ( nLastRoot )
         aLbEntries.SetRootType( nLastRoot );
 
@@ -767,15 +744,19 @@ ScNavigatorDlg::ScNavigatorDlg( SfxBindings* pB, SfxChildWindowContext* pCW, Win
     aContentTimer.SetTimeout( SC_CONTENT_TIMEOUT );
 
     FreeResource();
+
+    aLbEntries.SetAccessibleRelationLabeledBy(&aLbEntries);
+    aTbxCmd.SetAccessibleRelationLabeledBy(&aTbxCmd);
+    aLbDocuments.SetAccessibleName(aStrActiveWin);
 }
 
 //------------------------------------------------------------------------
 
-__EXPORT ScNavigatorDlg::~ScNavigatorDlg()
+ScNavigatorDlg::~ScNavigatorDlg()
 {
     aContentTimer.Stop();
 
-    USHORT i;
+    sal_uInt16 i;
     for ( i=0; i<CTRL_ITEMS; i++ )
         delete ppBoundItems[i];
 
@@ -788,7 +769,7 @@ __EXPORT ScNavigatorDlg::~ScNavigatorDlg()
 
 //------------------------------------------------------------------------
 
-void __EXPORT ScNavigatorDlg::Resizing( Size& rNewSize )  // Size = Outputsize?
+void ScNavigatorDlg::Resizing( Size& rNewSize )  // Size = Outputsize?
 {
     FloatingWindow* pFloat = pContextWin->GetFloatingWindow();
     if ( pFloat )
@@ -806,8 +787,6 @@ void __EXPORT ScNavigatorDlg::Resizing( Size& rNewSize )  // Size = Outputsize?
                 rNewSize.Height() = aMinOut.Height();
         }
     }
-//	else
-//		SfxDockingWindow::Resizing(rNewSize);
 }
 
 
@@ -838,7 +817,7 @@ void ScNavigatorDlg::DataChanged( const DataChangedEvent& rDCEvt )
 
 //------------------------------------------------------------------------
 
-void __EXPORT ScNavigatorDlg::Resize()
+void ScNavigatorDlg::Resize()
 {
     DoResize();
 }
@@ -850,27 +829,26 @@ void ScNavigatorDlg::DoResize()
     Size aNewSize = GetOutputSizePixel();
     long nTotalHeight = aNewSize.Height();
 
-    //	#41403# bei angedocktem Navigator wird das Fenster evtl. erst klein erzeugt,
+    //	bei angedocktem Navigator wird das Fenster evtl. erst klein erzeugt,
     //	dann kommt ein Resize auf die wirkliche Groesse -> dann Inhalte einschalten
 
-    BOOL bSmall = ( nTotalHeight <= aInitSize.Height() + SCNAV_MINTOL );
+    sal_Bool bSmall = ( nTotalHeight <= aInitSize.Height() + SCNAV_MINTOL );
     if ( !bSmall && bFirstBig )
     {
         //	Inhalte laut Config wieder einschalten
 
-        bFirstBig = FALSE;
+        bFirstBig = false;
         NavListMode eNavMode = NAV_LMODE_AREAS;
         ScNavipiCfg& rCfg = SC_MOD()->GetNavipiCfg();
         NavListMode eLastMode = (NavListMode) rCfg.GetListMode();
         if ( eLastMode == NAV_LMODE_SCENARIOS )
             eNavMode = NAV_LMODE_SCENARIOS;
-        SetListMode( eNavMode, FALSE );			// FALSE: Groesse des Float nicht setzen
+        SetListMode( eNavMode, false );			// FALSE: Groesse des Float nicht setzen
     }
 
     //	auch wenn die Inhalte nicht sichtbar sind, die Groessen anpassen,
     //	damit die Breite stimmt
 
-    //@@ 03.11.97 changes begin
     Point aEntryPos = aLbEntries.GetPosPixel();
     Point aListPos = aLbDocuments.GetPosPixel();
     aNewSize.Width() -= 2*nBorderOffset;
@@ -894,9 +872,7 @@ void ScNavigatorDlg::DoResize()
     aWndScenarios.SetSizePixel( aNewSize );
     aLbDocuments.SetSizePixel( aDocSize );
 
-    //@@ 03.11.97 end
-
-    BOOL bListMode = (eListMode != NAV_LMODE_NONE);
+    sal_Bool bListMode = (eListMode != NAV_LMODE_NONE);
     FloatingWindow* pFloat = pContextWin->GetFloatingWindow();
     if ( pFloat && bListMode )
         nListModeHeight = nTotalHeight;
@@ -904,11 +880,11 @@ void ScNavigatorDlg::DoResize()
 
 //------------------------------------------------------------------------
 
-void __EXPORT ScNavigatorDlg::Notify( SfxBroadcaster&, const SfxHint& rHint )
+void ScNavigatorDlg::Notify( SfxBroadcaster&, const SfxHint& rHint )
 {
     if ( rHint.ISA(SfxSimpleHint) )
     {
-        ULONG nHintId = ((SfxSimpleHint&)rHint).GetId();
+        sal_uLong nHintId = ((SfxSimpleHint&)rHint).GetId();
 
         if ( nHintId == SC_HINT_DOCNAME_CHANGED )
         {
@@ -962,7 +938,7 @@ void __EXPORT ScNavigatorDlg::Notify( SfxBroadcaster&, const SfxHint& rHint )
     }
     else if ( rHint.ISA(SfxEventHint) )
     {
-        ULONG nEventId = ((SfxEventHint&)rHint).GetEventId();
+        sal_uLong nEventId = ((SfxEventHint&)rHint).GetEventId();
         if ( nEventId == SFX_EVENT_ACTIVATEDOC )
         {
             aLbEntries.ActiveDocChanged();
@@ -984,7 +960,7 @@ IMPL_LINK( ScNavigatorDlg, TimeHdl, Timer*, pTimer )
 
 //------------------------------------------------------------------------
 
-void ScNavigatorDlg::SetDropMode(USHORT nNew)
+void ScNavigatorDlg::SetDropMode(sal_uInt16 nNew)
 {
     nDropMode = nNew;
     aTbxCmd.UpdateButtons();
@@ -1017,7 +993,7 @@ void ScNavigatorDlg::SetCurrentCell( SCCOL nColNo, SCROW nRowNo )
         String	aAddr;
         aScAddress.Format( aAddr, SCA_ABS );
 
-        BOOL bUnmark = FALSE;
+        sal_Bool bUnmark = false;
         if ( GetViewData() )
             bUnmark = !pViewData->GetMarkData().IsCellMarked( nColNo, nRowNo );
 
@@ -1106,7 +1082,7 @@ ScTabViewShell* ScNavigatorDlg::GetTabViewShell() const
 
 ScNavigatorSettings* ScNavigatorDlg::GetNavigatorSettings()
 {
-    //  #95791# Don't store the settings pointer here, because the settings belong to
+    //  Don't store the settings pointer here, because the settings belong to
     //  the view, and the view may be closed while the navigator is open (reload).
     //  If the pointer is cached here again later for performance reasons, it has to
     //  be forgotten when the view is closed.
@@ -1117,7 +1093,7 @@ ScNavigatorSettings* ScNavigatorDlg::GetNavigatorSettings()
 
 //------------------------------------------------------------------------
 
-BOOL ScNavigatorDlg::GetViewData()
+sal_Bool ScNavigatorDlg::GetViewData()
 {
     ScTabViewShell* pViewSh = GetTabViewShell();
     pViewData = pViewSh ? pViewSh->GetViewData() : NULL;
@@ -1160,7 +1136,6 @@ void ScNavigatorDlg::UpdateTable( const SCTAB* pTab )
     else if ( GetViewData() )
         nCurTab = pViewData->GetTabNo();
 
-//	aLbTables.SetTab( nCurTab );
     CheckDataArea();
 }
 
@@ -1189,30 +1164,30 @@ void ScNavigatorDlg::UpdateAll()
 
 //------------------------------------------------------------------------
 
-void ScNavigatorDlg::SetListMode( NavListMode eMode, BOOL bSetSize )
+void ScNavigatorDlg::SetListMode( NavListMode eMode, sal_Bool bSetSize )
 {
     if ( eMode != eListMode )
     {
         if ( eMode != NAV_LMODE_NONE )
-            bFirstBig = FALSE;				// nicht mehr automatisch umschalten
+            bFirstBig = false;				// nicht mehr automatisch umschalten
 
         eListMode = eMode;
 
         switch ( eMode )
         {
             case NAV_LMODE_NONE:
-                ShowList( FALSE, bSetSize );
+                ShowList( false, bSetSize );
                 break;
 
             case NAV_LMODE_AREAS:
             case NAV_LMODE_DBAREAS:
             case NAV_LMODE_DOCS:
                 aLbEntries.Refresh();
-                ShowList( TRUE, bSetSize );
+                ShowList( sal_True, bSetSize );
                 break;
 
             case NAV_LMODE_SCENARIOS:
-                ShowScenarios( TRUE, bSetSize );
+                ShowScenarios( sal_True, bSetSize );
                 break;
         }
 
@@ -1221,7 +1196,7 @@ void ScNavigatorDlg::SetListMode( NavListMode eMode, BOOL bSetSize )
         if ( eMode != NAV_LMODE_NONE )
         {
             ScNavipiCfg& rCfg = SC_MOD()->GetNavipiCfg();
-            rCfg.SetListMode( (USHORT) eMode );
+            rCfg.SetListMode( (sal_uInt16) eMode );
         }
     }
 
@@ -1231,7 +1206,7 @@ void ScNavigatorDlg::SetListMode( NavListMode eMode, BOOL bSetSize )
 
 //------------------------------------------------------------------------
 
-void ScNavigatorDlg::ShowList( BOOL bShow, BOOL bSetSize )
+void ScNavigatorDlg::ShowList( sal_Bool bShow, sal_Bool bSetSize )
 {
     FloatingWindow* pFloat = pContextWin->GetFloatingWindow();
     Size aSize = GetParent()->GetOutputSizePixel();
@@ -1276,7 +1251,7 @@ void ScNavigatorDlg::ShowList( BOOL bShow, BOOL bSetSize )
 
 //------------------------------------------------------------------------
 
-void ScNavigatorDlg::ShowScenarios( BOOL bShow, BOOL bSetSize )
+void ScNavigatorDlg::ShowScenarios( sal_Bool bShow, sal_Bool bSetSize )
 {
     FloatingWindow* pFloat = pContextWin->GetFloatingWindow();
     Size aSize = GetParent()->GetOutputSizePixel();
@@ -1332,7 +1307,7 @@ void ScNavigatorDlg::ShowScenarios( BOOL bShow, BOOL bSetSize )
 void ScNavigatorDlg::GetDocNames( const String* pManualSel )
 {
     aLbDocuments.Clear();
-    aLbDocuments.SetUpdateMode( FALSE );
+    aLbDocuments.SetUpdateMode( false );
 
     ScDocShell* pCurrentSh = PTR_CAST( ScDocShell, SfxObjectShell::Current() );
 
@@ -1371,7 +1346,7 @@ void ScNavigatorDlg::GetDocNames( const String* pManualSel )
             aSelEntry = aEntry;
     }
 
-    aLbDocuments.SetUpdateMode( TRUE );
+    aLbDocuments.SetUpdateMode( sal_True );
 
     aLbDocuments.SelectEntry( aSelEntry );
 }
@@ -1471,7 +1446,7 @@ void ScNavigatorDlg::EndOfDataArea()
 
 //------------------------------------------------------------------------
 
-SfxChildAlignment __EXPORT ScNavigatorDlg::CheckAlignment(
+SfxChildAlignment ScNavigatorDlg::CheckAlignment(
                             SfxChildAlignment eActAlign, SfxChildAlignment eAlign )
 {
     SfxChildAlignment eRetAlign;
