@@ -83,12 +83,11 @@ using namespace com::sun::star;
 
 void ScDrawView::Construct()
 {
-    EnableExtendedKeyInputDispatcher(FALSE);
-    EnableExtendedMouseEventDispatcher(FALSE);
-    EnableExtendedCommandEventDispatcher(FALSE);
+    EnableExtendedKeyInputDispatcher(false);
+    EnableExtendedMouseEventDispatcher(false);
+    EnableExtendedCommandEventDispatcher(false);
 
-    SetFrameDragSingles(TRUE);
-//	SetSolidMarkHdl(TRUE);				// einstellbar -> UpdateUserViewOptions
+    SetFrameDragSingles(true);
 
     SetMinMoveDistancePixel( 2 );
     SetHitTolerancePixel( 2 );
@@ -98,8 +97,8 @@ void ScDrawView::Construct()
         SCTAB nViewTab = pViewData->GetTabNo();
         ShowSdrPage(GetModel()->GetPage(nViewTab));
 
-        BOOL bEx = pViewData->GetViewShell()->IsDrawSelMode();
-        BOOL bProt = pDoc->IsTabProtected( nViewTab ) ||
+        sal_Bool bEx = pViewData->GetViewShell()->IsDrawSelMode();
+        sal_Bool bProt = pDoc->IsTabProtected( nViewTab ) ||
                      pViewData->GetSfxDocShell()->IsReadOnly();
 
         SdrLayer* pLayer;
@@ -109,12 +108,12 @@ void ScDrawView::Construct()
             SetLayerLocked( pLayer->GetName(), bProt || !bEx );
         pLayer = rAdmin.GetLayerPerID(SC_LAYER_INTERN);
         if (pLayer)
-            SetLayerLocked( pLayer->GetName(), TRUE );
+            SetLayerLocked( pLayer->GetName(), sal_True );
         pLayer = rAdmin.GetLayerPerID(SC_LAYER_FRONT);
         if (pLayer)
         {
             SetLayerLocked( pLayer->GetName(), bProt );
-            SetActiveLayer( pLayer->GetName() );		// FRONT als aktiven Layer setzen
+            SetActiveLayer( pLayer->GetName() );		// set active layer to FRONT
         }
         pLayer = rAdmin.GetLayerPerID(SC_LAYER_CONTROLS);
         if (pLayer)
@@ -123,10 +122,10 @@ void ScDrawView::Construct()
         if (pLayer)
         {
             SetLayerLocked( pLayer->GetName(), bProt );
-            SetLayerVisible( pLayer->GetName(), sal_False);
+            SetLayerVisible( pLayer->GetName(), false);
         }
 
-        SetSwapAsynchron(TRUE);
+        SetSwapAsynchron(sal_True);
     }
     else
     {
@@ -137,7 +136,7 @@ void ScDrawView::Construct()
     RecalcScale();
     UpdateWorkArea();
 
-    bInConstruct = FALSE;
+    bInConstruct = false;
 }
 
 void ScDrawView::ImplClearCalcDropMarker()
@@ -149,53 +148,22 @@ void ScDrawView::ImplClearCalcDropMarker()
     }
 }
 
-__EXPORT ScDrawView::~ScDrawView()
+ScDrawView::~ScDrawView()
 {
     ImplClearCalcDropMarker();
 }
 
 void ScDrawView::AddCustomHdl()
 {
-    BOOL bNegativePage = pDoc->IsNegativePage( nTab );
-
     const SdrMarkList &rMrkList = GetMarkedObjectList();
-    UINT32 nCount = rMrkList.GetMarkCount();
-    for(UINT32 nPos=0; nPos<nCount; nPos++ )
+    sal_uInt32 nCount = rMrkList.GetMarkCount();
+    for(sal_uInt32 nPos=0; nPos<nCount; nPos++ )
     {
-        const SdrObject* pObj = rMrkList.GetMark(nPos)->GetMarkedSdrObj();
-        if(ScDrawLayer::GetAnchor(pObj) == SCA_CELL)
+        SdrObject* pObj = rMrkList.GetMark(nPos)->GetMarkedSdrObj();
+        if (ScDrawObjData *pAnchor = ScDrawLayer::GetObjDataTab(pObj, nTab))
         {
-            const INT32 nDelta = 1;
-
-            Rectangle aBoundRect = pObj->GetCurrentBoundRect();
-            Point aPos;
-            if (bNegativePage)
-            {
-                aPos = aBoundRect.TopRight();
-                aPos.X() = -aPos.X();			// so the loop below is the same
-            }
-            else
-                aPos = aBoundRect.TopLeft();
-            long nPosX = (long) (aPos.X() / HMM_PER_TWIPS) + nDelta;
-            long nPosY = (long) (aPos.Y() / HMM_PER_TWIPS) + nDelta;
-
-            SCCOL nCol;
-            INT32 nWidth = 0;
-
-            for(nCol=0; nCol<=MAXCOL && nWidth<=nPosX; nCol++)
-                nWidth += pDoc->GetColWidth(nCol,nTab);
-
-            if(nCol > 0)
-                --nCol;
-
-            SCROW nRow = nPosY <= 0 ? 0 : pDoc->GetRowForHeight( nTab,
-                    (ULONG) nPosY);
-            if(nRow > 0)
-                --nRow;
-
-            ScTabView* pView = pViewData->GetView();
-            ScAddress aScAddress(nCol, nRow, nTab);
-            pView->CreateAnchorHandles(aHdl, aScAddress);
+            if (ScTabView* pView = pViewData->GetView())
+                pView->CreateAnchorHandles(aHdl, pAnchor->maStart);
         }
     }
 }
@@ -205,8 +173,8 @@ void ScDrawView::InvalidateAttribs()
     if (!pViewData) return;
     SfxBindings& rBindings = pViewData->GetBindings();
 
-        // echte Statuswerte:
-    rBindings.InvalidateAll( TRUE );
+        // true status values:
+    rBindings.InvalidateAll( true );
 }
 
 void ScDrawView::InvalidateDrawTextAttrs()
@@ -248,21 +216,7 @@ void ScDrawView::InvalidateDrawTextAttrs()
     rBindings.Invalidate( SID_ALIGN_ANY_JUSTIFIED );
 }
 
-//void ScDrawView::DrawMarks( OutputDevice* pOut ) const
-//{
-//	DBG_ASSERT(pOut, "ScDrawView::DrawMarks: No OutputDevice (!)");
-//	SdrPaintWindow* pPaintWindow = FindPaintWindow(*pOut);
-//
-//	if(pPaintWindow)
-//	{
-//		if(pPaintWindow->isXorVisible())
-//		{
-//			ToggleShownXor(pOut, 0L);
-//		}
-//	}
-//}
-
-void ScDrawView::SetMarkedToLayer( BYTE nLayerNo )
+void ScDrawView::SetMarkedToLayer( sal_uInt8 nLayerNo )
 {
     if (AreObjectsMarked())
     {
@@ -271,8 +225,8 @@ void ScDrawView::SetMarkedToLayer( BYTE nLayerNo )
         BegUndo( ScGlobal::GetRscString( STR_UNDO_SELATTR ) );
 
         const SdrMarkList& rMark = GetMarkedObjectList();
-        ULONG nCount = rMark.GetMarkCount();
-        for (ULONG i=0; i<nCount; i++)
+        sal_uLong nCount = rMark.GetMarkCount();
+        for (sal_uLong i=0; i<nCount; i++)
         {
             SdrObject* pObj = rMark.GetMark(i)->GetMarkedSdrObj();
             if ( !pObj->ISA(SdrUnoObj) && (pObj->GetLayer() != SC_LAYER_INTERN) )
@@ -288,7 +242,7 @@ void ScDrawView::SetMarkedToLayer( BYTE nLayerNo )
 
         pViewData->GetDocShell()->SetDrawModified();
 
-        //	#84073# check mark list now instead of later in a timer
+        //	check mark list now instead of later in a timer
         CheckMarked();
         MarkListHasChanged();
     }
@@ -331,7 +285,7 @@ void ScDrawView::UpdateWorkArea()
     }
     else
     {
-        DBG_ERROR("Page nicht gefunden");
+        OSL_FAIL("Page nicht gefunden");
     }
 }
 
@@ -403,7 +357,7 @@ void ScDrawView::MarkListHasChanged()
     {
         pViewSh->Unmark();      // remove cell selection
 
-        //	#65379# end cell edit mode if drawing objects are selected
+        //	end cell edit mode if drawing objects are selected
         SC_MOD()->InputEnterHandler();
     }
 
@@ -415,10 +369,8 @@ void ScDrawView::MarkListHasChanged()
     ScClient* pClient = (ScClient*) pViewSh->GetIPClient();
     if ( pClient && pClient->IsObjectInPlaceActive() && !bUnoRefDialog )
     {
-        //	#41730# beim ViewShell::Activate aus dem Reset2Open nicht die Handles anzeigen
-        //HMHbDisableHdl = TRUE;
+        //	beim ViewShell::Activate aus dem Reset2Open nicht die Handles anzeigen
         pClient->DeactivateObject();
-        //HMHbDisableHdl = FALSE;
         //	Image-Ole wieder durch Grafik ersetzen passiert jetzt in ScClient::UIActivate
     }
 
@@ -426,10 +378,9 @@ void ScDrawView::MarkListHasChanged()
 
     SdrOle2Obj* pOle2Obj = NULL;
     SdrGrafObj* pGrafObj = NULL;
-    SdrMediaObj* pMediaObj = NULL;
 
     const SdrMarkList& rMarkList = GetMarkedObjectList();
-    ULONG nMarkCount = rMarkList.GetMarkCount();
+    sal_uLong nMarkCount = rMarkList.GetMarkCount();
 
     if ( nMarkCount == 0 && !pViewData->GetViewShell()->IsDrawSelMode() && !bInConstruct )
     {
@@ -438,7 +389,7 @@ void ScDrawView::MarkListHasChanged()
         LockInternalLayer();
     }
 
-    BOOL bSubShellSet = FALSE;
+    sal_Bool bSubShellSet = false;
     if (nMarkCount == 1)
     {
         SdrObject* pObj = rMarkList.GetMark(0)->GetMarkedSdrObj();
@@ -446,56 +397,55 @@ void ScDrawView::MarkListHasChanged()
         {
             pOle2Obj = (SdrOle2Obj*) pObj;
             if (!pDoc->IsChart(pObj) )
-                pViewSh->SetOleObjectShell(TRUE);
+                pViewSh->SetOleObjectShell(sal_True);
             else
-                pViewSh->SetChartShell(TRUE);
-            bSubShellSet = TRUE;
+                pViewSh->SetChartShell(sal_True);
+            bSubShellSet = sal_True;
         }
         else if (pObj->GetObjIdentifier() == OBJ_GRAF)
         {
             pGrafObj = (SdrGrafObj*) pObj;
-            pViewSh->SetGraphicShell(TRUE);
-            bSubShellSet = TRUE;
+            pViewSh->SetGraphicShell(sal_True);
+            bSubShellSet = sal_True;
         }
         else if (pObj->GetObjIdentifier() == OBJ_MEDIA)
         {
-            pMediaObj = (SdrMediaObj*) pObj;
-            pViewSh->SetMediaShell(TRUE);
-            bSubShellSet = TRUE;
+            pViewSh->SetMediaShell(true);
+            bSubShellSet = true;
         }
         else if (pObj->GetObjIdentifier() != OBJ_TEXT   // Verhindern, das beim Anlegen
                     || !pViewSh->IsDrawTextShell())		// eines TextObjekts auf die
         {												// DrawShell umgeschaltet wird.
-            pViewSh->SetDrawShell(TRUE);				//@#70206#
+            pViewSh->SetDrawShell(sal_True);				//@#70206#
         }
     }
 
     if ( nMarkCount && !bSubShellSet )
     {
-        BOOL bOnlyControls = TRUE;
-        BOOL bOnlyGraf     = TRUE;
-        for (ULONG i=0; i<nMarkCount; i++)
+        sal_Bool bOnlyControls = sal_True;
+        sal_Bool bOnlyGraf     = sal_True;
+        for (sal_uLong i=0; i<nMarkCount; i++)
         {
             SdrObject* pObj = rMarkList.GetMark(i)->GetMarkedSdrObj();
             if ( pObj->ISA( SdrObjGroup ) )
             {
                 const SdrObjList *pLst = ((SdrObjGroup*)pObj)->GetSubList();
-                ULONG nListCount = pLst->GetObjCount();
+                sal_uLong nListCount = pLst->GetObjCount();
                 if ( nListCount == 0 )
                 {
-                    //	#104156# An empty group (may occur during Undo) is no control or graphics object.
+                    //	An empty group (may occur during Undo) is no control or graphics object.
                     //	Creating the form shell during undo would lead to problems with the undo manager.
-                    bOnlyControls = FALSE;
-                    bOnlyGraf = FALSE;
+                    bOnlyControls = false;
+                    bOnlyGraf = false;
                 }
-                for ( USHORT j = 0; j < nListCount; ++j )
+                for ( sal_uInt16 j = 0; j < nListCount; ++j )
                 {
                     SdrObject *pSubObj = pLst->GetObj( j );
 
                     if (!pSubObj->ISA(SdrUnoObj))
-                        bOnlyControls = FALSE;
+                        bOnlyControls = false;
                     if (pSubObj->GetObjIdentifier() != OBJ_GRAF)
-                        bOnlyGraf = FALSE;
+                        bOnlyGraf = false;
 
                     if ( !bOnlyControls && !bOnlyGraf ) break;
                 }
@@ -503,9 +453,9 @@ void ScDrawView::MarkListHasChanged()
             else
             {
                 if (!pObj->ISA(SdrUnoObj))
-                    bOnlyControls = FALSE;
+                    bOnlyControls = false;
                 if (pObj->GetObjIdentifier() != OBJ_GRAF)
-                    bOnlyGraf = FALSE;
+                    bOnlyGraf = false;
             }
 
             if ( !bOnlyControls && !bOnlyGraf ) break;
@@ -513,15 +463,15 @@ void ScDrawView::MarkListHasChanged()
 
         if(bOnlyControls)
         {
-            pViewSh->SetDrawFormShell(TRUE);			// jetzt UNO-Controls
+            pViewSh->SetDrawFormShell(sal_True);			// jetzt UNO-Controls
         }
         else if(bOnlyGraf)
         {
-            pViewSh->SetGraphicShell(TRUE);
+            pViewSh->SetGraphicShell(sal_True);
         }
         else if(nMarkCount>1)
         {
-            pViewSh->SetDrawShell(TRUE);
+            pViewSh->SetDrawShell(sal_True);
         }
     }
 
@@ -530,20 +480,16 @@ void ScDrawView::MarkListHasChanged()
     //	Verben anpassen
 
     SfxViewFrame* pViewFrame = pViewSh->GetViewFrame();
-    BOOL bOle = pViewSh->GetViewFrame()->GetFrame().IsInPlace();
+    sal_Bool bOle = pViewSh->GetViewFrame()->GetFrame().IsInPlace();
+    uno::Sequence< embed::VerbDescriptor > aVerbs;
     if ( pOle2Obj && !bOle )
     {
         uno::Reference < embed::XEmbeddedObject > xObj = pOle2Obj->GetObjRef();
+        DBG_ASSERT( xObj.is(), "SdrOle2Obj ohne ObjRef" );
         if (xObj.is())
-            pViewSh->SetVerbs( xObj->getSupportedVerbs() );
-        else
-        {
-            DBG_ERROR("SdrOle2Obj ohne ObjRef");
-            pViewSh->SetVerbs( 0 );
-        }
+            aVerbs = xObj->getSupportedVerbs();
     }
-    else
-        pViewSh->SetVerbs( 0 );
+    pViewSh->SetVerbs( aVerbs );
 
     //	Image-Map Editor
 
@@ -587,12 +533,12 @@ void ScDrawView::MarkListHasChanged()
 
 }
 
-void __EXPORT ScDrawView::ModelHasChanged()
+void ScDrawView::ModelHasChanged()
 {
     SdrObject* pEditObj = GetTextEditObject();
     if ( pEditObj && !pEditObj->IsInserted() && pViewData )
     {
-        //	#111700# SdrObjEditView::ModelHasChanged will end text edit in this case,
+        //	SdrObjEditView::ModelHasChanged will end text edit in this case,
         //	so make sure the EditEngine's undo manager is no longer used.
         pViewData->GetViewShell()->SetDrawTextUndo(NULL);
         SetCreateMode();	// don't leave FuText in a funny state
@@ -601,14 +547,14 @@ void __EXPORT ScDrawView::ModelHasChanged()
     FmFormView::ModelHasChanged();
 }
 
-void __EXPORT ScDrawView::UpdateUserViewOptions()
+void ScDrawView::UpdateUserViewOptions()
 {
     if (pViewData)
     {
         const ScViewOptions&	rOpt = pViewData->GetOptions();
         const ScGridOptions&	rGrid = rOpt.GetGridOptions();
 
-        BOOL bBigHdl = rOpt.GetOption( VOPT_BIGHANDLES );
+        sal_Bool bBigHdl = rOpt.GetOption( VOPT_BIGHANDLES );
 
         SetDragStripes( rOpt.GetOption( VOPT_HELPLINES ) );
         SetSolidMarkHdl( rOpt.GetOption( VOPT_SOLIDHANDLES ) );
@@ -618,9 +564,6 @@ void __EXPORT ScDrawView::UpdateUserViewOptions()
         SetSnapEnabled( rGrid.GetUseGridSnap() );
         SetGridSnap( rGrid.GetUseGridSnap() );
 
-        //	Snap from grid options is no longer used
-//		SetSnapGrid( Size( rGrid.GetFldSnapX(), rGrid.GetFldSnapY() ) );
-
         Fraction aFractX( rGrid.GetFldDrawX(), rGrid.GetFldDivisionX() + 1 );
         Fraction aFractY( rGrid.GetFldDrawY(), rGrid.GetFldDivisionY() + 1 );
         SetSnapGridWidth( aFractX, aFractY );
@@ -635,7 +578,7 @@ void __EXPORT ScDrawView::UpdateUserViewOptions()
 #pragma optimize ( "", on )
 #endif
 
-BOOL ScDrawView::SelectObject( const String& rName )
+sal_Bool ScDrawView::SelectObject( const String& rName )
 {
     UnmarkAll();
 
@@ -678,7 +621,7 @@ BOOL ScDrawView::SelectObject( const String& rName )
 
         pView->ScrollToObject( pFound );
 
-        /*  #61585# To select an object on the background layer, the layer has to
+        /*  To select an object on the background layer, the layer has to
             be unlocked even if exclusive drawing selection mode is not active
             (this is reversed in MarkListHasChanged when nothing is selected) */
         if ( pFound->GetLayer() == SC_LAYER_BACK &&
@@ -697,7 +640,7 @@ BOOL ScDrawView::SelectObject( const String& rName )
 }
 
 
-bool ScDrawView::InsertObjectSafe(SdrObject* pObj, SdrPageView& rPV, ULONG nOptions)
+bool ScDrawView::InsertObjectSafe(SdrObject* pObj, SdrPageView& rPV, sal_uLong nOptions)
 {
     //	Markierung nicht aendern, wenn Ole-Objekt aktiv
     //	(bei Drop aus Ole-Objekt wuerde sonst mitten im ExecuteDrag deaktiviert!)
@@ -734,7 +677,7 @@ void ScDrawView::LockCalcLayer( SdrLayerID nLayer, bool bLock )
         SetLayerLocked( pLockLayer->GetName(), bLock );
 }
 
-void __EXPORT ScDrawView::MakeVisible( const Rectangle& rRect, Window& rWin )
+void ScDrawView::MakeVisible( const Rectangle& rRect, Window& rWin )
 {
     //!	rWin richtig auswerten
     //!	ggf Zoom aendern
@@ -752,7 +695,7 @@ void ScDrawView::DeleteMarked()
         (void)pCaptObj; // prevent 'unused variable' compiler warning in pro builds
         ScDrawLayer* pDrawLayer = pDoc->GetDrawLayer();
         ScDocShell* pDocShell = pViewData ? pViewData->GetDocShell() : 0;
-        SfxUndoManager* pUndoMgr = pDocShell ? pDocShell->GetUndoManager() : 0;
+        ::svl::IUndoManager* pUndoMgr = pDocShell ? pDocShell->GetUndoManager() : 0;
         bool bUndo = pDrawLayer && pDocShell && pUndoMgr && pDoc->IsUndoEnabled();
 
         // remove the cell note from document, we are its owner now
@@ -784,7 +727,7 @@ void ScDrawView::DeleteMarked()
 
 SdrEndTextEditKind ScDrawView::ScEndTextEdit()
 {
-    BOOL bIsTextEdit = IsTextEdit();
+    sal_Bool bIsTextEdit = IsTextEdit();
     SdrEndTextEditKind eKind = SdrEndTextEdit();
 
     if ( bIsTextEdit && pViewData )
