@@ -54,10 +54,10 @@ namespace scripting_runtimemgr
 {
 
 const sal_Char* const LANGUAGE_TO_RESOLVE_ON[] = { "All" }; // should be configurable
-OUString nrs_implName = OUString::createFromAscii( 
-    "drafts.com.sun.star.script.framework.runtime.DefaultScriptNameResolver" );
-OUString nrs_serviceName = OUString::createFromAscii( 
-    "drafts.com.sun.star.script.framework.runtime.DefaultScriptNameResolver" );
+OUString nrs_implName(RTL_CONSTASCII_USTRINGPARAM(
+    "drafts.com.sun.star.script.framework.runtime.DefaultScriptNameResolver" ));
+OUString nrs_serviceName(RTL_CONSTASCII_USTRINGPARAM(
+    "drafts.com.sun.star.script.framework.runtime.DefaultScriptNameResolver" ));
 Sequence< OUString > nrs_serviceNames = Sequence< OUString >( &nrs_serviceName, 1 );
 
 const char* const SCRIPTSTORAGEMANAGER_SERVICE =
@@ -71,13 +71,11 @@ static ::std::vector< sal_Int32 >* m_pSearchIDs = NULL;
 //*************************************************************************
 ScriptNameResolverImpl::ScriptNameResolverImpl(
     const Reference< XComponentContext > & xContext ) :
-    m_xContext( xContext )
+    m_xContext( xContext, UNO_SET_THROW )
 {
     OSL_TRACE( "< ScriptNameResolverImpl ctor called >\n" );
     validateXRef( m_xContext, "ScriptNameResolverImpl::ScriptNameResolverImpl: invalid context" );
-    m_xMultiComFac = m_xContext->getServiceManager();
-
-    validateXRef( m_xMultiComFac, "ScriptNameResolverImpl::ScriptNameResolverImpl: invalid XMultiComponentFactory " );
+    m_xMultiComFac.set( m_xContext->getServiceManager(), UNO_SET_THROW );
 
     if( !m_pSearchIDs )
     {
@@ -173,10 +171,10 @@ throw ( lang::IllegalArgumentException, script::CannotConvertException, RuntimeE
 
 
     OSL_TRACE( "ScriptNameResolverImpl::resolve Starting..." );
-    OUString docString = OUString::createFromAscii( "location=document" );
-    OUString userString = OUString::createFromAscii( "location=user" );
-    OUString shareString = OUString::createFromAscii( "location=share" );
-    OUString filesysString = OUString::createFromAscii( "location=filesystem" );
+    OUString docString(RTL_CONSTASCII_USTRINGPARAM("location=document"));
+    OUString userString(RTL_CONSTASCII_USTRINGPARAM("location=user"));
+    OUString shareString(RTL_CONSTASCII_USTRINGPARAM("location=share"));
+    OUString filesysString(RTL_CONSTASCII_USTRINGPARAM("location=filesystem"));
 
     // initialise vector with doc, user and share
 
@@ -221,11 +219,14 @@ throw ( lang::IllegalArgumentException, script::CannotConvertException, RuntimeE
             OUString temp = OUSTR( "ScriptNameResolverImpl::resolve: " );
             throw RuntimeException( temp.concat( e.Message ), Reference< XInterface >() );
         }
-        Reference< XInterface > xInterface = m_xMultiComFac->createInstanceWithContext(
-            ::rtl::OUString::createFromAscii( 
-                    "com.sun.star.ucb.SimpleFileAccess" ), m_xContext );
-        validateXRef( xInterface,
-            "ScriptProvider::initialise: cannot get SimpleFileAccess Service\n" );
+        Reference< XInterface > xInterface(
+            m_xMultiComFac->createInstanceWithContext(
+                ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+                    "com.sun.star.ucb.SimpleFileAccess" ),
+                m_xContext
+            ),
+            UNO_SET_THROW
+        );
         Reference < ucb::XSimpleFileAccess > xSimpleFileAccess = Reference <
                     ucb::XSimpleFileAccess > ( xInterface, UNO_QUERY_THROW );
 
@@ -237,15 +238,8 @@ throw ( lang::IllegalArgumentException, script::CannotConvertException, RuntimeE
         try
         {
             // need to get the ScriptStorageManager
-            Any a = m_xContext->getValueByName( 
-                    scriptingConstantsPool.SCRIPTSTORAGEMANAGER_SERVICE );
-            if ( sal_False == ( a >>= xScriptStorageMgr ) )
-            {
-                OUString temp = OUSTR( "ScriptNameResolverImpl::resolve: failed to get ScriptStorageManager" );
-                throw RuntimeException( temp, Reference< XInterface >() );
-                // need to throw
-            }
-            validateXRef( xScriptStorageMgr, "Cannot get ScriptStorageManager" );
+            xScriptStorageMgr.set( m_xContext->getValueByName( 
+                    scriptingConstantsPool.SCRIPTSTORAGEMANAGER_SERVICE ), UNO_QUERY_THROW );
             filesysScriptStorageID =
                     xScriptStorageMgr->createScriptStorageWithURI( 
                         xSimpleFileAccess, filesysURL );
@@ -270,7 +264,7 @@ throw ( lang::IllegalArgumentException, script::CannotConvertException, RuntimeE
         // b) an illegal location
 
         // detect illegal location
-        if (  scriptURI.indexOf( OUString::createFromAscii( "location=" ) ) != -1 )
+        if (  scriptURI.indexOf( OUString(RTL_CONSTASCII_USTRINGPARAM("location=")) ) != -1 )
         {
             OSL_TRACE( 
                 "ScriptNameResolver::resolve, throwing IllegalArgException" );
@@ -365,20 +359,12 @@ throw ( lang::IllegalArgumentException, script::CannotConvertException, RuntimeE
         if( filesysScriptStorageID >  2 )
         {
             // get the filesys storage and dispose of it
-            Reference< XInterface > xScriptStorage =
-                xScriptStorageMgr->getScriptStorage( filesysScriptStorageID );
-            validateXRef( xScriptStorage,
-                          "ScriptNameResolverImpl::getStorageInstance: cannot get Script Storage service" );
+            Reference< XInterface > xScriptStorage( xScriptStorageMgr->getScriptStorage( filesysScriptStorageID ), UNO_SET_THROW );
             Reference< storage::XScriptInfoAccess > xScriptInfoAccess = Reference< 
                 storage::XScriptInfoAccess > ( xScriptStorage, UNO_QUERY_THROW );
-            validateXRef( xScriptInfoAccess,
-            "ScriptNameResolverImpl::resolveURIFromStorageID: cannot get XScriptInfoAccess" );
             Sequence< Reference< storage::XScriptInfo > > results =
                 xScriptInfoAccess->getAllImplementations( );
-            Reference < lang::XEventListener > xEL_ScriptStorageMgr =
-                Reference< lang::XEventListener > 
-                    ( xScriptStorageMgr ,UNO_QUERY_THROW );
-            validateXRef( xEL_ScriptStorageMgr, "ScriptNameResolverImpl::resolve: can't get ScriptStorageManager XEventListener interface when trying to dispose of filesystem storage" );
+            Reference < lang::XEventListener > xEL_ScriptStorageMgr(( xScriptStorageMgr ,UNO_QUERY_THROW );
             lang::EventObject event( results[ 0 ] );
             xEL_ScriptStorageMgr->disposing( event );
         }
@@ -432,7 +418,7 @@ SAL_THROW ( ( lang::IllegalArgumentException, css::security::AccessControlExcept
     try
     {
         OUString permissionURI = docURI;
-        OUString filesysString = OUString::createFromAscii( "location=filesystem" );
+        OUString filesysString(RTL_CONSTASCII_USTRINGPARAM("location=filesystem"));
         if ( scriptURI.indexOf( filesysString ) != -1 )
         {
             // in the case of filesys scripts we're checking whether the
@@ -448,9 +434,7 @@ SAL_THROW ( ( lang::IllegalArgumentException, css::security::AccessControlExcept
                 throw RuntimeException( temp.concat( e.Message ), Reference< XInterface >() );
             }
         }
-        Reference< storage::XScriptInfoAccess > storage = getStorageInstance( sid, permissionURI ); 
-        validateXRef( storage,
-        "ScriptNameResolverImpl::resolveURIFromStorageID: cannot get XScriptInfoAccess" );
+        Reference< storage::XScriptInfoAccess > storage( getStorageInstance( sid, permissionURI ), UNO_SET_THROW );
         Sequence< Reference< storage::XScriptInfo > > results =
             storage->getImplementations( scriptURI );
         
@@ -517,22 +501,10 @@ const ::rtl::OUString & permissionURI ) SAL_THROW ( ( RuntimeException, css::sec
     Reference< storage::XScriptInfoAccess > xScriptInfoAccess;
     try
     {
-        Reference< XInterface > xInterface;
-
-        Any a = m_xContext->getValueByName(
-                    OUString::createFromAscii( SCRIPTSTORAGEMANAGER_SERVICE ) );
-        if ( sal_False == ( a >>= xInterface ) )
-        {
-            throw RuntimeException( 
-                OUSTR( "ScriptNameResolverImpl::getStorageInstance: could not obtain ScriptStorageManager singleton" ),
-                Reference< XInterface >() );
-        }
-        validateXRef( xInterface,
-                      "ScriptNameResolverImpl::getStorageInstance: cannot get Storage service" );
+        Reference< XInterface > xInterface( m_xContext->getValueByName(
+                    OUString::createFromAscii( SCRIPTSTORAGEMANAGER_SERVICE ) ), UNO_QUERY_THROW );
         // check that we have permissions for this storage
         Reference< dcsssf::security::XScriptSecurity > xScriptSecurity( xInterface, UNO_QUERY_THROW );
-        validateXRef( xScriptSecurity,
-                      "ScriptNameResolverImpl::getStorageInstance:  cannot get Script Security service" );
         scripting_constants::ScriptingConstantsPool& scriptingConstantsPool = 
                 scripting_constants::ScriptingConstantsPool::instance();
         // if we dealing with a document storage (ie. not user or share
@@ -541,20 +513,14 @@ const ::rtl::OUString & permissionURI ) SAL_THROW ( ( RuntimeException, css::sec
             ( sid != scriptingConstantsPool.SHARED_STORAGE_ID ) )
         {
             xScriptSecurity->checkPermission( permissionURI,
-                OUString::createFromAscii( "execute" ) );
+                OUString(RTL_CONSTASCII_USTRINGPARAM("execute")) );
             // if we get here, the checkPermission hasn't thrown an
             // AccessControlException, ie. permission has been granted
             OSL_TRACE( "ScriptNameResolverImpl::getStorageInstance: got execute permission for ID=%d", sid );
         }
         Reference< storage::XScriptStorageManager > xScriptStorageManager( xInterface, UNO_QUERY_THROW );
-        validateXRef( xScriptStorageManager,
-                      "ScriptNameResolverImpl::getStorageInstance:  cannot get Script Storage Manager service" );
-        Reference< XInterface > xScriptStorage =
-            xScriptStorageManager->getScriptStorage( sid );
-        validateXRef( xScriptStorage,
-                      "ScriptNameResolverImpl::getStorageInstance: cannot get Script Storage service" );
-        xScriptInfoAccess = Reference< 
-            storage::XScriptInfoAccess > ( xScriptStorage, UNO_QUERY_THROW );
+        Reference< XInterface > xScriptStorage( ScriptStorageManager->getScriptStorage( sid ), UNO_SET_THROW );
+        xScriptInfoAccess.set( xScriptStorage, UNO_QUERY_THROW );
     }
     catch ( lang::IllegalArgumentException & e )
     {
@@ -586,7 +552,7 @@ throw( lang::IllegalArgumentException )
 {
         OUString filePath;
         OUString fileName;
-        OUString filesysString = OUString::createFromAscii( "location=filesystem" );
+        OUString filesysString(RTL_CONSTASCII_USTRINGPARAM("location=filesystem"));
         sal_Int32 locationPos = scriptURI.indexOf( filesysString );
         // expect location=filesys:file:///foo/bar/myscript.bsh etc
         // except the file url at this point is encoded
@@ -603,7 +569,7 @@ throw( lang::IllegalArgumentException )
                                 endOfLocn - locationPos - filesysStrLen );
         }
         //file name shoul also be encoded so again ok to search for '&'
-        OUString functionKey = OUString::createFromAscii( "function=" );
+        OUString functionKey(RTL_CONSTASCII_USTRINGPARAM("function="));
         sal_Int32 functionKeyLength = functionKey.getLength();
         sal_Int32 functionNamePos = scriptURI.indexOf( functionKey );
         if ( functionNamePos > 0 )
