@@ -115,11 +115,11 @@ extern OUString getAnnotationDateTimeString( const Reference< XAnnotation >& xAn
 extern SfxItemPool* GetAnnotationPool();
 extern com::sun::star::util::DateTime getCurrentDateTime();
 
-Color ColorFromAlphaColor(UINT8 aTransparency, Color &aFront, Color &aBack )
+Color ColorFromAlphaColor(sal_uInt8 aTransparency, Color &aFront, Color &aBack )
 {
-    return Color((UINT8)(aFront.GetRed()	* aTransparency/(double)255	+ aBack.GetRed()	* (1-aTransparency/(double)255)),
-                 (UINT8)(aFront.GetGreen()	* aTransparency/(double)255	+ aBack.GetGreen()	* (1-aTransparency/(double)255)),
-                 (UINT8)(aFront.GetBlue()	* aTransparency/(double)255	+ aBack.GetBlue()	* (1-aTransparency/(double)255)));
+    return Color((sal_uInt8)(aFront.GetRed()	* aTransparency/(double)255	+ aBack.GetRed()	* (1-aTransparency/(double)255)),
+                 (sal_uInt8)(aFront.GetGreen()	* aTransparency/(double)255	+ aBack.GetGreen()	* (1-aTransparency/(double)255)),
+                 (sal_uInt8)(aFront.GetBlue()	* aTransparency/(double)255	+ aBack.GetBlue()	* (1-aTransparency/(double)255)));
 }
 
 /************ AnnotationTextWindow **********************************/
@@ -161,7 +161,7 @@ void AnnotationTextWindow::Paint( const Rectangle& rRect)
 void AnnotationTextWindow::KeyInput( const KeyEvent& rKeyEvt )
 {
     const KeyCode& rKeyCode = rKeyEvt.GetKeyCode();
-    USHORT nKey = rKeyCode.GetCode();
+    sal_uInt16 nKey = rKeyCode.GetCode();
 
     if ((rKeyCode.IsMod1() && rKeyCode.IsMod2()) && ((nKey == KEY_PAGEUP) || (nKey == KEY_PAGEDOWN)))
     {
@@ -212,7 +212,7 @@ void AnnotationTextWindow::MouseButtonDown( const MouseEvent& rMEvt )
     GrabFocus();
     if ( mpOutlinerView )
         mpOutlinerView->MouseButtonDown( rMEvt );
-    // todo mpOutlinerView->DocView()->GetViewFrame()->GetBindings().InvalidateAll(FALSE);
+    // todo mpOutlinerView->DocView()->GetViewFrame()->GetBindings().InvalidateAll(sal_False);
 }
 
 void AnnotationTextWindow::MouseButtonUp( const MouseEvent& rMEvt )
@@ -243,9 +243,6 @@ void AnnotationTextWindow::GetFocus()
 
 void AnnotationTextWindow::LoseFocus()
 {
-//    if ( mpAnnotationWindow )
-//        mpAnnotationWindow->UpdateAnnotation();
-
     Window::LoseFocus();
 }
 
@@ -324,9 +321,6 @@ void AnnotationWindow::InitControls()
     mpMeta->AlwaysDisableInput(true);
     mpMeta->SetCallHandlersOnInputDisabled(true);
 
-//	mpMeta->AddEventListener( LINK( mpPostItTxt, PostItTxt, WindowEventListener ) );
-//	AddEventListener( LINK( mpTextWindow, PostItTxt, WindowEventListener ) );
-
     // we should leave this setting alone, but for this we need a better layout algo
     // with variable meta size height
     AllSettings aSettings = mpMeta->GetSettings();
@@ -339,7 +333,7 @@ void AnnotationWindow::InitControls()
 
     mpOutliner = new ::Outliner(GetAnnotationPool(),OUTLINERMODE_TEXTOBJECT);
     Doc()->SetCalcFieldValueHdl( mpOutliner );
-    mpOutliner->SetUpdateMode( TRUE );
+    mpOutliner->SetUpdateMode( sal_True );
     Rescale();
 
     OutputDevice* pDev = Doc()->GetRefDevice();
@@ -353,10 +347,6 @@ void AnnotationWindow::InitControls()
     mpTextWindow->SetOutlinerView(mpOutlinerView);
     mpOutlinerView->SetOutputArea( PixelToLogic( Rectangle(0,0,1,1) ) );
 
-//	SfxItemSet item(DocShell()->GetPool());
-//	item.Put(SvxFontHeightItem(352,100,EE_CHAR_FONTHEIGHT));
-//	mpOutlinerView->SetAttribs(item);
-
     // TODO: ??
     EEHorizontalTextDirection aDefHoriTextDir = Application::GetSettings().GetLayoutRTL() ? EE_HTEXTDIR_R2L : EE_HTEXTDIR_L2R;
     mpOutliner->SetDefaultHorizontalTextDirection( aDefHoriTextDir );
@@ -367,29 +357,17 @@ void AnnotationWindow::InitControls()
     mpVScrollbar->EnableRTL( false );
     mpVScrollbar->SetScrollHdl(LINK(this, AnnotationWindow, ScrollHdl));
     mpVScrollbar->EnableDrag();
-//	mpVScrollbar->AddEventListener( LINK( this, AnnotationWindow, WindowEventListener ) );
 
-    ULONG nCntrl = mpOutliner->GetControlWord();
+    sal_uLong nCntrl = mpOutliner->GetControlWord();
     nCntrl |= EE_CNTRL_PASTESPECIAL | EE_CNTRL_AUTOCORRECT  | EV_CNTRL_AUTOSCROLL | EE_CNTRL_NOCOLORS;
-/*
-    if (pVOpt->IsFieldShadings())
-        nCntrl |= EE_CNTRL_MARKFIELDS;
-    else
-        nCntrl &= ~EE_CNTRL_MARKFIELDS;
-    if (pVOpt->IsOnlineSpell())
-        nCntrl |= EE_CNTRL_ONLINESPELLING;
-    else
-        nCntrl &= ~EE_CNTRL_ONLINESPELLING;
-*/
     mpOutliner->SetControlWord(nCntrl);
-//	mpOutliner->SetFlatMode( TRUE );
 
     Engine()->SetModifyHdl( Link() );
-    Engine()->EnableUndo( FALSE );
+    Engine()->EnableUndo( sal_False );
 
     Engine()->ClearModifyFlag();
     Engine()->GetUndoManager().Clear();
-    Engine()->EnableUndo( TRUE );
+    Engine()->EnableUndo( sal_True );
     Engine()->SetModifyHdl( LINK( this, AnnotationWindow, ModifyHdl ) );
 
     Invalidate();
@@ -411,8 +389,6 @@ void AnnotationWindow::Rescale()
 {
     MapMode aMode(MAP_100TH_MM);
     aMode.SetOrigin( Point() );
-    //aMode.SetScaleX( aMode.GetScaleX() * Fraction( 8, 10 ) );
-    //aMode.SetScaleY( aMode.GetScaleY() * Fraction( 8, 10 ) );
     mpOutliner->SetRefMapMode( aMode );
     SetMapMode( aMode );
     mpTextWindow->SetMapMode( aMode );
@@ -510,7 +486,7 @@ void AnnotationWindow::SetLanguage(const SvxLanguageItem aNewItem)
     Engine()->SetModifyHdl( Link() );
     ESelection aOld = getView()->GetSelection();
 
-    ESelection aNewSelection( 0, 0, (USHORT)Engine()->GetParagraphCount()-1, USHRT_MAX );
+    ESelection aNewSelection( 0, 0, (sal_uInt16)Engine()->GetParagraphCount()-1, USHRT_MAX );
     getView()->SetSelection( aNewSelection );
     SfxItemSet aEditAttr(getView()->GetAttribs());
     aEditAttr.Put(aNewItem);
@@ -552,7 +528,6 @@ IMPL_LINK(AnnotationWindow, ModifyHdl, void*, EMPTYARG)
 sal_Int32 AnnotationWindow::GetScrollbarWidth()
 {
     return 16;
-//	return mpView->GetWrtShell().GetViewOptions()->GetZoom() / 10;
 }
 
 SvxLanguageItem AnnotationWindow::GetLanguage(void)
@@ -799,7 +774,7 @@ void AnnotationWindow::GetFocus()
         FloatingWindow::GetFocus();
 }
 
-void AnnotationWindow::ExecuteSlot( USHORT nSID )
+void AnnotationWindow::ExecuteSlot( sal_uInt16 nSID )
 {
     if( nSID == SID_COPY )
     {
