@@ -200,16 +200,16 @@ void DrawViewShell::GetCtrlState(SfxItemSet &rSet)
         SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_OUTPUT_QUALITY_BLACKWHITE ) ||
         SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_OUTPUT_QUALITY_CONTRAST ) )
     {
-        const ULONG nMode = (sal_Int32)GetActiveWindow()->GetDrawMode();
-        rSet.Put( SfxBoolItem( SID_OUTPUT_QUALITY_COLOR, (BOOL)((ULONG)OUTPUT_DRAWMODE_COLOR == nMode) ) );
-        rSet.Put( SfxBoolItem( SID_OUTPUT_QUALITY_GRAYSCALE, (BOOL)((ULONG)OUTPUT_DRAWMODE_GRAYSCALE == nMode) ) );
-        rSet.Put( SfxBoolItem( SID_OUTPUT_QUALITY_BLACKWHITE, (BOOL)((ULONG)OUTPUT_DRAWMODE_BLACKWHITE == nMode) ) );
-        rSet.Put( SfxBoolItem( SID_OUTPUT_QUALITY_CONTRAST, (BOOL)((ULONG)OUTPUT_DRAWMODE_CONTRAST == nMode) ) );
+        const sal_uLong nMode = (sal_Int32)GetActiveWindow()->GetDrawMode();
+        rSet.Put( SfxBoolItem( SID_OUTPUT_QUALITY_COLOR, (sal_Bool)((sal_uLong)OUTPUT_DRAWMODE_COLOR == nMode) ) );
+        rSet.Put( SfxBoolItem( SID_OUTPUT_QUALITY_GRAYSCALE, (sal_Bool)((sal_uLong)OUTPUT_DRAWMODE_GRAYSCALE == nMode) ) );
+        rSet.Put( SfxBoolItem( SID_OUTPUT_QUALITY_BLACKWHITE, (sal_Bool)((sal_uLong)OUTPUT_DRAWMODE_BLACKWHITE == nMode) ) );
+        rSet.Put( SfxBoolItem( SID_OUTPUT_QUALITY_CONTRAST, (sal_Bool)((sal_uLong)OUTPUT_DRAWMODE_CONTRAST == nMode) ) );
     }
 
     if ( SFX_ITEM_AVAILABLE == rSet.GetItemState(SID_MAIL_SCROLLBODY_PAGEDOWN) )
     {
-        rSet.Put( SfxBoolItem( SID_MAIL_SCROLLBODY_PAGEDOWN, TRUE ) );
+        rSet.Put( SfxBoolItem( SID_MAIL_SCROLLBODY_PAGEDOWN, sal_True ) );
     }
 
     if ( SFX_ITEM_AVAILABLE == rSet.GetItemState(SID_ATTR_YEAR2000) )
@@ -217,7 +217,7 @@ void DrawViewShell::GetCtrlState(SfxItemSet &rSet)
         FmFormShell* pFormShell = GetViewShellBase().GetFormShellManager()->GetFormShell();
         if (pFormShell != NULL)
         {
-            UINT16 nState = 0;
+            sal_uInt16 nState = 0;
             if (pFormShell->GetY2KState(nState))
                 rSet.Put( SfxUInt16Item( SID_ATTR_YEAR2000, nState ) );
             else
@@ -287,14 +287,14 @@ void DrawViewShell::GetCtrlState(SfxItemSet &rSet)
 void DrawViewShell::GetAttrState( SfxItemSet& rSet )
 {
     SfxWhichIter	aIter( rSet );
-    USHORT			nWhich = aIter.FirstWhich();
+    sal_uInt16			nWhich = aIter.FirstWhich();
 
-    BOOL	bAttr = FALSE;
+    sal_Bool	bAttr = sal_False;
     SfxAllItemSet aAllSet( *rSet.GetPool() );
 
     while ( nWhich )
     {
-        USHORT nSlotId = SfxItemPool::IsWhich(nWhich)
+        sal_uInt16 nSlotId = SfxItemPool::IsWhich(nWhich)
             ? GetPool().GetSlotId(nWhich)
             : nWhich;
         switch ( nSlotId )
@@ -311,7 +311,7 @@ void DrawViewShell::GetAttrState( SfxItemSet& rSet )
             case SID_ATTR_LINE_COLOR:
             case SID_ATTR_TEXT_FITTOSIZE:
             {
-                bAttr = TRUE;
+                bAttr = sal_True;
             }
             break;
 
@@ -321,7 +321,7 @@ void DrawViewShell::GetAttrState( SfxItemSet& rSet )
                 mpDrawView->GetAttributes( aAttrs );
                 if( aAttrs.GetItemState( EE_PARA_HYPHENATE ) >= SFX_ITEM_AVAILABLE )
                 {
-                    BOOL bValue = ( (const SfxBoolItem&) aAttrs.Get( EE_PARA_HYPHENATE ) ).GetValue();
+                    sal_Bool bValue = ( (const SfxBoolItem&) aAttrs.Get( EE_PARA_HYPHENATE ) ).GetValue();
                     rSet.Put( SfxBoolItem( SID_HYPHENATION, bValue ) );
                 }
             }
@@ -367,7 +367,6 @@ void DrawViewShell::GetAttrState( SfxItemSet& rSet )
                 else
                 {	SfxTemplateItem aItem( nWhich, String() );
                     aAllSet.Put( aItem, aItem.Which() );
-                    // rSet.DisableItem( nWhich );
                 }
             }
             break;
@@ -385,7 +384,7 @@ void DrawViewShell::GetAttrState( SfxItemSet& rSet )
             {
                 ISfxTemplateCommon* pTemplateCommon = SFX_APP()->GetCurrentTemplateCommon(GetViewFrame()->GetBindings());
                 if (pTemplateCommon && pTemplateCommon->GetActualFamily() == SD_STYLE_FAMILY_PSEUDO)
-                    rSet.Put(SfxBoolItem(nWhich,FALSE));
+                    rSet.Put(SfxBoolItem(nWhich,sal_False));
                 else
                 {
                     SfxBoolItem aItem(nWhich, SD_MOD()->GetWaterCan());
@@ -461,10 +460,10 @@ void DrawViewShell::GetAttrState( SfxItemSet& rSet )
     {
         pSet = new SfxItemSet( GetDoc()->GetPool() );
         mpDrawView->GetAttributes( *pSet );
-        rSet.Put( *pSet, FALSE );
+        rSet.Put( *pSet, sal_False );
     }
 
-    rSet.Put( aAllSet, FALSE );
+    rSet.Put( aAllSet, sal_False );
 
     // Flaechen und/oder Linienattribute wurden geaendert
     if( bAttr && pSet )
@@ -488,22 +487,6 @@ void DrawViewShell::GetAttrState( SfxItemSet& rSet )
         delete pSet;
     }
 
-//    const SdrMarkList& rMarkList = mpDrawView->GetMarkedObjectList();
-//    ULONG nMarkCount = rMarkList.GetMarkCount();
-//    BOOL bDisabled = FALSE;
-//
-//    for (ULONG i = 0;
-//         i < nMarkCount && !bDisabled && i < 50; i++)
-//    {
-//        SdrObject* pObj = rMarkList.GetMark(i)->GetMarkedSdrObj();
-//
-//        if (pObj->GetObjInventor() == E3dInventor)
-//        {
-//            bDisabled = TRUE;
-//            rSet.ClearItem(SDRATTR_SHADOW);
-//            rSet.DisableItem(SDRATTR_SHADOW);
-//        }
-//    }
 }
 
 
@@ -513,7 +496,7 @@ void DrawViewShell::GetAttrState( SfxItemSet& rSet )
 |*
 \************************************************************************/
 
-String DrawViewShell::GetSelectionText(BOOL bCompleteWords)
+String DrawViewShell::GetSelectionText(sal_Bool bCompleteWords)
 {
     String aStrSelection;
     ::Outliner* pOl = mpDrawView->GetTextEditOutliner();
@@ -545,9 +528,9 @@ String DrawViewShell::GetSelectionText(BOOL bCompleteWords)
 |*
 \************************************************************************/
 
-BOOL DrawViewShell::HasSelection(BOOL bText) const
+sal_Bool DrawViewShell::HasSelection(sal_Bool bText) const
 {
-    BOOL bReturn = FALSE;
+    sal_Bool bReturn = sal_False;
 
     if (bText)
     {
@@ -555,12 +538,12 @@ BOOL DrawViewShell::HasSelection(BOOL bText) const
 
         if (pOlView && pOlView->GetSelected().Len() != 0)
         {
-            bReturn = TRUE;
+            bReturn = sal_True;
         }
     }
     else if (mpDrawView->GetMarkedObjectList().GetMarkCount() != 0)
     {
-        bReturn = TRUE;
+        bReturn = sal_True;
     }
 
     return bReturn;
