@@ -78,8 +78,8 @@
 #include <svx/extrusionbar.hxx>
 #include <svx/fontworkbar.hxx>
 #include <svx/svdoutl.hxx>
+#include <tools/diagnose_ex.h>
 
-// #96090#
 #include <svl/slstitm.hxx>
 #include <sfx2/request.hxx>
 #include "SpellDialogChildWindow.hxx"
@@ -129,7 +129,7 @@ namespace sd {
 
 static const int DELTA_ZOOM = 10;
 
-BOOL ViewShell::IsPageFlipMode(void) const
+sal_Bool ViewShell::IsPageFlipMode(void) const
 {
     return this->ISA(DrawViewShell) && mpContentWindow.get() != NULL &&
         mpContentWindow->GetVisibleHeight() >= 1.0;
@@ -195,7 +195,7 @@ void ViewShell::construct(void)
     mpView = 0;
     mpFrameView = 0;
     mpZoomList = 0;
-    mbStartShowWithDialog = FALSE;
+    mbStartShowWithDialog = sal_False;
     mnPrintedHandoutPageNum = 1;
     mnPrintedHandoutPageCount = 0;
     mpWindowUpdater.reset( new ::sd::WindowUpdater() );
@@ -228,7 +228,7 @@ void ViewShell::construct(void)
     {
         // Create scroll bars and the filler between the scroll bars.
         mpHorizontalScrollBar.reset (new ScrollBar(GetParentWindow(), WinBits(WB_HSCROLL | WB_DRAG)));
-        mpHorizontalScrollBar->EnableRTL (FALSE);
+        mpHorizontalScrollBar->EnableRTL (sal_False);
         mpHorizontalScrollBar->SetRange(Range(0, 32000));
         mpHorizontalScrollBar->SetScrollHdl(LINK(this, ViewShell, HScrollHdl));
         mpHorizontalScrollBar->Show();
@@ -248,7 +248,7 @@ void ViewShell::construct(void)
     String aName( RTL_CONSTASCII_USTRINGPARAM( "ViewShell" ));
     SetName (aName);
 
-    GetDoc()->StartOnlineSpelling(FALSE);
+    GetDoc()->StartOnlineSpelling(sal_False);
 
     mpWindowUpdater->SetViewShell (*this);
     mpWindowUpdater->SetDocument (GetDoc());
@@ -291,7 +291,7 @@ void ViewShell::Exit (void)
         pView->UnmarkAll();
     }
 
-    Deactivate (TRUE);
+    Deactivate (sal_True);
 
     if (IsMainViewShell())
     {
@@ -310,25 +310,24 @@ void ViewShell::Exit (void)
 |*
 \************************************************************************/
 
-void ViewShell::Activate(BOOL bIsMDIActivate)
+void ViewShell::Activate(sal_Bool bIsMDIActivate)
 {
     SfxShell::Activate(bIsMDIActivate);
 
     // Laut MI darf keiner GrabFocus rufen, der nicht genau weiss von
     // welchem Window der Focus gegrabt wird. Da Activate() vom SFX teilweise
     // asynchron verschickt wird, kann es sein, dass ein falsches Window
-    // den Focus hat (#29682#):
-    //GetViewFrame()->GetWindow().GrabFocus();
+    // den Focus hat 
 
     if (mpHorizontalRuler.get() != NULL)
-        mpHorizontalRuler->SetActive(TRUE);
+        mpHorizontalRuler->SetActive(sal_True);
     if (mpVerticalRuler.get() != NULL)
-        mpVerticalRuler->SetActive(TRUE);
+        mpVerticalRuler->SetActive(sal_True);
 
     if (bIsMDIActivate)
     {
         // Damit der Navigator auch einen aktuellen Status bekommt
-        SfxBoolItem aItem( SID_NAVIGATOR_INIT, TRUE );
+        SfxBoolItem aItem( SID_NAVIGATOR_INIT, sal_True );
         if (GetDispatcher() != NULL)
             GetDispatcher()->Execute(
                 SID_NAVIGATOR_INIT,
@@ -339,7 +338,7 @@ void ViewShell::Activate(BOOL bIsMDIActivate)
         SfxViewShell* pViewShell = GetViewShell();
         OSL_ASSERT (pViewShell!=NULL);
         SfxBindings& rBindings = pViewShell->GetViewFrame()->GetBindings();
-        rBindings.Invalidate( SID_3D_STATE, TRUE, FALSE );
+        rBindings.Invalidate( SID_3D_STATE, sal_True, sal_False );
 
         rtl::Reference< SlideShow > xSlideShow( SlideShow::GetSlideShow( GetViewShellBase() ) );
         if(xSlideShow.is() && xSlideShow->isRunning() )
@@ -352,14 +351,8 @@ void ViewShell::Activate(BOOL bIsMDIActivate)
         }
 
         if(!GetDocSh()->IsUIActive())
-            UpdatePreview( GetActualPage(), TRUE );
+            UpdatePreview( GetActualPage(), sal_True );
 
-        //HMH::sd::View* pView = GetView();
-
-        //HMHif (pView)
-        //HMH{
-        //HMH	pView->ShowMarkHdl();
-        //HMH}
     }
 
     ReadFrameViewData( mpFrameView );
@@ -390,7 +383,7 @@ void ViewShell::UIDeactivated( SfxInPlaceClient*  )
 |*
 \************************************************************************/
 
-void ViewShell::Deactivate(BOOL bIsMDIActivate)
+void ViewShell::Deactivate(sal_Bool bIsMDIActivate)
 {
     // remove view from a still active drag'n'drop session
     SdTransferable* pDragTransferable = SD_MOD()->pTransferDrag;
@@ -420,9 +413,9 @@ void ViewShell::Deactivate(BOOL bIsMDIActivate)
     }
 
     if (mpHorizontalRuler.get() != NULL)
-        mpHorizontalRuler->SetActive(FALSE);
+        mpHorizontalRuler->SetActive(sal_False);
     if (mpVerticalRuler.get() != NULL)
-        mpVerticalRuler->SetActive(FALSE);
+        mpVerticalRuler->SetActive(sal_False);
 
     SfxShell::Deactivate(bIsMDIActivate);
 }
@@ -444,9 +437,9 @@ void ViewShell::Shutdown (void)
 |*
 \************************************************************************/
 
-BOOL ViewShell::KeyInput(const KeyEvent& rKEvt, ::sd::Window* pWin)
+sal_Bool ViewShell::KeyInput(const KeyEvent& rKEvt, ::sd::Window* pWin)
 {
-    BOOL bReturn(FALSE);
+    sal_Bool bReturn(sal_False);
 
     if(pWin)
     {
@@ -455,11 +448,10 @@ BOOL ViewShell::KeyInput(const KeyEvent& rKEvt, ::sd::Window* pWin)
 
     if(!bReturn)
     {
-        // #76008#
         // give key input first to SfxViewShell to give CTRL+Key
         // (e.g. CTRL+SHIFT+'+', to front) priority.
         OSL_ASSERT (GetViewShell()!=NULL);
-        bReturn = (BOOL)GetViewShell()->KeyInput(rKEvt);
+        bReturn = (sal_Bool)GetViewShell()->KeyInput(rKEvt);
     }
 
     if(!bReturn)
@@ -486,7 +478,7 @@ BOOL ViewShell::KeyInput(const KeyEvent& rKEvt, ::sd::Window* pWin)
                 }
                 else
                 {
-                    bReturn = TRUE;
+                    bReturn = sal_True;
                 }
             }
         }
@@ -500,7 +492,7 @@ BOOL ViewShell::KeyInput(const KeyEvent& rKEvt, ::sd::Window* pWin)
             && aKeyCode.GetCode() == KEY_R)
         {
             InvalidateWindows();
-            bReturn = TRUE;
+            bReturn = sal_True;
         }
     }
 
@@ -529,7 +521,6 @@ void ViewShell::MouseButtonDown(const MouseEvent& rMEvt, ::sd::Window* pWin)
     {
         pWin->GrabFocus();
         SetActiveWindow(pWin);
-//		  GetViewFrame()->GetWindow().GrabFocus();
     }
 
     // MouseEvent in E3dView eintragen
@@ -637,7 +628,7 @@ void ViewShell::MouseButtonUp(const MouseEvent& rMEvt, ::sd::Window* pWin)
 
 void ViewShell::Command(const CommandEvent& rCEvt, ::sd::Window* pWin)
 {
-    BOOL bDone = HandleScrollCommand (rCEvt, pWin);
+    sal_Bool bDone = HandleScrollCommand (rCEvt, pWin);
 
     if( !bDone )
     {
@@ -666,7 +657,7 @@ void ViewShell::Command(const CommandEvent& rCEvt, ::sd::Window* pWin)
 long ViewShell::Notify(NotifyEvent& rNEvt, ::sd::Window* pWin)
 {
     // handle scroll commands when they arrived at child windows
-    long nRet = FALSE;
+    long nRet = sal_False;
     if( rNEvt.GetType() == EVENT_COMMAND )
     {
         // note: dynamic_cast is not possible as GetData() returns a void*
@@ -677,9 +668,9 @@ long ViewShell::Notify(NotifyEvent& rNEvt, ::sd::Window* pWin)
 }
 
 
-BOOL ViewShell::HandleScrollCommand(const CommandEvent& rCEvt, ::sd::Window* pWin)
+bool ViewShell::HandleScrollCommand(const CommandEvent& rCEvt, ::sd::Window* pWin)
 {
-    BOOL bDone = FALSE;
+    bool bDone = false;
 
     switch( rCEvt.GetCommand() )
     {
@@ -729,14 +720,14 @@ BOOL ViewShell::HandleScrollCommand(const CommandEvent& rCEvt, ::sd::Window* pWi
                         Invalidate( SID_ATTR_ZOOM );
                         Invalidate( SID_ATTR_ZOOMSLIDER );
 
-                        bDone = TRUE;
+                        bDone = true;
                     }
                 }
                 else
                 {
                     if( mpContentWindow.get() == pWin )
                     {
-                        ULONG nScrollLines = pData->GetScrollLines();
+                        sal_uLong nScrollLines = pData->GetScrollLines();
                         if(IsPageFlipMode())
                             nScrollLines = COMMAND_WHEEL_PAGESCROLL;
                         CommandWheelData aWheelData( pData->GetDelta(),pData->GetNotchDelta(),
@@ -745,7 +736,7 @@ BOOL ViewShell::HandleScrollCommand(const CommandEvent& rCEvt, ::sd::Window* pWi
                             rCEvt.IsMouseEvent(),(const void *) &aWheelData );
                         bDone = pWin->HandleScrollCommand( aReWrite,
                             mpHorizontalScrollBar.get(),
-                            mpVerticalScrollBar.get());
+                            mpVerticalScrollBar.get()) == sal_True;
                     }
                 }
             }
@@ -773,17 +764,17 @@ void ViewShell::SetupRulers (void)
             if ( mpVerticalRuler.get() != NULL )
             {
                 nHRulerOfs = mpVerticalRuler->GetSizePixel().Width();
-                mpVerticalRuler->SetActive(TRUE);
+                mpVerticalRuler->SetActive(sal_True);
                 mpVerticalRuler->Show();
             }
         }
         if ( mpHorizontalRuler.get() == NULL )
         {
-            mpHorizontalRuler.reset(CreateHRuler(GetActiveWindow(), TRUE));
+            mpHorizontalRuler.reset(CreateHRuler(GetActiveWindow(), sal_True));
             if ( mpHorizontalRuler.get() != NULL )
             {
                 mpHorizontalRuler->SetWinPos(nHRulerOfs);
-                mpHorizontalRuler->SetActive(TRUE);
+                mpHorizontalRuler->SetActive(sal_True);
                 mpHorizontalRuler->Show();
             }
         }
@@ -793,7 +784,7 @@ void ViewShell::SetupRulers (void)
 
 
 
-BOOL ViewShell::HasRuler (void)
+sal_Bool ViewShell::HasRuler (void)
 {
     return mbHasRulers;
 }
@@ -814,7 +805,7 @@ void ViewShell::Resize (void)
         return;
 
     // Remember the new position and size.
-    maViewPos = Point(0,0); //mpParentWindow->GetPosPixel();
+    maViewPos = Point(0,0); 
     maViewSize = aSize;
 
     // Rearrange the UI elements to take care of the new position and size.
@@ -822,19 +813,13 @@ void ViewShell::Resize (void)
     // end of included AdjustPosSizePixel.
 
     Size aS (GetParentWindow()->GetOutputSizePixel());
-    Size aVisSizePixel = GetActiveWindow()->GetOutputSizePixel();
-    Rectangle aVisArea = GetParentWindow()->PixelToLogic(
-        Rectangle( Point(0,0), aVisSizePixel));
     Rectangle aCurrentVisArea (GetDocSh()->GetVisArea(ASPECT_CONTENT));
-    Rectangle aWindowRect = GetActiveWindow()->LogicToPixel(aCurrentVisArea);
     if (GetDocSh()->GetCreateMode() == SFX_CREATE_MODE_EMBEDDED
         && IsMainViewShell())
     {
-        //        GetDocSh()->SetVisArea(aVisArea);
+        
     }
 
-    //	VisAreaChanged(aVisArea);
-
     ::sd::View* pView = GetView();
 
     if (pView)
@@ -1000,7 +985,7 @@ void ViewShell::SetUIUnit(FieldUnit eUnit)
 |* DefTab an den horizontalen Linealen setzen
 |*
 \************************************************************************/
-void ViewShell::SetDefTabHRuler( UINT16 nDefTab )
+void ViewShell::SetDefTabHRuler( sal_uInt16 nDefTab )
 {
     if (mpHorizontalRuler.get() != NULL)
         mpHorizontalRuler->SetDefTabDist( nDefTab );
@@ -1012,9 +997,9 @@ void ViewShell::SetDefTabHRuler( UINT16 nDefTab )
 /** Tell the FmFormShell that the view shell is closing.  Give it the
     oportunity to prevent that.
 */
-USHORT ViewShell::PrepareClose (BOOL bUI, BOOL bForBrowsing)
+sal_uInt16 ViewShell::PrepareClose (sal_Bool bUI, sal_Bool bForBrowsing)
 {
-    USHORT nResult = TRUE;
+    sal_uInt16 nResult = sal_True;
 
     FmFormShell* pFormShell = GetViewShellBase().GetFormShellManager()->GetFormShell();
     if (pFormShell != NULL)
@@ -1026,14 +1011,14 @@ USHORT ViewShell::PrepareClose (BOOL bUI, BOOL bForBrowsing)
 
 
 
-void ViewShell::UpdatePreview (SdPage*, BOOL )
+void ViewShell::UpdatePreview (SdPage*, sal_Bool )
 {
     // Do nothing.  After the actual preview has been removed,
     // OutlineViewShell::UpdatePreview() is the place where something
     // usefull is still done.
 }
 
-SfxUndoManager* ViewShell::ImpGetUndoManager (void) const
+::svl::IUndoManager* ViewShell::ImpGetUndoManager (void) const
 {
     const ViewShell* pMainViewShell = GetViewShellBase().GetMainViewShell().get();
 
@@ -1074,7 +1059,7 @@ SfxUndoManager* ViewShell::ImpGetUndoManager (void) const
 
 void ViewShell::ImpGetUndoStrings(SfxItemSet &rSet) const
 {
-    SfxUndoManager* pUndoManager = ImpGetUndoManager();
+    ::svl::IUndoManager* pUndoManager = ImpGetUndoManager();
     if(pUndoManager)
     {
         sal_uInt16 nCount(pUndoManager->GetUndoActionCount());
@@ -1109,7 +1094,7 @@ void ViewShell::ImpGetUndoStrings(SfxItemSet &rSet) const
 
 void ViewShell::ImpGetRedoStrings(SfxItemSet &rSet) const
 {
-    SfxUndoManager* pUndoManager = ImpGetUndoManager();
+    ::svl::IUndoManager* pUndoManager = ImpGetUndoManager();
     if(pUndoManager)
     {
         sal_uInt16 nCount(pUndoManager->GetRedoActionCount());
@@ -1142,9 +1127,9 @@ void ViewShell::ImpGetRedoStrings(SfxItemSet &rSet) const
 
 // -----------------------------------------------------------------------------
 
-void ViewShell::ImpSidUndo(BOOL, SfxRequest& rReq)
+void ViewShell::ImpSidUndo(sal_Bool, SfxRequest& rReq)
 {
-    SfxUndoManager* pUndoManager = ImpGetUndoManager();
+    ::svl::IUndoManager* pUndoManager = ImpGetUndoManager();
     sal_uInt16 nNumber(1);
     const SfxItemSet* pReqArgs = rReq.GetArgs();
 
@@ -1159,15 +1144,23 @@ void ViewShell::ImpSidUndo(BOOL, SfxRequest& rReq)
         sal_uInt16 nCount(pUndoManager->GetUndoActionCount());
         if(nCount >= nNumber)
         {
-            // #94637# when UndoStack is cleared by ModifyPageUndoAction
-            // the nCount may have changed, so test GetUndoActionCount()
-            while(nNumber-- && pUndoManager->GetUndoActionCount())
+            try
             {
-                pUndoManager->Undo();
+                // when UndoStack is cleared by ModifyPageUndoAction
+                // the nCount may have changed, so test GetUndoActionCount()
+                while(nNumber-- && pUndoManager->GetUndoActionCount())
+                {
+                    pUndoManager->Undo();
+                }
+            }
+            catch( const Exception& e )
+            {
+                // no need to handle. By definition, the UndoManager handled this by clearing the
+                // Undo/Redo stacks
             }
         }
 
-        // #91081# refresh rulers, maybe UNDO was move of TAB marker in ruler
+        // refresh rulers, maybe UNDO was move of TAB marker in ruler
         if (mbHasRulers)
         {
             Invalidate(SID_ATTR_TABSTOP);
@@ -1183,9 +1176,9 @@ void ViewShell::ImpSidUndo(BOOL, SfxRequest& rReq)
 
 // -----------------------------------------------------------------------------
 
-void ViewShell::ImpSidRedo(BOOL, SfxRequest& rReq)
+void ViewShell::ImpSidRedo(sal_Bool, SfxRequest& rReq)
 {
-    SfxUndoManager* pUndoManager = ImpGetUndoManager();
+    ::svl::IUndoManager* pUndoManager = ImpGetUndoManager();
     sal_uInt16 nNumber(1);
     const SfxItemSet* pReqArgs = rReq.GetArgs();
 
@@ -1200,15 +1193,23 @@ void ViewShell::ImpSidRedo(BOOL, SfxRequest& rReq)
         sal_uInt16 nCount(pUndoManager->GetRedoActionCount());
         if(nCount >= nNumber)
         {
-            // #94637# when UndoStack is cleared by ModifyPageRedoAction
-            // the nCount may have changed, so test GetRedoActionCount()
-            while(nNumber-- && pUndoManager->GetRedoActionCount())
+            try
             {
-                pUndoManager->Redo();
+                // when UndoStack is cleared by ModifyPageRedoAction
+                // the nCount may have changed, so test GetRedoActionCount()
+                while(nNumber-- && pUndoManager->GetRedoActionCount())
+                {
+                    pUndoManager->Redo();
+                }
+            }
+            catch( const Exception& e )
+            {
+                // no need to handle. By definition, the UndoManager handled this by clearing the
+                // Undo/Redo stacks
             }
         }
 
-        // #91081# refresh rulers, maybe REDO was move of TAB marker in ruler
+        // refresh rulers, maybe REDO was move of TAB marker in ruler
         if (mbHasRulers)
         {
             Invalidate(SID_ATTR_TABSTOP);
@@ -1226,7 +1227,7 @@ void ViewShell::ImpSidRedo(BOOL, SfxRequest& rReq)
 
 void ViewShell::ExecReq( SfxRequest& rReq )
 {
-    USHORT nSlot = rReq.GetSlot();
+    sal_uInt16 nSlot = rReq.GetSlot();
     switch( nSlot )
     {
         case SID_MAIL_SCROLLBODY_PAGEDOWN:
@@ -1248,7 +1249,7 @@ void ViewShell::ExecReq( SfxRequest& rReq )
         case SID_OUTPUT_QUALITY_BLACKWHITE:
         case SID_OUTPUT_QUALITY_CONTRAST:
         {
-            ULONG nMode = OUTPUT_DRAWMODE_COLOR;
+            sal_uLong nMode = OUTPUT_DRAWMODE_COLOR;
 
             switch( nSlot )
             {
@@ -1260,8 +1261,7 @@ void ViewShell::ExecReq( SfxRequest& rReq )
 
             GetActiveWindow()->SetDrawMode( nMode );
             mpFrameView->SetDrawMode( nMode );
-// #110094#-7
-//            GetView()->ReleaseMasterPagePaintCache();
+
             GetActiveWindow()->Invalidate();
 
             Invalidate();
@@ -1403,7 +1403,6 @@ void ViewShell::DisposeFunctions()
 bool ViewShell::IsMainViewShell (void) const
 {
     return mpImpl->mbIsMainViewShell;
-    //    return GetViewShellBase().GetMainViewShell() == this;
 }
 
 void ViewShell::SetIsMainViewShell (bool bIsMainViewShell)
