@@ -51,7 +51,7 @@
 #include "fileobj.hxx"
 #include "impldde.hxx"
 #include "app.hrc"
-#include "sfxresid.hxx"
+#include "sfx2/sfxresid.hxx"
 
 #define _SVSTDARR_STRINGSDTOR
 #include <svl/svstdarr.hxx>
@@ -74,7 +74,7 @@ class SvxInternalLink : public sfx2::SvLinkSource
 public:
     SvxInternalLink() {}
 
-    virtual BOOL Connect( sfx2::SvBaseLink* );
+    virtual sal_Bool Connect( sfx2::SvBaseLink* );
 };
 
 
@@ -89,7 +89,7 @@ LinkManager::LinkManager(SfxObjectShell* p)
 LinkManager::~LinkManager()
 {
     SvBaseLinkRef** ppRef = (SvBaseLinkRef**)aLinkTbl.GetData();
-    for( USHORT n = aLinkTbl.Count(); n; --n, ++ppRef )
+    for( sal_uInt16 n = aLinkTbl.Count(); n; --n, ++ppRef )
     {
         if( (*ppRef)->Is() )
         {
@@ -119,28 +119,24 @@ void LinkManager::CloseCachedComps()
     maCachedComps.clear();
 }
 
-/************************************************************************
-|*    LinkManager::Remove()
-|*
-|*    Beschreibung
-*************************************************************************/
+//--------------------------------------------------------------------------
 
 void LinkManager::Remove( SvBaseLink *pLink )
 {
-    // keine Links doppelt einfuegen
-    int bFound = FALSE;
+    // No duplicate links inserted
+    int bFound = sal_False;
     SvBaseLinkRef** ppRef = (SvBaseLinkRef**)aLinkTbl.GetData();
-    for( USHORT n = aLinkTbl.Count(); n; --n, ++ppRef )
+    for( sal_uInt16 n = aLinkTbl.Count(); n; --n, ++ppRef )
     {
         if( pLink == *(*ppRef) )
         {
             (*(*ppRef))->Disconnect();
             (*(*ppRef))->SetLinkManager( NULL );
             (*(*ppRef)).Clear();
-            bFound = TRUE;
+            bFound = sal_True;
         }
 
-        // falls noch leere rum stehen sollten, weg damit
+        // Remove emty ones if they exist
         if( !(*ppRef)->Is() )
         {
             delete *ppRef;
@@ -153,7 +149,7 @@ void LinkManager::Remove( SvBaseLink *pLink )
 }
 
 
-void LinkManager::Remove( USHORT nPos, USHORT nCnt )
+void LinkManager::Remove( sal_uInt16 nPos, sal_uInt16 nCnt )
 {
     if( nCnt && nPos < aLinkTbl.Count() )
     {
@@ -161,7 +157,7 @@ void LinkManager::Remove( USHORT nPos, USHORT nCnt )
             nCnt = aLinkTbl.Count() - nPos;
 
         SvBaseLinkRef** ppRef = (SvBaseLinkRef**)aLinkTbl.GetData() + nPos;
-        for( USHORT n = nCnt; n; --n, ++ppRef )
+        for( sal_uInt16 n = nCnt; n; --n, ++ppRef )
         {
             if( (*ppRef)->Is() )
             {
@@ -175,32 +171,32 @@ void LinkManager::Remove( USHORT nPos, USHORT nCnt )
 }
 
 
-BOOL LinkManager::Insert( SvBaseLink* pLink )
+sal_Bool LinkManager::Insert( SvBaseLink* pLink )
 {
-    // keine Links doppelt einfuegen
-    for( USHORT n = 0; n < aLinkTbl.Count(); ++n )
+  // No duplicate links inserted
+    for( sal_uInt16 n = 0; n < aLinkTbl.Count(); ++n )
     {
         SvBaseLinkRef* pTmp = aLinkTbl[ n ];
         if( !pTmp->Is() )
             aLinkTbl.DeleteAndDestroy( n-- );
 
         if( pLink == *pTmp )
-            return FALSE;
+            return sal_False;
     }
 
     SvBaseLinkRef* pTmp = new SvBaseLinkRef( pLink );
     pLink->SetLinkManager( this );
     aLinkTbl.Insert( pTmp, aLinkTbl.Count() );
-    return TRUE;
+    return sal_True;
 }
 
 
-BOOL LinkManager::InsertLink( SvBaseLink * pLink,
-                                USHORT nObjType,
-                                USHORT nUpdateMode,
+sal_Bool LinkManager::InsertLink( SvBaseLink * pLink,
+                                sal_uInt16 nObjType,
+                                sal_uInt16 nUpdateMode,
                                 const String* pName )
 {
-    // unbedingt zuerst
+    // This First
     pLink->SetObjType( nObjType );
     if( pName )
         pLink->SetName( *pName );
@@ -209,13 +205,13 @@ BOOL LinkManager::InsertLink( SvBaseLink * pLink,
 }
 
 
-BOOL LinkManager::InsertDDELink( SvBaseLink * pLink,
+sal_Bool LinkManager::InsertDDELink( SvBaseLink * pLink,
                                     const String& rServer,
                                     const String& rTopic,
                                     const String& rItem )
 {
     if( !( OBJECT_CLIENT_SO & pLink->GetObjType() ) )
-        return FALSE;
+        return sal_False;
 
     String sCmd;
     ::sfx2::MakeLnkName( sCmd, &rServer, rTopic, rItem );
@@ -226,11 +222,11 @@ BOOL LinkManager::InsertDDELink( SvBaseLink * pLink,
 }
 
 
-BOOL LinkManager::InsertDDELink( SvBaseLink * pLink )
+sal_Bool LinkManager::InsertDDELink( SvBaseLink * pLink )
 {
     DBG_ASSERT( OBJECT_CLIENT_SO & pLink->GetObjType(), "no OBJECT_CLIENT_SO" );
     if( !( OBJECT_CLIENT_SO & pLink->GetObjType() ) )
-        return FALSE;
+        return sal_False;
 
     if( pLink->GetObjType() == OBJECT_CLIENT_SO )
         pLink->SetObjType( OBJECT_CLIENT_DDE );
@@ -239,14 +235,14 @@ BOOL LinkManager::InsertDDELink( SvBaseLink * pLink )
 }
 
 
-// erfrage die Strings fuer den Dialog
-BOOL LinkManager::GetDisplayNames( const SvBaseLink * pLink,
+// Obtain the string for the dialog
+sal_Bool LinkManager::GetDisplayNames( const SvBaseLink * pLink,
                                         String* pType,
                                         String* pFile,
                                         String* pLinkStr,
                                         String* pFilter ) const
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
     const String sLNm( pLink->GetLinkSourceName() );
     if( sLNm.Len() )
     {
@@ -256,7 +252,7 @@ BOOL LinkManager::GetDisplayNames( const SvBaseLink * pLink,
             case OBJECT_CLIENT_GRF:
             case OBJECT_CLIENT_OLE:
                 {
-                    USHORT nPos = 0;
+                    sal_uInt16 nPos = 0;
                     String sFile( sLNm.GetToken( 0, ::sfx2::cTokenSeperator, nPos ) );
                     String sRange( sLNm.GetToken( 0, ::sfx2::cTokenSeperator, nPos ) );
 
@@ -275,12 +271,12 @@ BOOL LinkManager::GetDisplayNames( const SvBaseLink * pLink,
                                             ? RID_SVXSTR_FILELINK
                                             : RID_SVXSTR_GRAFIKLINK ));
                     }
-                    bRet = TRUE;
+                    bRet = sal_True;
                 }
                 break;
             case OBJECT_CLIENT_DDE:
                 {
-                    USHORT nTmp = 0;
+                    sal_uInt16 nTmp = 0;
                     String sCmd( sLNm );
                     String sServer( sCmd.GetToken( 0, cTokenSeperator, nTmp ) );
                     String sTopic( sCmd.GetToken( 0, cTokenSeperator, nTmp ) );
@@ -291,7 +287,7 @@ BOOL LinkManager::GetDisplayNames( const SvBaseLink * pLink,
                         *pFile = sTopic;
                     if( pLinkStr )
                         *pLinkStr = sCmd.Copy( nTmp );
-                    bRet = TRUE;
+                    bRet = sal_True;
                 }
                 break;
             default:
@@ -304,18 +300,18 @@ BOOL LinkManager::GetDisplayNames( const SvBaseLink * pLink,
 
 
 void LinkManager::UpdateAllLinks(
-    BOOL bAskUpdate,
-    BOOL /*bCallErrHdl*/,
-    BOOL bUpdateGrfLinks,
+    sal_Bool bAskUpdate, 
+    sal_Bool /*bCallErrHdl*/,
+    sal_Bool bUpdateGrfLinks, 
     Window* pParentWin )
 {
     SvStringsDtor aApps, aTopics, aItems;
     String sApp, sTopic, sItem;
 
-    // erstmal eine Kopie vom Array machen, damit sich updatende Links in
-    // Links in ... nicht dazwischen funken!!
+    // First make a copy of the array in order to update links 
+    // links in ... no contact between them!
     SvPtrarr aTmpArr( 255, 50 );
-    USHORT n;
+    sal_uInt16 n;
     for( n = 0; n < aLinkTbl.Count(); ++n )
     {
         SvBaseLink* pLink = *aLinkTbl[ n ];
@@ -331,9 +327,9 @@ void LinkManager::UpdateAllLinks(
     {
         SvBaseLink* pLink = (SvBaseLink*)aTmpArr[ n ];
 
-        // suche erstmal im Array nach dem Eintrag
-        USHORT nFndPos = USHRT_MAX;
-        for( USHORT i = 0; i < aLinkTbl.Count(); ++i )
+        // search first in the array after the entry
+        sal_uInt16 nFndPos = USHRT_MAX;
+        for( sal_uInt16 i = 0; i < aLinkTbl.Count(); ++i )
             if( pLink == *aLinkTbl[ i ] )
             {
                 nFndPos = i;
@@ -341,9 +337,9 @@ void LinkManager::UpdateAllLinks(
             }
 
         if( USHRT_MAX == nFndPos )
-            continue;					// war noch nicht vorhanden!
+            continue;  // was not available!
 
-        // Graphic-Links noch nicht updaten
+        // Graphic-Links not to update yet
         if( !pLink->IsVisible() ||
             ( !bUpdateGrfLinks && OBJECT_CLIENT_GRF == pLink->GetObjType() ))
             continue;
@@ -352,8 +348,8 @@ void LinkManager::UpdateAllLinks(
         {
             int nRet = QueryBox( pParentWin, WB_YES_NO | WB_DEF_YES, SfxResId( STR_QUERY_UPDATE_LINKS ) ).Execute();
             if( RET_YES != nRet )
-                return ;		// es soll nichts geupdatet werden
-            bAskUpdate = FALSE;		// einmal reicht
+                return ;         // nothing should be updated
+            bAskUpdate = sal_False;  // once is enough
         }
 
         pLink->Update();
@@ -361,11 +357,7 @@ void LinkManager::UpdateAllLinks(
     CloseCachedComps();
 }
 
-/************************************************************************
-|*    SvBaseLink::CreateObject()
-|*
-|*    Beschreibung
-*************************************************************************/
+//--------------------------------------------------------------------------
 
 SvLinkSourceRef LinkManager::CreateObj( SvBaseLink * pLink )
 {
@@ -384,20 +376,20 @@ SvLinkSourceRef LinkManager::CreateObj( SvBaseLink * pLink )
        }
 }
 
-BOOL LinkManager::InsertServer( SvLinkSource* pObj )
+sal_Bool LinkManager::InsertServer( SvLinkSource* pObj )
 {
-    // keine doppelt einfuegen
+    // no duplicate inserts
     if( !pObj || USHRT_MAX != aServerTbl.GetPos( pObj ) )
-        return FALSE;
+        return sal_False;
 
     aServerTbl.Insert( pObj, aServerTbl.Count() );
-    return TRUE;
+    return sal_True;
 }
 
 
 void LinkManager::RemoveServer( SvLinkSource* pObj )
 {
-    USHORT nPos = aServerTbl.GetPos( pObj );
+    sal_uInt16 nPos = aServerTbl.GetPos( pObj );
     if( USHRT_MAX != nPos )
         aServerTbl.Remove( nPos, 1 );
 }
@@ -467,14 +459,14 @@ void LinkManager::LinkServerShell(const OUString& rPath, SfxObjectShell& rServer
     }
 }
 
-BOOL LinkManager::InsertFileLink( sfx2::SvBaseLink& rLink,
-                                    USHORT nFileType,
+sal_Bool LinkManager::InsertFileLink( sfx2::SvBaseLink& rLink,
+                                    sal_uInt16 nFileType,
                                     const String& rFileNm,
                                     const String* pFilterNm,
                                     const String* pRange )
 {
     if( !( OBJECT_CLIENT_SO & rLink.GetObjType() ))
-        return FALSE;
+        return sal_False;
 
     String sCmd( rFileNm );
     sCmd += ::sfx2::cTokenSeperator;
@@ -486,57 +478,52 @@ BOOL LinkManager::InsertFileLink( sfx2::SvBaseLink& rLink,
     return InsertLink( &rLink, nFileType, sfx2::LINKUPDATE_ONCALL, &sCmd );
 }
 
-BOOL LinkManager::InsertFileLink( sfx2::SvBaseLink& rLink )
+sal_Bool LinkManager::InsertFileLink( sfx2::SvBaseLink& rLink )
 {
     if( OBJECT_CLIENT_FILE == ( OBJECT_CLIENT_FILE & rLink.GetObjType() ))
         return InsertLink( &rLink, rLink.GetObjType(), sfx2::LINKUPDATE_ONCALL );
-    return FALSE;
+    return sal_False;
 }
 
-// eine Uebertragung wird abgebrochen, also alle DownloadMedien canceln
-// (ist zur Zeit nur fuer die FileLinks interressant!)
+// A transfer is aborted, so cancel all download media 
+// (for now this is only of interest for the file links!)
 void LinkManager::CancelTransfers()
 {
     SvFileObject* pFileObj;
     sfx2::SvBaseLink* pLnk;
 
     const sfx2::SvBaseLinks& rLnks = GetLinks();
-    for( USHORT n = rLnks.Count(); n; )
+    for( sal_uInt16 n = rLnks.Count(); n; )
         if( 0 != ( pLnk = &(*rLnks[ --n ])) &&
             OBJECT_CLIENT_FILE == (OBJECT_CLIENT_FILE & pLnk->GetObjType()) &&
             0 != ( pFileObj = (SvFileObject*)pLnk->GetObj() ) )
-//			0 != ( pFileObj = (SvFileObject*)SvFileObject::ClassFactory()->
-//									CastAndAddRef( pLnk->GetObj() )) )
             pFileObj->CancelTransfers();
 }
-
-    // um Status Informationen aus dem FileObject an den BaseLink zu
-    // senden, gibt es eine eigene ClipBoardId. Das SvData-Object hat
-    // dann die entsprechenden Informationen als String.
-    // Wird zur Zeit fuer FileObject in Verbindung mit JavaScript benoetigt
-    // - das braucht Informationen ueber Load/Abort/Error
-ULONG LinkManager::RegisterStatusInfoId()
+    // For the purpose of sending Status information from the file object to 
+    // the base link, there exist a dedicated ClipBoardId. The SvData-object 
+    // gets the appropriate information as a string  
+    // For now this is required for file object in conjunction with JavaScript
+    // - needs information about Load/Abort/Error
+sal_uIntPtr LinkManager::RegisterStatusInfoId()
 {
-    static ULONG nFormat = 0;
+    static sal_uIntPtr nFormat = 0;
 
     if( !nFormat )
     {
-// wie sieht die neue Schnittstelle aus?
-//		nFormat = Exchange::RegisterFormatName( "StatusInfo vom SvxInternalLink" );
         nFormat = SotExchange::RegisterFormatName(
                     String::CreateFromAscii( RTL_CONSTASCII_STRINGPARAM(
-                                "StatusInfo vom SvxInternalLink" )));
+                                "StatusInfo from SvxInternalLink" )));
     }
     return nFormat;
 }
 
 // ----------------------------------------------------------------------
 
-BOOL LinkManager::GetGraphicFromAny( const String& rMimeType,
+sal_Bool LinkManager::GetGraphicFromAny( const String& rMimeType,
                                 const ::com::sun::star::uno::Any & rValue,
                                 Graphic& rGrf )
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
     ::com::sun::star::uno::Sequence< sal_Int8 > aSeq;
     if( rValue.hasValue() && ( rValue >>= aSeq ) )
     {
@@ -549,7 +536,7 @@ BOOL LinkManager::GetGraphicFromAny( const String& rMimeType,
         case SOT_FORMATSTR_ID_SVXB:
             {
                 aMemStm >> rGrf;
-                bRet = TRUE;
+                bRet = sal_True;
             }
             break;
         case FORMAT_GDIMETAFILE:
@@ -557,7 +544,7 @@ BOOL LinkManager::GetGraphicFromAny( const String& rMimeType,
                 GDIMetaFile aMtf;
                 aMtf.Read( aMemStm );
                 rGrf = aMtf;
-                bRet = TRUE;
+                bRet = sal_True;
             }
             break;
         case FORMAT_BITMAP:
@@ -565,7 +552,7 @@ BOOL LinkManager::GetGraphicFromAny( const String& rMimeType,
                 Bitmap aBmp;
                 aMemStm >> aBmp;
                 rGrf = aBmp;
-                bRet = TRUE;
+                bRet = sal_True;
             }
             break;
         }
@@ -586,17 +573,16 @@ String lcl_DDE_RelToAbs( const String& rTopic, const String& rBaseURL )
     return sRet;
 }
 
-BOOL SvxInternalLink::Connect( sfx2::SvBaseLink* pLink )
+sal_Bool SvxInternalLink::Connect( sfx2::SvBaseLink* pLink )
 {
     SfxObjectShell* pFndShell = 0;
-    USHORT nUpdateMode = com::sun::star::document::UpdateDocMode::NO_UPDATE;
+    sal_uInt16 nUpdateMode = com::sun::star::document::UpdateDocMode::NO_UPDATE;
     String sTopic, sItem, sReferer;
     LinkManager* pLinkMgr = pLink->GetLinkManager();
     if (pLinkMgr && pLinkMgr->GetDisplayNames(pLink, 0, &sTopic, &sItem) && sTopic.Len())
     {
-        // erstmal nur ueber die DocumentShells laufen und die mit dem
-        // Namen heraussuchen:
-
+        // first only loop over the DocumentShells the shells and find those 
+        // with the name:
         com::sun::star::lang::Locale aLocale;
         MsLangId::convertLanguageToLocale( LANGUAGE_SYSTEM, aLocale );
         CharClass aCC( aLocale );
@@ -606,7 +592,7 @@ BOOL SvxInternalLink::Connect( sfx2::SvBaseLink* pLink )
 
         TypeId aType( TYPE(SfxObjectShell) );
 
-        BOOL bFirst = TRUE;
+        sal_Bool bFirst = sal_True;
         SfxObjectShell* pShell = pLinkMgr->GetPersist();
         if( pShell && pShell->GetMedium() )
         {
@@ -621,7 +607,7 @@ BOOL SvxInternalLink::Connect( sfx2::SvBaseLink* pLink )
 
         if ( !pShell )
         {
-            bFirst = FALSE;
+            bFirst = sal_False;
             pShell = SfxObjectShell::GetFirst( &aType, sal_False );
         }
 
@@ -635,7 +621,7 @@ BOOL SvxInternalLink::Connect( sfx2::SvBaseLink* pLink )
 
 
             aCC.toLower( sTmp );
-            if( sTmp == sNmURL )		// die wollen wir haben
+            if( sTmp == sNmURL )  // we want these
             {
                 pFndShell = pShell;
                 break;
@@ -643,7 +629,7 @@ BOOL SvxInternalLink::Connect( sfx2::SvBaseLink* pLink )
 
             if( bFirst )
             {
-                bFirst = FALSE;
+                bFirst = sal_False;
                 pShell = SfxObjectShell::GetFirst( &aType, sal_False );
             }
             else
@@ -655,7 +641,7 @@ BOOL SvxInternalLink::Connect( sfx2::SvBaseLink* pLink )
 
     // empty topics are not allowed - which document is it
     if( !sTopic.Len() )
-        return FALSE;
+        return sal_False;
 
     if (pFndShell)
     {
@@ -675,7 +661,7 @@ BOOL SvxInternalLink::Connect( sfx2::SvBaseLink* pLink )
     }
     else
     {
-        // dann versuche die Datei zu laden:
+        // then try to download the file:
         INetURLObject aURL( sTopic );
         INetProtocol eOld = aURL.GetProtocol();
         aURL.SetURL( sTopic = lcl_DDE_RelToAbs( sTopic, sReferer ) );
@@ -683,8 +669,8 @@ BOOL SvxInternalLink::Connect( sfx2::SvBaseLink* pLink )
             INET_PROT_HTTP != aURL.GetProtocol() )
         {
             SfxStringItem aName( SID_FILE_NAME, sTopic );
-            SfxBoolItem aMinimized(SID_MINIMIZED, TRUE);
-            SfxBoolItem aHidden(SID_HIDDEN, TRUE);
+            SfxBoolItem aMinimized(SID_MINIMIZED, sal_True);
+            SfxBoolItem aHidden(SID_HIDDEN, sal_True);
             SfxStringItem aTarget( SID_TARGETNAME, String::CreateFromAscii("_blank") );
             SfxStringItem aReferer( SID_REFERER, sReferer );
             SfxUInt16Item aUpdate( SID_UPDATEDOCMODE, nUpdateMode );
