@@ -98,7 +98,6 @@ bool isValidNCName(::rtl::OUString const & i_rIdref)
         reinterpret_cast<const unsigned char*>(id.getStr()), 0));
 }
 
-////////////////////////////////////////////////////////////////////////////
 
 static const char s_content [] = "content.xml";
 static const char s_styles  [] = "styles.xml";
@@ -108,27 +107,25 @@ static const char s_manifest[] = "manifest.rdf";
 static const char s_rdfxml  [] = "application/rdf+xml";
 static const char s_odfmime [] = "application/vnd.oasis.opendocument.";
 
-////////////////////////////////////////////////////////////////////////////
 
 static bool isContentFile(::rtl::OUString const & i_rPath)
 {
-    return i_rPath.equalsAscii(s_content);
+    return i_rPath.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(s_content));
 }
 
 static bool isStylesFile (::rtl::OUString const & i_rPath)
 {
-    return i_rPath.equalsAscii(s_styles);
+    return i_rPath.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(s_styles));
 }
 
 static bool isReservedFile(::rtl::OUString const & i_rPath)
 {
     return isContentFile(i_rPath)
         || isStylesFile(i_rPath)
-        || i_rPath.equalsAscii(s_meta)
-        || i_rPath.equalsAscii(s_settings);
+        || i_rPath.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(s_meta))
+        || i_rPath.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(s_settings));
 }
 
-////////////////////////////////////////////////////////////////////////////
 
 uno::Reference<rdf::XURI> createBaseURI(
     uno::Reference<uno::XComponentContext> const & i_xContext,
@@ -161,8 +158,8 @@ uno::Reference<rdf::XURI> createBaseURI(
         i_xContext->getServiceManager(), uno::UNO_SET_THROW);
     const uno::Reference<uri::XUriReferenceFactory> xUriFactory(
         xServiceFactory->createInstanceWithContext(
-            ::rtl::OUString::createFromAscii(
-                "com.sun.star.uri.UriReferenceFactory"), i_xContext),
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+                "com.sun.star.uri.UriReferenceFactory")), i_xContext),
         uno::UNO_QUERY_THROW);
     uno::Reference< uri::XUriReference > xBaseURI;
 
@@ -206,7 +203,6 @@ uno::Reference<rdf::XURI> createBaseURI(
     return rdf::URI::create(i_xContext, xBaseURI->getUriReference());
 }
 
-////////////////////////////////////////////////////////////////////////////
 
 struct DocumentMetadataAccess_Impl
 {
@@ -250,8 +246,8 @@ static bool isFileNameValid(const ::rtl::OUString & i_rFileName)
       const ::rtl::OUString segment(
         i_rFileName.getToken(0, static_cast<sal_Unicode> ('/'), idx) );
       if (!segment.getLength()      ||  // no empty segments
-          segment.equalsAscii(".")  ||  // no . segments
-          segment.equalsAscii("..") ||  // no .. segments
+          segment.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("."))  ||  // no . segments
+          segment.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("..")) ||  // no .. segments
           !::comphelper::OStorageHelper::IsValidZipEntryFileName(
               segment, sal_False))      // no invalid characters
                                       return false;
@@ -293,7 +289,6 @@ splitXmlId(::rtl::OUString const & i_XmlId,
     }
 }
 
-////////////////////////////////////////////////////////////////////////////
 
 static uno::Reference<rdf::XURI>
 getURIForStream(struct DocumentMetadataAccess_Impl& i_rImpl,
@@ -335,8 +330,8 @@ addFile(struct DocumentMetadataAccess_Impl & i_rImpl,
         throw;
     } catch (uno::Exception & e) {
         throw lang::WrappedTargetRuntimeException(
-            ::rtl::OUString::createFromAscii(
-                "addFile: exception"), /*this*/0, uno::makeAny(e));
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+                "addFile: exception")), /*this*/0, uno::makeAny(e));
     }
 }
 
@@ -384,7 +379,7 @@ removeFile(struct DocumentMetadataAccess_Impl & i_rImpl,
         throw;
     } catch (uno::Exception & e) {
         throw lang::WrappedTargetRuntimeException(
-            ::rtl::OUString::createFromAscii("removeFile: exception"),
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("removeFile: exception")),
             0, uno::makeAny(e));
     }
 }
@@ -413,7 +408,7 @@ getAllParts(struct DocumentMetadataAccess_Impl & i_rImpl)
         throw;
     } catch (uno::Exception & e) {
         throw lang::WrappedTargetRuntimeException(
-            ::rtl::OUString::createFromAscii("getAllParts: exception"),
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("getAllParts: exception")),
             0, uno::makeAny(e));
     }
 }
@@ -435,12 +430,11 @@ isPartOfType(struct DocumentMetadataAccess_Impl & i_rImpl,
         throw;
     } catch (uno::Exception & e) {
         throw lang::WrappedTargetRuntimeException(
-            ::rtl::OUString::createFromAscii("isPartOfType: exception"),
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("isPartOfType: exception")),
             0, uno::makeAny(e));
     }
 }
 
-////////////////////////////////////////////////////////////////////////////
 
 static ucb::InteractiveAugmentedIOException
 mkException( ::rtl::OUString const & i_rMessage,
@@ -452,10 +446,10 @@ mkException( ::rtl::OUString const & i_rMessage,
     iaioe.Classification = task::InteractionClassification_ERROR;
     iaioe.Code = i_ErrorCode;
 
-    const beans::PropertyValue uriProp(::rtl::OUString::createFromAscii("Uri"),
+    const beans::PropertyValue uriProp(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Uri")),
         -1, uno::makeAny(i_rUri), static_cast<beans::PropertyState>(0));
     const beans::PropertyValue rnProp(
-        ::rtl::OUString::createFromAscii("ResourceName"),
+        ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ResourceName")),
         -1, uno::makeAny(i_rResource), static_cast<beans::PropertyState>(0));
     iaioe.Arguments = ::comphelper::makeSequence(
         uno::makeAny(uriProp), uno::makeAny(rnProp));
@@ -475,8 +469,8 @@ handleError( ucb::InteractiveAugmentedIOException const & i_rException,
     const uno::Reference<task::XInteractionHandler> & i_xHandler)
 {
     if (!i_xHandler.is()) {
-        throw lang::WrappedTargetException(::rtl::OUString::createFromAscii(
-            "DocumentMetadataAccess::loadMetadataFromStorage: exception"),
+        throw lang::WrappedTargetException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+            "DocumentMetadataAccess::loadMetadataFromStorage: exception")),
             /* *this*/ 0, uno::makeAny(i_rException));
     }
 
@@ -488,11 +482,7 @@ handleError( ucb::InteractiveAugmentedIOException const & i_rException,
         new ::comphelper::OInteractionApprove );
     ::rtl::Reference< ::comphelper::OInteractionAbort > pAbort(
         new ::comphelper::OInteractionAbort );
-    /* this does not seem to work
-    if (i_rException.Code != ucb::IOErrorCode_WRONG_FORMAT) {
-        pRequest->addContinuation( pRetry.get() );
-    }
-    */
+
     pRequest->addContinuation( pApprove.get() );
     pRequest->addContinuation( pAbort.get() );
     // actually call the handler
@@ -503,8 +493,8 @@ handleError( ucb::InteractiveAugmentedIOException const & i_rException,
         return false;
     } else {
         OSL_ENSURE(pAbort->wasSelected(), "no continuation selected?");
-        throw lang::WrappedTargetException(::rtl::OUString::createFromAscii(
-            "DocumentMetadataAccess::loadMetadataFromStorage: exception"),
+        throw lang::WrappedTargetException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+            "DocumentMetadataAccess::loadMetadataFromStorage: exception")),
             /* *this*/ 0, uno::makeAny(i_rException));
     }
 }
@@ -516,8 +506,8 @@ collectFilesFromStorage(uno::Reference<embed::XStorage> const& i_xStorage,
     ::rtl::OUString i_Path,
     std::set< ::rtl::OUString > & o_rFiles)
 {
-    static ::rtl::OUString content(::rtl::OUString::createFromAscii(s_content));
-    static ::rtl::OUString styles (::rtl::OUString::createFromAscii(s_styles ));
+    static ::rtl::OUString content(RTL_CONSTASCII_USTRINGPARAM(s_content));
+    static ::rtl::OUString styles(RTL_CONSTASCII_USTRINGPARAM(s_styles ));
     try {
         if (i_xStorage->hasByName(content) &&
             i_xStorage->isStreamElement(content))
@@ -545,7 +535,7 @@ readStream(struct DocumentMetadataAccess_Impl & i_rImpl,
     ::rtl::OUString rest;
     try {
         if (!splitPath(i_rPath, dir, rest)) throw uno::RuntimeException();
-        if (dir.equalsAscii("")) {
+        if (dir.getLength() == 0) {
             if (i_xStorage->isStreamElement(i_rPath)) {
                 const uno::Reference<io::XStream> xStream(
                     i_xStorage->openStreamElement(i_rPath,
@@ -560,8 +550,8 @@ readStream(struct DocumentMetadataAccess_Impl & i_rImpl,
                 i_rImpl.m_xRepository->importGraph(rdf::FileFormat::RDF_XML,
                     xInStream, xURI, xBaseURI);
             } else {
-                throw mkException(::rtl::OUString::createFromAscii(
-                    "readStream: is not a stream"),
+                throw mkException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+                    "readStream: is not a stream")),
                     ucb::IOErrorCode_NO_FILE, i_rBaseURI + i_rPath, i_rPath);
             }
         } else {
@@ -587,8 +577,8 @@ readStream(struct DocumentMetadataAccess_Impl & i_rImpl,
                 buf.append(dir).append(static_cast<sal_Unicode>('/'));
                 readStream(i_rImpl, xDir, rest, buf.makeStringAndClear() );
             } else {
-                throw mkException(::rtl::OUString::createFromAscii(
-                    "readStream: is not a directory"),
+                throw mkException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+                    "readStream: is not a directory")),
                     ucb::IOErrorCode_NO_DIRECTORY, i_rBaseURI + dir, dir);
             }
         }
@@ -621,7 +611,7 @@ retry:
         throw;
     } catch (uno::Exception & e) {
         throw lang::WrappedTargetRuntimeException(
-            ::rtl::OUString::createFromAscii("importFile: exception"),
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("importFile: exception")),
             0, uno::makeAny(e));
     }
 }
@@ -642,8 +632,8 @@ exportStream(struct DocumentMetadataAccess_Impl & i_rImpl,
         uno::UNO_QUERY);
     if (xStreamProps.is()) { // this is NOT supported in FileSystemStorage
         xStreamProps->setPropertyValue(
-            ::rtl::OUString::createFromAscii("MediaType"),
-            uno::makeAny(::rtl::OUString::createFromAscii(s_rdfxml)));
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("MediaType")),
+            uno::makeAny(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(s_rdfxml))));
     }
     const uno::Reference<io::XOutputStream> xOutStream(
         xStream->getOutputStream(), uno::UNO_SET_THROW );
@@ -665,7 +655,7 @@ writeStream(struct DocumentMetadataAccess_Impl & i_rImpl,
     ::rtl::OUString rest;
     if (!splitPath(i_rPath, dir, rest)) throw uno::RuntimeException();
     try {
-        if (dir.equalsAscii("")) {
+        if (dir.getLength() == 0) {
             exportStream(i_rImpl, i_xStorage, i_xGraphName, i_rPath,
                 i_rBaseURI);
         } else {
@@ -762,9 +752,9 @@ retry:
 
     if (rterr.hasValue()) {
         throw lang::WrappedTargetRuntimeException(
-            ::rtl::OUString::createFromAscii(
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
                 "DocumentMetadataAccess::loadMetadataFromStorage: "
-                "exception"), 0, rterr);
+                "exception")), 0, rterr);
     }
 
     if (err) {
@@ -788,7 +778,7 @@ static void init(struct DocumentMetadataAccess_Impl & i_rImpl)
             getURI<rdf::URIs::PKG_DOCUMENT>(i_rImpl.m_xContext).get());
     } catch (uno::Exception & e) {
         throw lang::WrappedTargetRuntimeException(
-            ::rtl::OUString::createFromAscii("init: unexpected exception"), 0,
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("init: unexpected exception")), 0,
             uno::makeAny(e));
     }
 
@@ -804,7 +794,6 @@ static void init(struct DocumentMetadataAccess_Impl & i_rImpl)
 }
 
 
-////////////////////////////////////////////////////////////////////////////
 
 DocumentMetadataAccess::DocumentMetadataAccess(
         uno::Reference< uno::XComponentContext > const & i_xContext,
@@ -839,7 +828,6 @@ DocumentMetadataAccess::~DocumentMetadataAccess()
 {
 }
 
-
 // ::com::sun::star::rdf::XRepositorySupplier:
 uno::Reference< rdf::XRepository > SAL_CALL
 DocumentMetadataAccess::getRDFRepository() throw (uno::RuntimeException)
@@ -877,8 +865,8 @@ throw (uno::RuntimeException)
     const IXmlIdRegistry * pReg(
         m_pImpl->m_rXmlIdRegistrySupplier.GetXmlIdRegistry() );
     if (!pReg) {
-        throw uno::RuntimeException(::rtl::OUString::createFromAscii(
-            "DocumentMetadataAccess::getElementByXmlId: no registry"), *this);
+        throw uno::RuntimeException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+            "DocumentMetadataAccess::getElementByXmlId: no registry")), *this);
     }
     return pReg->GetElementByMetadataReference(i_rReference);
 }
@@ -889,8 +877,8 @@ DocumentMetadataAccess::getElementByURI(
 throw (uno::RuntimeException, lang::IllegalArgumentException)
 {
     if (!i_xURI.is()) {
-        throw lang::IllegalArgumentException(::rtl::OUString::createFromAscii(
-            "DocumentMetadataAccess::getElementByURI: URI is null"), *this, 0);
+        throw lang::IllegalArgumentException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+            "DocumentMetadataAccess::getElementByURI: URI is null")), *this, 0);
     }
 
     const ::rtl::OUString baseURI( m_pImpl->m_xBaseURI->getStringValue() );
@@ -915,9 +903,9 @@ DocumentMetadataAccess::getMetadataGraphsWithType(
 throw (uno::RuntimeException, lang::IllegalArgumentException)
 {
     if (!i_xType.is()) {
-        throw lang::IllegalArgumentException(::rtl::OUString::createFromAscii(
+        throw lang::IllegalArgumentException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
             "DocumentMetadataAccess::getMetadataGraphsWithType: "
-            "type is null"), *this, 0);
+            "type is null")), *this, 0);
     }
 
     ::comphelper::SequenceAsVector< uno::Reference< rdf::XURI > > ret;
@@ -938,21 +926,21 @@ throw (uno::RuntimeException, lang::IllegalArgumentException,
     container::ElementExistException)
 {
     if (!isFileNameValid(i_rFileName)) {
-        throw lang::IllegalArgumentException(::rtl::OUString::createFromAscii(
-            "DocumentMetadataAccess::addMetadataFile: invalid FileName"),
+        throw lang::IllegalArgumentException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+            "DocumentMetadataAccess::addMetadataFile: invalid FileName")),
             *this, 0);
     }
     if (isReservedFile(i_rFileName)) {
-        throw lang::IllegalArgumentException(::rtl::OUString::createFromAscii(
+        throw lang::IllegalArgumentException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
             "DocumentMetadataAccess::addMetadataFile:"
-            "invalid FileName: reserved"), *this, 0);
+            "invalid FileName: reserved")), *this, 0);
     }
     for (sal_Int32 i = 0; i < i_rTypes.getLength(); ++i) {
         if (!i_rTypes[i].is()) {
             throw lang::IllegalArgumentException(
-                ::rtl::OUString::createFromAscii(
+                ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
                     "DocumentMetadataAccess::addMetadataFile: "
-                    "null type"), *this, 2);
+                    "null type")), *this, 2);
         }
     }
 
@@ -963,8 +951,8 @@ throw (uno::RuntimeException, lang::IllegalArgumentException,
         m_pImpl->m_xRepository->createGraph(xGraphName);
     } catch (rdf::RepositoryException & e) {
         throw lang::WrappedTargetRuntimeException(
-            ::rtl::OUString::createFromAscii(
-                "DocumentMetadataAccess::addMetadataFile: exception"),
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+                "DocumentMetadataAccess::addMetadataFile: exception")),
             *this, uno::makeAny(e));
         // note: all other exceptions are propagated
     }
@@ -984,20 +972,20 @@ throw (uno::RuntimeException, lang::IllegalArgumentException,
     container::ElementExistException, rdf::ParseException, io::IOException)
 {
     if (!isFileNameValid(i_rFileName)) {
-        throw lang::IllegalArgumentException(::rtl::OUString::createFromAscii(
-            "DocumentMetadataAccess::importMetadataFile: invalid FileName"),
+        throw lang::IllegalArgumentException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+            "DocumentMetadataAccess::importMetadataFile: invalid FileName")),
             *this, 0);
     }
     if (isReservedFile(i_rFileName)) {
-        throw lang::IllegalArgumentException(::rtl::OUString::createFromAscii(
+        throw lang::IllegalArgumentException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
             "DocumentMetadataAccess::importMetadataFile:"
-            "invalid FileName: reserved"), *this, 0);
+            "invalid FileName: reserved")), *this, 0);
     }
     for (sal_Int32 i = 0; i < i_rTypes.getLength(); ++i) {
         if (!i_rTypes[i].is()) {
             throw lang::IllegalArgumentException(
-                ::rtl::OUString::createFromAscii(
-                    "DocumentMetadataAccess::importMetadataFile: null type"),
+                ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+                    "DocumentMetadataAccess::importMetadataFile: null type")),
                 *this, 5);
         }
     }
@@ -1010,9 +998,9 @@ throw (uno::RuntimeException, lang::IllegalArgumentException,
             i_Format, i_xInStream, xGraphName, i_xBaseURI);
     } catch (rdf::RepositoryException & e) {
         throw lang::WrappedTargetRuntimeException(
-            ::rtl::OUString::createFromAscii(
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
                 "DocumentMetadataAccess::importMetadataFile: "
-                "RepositoryException"), *this, uno::makeAny(e));
+                "RepositoryException")), *this, uno::makeAny(e));
         // note: all other exceptions are propagated
     }
 
@@ -1031,9 +1019,9 @@ throw (uno::RuntimeException, lang::IllegalArgumentException,
         m_pImpl->m_xRepository->destroyGraph(i_xGraphName);
     } catch (rdf::RepositoryException & e) {
         throw lang::WrappedTargetRuntimeException(
-            ::rtl::OUString::createFromAscii(
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
                 "DocumentMetadataAccess::removeMetadataFile: "
-                "RepositoryException"), *this, uno::makeAny(e));
+                "RepositoryException")), *this, uno::makeAny(e));
         // note: all other exceptions are propagated
     }
 
@@ -1048,15 +1036,15 @@ throw (uno::RuntimeException, lang::IllegalArgumentException,
     container::ElementExistException)
 {
     if (!isFileNameValid(i_rFileName)) {
-        throw lang::IllegalArgumentException(::rtl::OUString::createFromAscii(
+        throw lang::IllegalArgumentException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
             "DocumentMetadataAccess::addContentOrStylesFile: "
-            "invalid FileName"), *this, 0);
+            "invalid FileName")), *this, 0);
     }
 
     if (!addContentOrStylesFileImpl(*m_pImpl, i_rFileName)) {
-        throw lang::IllegalArgumentException(::rtl::OUString::createFromAscii(
+        throw lang::IllegalArgumentException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
             "DocumentMetadataAccess::addContentOrStylesFile: "
-            "invalid FileName: must end with content.xml or styles.xml"),
+            "invalid FileName: must end with content.xml or styles.xml")),
             *this, 0);
     }
 }
@@ -1068,9 +1056,9 @@ throw (uno::RuntimeException, lang::IllegalArgumentException,
     container::NoSuchElementException)
 {
     if (!isFileNameValid(i_rFileName)) {
-        throw lang::IllegalArgumentException(::rtl::OUString::createFromAscii(
+        throw lang::IllegalArgumentException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
             "DocumentMetadataAccess::removeContentOrStylesFile: "
-            "invalid FileName"), *this, 0);
+            "invalid FileName")), *this, 0);
     }
 
     try {
@@ -1083,9 +1071,9 @@ throw (uno::RuntimeException, lang::IllegalArgumentException,
             uno::UNO_SET_THROW);
         if (!xEnum->hasMoreElements()) {
             throw container::NoSuchElementException(
-                ::rtl::OUString::createFromAscii(
+                ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
                     "DocumentMetadataAccess::removeContentOrStylesFile: "
-                    "cannot find stream in manifest graph: ") + i_rFileName,
+                    "cannot find stream in manifest graph: ")) + i_rFileName,
                 *this);
         }
 
@@ -1096,8 +1084,8 @@ throw (uno::RuntimeException, lang::IllegalArgumentException,
         throw;
     } catch (uno::Exception & e) {
         throw lang::WrappedTargetRuntimeException(
-            ::rtl::OUString::createFromAscii(
-                "DocumentMetadataAccess::removeContentOrStylesFile: exception"),
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+                "DocumentMetadataAccess::removeContentOrStylesFile: exception")),
             *this, uno::makeAny(e));
     }
 }
@@ -1110,32 +1098,32 @@ throw (uno::RuntimeException, lang::IllegalArgumentException,
     lang::WrappedTargetException)
 {
     if (!i_xStorage.is()) {
-        throw lang::IllegalArgumentException(::rtl::OUString::createFromAscii(
+        throw lang::IllegalArgumentException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
             "DocumentMetadataAccess::loadMetadataFromStorage: "
-            "storage is null"), *this, 0);
+            "storage is null")), *this, 0);
     }
     if (!i_xBaseURI.is()) {
-        throw lang::IllegalArgumentException(::rtl::OUString::createFromAscii(
+        throw lang::IllegalArgumentException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
             "DocumentMetadataAccess::loadMetadataFromStorage: "
-            "base URI is null"), *this, 1);
+            "base URI is null")), *this, 1);
     }
     const ::rtl::OUString baseURI( i_xBaseURI->getStringValue());
     if (baseURI.indexOf('#') >= 0) {
-        throw lang::IllegalArgumentException(::rtl::OUString::createFromAscii(
+        throw lang::IllegalArgumentException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
             "DocumentMetadataAccess::loadMetadataFromStorage: "
-            "base URI not absolute"), *this, 1);
+            "base URI not absolute")), *this, 1);
     }
     if (!baseURI.getLength() || !baseURI.endsWithAsciiL("/", 1)) {
-        throw lang::IllegalArgumentException(::rtl::OUString::createFromAscii(
+        throw lang::IllegalArgumentException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
             "DocumentMetadataAccess::loadMetadataFromStorage: "
-            "base URI does not end with slash"), *this, 1);
+            "base URI does not end with slash")), *this, 1);
     }
 
     initLoading(*m_pImpl, i_xStorage, i_xBaseURI, i_xHandler);
 
     std::set< ::rtl::OUString > StgFiles;
     collectFilesFromStorage(i_xStorage,
-        ::rtl::OUString::createFromAscii(""), StgFiles);
+        ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("")), StgFiles);
 
     std::vector< ::rtl::OUString > MfstMetadataFiles;
 
@@ -1202,9 +1190,9 @@ throw (uno::RuntimeException, lang::IllegalArgumentException,
         throw;
     } catch (uno::Exception & e) {
         throw lang::WrappedTargetRuntimeException(
-            ::rtl::OUString::createFromAscii(
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
                 "DocumentMetadataAccess::loadMetadataFromStorage: "
-                "exception"), *this, uno::makeAny(e));
+                "exception")), *this, uno::makeAny(e));
     }
 
     std::for_each(StgFiles.begin(), StgFiles.end(),
@@ -1221,9 +1209,9 @@ throw (uno::RuntimeException, lang::IllegalArgumentException,
     lang::WrappedTargetException)
 {
     if (!i_xStorage.is()) {
-        throw lang::IllegalArgumentException(::rtl::OUString::createFromAscii(
+        throw lang::IllegalArgumentException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
             "DocumentMetadataAccess::storeMetadataToStorage: "
-            "storage is null"), *this, 0);
+            "storage is null")), *this, 0);
     }
 
     // export manifest
@@ -1237,12 +1225,12 @@ throw (uno::RuntimeException, lang::IllegalArgumentException,
     } catch (uno::RuntimeException &) {
         throw;
     } catch (io::IOException & e) {
-        throw lang::WrappedTargetException( ::rtl::OUString::createFromAscii(
-            "storeMetadataToStorage: IO exception"), *this, uno::makeAny(e));
+        throw lang::WrappedTargetException( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+            "storeMetadataToStorage: IO exception")), *this, uno::makeAny(e));
     } catch (uno::Exception & e) {
         throw lang::WrappedTargetRuntimeException(
-            ::rtl::OUString::createFromAscii(
-                "storeMetadataToStorage: exception"), *this, uno::makeAny(e));
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+                "storeMetadataToStorage: exception")), *this, uno::makeAny(e));
     }
 
     // export metadata streams
@@ -1275,20 +1263,20 @@ throw (uno::RuntimeException, lang::IllegalArgumentException,
                 throw;
             } catch (io::IOException & e) {
                 throw lang::WrappedTargetException(
-                    ::rtl::OUString::createFromAscii(
-                        "storeMetadataToStorage: IO exception"),
+                    ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+                        "storeMetadataToStorage: IO exception")),
                     *this, uno::makeAny(e));
             } catch (uno::Exception & e) {
                 throw lang::WrappedTargetRuntimeException(
-                    ::rtl::OUString::createFromAscii(
-                        "storeMetadataToStorage: exception"),
+                    ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+                        "storeMetadataToStorage: exception")),
                     *this, uno::makeAny(e));
             }
         }
     } catch (rdf::RepositoryException & e) {
         throw lang::WrappedTargetRuntimeException(
-            ::rtl::OUString::createFromAscii(
-                "storeMetadataToStorage: exception"), *this, uno::makeAny(e));
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+                "storeMetadataToStorage: exception")), *this, uno::makeAny(e));
     }
 }
 
@@ -1307,10 +1295,10 @@ throw (uno::RuntimeException, lang::IllegalArgumentException,
     if (md.addInputStream()) {
         md[ ::comphelper::MediaDescriptor::PROP_INPUTSTREAM() ] >>= xIn;
     }
-    if (!xIn.is() && URL.equalsAscii("")) {
-        throw lang::IllegalArgumentException(::rtl::OUString::createFromAscii(
+    if (!xIn.is() && (URL.getLength() == 0)) {
+        throw lang::IllegalArgumentException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
             "DocumentMetadataAccess::loadMetadataFromMedium: "
-            "inalid medium: no URL, no input stream"), *this, 0);
+            "inalid medium: no URL, no input stream")), *this, 0);
     }
     uno::Reference<embed::XStorage> xStorage;
     try {
@@ -1329,14 +1317,14 @@ throw (uno::RuntimeException, lang::IllegalArgumentException,
         throw;
     } catch (uno::Exception & e) {
         throw lang::WrappedTargetException(
-                ::rtl::OUString::createFromAscii(
+                ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
                     "DocumentMetadataAccess::loadMetadataFromMedium: "
-                    "exception"), *this, uno::makeAny(e));
+                    "exception")), *this, uno::makeAny(e));
     }
     if (!xStorage.is()) {
-        throw uno::RuntimeException(::rtl::OUString::createFromAscii(
+        throw uno::RuntimeException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
             "DocumentMetadataAccess::loadMetadataFromMedium: "
-            "cannot get Storage"), *this);
+            "cannot get Storage")), *this);
     }
     uno::Reference<rdf::XURI> xBaseURI;
     try {
@@ -1346,7 +1334,7 @@ throw (uno::RuntimeException, lang::IllegalArgumentException,
         try {
             xBaseURI = createBaseURI(m_pImpl->m_xContext, xStorage, URL);
         } catch (uno::Exception &) {
-            OSL_ENSURE(false, "cannot create base URI");
+            OSL_FAIL("cannot create base URI");
         }
     }
     uno::Reference<task::XInteractionHandler> xIH;
@@ -1363,10 +1351,10 @@ throw (uno::RuntimeException, lang::IllegalArgumentException,
     ::comphelper::MediaDescriptor md(i_rMedium);
     ::rtl::OUString URL;
     md[ ::comphelper::MediaDescriptor::PROP_URL() ] >>= URL;
-    if (URL.equalsAscii("")) {
-        throw lang::IllegalArgumentException(::rtl::OUString::createFromAscii(
+    if (URL.getLength() == 0) {
+        throw lang::IllegalArgumentException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
             "DocumentMetadataAccess::storeMetadataToMedium: "
-            "invalid medium: no URL"), *this, 0);
+            "invalid medium: no URL")), *this, 0);
     }
 
     SfxMedium aMedium(i_rMedium);
@@ -1383,9 +1371,9 @@ throw (uno::RuntimeException, lang::IllegalArgumentException,
     }
 
     if (!xStorage.is()) {
-        throw uno::RuntimeException(::rtl::OUString::createFromAscii(
+        throw uno::RuntimeException(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
             "DocumentMetadataAccess::storeMetadataToMedium: "
-            "cannot get Storage"), *this);
+            "cannot get Storage")), *this);
     }
     // set MIME type of the storage
     ::comphelper::MediaDescriptor::const_iterator iter
