@@ -43,7 +43,7 @@ use File::Spec;
 
 ( $script_name = $0 ) =~ s/^.*\b(\w+)\.pl$/$1/; 
 
-$id_str = ' $Revision$ ';
+$id_str = ' $Revision: 275594 $ ';
 $id_str =~ /Revision:\s+(\S+)\s+\$/
   ? ($script_rev = $1) : ($script_rev = "-");
 
@@ -268,7 +268,6 @@ sub do_linklib
         }
         else
         {
-            # $lib =~ /^(lib[\w-]+(\.so|\.dylib))\.(\d+)$/;
             $long = 0;
         }
 
@@ -404,6 +403,8 @@ sub parse_options
 {
     my $arg;
     my $dontdeletecommon = 0;
+    $opt_silent = 1 if ( defined $ENV{VERBOSE} && $ENV{VERBOSE} eq 'FALSE');
+    $opt_verbose = 1 if ( defined $ENV{VERBOSE} && $ENV{VERBOSE} eq 'TRUE');
     while ( $arg = shift @ARGV ) {
         $arg =~ /^-force$/      and $opt_force  = 1  and next;
         $arg =~ /^-check$/      and $opt_check  = 1  and $opt_verbose = 1 and next;
@@ -423,15 +424,13 @@ sub parse_options
         }
         $dest = $arg;
     }
-    $opt_silent = 1 if ( !defined $ENV{VERBOSE} || (defined $ENV{VERBOSE} && $ENV{VERBOSE} eq 'FALSE')) && ( ! $opt_verbose );
-    $opt_verbose = 1 if ( defined $ENV{VERBOSE} && $ENV{VERBOSE} eq 'TRUE') && ( ! $opt_silent );
     # $dest and $opt_zip or $opt_delete are mutually exclusive
     if ( $dest and ($opt_zip || $opt_delete) ) {
         usage(1);
     }
     # $opt_silent and $opt_check or $opt_verbose are mutually exclusive
     if ( ($opt_check or $opt_verbose) and $opt_silent ) {
-        print STDERR "Error on command line: options '-check'/'-verbose' and '-quiet' are mutually exclusive.\n";
+        print STDERR "Error on command line: options '-check' and '-quiet' are mutually exclusive.\n";
         usage(1);
     }
     if ($dontdeletecommon) {
@@ -679,6 +678,12 @@ sub glob_line
     }
     else {
         # no globbing but renaming possible
+        # #i89066#
+        if (-d $to && -f $from) {
+            my $filename = File::Basename::basename($from);
+            $to .= '/' if ($to !~ /[\\|\/]$/);
+            $to .= $filename;
+        };
         push(@globbed_files, [$from, $to]);
     }
     if ( $opt_checkdlst ) {
@@ -783,11 +788,6 @@ sub copy_if_newer
     if ( $opt_delete ) {
         print "REMOVE: $to\n" if $opt_verbose;
         $rc = unlink($to) unless $opt_check;
-        # handle special packaging of *.dylib files for Mac OS X
-        if ( $to =~ s/\.dylib$/.jnilib/ ) {
-            print "REMOVE: $to\n" if $opt_verbose;
-            $rc += unlink "$to" unless $opt_check;
-        } 
         return 1 if $opt_check;
         return $rc;
     }
@@ -852,19 +852,6 @@ sub copy_if_newer
             # handle special packaging of *.dylib files for Mac OS X
             if ( $^O eq 'darwin' )
             {
-                if ( $to =~ /\.dylib/ ) {
-                    system("macosx-create-bundle", $to);
-                    my $bundlelib = $to;
-                    $bundlelib =~ s/\.dylib$//; 
-                    $bundlelib .= ".jnilib";
-                    if ( $opt_delete ) {
-                        print "REMOVE: $bundlelib\n" if $opt_verbose;
-                        unlink "$bundlelib" unless $opt_check;
-                    } else {
-                        push_on_ziplist($bundlelib) if $opt_zip;
-                        push_on_loglist("LINK", basename($to), "$bundlelib") if $opt_log;
-                    }
-                }
                 system("macosx-create-bundle", "$to=$from.app") if ( -d "$from.app" );
                 system("ranlib", "$to" ) if ( $to =~ /\.a/ );
             }
