@@ -34,11 +34,6 @@
 
 #include <tools/poly.hxx>
 
-#if defined( WIN ) && defined( MSC )
-#pragma code_seg( "SVTOOLS_FILTER2", "SVTOOLS_CODE" )
-#pragma optimize( "", off )
-#endif
-
 #if defined( PM2 ) && defined( __BORLANDC__ )
 #pragma option -Od
 #endif
@@ -146,10 +141,6 @@ short basis()             /* BASIS maschinenunabhaengig bestimmen     */
 #define NEGMAX   -POSMIN                   /* groesste negative Zahl  */
 #define NEGMIN   -POSMAX                   /* kleinste negative Zahl  */
 
-#define TRUE      1
-#define FALSE     0
-
-
 /* Definition von Funktionsmakros:
    */
 
@@ -176,7 +167,7 @@ short basis()             /* BASIS maschinenunabhaengig bestimmen     */
 
 /*----------------------   MODUL TRIDIAGONAL  ------------------------*/
 
-USHORT TriDiagGS(BOOL rep, USHORT n, double* lower,
+sal_uInt16 TriDiagGS(sal_Bool rep, sal_uInt16 n, double* lower,
                  double* diag, double* upper, double* b)
                                               /************************/
                                               /* GAUSS-Verfahren fuer */
@@ -213,7 +204,7 @@ USHORT TriDiagGS(BOOL rep, USHORT n, double* lower,
 /*                                                                    */
 /*   Eingabeparameter:                                                */
 /*   ================                                                 */
-/*      n        Dimension der Matrix ( > 1 )  USHORT n               */
+/*      n        Dimension der Matrix ( > 1 )  sal_uInt16 n               */
 /*                                                                    */
 /*      lower    untere Nebendiagonale         double lower[n]        */
 /*      diag     Hauptdiagonale                double diag[n]         */
@@ -223,7 +214,7 @@ USHORT TriDiagGS(BOOL rep, USHORT n, double* lower,
 /*               Dreieckzerlegung der Ausgangsmatrix.                 */
 /*                                                                    */
 /*      b        rechte Seite des Systems      double b[n]            */
-/*      rep      = 0  erstmaliger Aufruf       BOOL rep               */
+/*      rep      = 0  erstmaliger Aufruf       sal_Bool rep               */
 /*               !=0  wiederholter Aufruf                             */
 /*                    fuer gleiche Matrix,                            */
 /*                    aber verschiedenes b.                           */
@@ -257,7 +248,7 @@ USHORT TriDiagGS(BOOL rep, USHORT n, double* lower,
 
 /*.cp 5 */
 {
- USHORT i;
+ sal_uInt16 i;
  short  j;
 
 // double fabs(double);
@@ -308,7 +299,7 @@ USHORT TriDiagGS(BOOL rep, USHORT n, double* lower,
 /*----------------  MODUL ZYKLISCH TRIDIAGONAL  ----------------------*/
 
 
-USHORT ZyklTriDiagGS(BOOL rep, USHORT n, double* lower, double* diag,
+sal_uInt16 ZyklTriDiagGS(sal_Bool rep, sal_uInt16 n, double* lower, double* diag,
                      double* upper, double* lowrow, double* ricol, double* b)
                                         /******************************/
                                         /* Systeme mit zyklisch tri-  */
@@ -349,12 +340,12 @@ USHORT ZyklTriDiagGS(BOOL rep, USHORT n, double* lower, double* diag,
 /*                                                                    */
 /*   Eingabeparameter:                                                */
 /*   ================                                                 */
-/*      n        Dimension der Matrix ( > 2 )  USHORT n               */
+/*      n        Dimension der Matrix ( > 2 )  sal_uInt16 n               */
 /*      lower    untere Nebendiagonale         double lower[n]        */
 /*      diag     Hauptdiagonale                double diag[n]         */
 /*      upper    obere Nebendiagonale          double upper[n]        */
 /*      b        rechte Seite des Systems      double b[n]            */
-/*      rep      = 0  erstmaliger Aufruf       BOOL rep               */
+/*      rep      = 0  erstmaliger Aufruf       sal_Bool rep               */
 /*               !=0  wiederholter Aufruf                             */
 /*                    fuer gleiche Matrix,                            */
 /*                    aber verschiedenes b.                           */
@@ -391,7 +382,7 @@ USHORT ZyklTriDiagGS(BOOL rep, USHORT n, double* lower, double* diag,
 /*.cp 5 */
 {
  double temp;  // fabs(double);
- USHORT i;
+ sal_uInt16 i;
  short  j;
 
  if ( n < 3 ) return(1);
@@ -459,20 +450,18 @@ USHORT ZyklTriDiagGS(BOOL rep, USHORT n, double* lower, double* diag,
 |*
 |*    Beschreibung      Berechnet die Koeffizienten eines natuerlichen
 |*                      kubischen Polynomsplines mit n Stuetzstellen.
-|*    Ersterstellung    JOE 17-08.93
-|*    Letzte Aenderung  JOE 17-08.93
 |*
 *************************************************************************/
 
-USHORT NaturalSpline(USHORT n, double* x, double* y,
+sal_uInt16 NaturalSpline(sal_uInt16 n, double* x, double* y,
                      double Marg0, double MargN,
-                     BYTE MargCond,
+                     sal_uInt8 MargCond,
                      double* b, double* c, double* d)
 {
-    USHORT  i;
+    sal_uInt16  i;
     double* a;
     double* h;
-    USHORT  error;
+    sal_uInt16  error;
 
     if (n<2) return 1;
     if ( (MargCond & ~3) ) return 2;
@@ -522,7 +511,7 @@ USHORT NaturalSpline(USHORT n, double* x, double* y,
     if (n==2) {
         c[1]=a[0]/d[0];
     } else {
-        error=TriDiagGS(FALSE,n-1,b,d,c,a);
+        error=TriDiagGS(sal_False,n-1,b,d,c,a);
         if (error!=0) { delete[] a; delete[] h; return error+2; }
         for (i=0;i<n-1;i++) c[i+1]=a[i];
     }
@@ -567,17 +556,15 @@ USHORT NaturalSpline(USHORT n, double* x, double* y,
 |*
 |*    Beschreibung      Berechnet die Koeffizienten eines periodischen
 |*                      kubischen Polynomsplines mit n Stuetzstellen.
-|*    Ersterstellung    JOE 17-08.93
-|*    Letzte Aenderung  JOE 17-08.93
 |*
 *************************************************************************/
 
 
-USHORT PeriodicSpline(USHORT n, double* x, double* y,
+sal_uInt16 PeriodicSpline(sal_uInt16 n, double* x, double* y,
                       double* b, double* c, double* d)
 {                     // Arrays muessen von [0..n] dimensioniert sein!
-    USHORT  Error;
-    USHORT  i,im1,nm1; //integer
+    sal_uInt16  Error;
+    sal_uInt16  i,im1,nm1; //integer
     double  hr,hl;
     double* a;
     double* lowrow;
@@ -614,7 +601,7 @@ USHORT PeriodicSpline(USHORT n, double* x, double* y,
         lowrow[0]=hr;
         ricol[0]=hr;
         a[nm1]=3.0*((y[1]-y[0])/hr-(y[n]-y[nm1])/hl);
-        Error=ZyklTriDiagGS(FALSE,n,b,d,c,lowrow,ricol,a);
+        Error=ZyklTriDiagGS(sal_False,n,b,d,c,lowrow,ricol,a);
         if ( Error != 0 )
         {
             delete[] a;
@@ -646,27 +633,25 @@ USHORT PeriodicSpline(USHORT n, double* x, double* y,
 |*    Beschreibung      Berechnet die Koeffizienten eines parametrischen
 |*                      natuerlichen oder periodischen kubischen
 |*                      Polynomsplines mit n Stuetzstellen.
-|*    Ersterstellung    JOE 17-08.93
-|*    Letzte Aenderung  JOE 17-08.93
 |*
 *************************************************************************/
 
-USHORT ParaSpline(USHORT n, double* x, double* y, BYTE MargCond,
+sal_uInt16 ParaSpline(sal_uInt16 n, double* x, double* y, sal_uInt8 MargCond,
                   double Marg01, double Marg02,
                   double MargN1, double MargN2,
-                  BOOL CondT, double* T,
+                  sal_Bool CondT, double* T,
                   double* bx, double* cx, double* dx,
                   double* by, double* cy, double* dy)
 {
-    USHORT Error,Marg;
-    USHORT i;
+    sal_uInt16 Error;
+    sal_uInt16 i;
     double deltX,deltY,delt,
            alphX = 0,alphY = 0,
            betX = 0,betY = 0;
 
     if (n<2) return 1;
     if ((MargCond & ~3) && (MargCond != 4)) return 2; // ungueltige Randbedingung
-    if (CondT==FALSE) {
+    if (CondT==sal_False) {
         T[0]=0.0;
         for (i=0;i<n;i++) {
             deltX=x[i+1]-x[i]; deltY=y[i+1]-y[i];
@@ -676,9 +661,8 @@ USHORT ParaSpline(USHORT n, double* x, double* y, BYTE MargCond,
         }
     }
     switch (MargCond) {
-        case 0: Marg=0; break;
+        case 0: break;
         case 1: case 2: {
-            Marg=MargCond;
             alphX=Marg01; betX=MargN1;
             alphY=Marg02; betY=MargN2;
         } break;
@@ -687,7 +671,6 @@ USHORT ParaSpline(USHORT n, double* x, double* y, BYTE MargCond,
             if (y[n]!=y[0]) return 4;
         } break;
         case 4: {
-            Marg=1;
             if (abs(Marg01)>=MAXROOT) {
                 alphX=0.0;
                 alphY=sign(1.0,y[1]-y[0]);
@@ -730,23 +713,21 @@ USHORT ParaSpline(USHORT n, double* x, double* y, BYTE MargCond,
 |*                      Polygons werden als Stuetzstellen angenommen.
 |*                      n liefert die Anzahl der Teilpolynome.
 |*                      Ist die Berechnung fehlerfrei verlaufen, so
-|*                      liefert die Funktion TRUE. Nur in diesem Fall
+|*                      liefert die Funktion sal_True. Nur in diesem Fall
 |*                      ist Speicher fuer die Koeffizientenarrays
 |*                      allokiert, der dann spaeter vom Aufrufer mittels
 |*                      delete freizugeben ist.
-|*    Ersterstellung    JOE 17-08.93
-|*    Letzte Aenderung  JOE 17-08.93
 |*
 *************************************************************************/
 
-BOOL CalcSpline(Polygon& rPoly, BOOL Periodic, USHORT& n,
+sal_Bool CalcSpline(Polygon& rPoly, sal_Bool Periodic, sal_uInt16& n,
                 double*& ax, double*& ay, double*& bx, double*& by,
                 double*& cx, double*& cy, double*& dx, double*& dy, double*& T)
 {
-    BYTE   Marg;
-    double Marg01,Marg02;
+    sal_uInt8   Marg;
+    double Marg01;
     double MargN1,MargN2;
-    USHORT i;
+    sal_uInt16 i;
     Point  P0(-32768,-32768);
     Point  Pt;
 
@@ -783,17 +764,16 @@ BOOL CalcSpline(Polygon& rPoly, BOOL Periodic, USHORT& n,
     T =new double[n+1];
 
     Marg01=0.0;
-    Marg02=0.0;
     MargN1=0.0;
     MargN2=0.0;
     if (n>0) n--; // n Korregieren (Anzahl der Teilpolynome)
 
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
     if ( ( Marg == 3 && n >= 3 ) || ( Marg == 2 && n >= 2 ) )
     {
-        bRet = ParaSpline(n,ax,ay,Marg,Marg01,Marg01,MargN1,MargN2,FALSE,T,bx,cx,dx,by,cy,dy) == 0;
+        bRet = ParaSpline(n,ax,ay,Marg,Marg01,Marg01,MargN1,MargN2,sal_False,T,bx,cx,dx,by,cy,dy) == 0;
     }
-    if ( bRet == FALSE )
+    if ( bRet == sal_False )
     {
         delete[] ax;
         delete[] ay;
@@ -817,17 +797,15 @@ BOOL CalcSpline(Polygon& rPoly, BOOL Periodic, USHORT& n,
 |*    Beschreibung      Konvertiert einen parametrichen kubischen
 |*                      Polynomspline Spline (natuerlich oder periodisch)
 |*                      in ein angenaehertes Polygon.
-|*                      Die Funktion liefert FALSE, wenn ein Fehler bei
+|*                      Die Funktion liefert sal_False, wenn ein Fehler bei
 |*                      der Koeffizientenberechnung aufgetreten ist oder
 |*                      das Polygon zu gross wird (>PolyMax=16380). Im 1.
 |*                      Fall hat das Polygon 0, im 2. Fall PolyMax Punkte.
 |*                      Um Koordinatenueberlaeufe zu vermeiden werden diese
 |*                      auf +/-32000 begrenzt.
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
 |*
 *************************************************************************/
-BOOL Spline2Poly(Polygon& rSpln, BOOL Periodic, Polygon& rPoly)
+sal_Bool Spline2Poly(Polygon& rSpln, sal_Bool Periodic, Polygon& rPoly)
 {
     short  MinKoord=-32000; // zur Vermeidung
     short  MaxKoord=32000;  // von Ueberlaeufen
@@ -845,11 +823,11 @@ BOOL Spline2Poly(Polygon& rSpln, BOOL Periodic, Polygon& rPoly)
     double  Step;        // Schrittweite fuer t
     double  dt1,dt2,dt3; // Delta t, y, ^3
     double  t;
-    BOOL    bEnde;       // Teilpolynom zu Ende?
-    USHORT  n;           // Anzahl der zu zeichnenden Teilpolynome
-    USHORT  i;           // aktuelles Teilpolynom
-    BOOL    bOk;         // noch alles ok?
-    USHORT  PolyMax=16380;// Maximale Anzahl von Polygonpunkten
+    sal_Bool    bEnde;       // Teilpolynom zu Ende?
+    sal_uInt16  n;           // Anzahl der zu zeichnenden Teilpolynome
+    sal_uInt16  i;           // aktuelles Teilpolynom
+    sal_Bool    bOk;         // noch alles ok?
+    sal_uInt16  PolyMax=16380;// Maximale Anzahl von Polygonpunkten
     long    x,y;
 
     bOk=CalcSpline(rSpln,Periodic,n,ax,ay,bx,by,cx,cy,dx,dy,tv);
@@ -861,7 +839,7 @@ BOOL Spline2Poly(Polygon& rSpln, BOOL Periodic, Polygon& rPoly)
         i=0;
         while (i<n) {       // n Teilpolynome malen
             t=tv[i]+Step;
-            bEnde=FALSE;
+            bEnde=sal_False;
             while (!bEnde) {  // ein Teilpolynom interpolieren
                 bEnde=t>=tv[i+1];
                 if (bEnde) t=tv[i+1];
@@ -874,7 +852,7 @@ BOOL Spline2Poly(Polygon& rSpln, BOOL Periodic, Polygon& rPoly)
                     rPoly.SetSize(rPoly.GetSize()+1);
                     rPoly.SetPoint(Point(short(x),short(y)),rPoly.GetSize()-1);
                 } else {
-                    bOk=FALSE; // Fehler: Polygon wird zu gross
+                    bOk=sal_False; // Fehler: Polygon wird zu gross
                 }
                 t=t+Step;
             } // Ende von Teilpolynom
@@ -892,7 +870,7 @@ BOOL Spline2Poly(Polygon& rSpln, BOOL Periodic, Polygon& rPoly)
         return bOk;
     } // Ende von if (bOk)
     rPoly.SetSize(0);
-    return FALSE;
+    return sal_False;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
