@@ -41,9 +41,8 @@
 #include <vcl/window.hxx>
 #include <comphelper/processfactory.hxx>
 #include <com/sun/star/datatransfer/dnd/XDropTargetDragContext.hpp>
-
 #include "svl/urlbmk.hxx"
-#include "inetimg.hxx"
+#include <svtools/inetimg.hxx>
 #include <svtools/imap.hxx>
 #include <svtools/transfer.hxx>
 
@@ -436,7 +435,7 @@ sal_Bool TransferDataContainer::GetData( const
     TDataCntnrEntryList::iterator	aIter( pImpl->aFmtList.begin() ),
                                     aEnd( pImpl->aFmtList.end() );
     sal_Bool bFnd = sal_False;
-    ULONG nFmtId = SotExchange::GetFormat( rFlavor );
+    sal_uLong nFmtId = SotExchange::GetFormat( rFlavor );
 
     // test first the list
     for( ; aIter != aEnd; ++aIter )
@@ -502,8 +501,8 @@ void TransferDataContainer::CopyINetBookmark( const INetBookmark& rBkmk )
 
 // -----------------------------------------------------------------------------
 
-void TransferDataContainer::CopyAnyData( ULONG nFormatId,
-                                        const sal_Char* pData, ULONG nLen )
+void TransferDataContainer::CopyAnyData( sal_uLong nFormatId,
+                                        const sal_Char* pData, sal_uLong nLen )
 {
     if( nLen )
     {
@@ -520,7 +519,7 @@ void TransferDataContainer::CopyAnyData( ULONG nFormatId,
 
 // -----------------------------------------------------------------------------
 
-void TransferDataContainer::CopyByteString( ULONG nFormatId,
+void TransferDataContainer::CopyByteString( sal_uLong nFormatId,
                                             const ByteString& rStr )
 {
     CopyAnyData( nFormatId, rStr.GetBuffer(), rStr.Len() );
@@ -570,7 +569,7 @@ void TransferDataContainer::CopyGraphic( const Graphic& rGrf )
 
 // -----------------------------------------------------------------------------
 
-void TransferDataContainer::CopyString( USHORT nFmt, const String& rStr )
+void TransferDataContainer::CopyString( sal_uInt16 nFmt, const String& rStr )
 {
     if( rStr.Len() )
     {
@@ -592,7 +591,7 @@ void TransferDataContainer::CopyString( const String& rStr )
 
 // -----------------------------------------------------------------------------
 
-void TransferDataContainer::CopyAny( USHORT nFmt,
+void TransferDataContainer::CopyAny( sal_uInt16 nFmt,
                                     const ::com::sun::star::uno::Any& rAny )
 {
     TDataCntnrEntry_Impl aEntry;
