@@ -32,12 +32,11 @@
 #define _SVT_UNOIFACE_CXX
 #include <tools/debug.hxx>
 #include <vcl/svapp.hxx>
-
 #include <svtools/svmedit.hxx>
 #include <unoiface.hxx>
-#include "filedlg.hxx"
-#include "filectrl.hxx"
-#include "roadmap.hxx"
+#include <svtools/filedlg.hxx>
+#include <svtools/filectrl.hxx>
+#include <svtools/roadmap.hxx>
 #include <svtools/fixedhyper.hxx>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/lang/XSingleServiceFactory.hpp>
@@ -47,9 +46,8 @@
 #include <toolkit/helper/property.hxx>
 #include <svtools/fmtfield.hxx>
 #include <svl/numuno.hxx>
-#include <calendar.hxx>
-#include <prgsbar.hxx>
-
+#include <svtools/calendar.hxx>
+#include <svtools/prgsbar.hxx>
 #include <svtools/svtreebx.hxx>
 #include "treecontrolpeer.hxx"
 #include "svtxgridcontrol.hxx"
@@ -124,7 +122,7 @@ SAL_DLLPUBLIC_EXPORT Window* CreateWindow( VCLXWindow** ppNewComp, const ::com::
         pWindow = new CalendarField( pParent, nWinBits);
         static_cast<CalendarField*>(pWindow)->EnableToday();
         static_cast<CalendarField*>(pWindow)->EnableNone();
-        static_cast<CalendarField*>(pWindow)->EnableEmptyFieldValue( TRUE );
+        static_cast<CalendarField*>(pWindow)->EnableEmptyFieldValue( sal_True );
         *ppNewComp = new SVTXDateField;
         ((VCLXFormattedSpinField*)*ppNewComp)->SetFormatter( (FormatterBase*)(DateField*)pWindow );
     }
@@ -226,7 +224,7 @@ void VCLXMultiLineEdit::removeTextListener( const ::com::sun::star::uno::Referen
 
 void VCLXMultiLineEdit::setText( const ::rtl::OUString& aText ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     MultiLineEdit* pEdit = (MultiLineEdit*)GetWindow();
     if ( pEdit )
@@ -243,7 +241,7 @@ void VCLXMultiLineEdit::setText( const ::rtl::OUString& aText ) throw(::com::sun
 
 void VCLXMultiLineEdit::insertText( const ::com::sun::star::awt::Selection& rSel, const ::rtl::OUString& aText ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     MultiLineEdit* pEdit = (MultiLineEdit*)GetWindow();
     if ( pEdit )
@@ -255,7 +253,7 @@ void VCLXMultiLineEdit::insertText( const ::com::sun::star::awt::Selection& rSel
 
 ::rtl::OUString VCLXMultiLineEdit::getText() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::rtl::OUString aText;
     MultiLineEdit* pEdit = (MultiLineEdit*)GetWindow();
@@ -266,7 +264,7 @@ void VCLXMultiLineEdit::insertText( const ::com::sun::star::awt::Selection& rSel
 
 ::rtl::OUString VCLXMultiLineEdit::getSelectedText() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::rtl::OUString aText;
     MultiLineEdit* pMultiLineEdit = (MultiLineEdit*) GetWindow();
@@ -278,7 +276,7 @@ void VCLXMultiLineEdit::insertText( const ::com::sun::star::awt::Selection& rSel
 
 void VCLXMultiLineEdit::setSelection( const ::com::sun::star::awt::Selection& aSelection ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     MultiLineEdit* pMultiLineEdit = (MultiLineEdit*) GetWindow();
     if ( pMultiLineEdit )
@@ -289,7 +287,7 @@ void VCLXMultiLineEdit::setSelection( const ::com::sun::star::awt::Selection& aS
 
 ::com::sun::star::awt::Selection VCLXMultiLineEdit::getSelection() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::com::sun::star::awt::Selection aSel;
     MultiLineEdit* pMultiLineEdit = (MultiLineEdit*) GetWindow();
@@ -303,7 +301,7 @@ void VCLXMultiLineEdit::setSelection( const ::com::sun::star::awt::Selection& aS
 
 sal_Bool VCLXMultiLineEdit::isEditable() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     MultiLineEdit* pMultiLineEdit = (MultiLineEdit*) GetWindow();
     return ( pMultiLineEdit && !pMultiLineEdit->IsReadOnly() && pMultiLineEdit->IsEnabled() ) ? sal_True : sal_False;
@@ -311,7 +309,7 @@ sal_Bool VCLXMultiLineEdit::isEditable() throw(::com::sun::star::uno::RuntimeExc
 
 void VCLXMultiLineEdit::setEditable( sal_Bool bEditable ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     MultiLineEdit* pMultiLineEdit = (MultiLineEdit*) GetWindow();
     if ( pMultiLineEdit )
@@ -320,7 +318,7 @@ void VCLXMultiLineEdit::setEditable( sal_Bool bEditable ) throw(::com::sun::star
 
 void VCLXMultiLineEdit::setMaxTextLen( sal_Int16 nLen ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     MultiLineEdit* pMultiLineEdit = (MultiLineEdit*) GetWindow();
     if ( pMultiLineEdit )
@@ -329,7 +327,7 @@ void VCLXMultiLineEdit::setMaxTextLen( sal_Int16 nLen ) throw(::com::sun::star::
 
 sal_Int16 VCLXMultiLineEdit::getMaxTextLen() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     MultiLineEdit* pMultiLineEdit = (MultiLineEdit*) GetWindow();
     return pMultiLineEdit ? (sal_Int16)pMultiLineEdit->GetMaxTextLen() : (sal_Int16)0;
@@ -337,7 +335,7 @@ sal_Int16 VCLXMultiLineEdit::getMaxTextLen() throw(::com::sun::star::uno::Runtim
 
 ::rtl::OUString VCLXMultiLineEdit::getTextLines() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::rtl::OUString aText;
     MultiLineEdit* pEdit = (MultiLineEdit*)GetWindow();
@@ -348,7 +346,7 @@ sal_Int16 VCLXMultiLineEdit::getMaxTextLen() throw(::com::sun::star::uno::Runtim
 
 ::com::sun::star::awt::Size VCLXMultiLineEdit::getMinimumSize() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::com::sun::star::awt::Size aSz;
     MultiLineEdit* pEdit = (MultiLineEdit*) GetWindow();
@@ -364,7 +362,7 @@ sal_Int16 VCLXMultiLineEdit::getMaxTextLen() throw(::com::sun::star::uno::Runtim
 
 ::com::sun::star::awt::Size VCLXMultiLineEdit::calcAdjustedSize( const ::com::sun::star::awt::Size& rNewSize ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::com::sun::star::awt::Size aSz = rNewSize;
     MultiLineEdit* pEdit = (MultiLineEdit*) GetWindow();
@@ -375,7 +373,7 @@ sal_Int16 VCLXMultiLineEdit::getMaxTextLen() throw(::com::sun::star::uno::Runtim
 
 ::com::sun::star::awt::Size VCLXMultiLineEdit::getMinimumSize( sal_Int16 nCols, sal_Int16 nLines ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::com::sun::star::awt::Size aSz;
     MultiLineEdit* pEdit = (MultiLineEdit*) GetWindow();
@@ -386,7 +384,7 @@ sal_Int16 VCLXMultiLineEdit::getMaxTextLen() throw(::com::sun::star::uno::Runtim
 
 void VCLXMultiLineEdit::getColumnsAndLines( sal_Int16& nCols, sal_Int16& nLines ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     nCols = nLines = 0;
     MultiLineEdit* pEdit = (MultiLineEdit*) GetWindow();
@@ -423,7 +421,7 @@ void VCLXMultiLineEdit::ProcessWindowEvent( const VclWindowEvent& rVclWindowEven
 
 void VCLXMultiLineEdit::setProperty( const ::rtl::OUString& PropertyName, const ::com::sun::star::uno::Any& Value) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     MultiLineEdit* pMultiLineEdit = (MultiLineEdit*)GetWindow();
     if ( pMultiLineEdit )
@@ -440,7 +438,7 @@ void VCLXMultiLineEdit::setProperty( const ::rtl::OUString& PropertyName, const
                 case ::com::sun::star::awt::LineEndFormat::CARRIAGE_RETURN:           meLineEndType = LINEEND_CR; break;
                 case ::com::sun::star::awt::LineEndFormat::LINE_FEED:                 meLineEndType = LINEEND_LF; break;
                 case ::com::sun::star::awt::LineEndFormat::CARRIAGE_RETURN_LINE_FEED: meLineEndType = LINEEND_CRLF; break;
-                default: DBG_ERROR( "VCLXMultiLineEdit::setProperty: invalid line end value!" ); break;
+                default: OSL_FAIL( "VCLXMultiLineEdit::setProperty: invalid line end value!" ); break;
                 }
             }
             break;
@@ -479,7 +477,7 @@ void VCLXMultiLineEdit::setProperty( const ::rtl::OUString& PropertyName, const
 
 ::com::sun::star::uno::Any VCLXMultiLineEdit::getProperty( const ::rtl::OUString& PropertyName ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::com::sun::star::uno::Any aProp;
     MultiLineEdit* pMultiLineEdit = (MultiLineEdit*)GetWindow();
@@ -496,7 +494,7 @@ void VCLXMultiLineEdit::setProperty( const ::rtl::OUString& PropertyName, const
                 case LINEEND_CR:   nLineEndType = ::com::sun::star::awt::LineEndFormat::CARRIAGE_RETURN; break;
                 case LINEEND_LF:   nLineEndType = ::com::sun::star::awt::LineEndFormat::LINE_FEED; break;
                 case LINEEND_CRLF: nLineEndType = ::com::sun::star::awt::LineEndFormat::CARRIAGE_RETURN_LINE_FEED; break;
-                default: DBG_ERROR( "VCLXMultiLineEdit::getProperty: invalid line end value!" ); break;
+                default: OSL_FAIL( "VCLXMultiLineEdit::getProperty: invalid line end value!" ); break;
                 }
                 aProp <<= nLineEndType;
             }
@@ -523,13 +521,13 @@ void VCLXMultiLineEdit::setProperty( const ::rtl::OUString& PropertyName, const
 
 void SAL_CALL VCLXMultiLineEdit::setFocus(  ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     // don't grab the focus if we already have it. Reason is that the only thing which the edit
     // does is forwarding the focus to it's text window. This text window then does a "select all".
     // So if the text window already has the focus, and we give the focus to the multi line
     // edit, then all which happens is that everything is selected.
-    // #i27072# - 2004-04-25 - fs@openoffice.org
+    // #i27072#
     if ( GetWindow() && !GetWindow()->HasChildPathFocus() )
         GetWindow()->GrabFocus();
 }
@@ -578,7 +576,7 @@ IMPL_XTYPEPROVIDER_END
 
 void SAL_CALL VCLXFileControl::setProperty( const ::rtl::OUString& PropertyName, const ::com::sun::star::uno::Any& Value) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FileControl* pControl = (FileControl*)GetWindow();
     if ( pControl )
@@ -628,7 +626,7 @@ void VCLXFileControl::removeTextListener( const ::com::sun::star::uno::Reference
 
 void VCLXFileControl::setText( const ::rtl::OUString& aText ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     Window* pWindow = GetWindow();
     if ( pWindow )
@@ -643,7 +641,7 @@ void VCLXFileControl::setText( const ::rtl::OUString& aText ) throw(::com::sun::
 
 void VCLXFileControl::insertText( const ::com::sun::star::awt::Selection& rSel, const ::rtl::OUString& aText ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FileControl* pFileControl = (FileControl*) GetWindow();
     if ( pFileControl )
@@ -655,7 +653,7 @@ void VCLXFileControl::insertText( const ::com::sun::star::awt::Selection& rSel,
 
 ::rtl::OUString VCLXFileControl::getText() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::rtl::OUString aText;
     Window* pWindow = GetWindow();
@@ -666,7 +664,7 @@ void VCLXFileControl::insertText( const ::com::sun::star::awt::Selection& rSel,
 
 ::rtl::OUString VCLXFileControl::getSelectedText() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::rtl::OUString aText;
     FileControl* pFileControl = (FileControl*) GetWindow();
@@ -678,7 +676,7 @@ void VCLXFileControl::insertText( const ::com::sun::star::awt::Selection& rSel,
 
 void VCLXFileControl::setSelection( const ::com::sun::star::awt::Selection& aSelection ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FileControl* pFileControl = (FileControl*) GetWindow();
     if ( pFileControl )
@@ -687,7 +685,7 @@ void VCLXFileControl::setSelection( const ::com::sun::star::awt::Selection& aSel
 
 ::com::sun::star::awt::Selection VCLXFileControl::getSelection() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::com::sun::star::awt::Selection aSel;
     FileControl* pFileControl = (FileControl*) GetWindow();
@@ -701,7 +699,7 @@ void VCLXFileControl::setSelection( const ::com::sun::star::awt::Selection& aSel
 
 sal_Bool VCLXFileControl::isEditable() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FileControl* pFileControl = (FileControl*) GetWindow();
     return ( pFileControl && !pFileControl->GetEdit().IsReadOnly() && pFileControl->GetEdit().IsEnabled() ) ? sal_True : sal_False;
@@ -709,7 +707,7 @@ sal_Bool VCLXFileControl::isEditable() throw(::com::sun::star::uno::RuntimeExcep
 
 void VCLXFileControl::setEditable( sal_Bool bEditable ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FileControl* pFileControl = (FileControl*) GetWindow();
     if ( pFileControl )
@@ -718,7 +716,7 @@ void VCLXFileControl::setEditable( sal_Bool bEditable ) throw(::com::sun::star::
 
 void VCLXFileControl::setMaxTextLen( sal_Int16 nLen ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FileControl* pFileControl = (FileControl*) GetWindow();
     if ( pFileControl )
@@ -727,7 +725,7 @@ void VCLXFileControl::setMaxTextLen( sal_Int16 nLen ) throw(::com::sun::star::un
 
 sal_Int16 VCLXFileControl::getMaxTextLen() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FileControl* pFileControl = (FileControl*) GetWindow();
     return pFileControl ? pFileControl->GetEdit().GetMaxTextLen() : 0;
@@ -745,7 +743,7 @@ IMPL_LINK( VCLXFileControl, ModifyHdl, Edit*, EMPTYARG )
 
 ::com::sun::star::awt::Size VCLXFileControl::getMinimumSize() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::com::sun::star::awt::Size aSz;
     FileControl* pControl = (FileControl*) GetWindow();
@@ -767,7 +765,7 @@ IMPL_LINK( VCLXFileControl, ModifyHdl, Edit*, EMPTYARG )
 
 ::com::sun::star::awt::Size VCLXFileControl::calcAdjustedSize( const ::com::sun::star::awt::Size& rNewSize ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::com::sun::star::awt::Size aSz =rNewSize;
     FileControl* pControl = (FileControl*) GetWindow();
@@ -782,7 +780,7 @@ IMPL_LINK( VCLXFileControl, ModifyHdl, Edit*, EMPTYARG )
 
 ::com::sun::star::awt::Size VCLXFileControl::getMinimumSize( sal_Int16 nCols, sal_Int16 ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::com::sun::star::awt::Size aSz;
     FileControl* pControl = (FileControl*) GetWindow();
@@ -796,7 +794,7 @@ IMPL_LINK( VCLXFileControl, ModifyHdl, Edit*, EMPTYARG )
 
 void VCLXFileControl::getColumnsAndLines( sal_Int16& nCols, sal_Int16& nLines ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     nCols = 0;
     nLines = 1;
@@ -841,13 +839,13 @@ void SVTXFormattedField::SetWindow( Window* _pWindow )
 {
     VCLXSpinField::SetWindow(_pWindow);
     if (GetFormattedField())
-        GetFormattedField()->SetAutoColor(TRUE);
+        GetFormattedField()->SetAutoColor(sal_True);
 }
 
 // --------------------------------------------------------------------------------------
 void SVTXFormattedField::setProperty( const ::rtl::OUString& PropertyName, const ::com::sun::star::uno::Any& Value) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     if ( pField )
@@ -972,7 +970,7 @@ void SVTXFormattedField::setProperty( const ::rtl::OUString& PropertyName, const
 // --------------------------------------------------------------------------------------
 ::com::sun::star::uno::Any SVTXFormattedField::getProperty( const ::rtl::OUString& PropertyName ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::com::sun::star::uno::Any aReturn;
 
@@ -1433,7 +1431,7 @@ void SVTXRoadmap::ProcessWindowEvent( const VclWindowEvent& rVclWindowEvent )
     {
         case VCLEVENT_ROADMAP_ITEMSELECTED:
         {
-            ::osl::SolarGuard aGuard( GetMutex() );
+            SolarMutexGuard aGuard;
             ::svt::ORoadmap* pField = GetRoadmap();
             if ( pField )
             {
@@ -1455,7 +1453,7 @@ void SVTXRoadmap::ProcessWindowEvent( const VclWindowEvent& rVclWindowEvent )
 
 void SVTXRoadmap::propertyChange( const ::com::sun::star::beans::PropertyChangeEvent& evt ) throw (::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
     ::svt::ORoadmap* pField = GetRoadmap();
     if ( pField )
     {
@@ -1463,25 +1461,25 @@ void SVTXRoadmap::propertyChange( const ::com::sun::star::beans::PropertyChangeE
         xRoadmapItem = evt.Source;
         sal_Int32 nID = 0;
         ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xPropertySet( xRoadmapItem, ::com::sun::star::uno::UNO_QUERY );
-        ::com::sun::star::uno::Any aValue = xPropertySet->getPropertyValue(::rtl::OUString::createFromAscii( "ID" ));
+        ::com::sun::star::uno::Any aValue = xPropertySet->getPropertyValue(::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ID" )));
         aValue >>= nID;
 
         ::com::sun::star::uno::Any rVal = evt.NewValue;
         evt.NewValue >>= rVal;
         ::rtl::OUString sPropertyName = evt.PropertyName;
-        if ( sPropertyName.equals(::rtl::OUString::createFromAscii( "Enabled" ) ) )
+        if ( sPropertyName.equals(::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Enabled" )) ) )
         {
             sal_Bool bEnable = false;
             evt.NewValue >>= bEnable;
             pField->EnableRoadmapItem( (RoadmapTypes::ItemId)nID , bEnable );
         }
-        else if ( sPropertyName.equals(::rtl::OUString::createFromAscii( "Label" ) ) )
+        else if ( sPropertyName.equals(::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Label" )) ) )
         {
             ::rtl::OUString sLabel;
             evt.NewValue >>= sLabel;
             pField->ChangeRoadmapItemLabel( (RoadmapTypes::ItemId)nID , sLabel );
         }
-        else if  ( sPropertyName.equals(::rtl::OUString::createFromAscii( "ID" ) ) )
+        else if  ( sPropertyName.equals(::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ID" )) ) )
         {
             sal_Int32 nNewID = 0;
             evt.NewValue >>= nNewID;
@@ -1512,11 +1510,11 @@ RMItemData SVTXRoadmap::GetRMItemData( const ::com::sun::star::container::Contai
     ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xPropertySet( xRoadmapItem, ::com::sun::star::uno::UNO_QUERY );
     if ( xPropertySet.is() )
     {
-        ::com::sun::star::uno::Any aValue = xPropertySet->getPropertyValue(::rtl::OUString::createFromAscii( "Label" ));
+        ::com::sun::star::uno::Any aValue = xPropertySet->getPropertyValue(::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Label" )));
         aValue >>= aCurRMItemData.Label;
-        aValue = xPropertySet->getPropertyValue(::rtl::OUString::createFromAscii( "ID" ));
+        aValue = xPropertySet->getPropertyValue(::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ID" )));
         aValue >>= aCurRMItemData.n_ID;
-        aValue = xPropertySet->getPropertyValue(::rtl::OUString::createFromAscii( "Enabled" ));
+        aValue = xPropertySet->getPropertyValue(::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Enabled" )));
         aValue >>= aCurRMItemData.b_Enabled;
     }
     return aCurRMItemData;;
@@ -1524,7 +1522,7 @@ RMItemData SVTXRoadmap::GetRMItemData( const ::com::sun::star::container::Contai
 
 void SVTXRoadmap::elementInserted( const ::com::sun::star::container::ContainerEvent& _rEvent )throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
     ::svt::ORoadmap* pField = GetRoadmap();
     if ( pField )
     {
@@ -1537,21 +1535,19 @@ void SVTXRoadmap::elementInserted( const ::com::sun::star::container::ContainerE
 
 void SVTXRoadmap::elementRemoved( const ::com::sun::star::container::ContainerEvent& _rEvent )throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
     ::svt::ORoadmap* pField = GetRoadmap();
     if ( pField )
     {
         sal_Int32 DelIndex = 0;
         _rEvent.Accessor >>= DelIndex;
         pField->DeleteRoadmapItem(DelIndex);
-//        pField->GetCurrentRoadmapItem()
-//        setProperty(::rtl::OUString.createFromAscii( "CurrentItem" )aAny,
     }
 }
 
 void SVTXRoadmap::elementReplaced( const ::com::sun::star::container::ContainerEvent& _rEvent )throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
     ::svt::ORoadmap* pField = GetRoadmap();
     if ( pField )
     {
@@ -1567,7 +1563,7 @@ void SVTXRoadmap::elementReplaced( const ::com::sun::star::container::ContainerE
 // --------------------------------------------------------------------------------------
 void SVTXRoadmap::setProperty( const ::rtl::OUString& PropertyName, const ::com::sun::star::uno::Any& Value) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::svt::ORoadmap* pField = GetRoadmap();
     if ( pField )
@@ -1622,7 +1618,7 @@ void SVTXRoadmap::setProperty( const ::rtl::OUString& PropertyName, const ::com:
 // --------------------------------------------------------------------------------------
 ::com::sun::star::uno::Any SVTXRoadmap::getProperty( const ::rtl::OUString& PropertyName ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::com::sun::star::uno::Any aReturn;
 
@@ -1653,7 +1649,7 @@ void SVTXRoadmap::ImplSetNewImage()
 {
     OSL_PRECOND( GetWindow(), "SVTXRoadmap::ImplSetNewImage: window is required to be not-NULL!" );
     ::svt::ORoadmap* pButton = static_cast< ::svt::ORoadmap* >( GetWindow() );
-    pButton->SetRoadmapBitmap( GetBitmap() );
+    pButton->SetRoadmapBitmap( GetImage().GetBitmapEx() );
 }
 
 void SVTXRoadmap::ImplGetPropertyIds( std::list< sal_uInt16 > &rIds )
@@ -1696,7 +1692,7 @@ IMPL_XTYPEPROVIDER_END
 
 void SVTXNumericField::setValue( double Value ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     if ( pField )
@@ -1705,7 +1701,7 @@ void SVTXNumericField::setValue( double Value ) throw(::com::sun::star::uno::Run
 
 double SVTXNumericField::getValue() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     return pField ? pField->GetValue() : 0;
@@ -1713,7 +1709,7 @@ double SVTXNumericField::getValue() throw(::com::sun::star::uno::RuntimeExceptio
 
 void SVTXNumericField::setMin( double Value ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     if ( pField )
@@ -1722,7 +1718,7 @@ void SVTXNumericField::setMin( double Value ) throw(::com::sun::star::uno::Runti
 
 double SVTXNumericField::getMin() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     return pField ? pField->GetMinValue() : 0;
@@ -1730,7 +1726,7 @@ double SVTXNumericField::getMin() throw(::com::sun::star::uno::RuntimeException)
 
 void SVTXNumericField::setMax( double Value ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     if ( pField )
@@ -1739,7 +1735,7 @@ void SVTXNumericField::setMax( double Value ) throw(::com::sun::star::uno::Runti
 
 double SVTXNumericField::getMax() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     return pField ? pField->GetMaxValue() : 0;
@@ -1747,7 +1743,7 @@ double SVTXNumericField::getMax() throw(::com::sun::star::uno::RuntimeException)
 
 void SVTXNumericField::setFirst( double Value ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     if ( pField )
@@ -1756,7 +1752,7 @@ void SVTXNumericField::setFirst( double Value ) throw(::com::sun::star::uno::Run
 
 double SVTXNumericField::getFirst() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     return pField ? pField->GetSpinFirst() : 0;
@@ -1764,7 +1760,7 @@ double SVTXNumericField::getFirst() throw(::com::sun::star::uno::RuntimeExceptio
 
 void SVTXNumericField::setLast( double Value ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     if ( pField )
@@ -1773,7 +1769,7 @@ void SVTXNumericField::setLast( double Value ) throw(::com::sun::star::uno::Runt
 
 double SVTXNumericField::getLast() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     return pField ? pField->GetSpinLast() : 0;
@@ -1781,7 +1777,7 @@ double SVTXNumericField::getLast() throw(::com::sun::star::uno::RuntimeException
 
 void SVTXNumericField::setSpinSize( double Value ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     if ( pField )
@@ -1790,7 +1786,7 @@ void SVTXNumericField::setSpinSize( double Value ) throw(::com::sun::star::uno::
 
 double SVTXNumericField::getSpinSize() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     return pField ? pField->GetSpinSize() : 0;
@@ -1798,7 +1794,7 @@ double SVTXNumericField::getSpinSize() throw(::com::sun::star::uno::RuntimeExcep
 
 void SVTXNumericField::setDecimalDigits( sal_Int16 Value ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     if ( pField )
@@ -1807,7 +1803,7 @@ void SVTXNumericField::setDecimalDigits( sal_Int16 Value ) throw(::com::sun::sta
 
 sal_Int16 SVTXNumericField::getDecimalDigits() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     return pField ? pField->GetDecimalDigits() : 0;
@@ -1815,7 +1811,7 @@ sal_Int16 SVTXNumericField::getDecimalDigits() throw(::com::sun::star::uno::Runt
 
 void SVTXNumericField::setStrictFormat( sal_Bool bStrict ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     if ( pField )
@@ -1824,7 +1820,7 @@ void SVTXNumericField::setStrictFormat( sal_Bool bStrict ) throw(::com::sun::sta
 
 sal_Bool SVTXNumericField::isStrictFormat() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     return pField ? pField->IsStrictFormat() : sal_False;
@@ -1862,7 +1858,7 @@ IMPL_XTYPEPROVIDER_END
 
 void SVTXCurrencyField::setValue( double Value ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     if ( pField )
@@ -1871,7 +1867,7 @@ void SVTXCurrencyField::setValue( double Value ) throw(::com::sun::star::uno::Ru
 
 double SVTXCurrencyField::getValue() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     return pField ? pField->GetValue() : 0;
@@ -1879,7 +1875,7 @@ double SVTXCurrencyField::getValue() throw(::com::sun::star::uno::RuntimeExcepti
 
 void SVTXCurrencyField::setMin( double Value ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     if ( pField )
@@ -1888,7 +1884,7 @@ void SVTXCurrencyField::setMin( double Value ) throw(::com::sun::star::uno::Runt
 
 double SVTXCurrencyField::getMin() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     return pField ? pField->GetMinValue() : 0;
@@ -1896,7 +1892,7 @@ double SVTXCurrencyField::getMin() throw(::com::sun::star::uno::RuntimeException
 
 void SVTXCurrencyField::setMax( double Value ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     if ( pField )
@@ -1905,7 +1901,7 @@ void SVTXCurrencyField::setMax( double Value ) throw(::com::sun::star::uno::Runt
 
 double SVTXCurrencyField::getMax() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     return pField ? pField->GetMaxValue() : 0;
@@ -1913,7 +1909,7 @@ double SVTXCurrencyField::getMax() throw(::com::sun::star::uno::RuntimeException
 
 void SVTXCurrencyField::setFirst( double Value ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     if ( pField )
@@ -1922,7 +1918,7 @@ void SVTXCurrencyField::setFirst( double Value ) throw(::com::sun::star::uno::Ru
 
 double SVTXCurrencyField::getFirst() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     return pField ? pField->GetSpinFirst() : 0;
@@ -1930,7 +1926,7 @@ double SVTXCurrencyField::getFirst() throw(::com::sun::star::uno::RuntimeExcepti
 
 void SVTXCurrencyField::setLast( double Value ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     if ( pField )
@@ -1939,7 +1935,7 @@ void SVTXCurrencyField::setLast( double Value ) throw(::com::sun::star::uno::Run
 
 double SVTXCurrencyField::getLast() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     return pField ? pField->GetSpinLast() : 0;
@@ -1947,7 +1943,7 @@ double SVTXCurrencyField::getLast() throw(::com::sun::star::uno::RuntimeExceptio
 
 void SVTXCurrencyField::setSpinSize( double Value ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     if ( pField )
@@ -1956,7 +1952,7 @@ void SVTXCurrencyField::setSpinSize( double Value ) throw(::com::sun::star::uno:
 
 double SVTXCurrencyField::getSpinSize() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     return pField ? pField->GetSpinSize() : 0;
@@ -1964,7 +1960,7 @@ double SVTXCurrencyField::getSpinSize() throw(::com::sun::star::uno::RuntimeExce
 
 void SVTXCurrencyField::setDecimalDigits( sal_Int16 Value ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     if ( pField )
@@ -1973,7 +1969,7 @@ void SVTXCurrencyField::setDecimalDigits( sal_Int16 Value ) throw(::com::sun::st
 
 sal_Int16 SVTXCurrencyField::getDecimalDigits() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     return pField ? pField->GetDecimalDigits() : 0;
@@ -1981,7 +1977,7 @@ sal_Int16 SVTXCurrencyField::getDecimalDigits() throw(::com::sun::star::uno::Run
 
 void SVTXCurrencyField::setStrictFormat( sal_Bool bStrict ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     if ( pField )
@@ -1990,7 +1986,7 @@ void SVTXCurrencyField::setStrictFormat( sal_Bool bStrict ) throw(::com::sun::st
 
 sal_Bool SVTXCurrencyField::isStrictFormat() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     FormattedField* pField = GetFormattedField();
     return pField ? pField->IsStrictFormat() : sal_False;
@@ -1998,7 +1994,7 @@ sal_Bool SVTXCurrencyField::isStrictFormat() throw(::com::sun::star::uno::Runtim
 
 void SVTXCurrencyField::setProperty( const ::rtl::OUString& PropertyName, const ::com::sun::star::uno::Any& Value) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::com::sun::star::uno::Any aReturn;
 
@@ -2038,7 +2034,7 @@ void SVTXCurrencyField::setProperty( const ::rtl::OUString& PropertyName, const
 
 ::com::sun::star::uno::Any SVTXCurrencyField::getProperty( const ::rtl::OUString& PropertyName ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::com::sun::star::uno::Any aReturn;
 
@@ -2137,7 +2133,7 @@ void VCLXProgressBar::ImplUpdateValue()
         }
 
         // set progressbar value
-        pProgressBar->SetValue( (USHORT) nPercent );
+        pProgressBar->SetValue( (sal_uInt16) nPercent );
     }
 }
 
@@ -2159,7 +2155,7 @@ IMPL_XTYPEPROVIDER_END
 // ::com::sun::star::awt::XProgressBar
 void VCLXProgressBar::setForegroundColor( sal_Int32 nColor ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     Window* pWindow = GetWindow();
     if ( pWindow )
@@ -2171,7 +2167,7 @@ void VCLXProgressBar::setForegroundColor( sal_Int32 nColor ) throw(::com::sun::s
 
 void VCLXProgressBar::setBackgroundColor( sal_Int32 nColor ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     Window* pWindow = GetWindow();
     if ( pWindow )
@@ -2185,7 +2181,7 @@ void VCLXProgressBar::setBackgroundColor( sal_Int32 nColor ) throw(::com::sun::s
 
 void VCLXProgressBar::setValue( sal_Int32 nValue ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     m_nValue = nValue;
     ImplUpdateValue();
@@ -2193,7 +2189,7 @@ void VCLXProgressBar::setValue( sal_Int32 nValue ) throw(::com::sun::star::uno::
 
 void VCLXProgressBar::setRange( sal_Int32 nMin, sal_Int32 nMax ) throw(::com::sun::star::uno::RuntimeException )
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     if ( nMin < nMax )
     {
@@ -2213,7 +2209,7 @@ void VCLXProgressBar::setRange( sal_Int32 nMin, sal_Int32 nMax ) throw(::com::su
 
 sal_Int32 VCLXProgressBar::getValue() throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     return m_nValue;
 }
@@ -2221,7 +2217,7 @@ sal_Int32 VCLXProgressBar::getValue() throw(::com::sun::star::uno::RuntimeExcept
 // ::com::sun::star::awt::VclWindowPeer
 void VCLXProgressBar::setProperty( const ::rtl::OUString& PropertyName, const ::com::sun::star::uno::Any& Value) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ProgressBar* pProgressBar = (ProgressBar*)GetWindow();
     if ( pProgressBar )
@@ -2279,7 +2275,7 @@ void VCLXProgressBar::setProperty( const ::rtl::OUString& PropertyName, const ::
 
 ::com::sun::star::uno::Any VCLXProgressBar::getProperty( const ::rtl::OUString& PropertyName ) throw(::com::sun::star::uno::RuntimeException)
 {
-    ::osl::SolarGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::com::sun::star::uno::Any aProp;
     ProgressBar* pProgressBar = (ProgressBar*)GetWindow();
