@@ -40,18 +40,12 @@
 
 #include <svx/graphctl.hxx>
 #include "GraphCtlAccessibleContext.hxx"
-#include "xoutbmp.hxx"
+#include "svx/xoutbmp.hxx"
 #include <svx/svxids.hrc>
 #include <svx/svdpage.hxx>
 
 // #i72889#
-#include "sdrpaintwindow.hxx"
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
+#include "svx/sdrpaintwindow.hxx"
 
 void GraphCtrlUserCall::Changed( const SdrObject& rObj, SdrUserCallType eType, const Rectangle& /*rOldBoundRect*/ )
 {
@@ -71,20 +65,13 @@ void GraphCtrlUserCall::Changed( const SdrObject& rObj, SdrUserCallType eType, c
     }
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 GraphCtrl::GraphCtrl( Window* pParent, const WinBits nWinBits ) :
             Control			( pParent, nWinBits ),
             aMap100			( MAP_100TH_MM ),
             eObjKind        ( OBJ_NONE ),
             nPolyEdit		( 0 ),
-            bEditMode		( FALSE ),
-            bSdrMode		( FALSE ),
+            bEditMode		( sal_False ),
+            bSdrMode		( sal_False ),
             mpAccContext    ( NULL ),
             pModel          ( NULL ),
             pView           ( NULL )
@@ -96,25 +83,18 @@ GraphCtrl::GraphCtrl( Window* pParent, const WinBits nWinBits ) :
 
     SetWinStyle( nWinBits );
 
-    EnableRTL( FALSE );
+    EnableRTL( sal_False );
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 GraphCtrl::GraphCtrl( Window* pParent, const ResId& rResId ) :
             Control			( pParent, rResId ),
             aMap100			( MAP_100TH_MM ),
             nWinStyle       ( 0 ),
             eObjKind        ( OBJ_NONE ),
             nPolyEdit		( 0 ),
-            bEditMode       ( FALSE ),
-            bSdrMode        ( FALSE ),
-            bAnim           ( FALSE ),
+            bEditMode       ( sal_False ),
+            bSdrMode        ( sal_False ),
+            bAnim           ( sal_False ),
             mpAccContext    ( NULL ),
             pModel          ( NULL ),
             pView           ( NULL )
@@ -123,16 +103,9 @@ GraphCtrl::GraphCtrl( Window* pParent, const ResId& rResId ) :
     aUpdateTimer.SetTimeout( 500 );
     aUpdateTimer.SetTimeoutHdl( LINK( this, GraphCtrl, UpdateHdl ) );
     aUpdateTimer.Start();
-    EnableRTL( FALSE );
+    EnableRTL( sal_False );
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 GraphCtrl::~GraphCtrl()
 {
     if( mpAccContext )
@@ -145,13 +118,6 @@ GraphCtrl::~GraphCtrl()
     delete pUserCall;
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void GraphCtrl::SetWinStyle( WinBits nWinBits )
 {
     nWinStyle = nWinBits;
@@ -172,24 +138,17 @@ void GraphCtrl::SetWinStyle( WinBits nWinBits )
         InitSdrModel();
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void GraphCtrl::InitSdrModel()
 {
     SolarMutexGuard aGuard;
 
     SdrPage* pPage;
 
-    // alten Kram zerstoeren
+    // destroy old junk
     delete pView;
     delete pModel;
 
-    // Model anlegen
+    // Creating a Model
     pModel = new SdrModel;
     pModel->GetItemPool().FreezeIdRanges();
     pModel->SetScaleUnit( aMap100.GetMapUnit() );
@@ -203,15 +162,14 @@ void GraphCtrl::InitSdrModel()
     pModel->InsertPage( pPage );
     pModel->SetChanged( sal_False );
 
-    // View anlegen
+    // Creating a View
     pView = new GraphCtrlView( pModel, this );
     pView->SetWorkArea( Rectangle( Point(), aGraphSize ) );
-    pView->EnableExtendedMouseEventDispatcher( TRUE );
+    pView->EnableExtendedMouseEventDispatcher( sal_True );
     pView->ShowSdrPage(pView->GetModel()->GetPage(0));
-//	pView->ShowSdrPage(pView->GetModel()->GetPage(0));
-    pView->SetFrameDragSingles( TRUE );
+    pView->SetFrameDragSingles( sal_True );
     pView->SetMarkedPointsSmooth( SDRPATHSMOOTH_SYMMETRIC );
-    pView->SetEditMode( TRUE );
+    pView->SetEditMode( sal_True );
 
     // #i72889# set neeeded flags
     pView->SetPagePaintingAllowed(false);
@@ -223,16 +181,9 @@ void GraphCtrl::InitSdrModel()
         mpAccContext->setModelAndView (pModel, pView);
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
-void GraphCtrl::SetGraphic( const Graphic& rGraphic, BOOL bNewModel )
+void GraphCtrl::SetGraphic( const Graphic& rGraphic, sal_Bool bNewModel )
 {
-    // Bitmaps dithern wir ggf. fuer die Anzeige
+    // If possible we dither bitmaps for the display
     if ( !bAnim && ( rGraphic.GetType() == GRAPHIC_BITMAP )  )
     {
         if ( rGraphic.IsTransparent() )
@@ -267,13 +218,6 @@ void GraphCtrl::SetGraphic( const Graphic& rGraphic, BOOL bNewModel )
     Invalidate();
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void GraphCtrl::Resize()
 {
     Control::Resize();
@@ -289,7 +233,7 @@ void GraphCtrl::Resize()
         double          fGrfWH = (double) aGraphSize.Width() / aGraphSize.Height();
         double          fWinWH = (double) nWidth / nHeight;
 
-        // Bitmap an Thumbgroesse anpassen
+        // Adapt Bitmap to Thumb size
         if ( fGrfWH < fWinWH)
         {
             aNewSize.Width() = (long) ( (double) nHeight * fGrfWH );
@@ -304,7 +248,7 @@ void GraphCtrl::Resize()
         aNewPos.X() = ( nWidth - aNewSize.Width() )  >> 1;
         aNewPos.Y() = ( nHeight - aNewSize.Height() ) >> 1;
 
-        // MapMode fuer Engine umsetzen
+        // Implementing MapMode for Engine
         aDisplayMap.SetScaleX( Fraction( aNewSize.Width(), aGraphSize.Width() ) );
         aDisplayMap.SetScaleY( Fraction( aNewSize.Height(), aGraphSize.Height() ) );
 
@@ -315,13 +259,6 @@ void GraphCtrl::Resize()
     Invalidate();
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void GraphCtrl::Paint( const Rectangle& rRect )
 {
     // #i72889# used splitted repaint to be able to paint an own background
@@ -356,52 +293,24 @@ void GraphCtrl::Paint( const Rectangle& rRect )
     }
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void GraphCtrl::SdrObjChanged( const SdrObject&  )
 {
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void GraphCtrl::SdrObjCreated( const SdrObject& )
 {
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void GraphCtrl::MarkListHasChanged()
 {
     if ( aMarkObjLink.IsSet() )
         aMarkObjLink.Call( this );
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void GraphCtrl::KeyInput( const KeyEvent& rKEvt )
 {
     KeyCode aCode( rKEvt.GetKeyCode() );
-    BOOL	bProc = FALSE;
+    sal_Bool	bProc = sal_False;
 
     switch ( aCode.GetCode() )
     {
@@ -411,7 +320,7 @@ void GraphCtrl::KeyInput( const KeyEvent& rKEvt )
             if ( bSdrMode )
             {
                 pView->DeleteMarked();
-                bProc = TRUE;
+                bProc = sal_True;
                 if( !pView->AreObjectsMarked() )
                     ((Dialog*)GetParent())->GrabFocusToFirstControl();
             }
@@ -444,7 +353,7 @@ void GraphCtrl::KeyInput( const KeyEvent& rKEvt )
                 {
                     ((Dialog*)GetParent())->GrabFocusToFirstControl();
                 }
-                bProc = TRUE;
+                bProc = sal_True;
             }
         }
         break;
@@ -465,7 +374,7 @@ void GraphCtrl::KeyInput( const KeyEvent& rKEvt )
                         pView->UnmarkAllObj();
                         pView->MarkNextObj (bForward);
                     }
-                    bProc = TRUE;
+                    bProc = sal_True;
                 }
                 else if(aCode.IsMod1())
                 {
@@ -486,9 +395,9 @@ void GraphCtrl::KeyInput( const KeyEvent& rKEvt )
 
             if ( aCode.IsMod1() )
             {
-                // #97016# mark last object
+                // mark last object
                 pView->UnmarkAllObj();
-                pView->MarkNextObj(FALSE);
+                pView->MarkNextObj(sal_False);
 
                 bProc = true;
             }
@@ -500,7 +409,7 @@ void GraphCtrl::KeyInput( const KeyEvent& rKEvt )
             if ( aCode.IsMod1() )
             {
                 pView->UnmarkAllObj();
-                pView->MarkNextObj(TRUE);
+                pView->MarkNextObj(sal_True);
 
                 bProc = true;
             }
@@ -517,25 +426,25 @@ void GraphCtrl::KeyInput( const KeyEvent& rKEvt )
 
             if (aCode.GetCode() == KEY_UP)
             {
-                // Scroll nach oben
+                // Scroll up
                 nX = 0;
                 nY =-1;
             }
             else if (aCode.GetCode() == KEY_DOWN)
             {
-                // Scroll nach unten
+                // Scroll down
                 nX = 0;
                 nY = 1;
             }
             else if (aCode.GetCode() == KEY_LEFT)
             {
-                // Scroll nach links
+                // Scroll left
                 nX =-1;
                 nY = 0;
             }
             else if (aCode.GetCode() == KEY_RIGHT)
             {
-                // Scroll nach rechts
+                // Scroll right
                 nX = 1;
                 nY = 0;
             }
@@ -544,7 +453,7 @@ void GraphCtrl::KeyInput( const KeyEvent& rKEvt )
             {
                 if(aCode.IsMod2())
                 {
-                    // #97016# move in 1 pixel distance
+                    // move in 1 pixel distance
                     Size aLogicSizeOnePixel = PixelToLogic(Size(1,1));
                     nX *= aLogicSizeOnePixel.Width();
                     nY *= aLogicSizeOnePixel.Height();
@@ -556,13 +465,13 @@ void GraphCtrl::KeyInput( const KeyEvent& rKEvt )
                     nY *= 100;
                 }
 
-                // #97016# II
+                // II
                 const SdrHdlList& rHdlList = pView->GetHdlList();
                 SdrHdl* pHdl = rHdlList.GetFocusHdl();
 
                 if(0L == pHdl)
                 {
-                    // #90129# restrict movement to WorkArea
+                    // restrict movement to WorkArea
                     const Rectangle& rWorkArea = pView->GetWorkArea();
 
                     if(!rWorkArea.IsEmpty())
@@ -616,13 +525,13 @@ void GraphCtrl::KeyInput( const KeyEvent& rKEvt )
                         if(pView->IsDragObj())
                         {
                             bool bWasNoSnap = rDragStat.IsNoSnap();
-                            BOOL bWasSnapEnabled = pView->IsSnapEnabled();
+                            sal_Bool bWasSnapEnabled = pView->IsSnapEnabled();
 
                             // switch snapping off
                             if(!bWasNoSnap)
-                                ((SdrDragStat&)rDragStat).SetNoSnap(TRUE);
+                                ((SdrDragStat&)rDragStat).SetNoSnap(sal_True);
                             if(bWasSnapEnabled)
-                                pView->SetSnapEnabled(FALSE);
+                                pView->SetSnapEnabled(sal_False);
 
                             pView->MovAction(aEndPoint);
                             pView->EndDragObj();
@@ -695,7 +604,7 @@ void GraphCtrl::KeyInput( const KeyEvent& rKEvt )
                         }
                     }
 
-                    bProc = TRUE;
+                    bProc = sal_True;
                 }
             }
         }
@@ -711,13 +620,6 @@ void GraphCtrl::KeyInput( const KeyEvent& rKEvt )
         ReleaseMouse();
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void GraphCtrl::MouseButtonDown( const MouseEvent& rMEvt )
 {
     if ( bSdrMode && ( rMEvt.GetClicks() < 2 ) )
@@ -728,7 +630,7 @@ void GraphCtrl::MouseButtonDown( const MouseEvent& rMEvt )
             Control::MouseButtonDown( rMEvt );
         else
         {
-            // Focus anziehen fuer Key-Inputs
+            // Get Focus for key inputs
             GrabFocus();
 
             if ( nPolyEdit )
@@ -747,7 +649,7 @@ void GraphCtrl::MouseButtonDown( const MouseEvent& rMEvt )
 
         SdrObject* pCreateObj = pView->GetCreateObj();
 
-        // Wir wollen das Inserten mitbekommen
+        // We want to realize the insert
         if ( pCreateObj && !pCreateObj->GetUserCall() )
             pCreateObj->SetUserCall( pUserCall );
 
@@ -757,13 +659,6 @@ void GraphCtrl::MouseButtonDown( const MouseEvent& rMEvt )
         Control::MouseButtonDown( rMEvt );
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void GraphCtrl::MouseMove(const MouseEvent& rMEvt)
 {
     const Point	aLogPos( PixelToLogic( rMEvt.GetPosPixel() ) );
@@ -795,13 +690,6 @@ void GraphCtrl::MouseMove(const MouseEvent& rMEvt)
     }
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void GraphCtrl::MouseButtonUp(const MouseEvent& rMEvt)
 {
     if ( bSdrMode )
@@ -818,13 +706,6 @@ void GraphCtrl::MouseButtonUp(const MouseEvent& rMEvt)
         Control::MouseButtonUp( rMEvt );
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 SdrObject* GraphCtrl::GetSelectedSdrObject() const
 {
     SdrObject* pSdrObj = NULL;
@@ -840,34 +721,20 @@ SdrObject* GraphCtrl::GetSelectedSdrObject() const
     return pSdrObj;
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
-void GraphCtrl::SetEditMode( const BOOL _bEditMode )
+void GraphCtrl::SetEditMode( const sal_Bool _bEditMode )
 {
     if ( bSdrMode )
     {
         bEditMode = _bEditMode;
         pView->SetEditMode( bEditMode );
         eObjKind = OBJ_NONE;
-        pView->SetCurrentObj( sal::static_int_cast< UINT16 >( eObjKind ) );
+        pView->SetCurrentObj( sal::static_int_cast< sal_uInt16 >( eObjKind ) );
     }
     else
-        bEditMode = FALSE;
+        bEditMode = sal_False;
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
-void GraphCtrl::SetPolyEditMode( const USHORT _nPolyEdit )
+void GraphCtrl::SetPolyEditMode( const sal_uInt16 _nPolyEdit )
 {
     if ( bSdrMode && ( _nPolyEdit != nPolyEdit ) )
     {
@@ -878,33 +745,19 @@ void GraphCtrl::SetPolyEditMode( const USHORT _nPolyEdit )
         nPolyEdit = 0;
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void GraphCtrl::SetObjKind( const SdrObjKind _eObjKind )
 {
     if ( bSdrMode )
     {
-        bEditMode = FALSE;
+        bEditMode = sal_False;
         pView->SetEditMode( bEditMode );
         eObjKind = _eObjKind;
-        pView->SetCurrentObj( sal::static_int_cast< UINT16 >( eObjKind ) );
+        pView->SetCurrentObj( sal::static_int_cast< sal_uInt16 >( eObjKind ) );
     }
     else
         eObjKind = OBJ_NONE;
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 String GraphCtrl::GetStringFromDouble( const double& rDouble )
 {
     sal_Unicode cSep =
@@ -914,13 +767,6 @@ String GraphCtrl::GetStringFromDouble( const double& rDouble )
     return aStr;
 }
 
-
-/*************************************************************************
-www|*
-|*
-|*
-\************************************************************************/
-
 IMPL_LINK( GraphCtrl, UpdateHdl, Timer*, pTimer )
 {
     if ( aUpdateLink.IsSet() )
@@ -944,7 +790,7 @@ IMPL_LINK( GraphCtrl, UpdateHdl, Timer*, pTimer )
         {
             ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible > xAccParent( pParent->GetAccessible() );
 
-            // #103856# Disable accessibility if no model/view data available
+            // Disable accessibility if no model/view data available
             if( pView &&                
                 pModel &&
                 xAccParent.is() )
