@@ -61,7 +61,7 @@ TYPEINIT1(SdrVirtObj,SdrObject);
 SdrVirtObj::SdrVirtObj(SdrObject& rNewObj):
     rRefObj(rNewObj)
 {
-    bVirtObj=TRUE; // Ja, ich bin ein virtuelles Objekt
+    bVirtObj=sal_True; // Ja, ich bin ein virtuelles Objekt
     rRefObj.AddReference(*this);
     bClosedObj=rRefObj.IsClosedObj();
 }
@@ -70,7 +70,7 @@ SdrVirtObj::SdrVirtObj(SdrObject& rNewObj, const Point& rAnchorPos):
     rRefObj(rNewObj)
 {
     aAnchor=rAnchorPos;
-    bVirtObj=TRUE; // Ja, ich bin ein virtuelles Objekt
+    bVirtObj=sal_True; // Ja, ich bin ein virtuelles Objekt
     rRefObj.AddReference(*this);
     bClosedObj=rRefObj.IsClosedObj();
 }
@@ -92,7 +92,7 @@ SdrObject& SdrVirtObj::ReferencedObj()
     return rRefObj;
 }
 
-void __EXPORT SdrVirtObj::Notify(SfxBroadcaster& /*rBC*/, const SfxHint& /*rHint*/)
+void SdrVirtObj::Notify(SfxBroadcaster& /*rBC*/, const SfxHint& /*rHint*/)
 {
     bClosedObj=rRefObj.IsClosedObj();
     SetRectsDirty(); // hier noch Optimieren.
@@ -120,12 +120,12 @@ void SdrVirtObj::TakeObjInfo(SdrObjTransformInfoRec& rInfo) const
     rRefObj.TakeObjInfo(rInfo);
 }
 
-UINT32 SdrVirtObj::GetObjInventor() const
+sal_uInt32 SdrVirtObj::GetObjInventor() const
 {
     return rRefObj.GetObjInventor();
 }
 
-UINT16 SdrVirtObj::GetObjIdentifier() const
+sal_uInt16 SdrVirtObj::GetObjIdentifier() const
 {
     return rRefObj.GetObjIdentifier();
 }
@@ -160,16 +160,16 @@ void SdrVirtObj::SetChanged()
     SdrObject::SetChanged();
 }
 
-SdrObject* SdrVirtObj::Clone() const
+SdrVirtObj* SdrVirtObj::Clone() const
 {
-    SdrObject* pObj=new SdrVirtObj(((SdrVirtObj*)this)->rRefObj); // Nur eine weitere Referenz
-    return pObj;
+    return new SdrVirtObj(this->rRefObj); // Nur eine weitere Referenz
 }
 
-void SdrVirtObj::operator=(const SdrObject& rObj)
+SdrVirtObj& SdrVirtObj::operator=(const SdrVirtObj& rObj)
 {   // ???anderes Objekt referenzieren???
     SdrObject::operator=(rObj);
-    aAnchor=((SdrVirtObj&)rObj).aAnchor;
+    aAnchor=rObj.aAnchor;
+    return *this;
 }
 
 void SdrVirtObj::TakeObjNameSingul(XubString& rName) const
@@ -198,7 +198,7 @@ void SdrVirtObj::TakeObjNamePlural(XubString& rName) const
 void operator +=(PolyPolygon& rPoly, const Point& rOfs)
 {
     if (rOfs.X()!=0 || rOfs.Y()!=0) {
-        USHORT i,j;
+        sal_uInt16 i,j;
         for (j=0; j<rPoly.Count(); j++) {
             Polygon aP1(rPoly.GetObject(j));
             for (i=0; i<aP1.GetSize(); i++) {
