@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -54,10 +54,10 @@
 #include <svx/svdview.hxx>
 #include <svx/svdoutl.hxx>
 
-#include "gallery.hxx"
-#include <dlgutil.hxx>
+#include "svx/gallery.hxx"
+#include <svx/dlgutil.hxx>
 
-#include "fontworkgallery.hxx"
+#include <svx/fontworkgallery.hxx>
 #include "fontworkgallery.hrc"
 
 #include <algorithm>
@@ -84,8 +84,8 @@ const int nLineCount = 4;
 \************************************************************************/
 FontWorkGalleryDialog::FontWorkGalleryDialog( SdrView* pSdrView, Window* pParent, sal_uInt16 /*nSID*/ ) :
         ModalDialog( pParent, SVX_RES( RID_SVX_MDLG_FONTWORK_GALLERY ) ),
-        maCtlFavorites		( this, SVX_RES( CTL_FAVORITES ) ),
         maFLFavorites		( this, SVX_RES( FL_FAVORITES ) ),
+        maCtlFavorites		( this, SVX_RES( CTL_FAVORITES ) ),
         maOKButton			( this, SVX_RES( BTN_OK ) ),
         maCancelButton		( this, SVX_RES( BTN_CANCEL ) ),
         maHelpButton        ( this, SVX_RES( BTN_HELP ) ),
@@ -122,7 +122,7 @@ FontWorkGalleryDialog::~FontWorkGalleryDialog()
 void FontWorkGalleryDialog::initfavorites(sal_uInt16 nThemeId, std::vector< Bitmap * >& rFavorites)
 {
     // Ueber die Gallery werden die Favoriten eingelesen
-    ULONG nFavCount = GalleryExplorer::GetSdrObjCount( nThemeId );
+    sal_uIntPtr nFavCount = GalleryExplorer::GetSdrObjCount( nThemeId );
 
     // Gallery thema locken
     GalleryExplorer::BeginLocking(nThemeId);
@@ -198,10 +198,10 @@ void FontWorkGalleryDialog::changeText( SdrTextObj* pObj )
     {
         SdrOutliner& rOutl = mpModel->GetDrawOutliner(pObj);
 
-        USHORT nOutlMode = rOutl.GetMode();
+        sal_uInt16 nOutlMode = rOutl.GetMode();
         Size aPaperSize = rOutl.GetPaperSize();
-        BOOL bUpdateMode = rOutl.GetUpdateMode();
-        rOutl.SetUpdateMode(FALSE);
+        sal_Bool bUpdateMode = rOutl.GetUpdateMode();
+        rOutl.SetUpdateMode(sal_False);
         rOutl.SetParaAttribs( 0, rOutl.GetEmptyItemSet() );
 
         // #95114# Always set the object's StyleSheet at the Outliner to
@@ -233,7 +233,7 @@ void FontWorkGalleryDialog::SetSdrObjectRef( SdrObject** ppSdrObject, SdrModel*
 
 void FontWorkGalleryDialog::insertSelectedFontwork()
 {
-    USHORT nItemId = maCtlFavorites.GetSelectItemId();
+    sal_uInt16 nItemId = maCtlFavorites.GetSelectItemId();
 
     if( nItemId > 0 )
     {
@@ -308,7 +308,7 @@ IMPL_LINK( FontWorkGalleryDialog, DoubleClickFavoriteHdl, void*, EMPTYARG )
 //------------------------------------------------------------------------
 
 SFX_IMPL_TOOLBOX_CONTROL( FontWorkShapeTypeControl, SfxStringItem );
-FontWorkShapeTypeControl::FontWorkShapeTypeControl(	USHORT nSlotId, USHORT nId, ToolBox &rTbx )
+FontWorkShapeTypeControl::FontWorkShapeTypeControl(	sal_uInt16 nSlotId, sal_uInt16 nId, ToolBox &rTbx )
 : SfxToolBoxControl( nSlotId, nId, rTbx )
 {
     rTbx.SetItemBits( nId, TIB_DROPDOWNONLY | rTbx.GetItemBits( nId ) );
@@ -339,7 +339,7 @@ SfxPopupWindow*	FontWorkShapeTypeControl::CreatePopupWindow()
 
 // -----------------------------------------------------------------------
 
-void FontWorkShapeTypeControl::Select( BOOL )
+void FontWorkShapeTypeControl::Select( sal_Bool )
 {
 
 }
@@ -364,11 +364,6 @@ private:
     Image maImgAlgin3;
     Image maImgAlgin4;
     Image maImgAlgin5;
-    Image maImgAlgin1h;
-    Image maImgAlgin2h;
-    Image maImgAlgin3h;
-    Image maImgAlgin4h;
-    Image maImgAlgin5h;
 
     const rtl::OUString msFontworkAlignment;
 
@@ -380,28 +375,21 @@ private:
 FontWorkAlignmentWindow::FontWorkAlignmentWindow( svt::ToolboxController& rController, const Reference< XFrame >& rFrame, Window* pParentWindow )
 : ToolbarMenu( rFrame, pParentWindow, SVX_RES( RID_SVXFLOAT_FONTWORK_ALIGNMENT ))
 , mrController( rController )
-, maImgAlgin1( SVX_RES( IMG_FONTWORK_ALIGN_LEFT_16 ) )
-, maImgAlgin2( SVX_RES( IMG_FONTWORK_ALIGN_CENTER_16 ) )
-, maImgAlgin3( SVX_RES( IMG_FONTWORK_ALIGN_RIGHT_16 ) )
-, maImgAlgin4( SVX_RES( IMG_FONTWORK_ALIGN_WORD_16 ) )
+, maImgAlgin1( SVX_RES( IMG_FONTWORK_ALIGN_LEFT_16    ) )
+, maImgAlgin2( SVX_RES( IMG_FONTWORK_ALIGN_CENTER_16  ) )
+, maImgAlgin3( SVX_RES( IMG_FONTWORK_ALIGN_RIGHT_16   ) )
+, maImgAlgin4( SVX_RES( IMG_FONTWORK_ALIGN_WORD_16    ) )
 , maImgAlgin5( SVX_RES( IMG_FONTWORK_ALIGN_STRETCH_16 ) )
-, maImgAlgin1h( SVX_RES( IMG_FONTWORK_ALIGN_LEFT_16_H ) )
-, maImgAlgin2h( SVX_RES( IMG_FONTWORK_ALIGN_CENTER_16_H ) )
-, maImgAlgin3h( SVX_RES( IMG_FONTWORK_ALIGN_RIGHT_16_H ) )
-, maImgAlgin4h( SVX_RES( IMG_FONTWORK_ALIGN_WORD_16_H ) )
-, maImgAlgin5h( SVX_RES( IMG_FONTWORK_ALIGN_STRETCH_16_H ) )
 , msFontworkAlignment( RTL_CONSTASCII_USTRINGPARAM( ".uno:FontworkAlignment" ) )
 {
-    bool bHighContrast = GetSettings().GetStyleSettings().GetHighContrastMode();
-
     SetHelpId( HID_POPUP_FONTWORK_ALIGN );
     SetSelectHdl( LINK( this, FontWorkAlignmentWindow, SelectHdl ) );
 
-    appendEntry( 0, String( SVX_RES( STR_ALIGN_LEFT ) ), bHighContrast ? maImgAlgin1h : maImgAlgin1 );
-    appendEntry( 1, String( SVX_RES( STR_ALIGN_CENTER ) ), bHighContrast ? maImgAlgin2h : maImgAlgin2 );
-    appendEntry( 2, String( SVX_RES( STR_ALIGN_RIGHT ) ), bHighContrast ? maImgAlgin3h : maImgAlgin3 );
-    appendEntry( 3, String( SVX_RES( STR_ALIGN_WORD ) ), bHighContrast ? maImgAlgin4h : maImgAlgin4 );
-    appendEntry( 4, String( SVX_RES( STR_ALIGN_STRETCH ) ), bHighContrast ? maImgAlgin5h : maImgAlgin5 );
+    appendEntry( 0, String( SVX_RES( STR_ALIGN_LEFT    ) ), maImgAlgin1 );
+    appendEntry( 1, String( SVX_RES( STR_ALIGN_CENTER  ) ), maImgAlgin2 );
+    appendEntry( 2, String( SVX_RES( STR_ALIGN_RIGHT   ) ), maImgAlgin3 );
+    appendEntry( 3, String( SVX_RES( STR_ALIGN_WORD    ) ), maImgAlgin4 );
+    appendEntry( 4, String( SVX_RES( STR_ALIGN_STRETCH ) ), maImgAlgin5 );
 
     SetOutputSizePixel( getMenuSize() );
 
@@ -449,13 +437,11 @@ void FontWorkAlignmentWindow::DataChanged( const DataChangedEvent& rDCEvt )
 
     if( ( rDCEvt.GetType() == DATACHANGED_SETTINGS ) && ( rDCEvt.GetFlags() & SETTINGS_STYLE ) )
     {
-        bool bHighContrast = GetSettings().GetStyleSettings().GetHighContrastMode();
-
-        appendEntry( 0, String( SVX_RES( STR_ALIGN_LEFT ) ), bHighContrast ? maImgAlgin1h : maImgAlgin1 );
-        appendEntry( 1, String( SVX_RES( STR_ALIGN_CENTER ) ), bHighContrast ? maImgAlgin2h : maImgAlgin2 );
-        appendEntry( 2, String( SVX_RES( STR_ALIGN_RIGHT ) ), bHighContrast ? maImgAlgin3h : maImgAlgin3 );
-        appendEntry( 3, String( SVX_RES( STR_ALIGN_WORD ) ), bHighContrast ? maImgAlgin4h : maImgAlgin4 );
-        appendEntry( 4, String( SVX_RES( STR_ALIGN_STRETCH ) ), bHighContrast ? maImgAlgin5h : maImgAlgin5 );
+        appendEntry( 0, String( SVX_RES( STR_ALIGN_LEFT    ) ), maImgAlgin1 );
+        appendEntry( 1, String( SVX_RES( STR_ALIGN_CENTER  ) ), maImgAlgin2 );
+        appendEntry( 2, String( SVX_RES( STR_ALIGN_RIGHT   ) ), maImgAlgin3 );
+        appendEntry( 3, String( SVX_RES( STR_ALIGN_WORD    ) ), maImgAlgin4 );
+        appendEntry( 4, String( SVX_RES( STR_ALIGN_STRETCH ) ), maImgAlgin5 );
     }
 }
 
@@ -494,7 +480,7 @@ public:
 
     // XServiceInfo
     virtual ::rtl::OUString SAL_CALL getImplementationName() throw( ::com::sun::star::uno::RuntimeException );
-    virtual ::com::sun::star::uno::Sequence< ::rtl::OUString > SAL_CALL getSupportedServiceNames() throw( ::com::sun::star::uno::RuntimeException );       
+    virtual ::com::sun::star::uno::Sequence< ::rtl::OUString > SAL_CALL getSupportedServiceNames() throw( ::com::sun::star::uno::RuntimeException );
 
     using  svt::PopupWindowController::createPopupWindow;
 };
@@ -587,13 +573,13 @@ FontWorkCharacterSpacingWindow::FontWorkCharacterSpacingWindow( svt::ToolboxCont
     SetSelectHdl( LINK( this, FontWorkCharacterSpacingWindow, SelectHdl ) );
 
     appendEntry( 0, String( SVX_RES( STR_CHARS_SPACING_VERY_TIGHT ) ), MIB_RADIOCHECK );
-    appendEntry( 1, String( SVX_RES( STR_CHARS_SPACING_TIGHT ) ), MIB_RADIOCHECK );
-    appendEntry( 2, String( SVX_RES( STR_CHARS_SPACING_NORMAL ) ), MIB_RADIOCHECK );
-    appendEntry( 3, String( SVX_RES( STR_CHARS_SPACING_LOOSE ) ), MIB_RADIOCHECK );
+    appendEntry( 1, String( SVX_RES( STR_CHARS_SPACING_TIGHT      ) ), MIB_RADIOCHECK );
+    appendEntry( 2, String( SVX_RES( STR_CHARS_SPACING_NORMAL     ) ), MIB_RADIOCHECK );
+    appendEntry( 3, String( SVX_RES( STR_CHARS_SPACING_LOOSE      ) ), MIB_RADIOCHECK );
     appendEntry( 4, String( SVX_RES( STR_CHARS_SPACING_VERY_LOOSE ) ), MIB_RADIOCHECK );
-    appendEntry( 5, String( SVX_RES( STR_CHARS_SPACING_CUSTOM ) ), MIB_RADIOCHECK );
+    appendEntry( 5, String( SVX_RES( STR_CHARS_SPACING_CUSTOM     ) ), MIB_RADIOCHECK );
     appendSeparator();
-    appendEntry( 6, String( SVX_RES( STR_CHARS_SPACING_KERN_PAIRS ) ), MIB_CHECKABLE );
+    appendEntry( 6, String( SVX_RES( STR_CHARS_SPACING_KERN_PAIRS ) ), MIB_CHECKABLE  );
 
     SetOutputSizePixel( getMenuSize() );
 
@@ -708,7 +694,7 @@ IMPL_LINK( FontWorkCharacterSpacingWindow, SelectHdl, void *, EMPTYARG )
         implSetKernCharacterPairs( sal_True, true );
     }
     else if( nSelection >= 0 )
-    {       
+    {
         Sequence< PropertyValue > aArgs( 1 );
         aArgs[0].Name = msFontworkCharacterSpacing.copy(5);
         aArgs[0].Value <<=( sal_Int32)nCharacterSpacing;
@@ -734,7 +720,7 @@ public:
 
     // XServiceInfo
     virtual ::rtl::OUString SAL_CALL getImplementationName() throw( ::com::sun::star::uno::RuntimeException );
-    virtual ::com::sun::star::uno::Sequence< ::rtl::OUString > SAL_CALL getSupportedServiceNames() throw( ::com::sun::star::uno::RuntimeException );       
+    virtual ::com::sun::star::uno::Sequence< ::rtl::OUString > SAL_CALL getSupportedServiceNames() throw( ::com::sun::star::uno::RuntimeException );
 
     using svt::PopupWindowController::createPopupWindow;
 };
