@@ -46,16 +46,16 @@
 namespace svx
 {
 
-static const ::rtl::OUString SEARCHITEM_SEARCHSTRING   = ::rtl::OUString::createFromAscii("SearchItem.SearchString");
-static const ::rtl::OUString SEARCHITEM_SEARCHBACKWARD = ::rtl::OUString::createFromAscii("SearchItem.Backward");
+static const ::rtl::OUString SEARCHITEM_SEARCHSTRING( RTL_CONSTASCII_USTRINGPARAM( "SearchItem.SearchString" ) );
+static const ::rtl::OUString SEARCHITEM_SEARCHBACKWARD( RTL_CONSTASCII_USTRINGPARAM( "SearchItem.Backward" ) );
 
-static const ::rtl::OUString COMMAND_EXECUTESEARCH = ::rtl::OUString::createFromAscii(".uno:ExecuteSearch");
-static const ::rtl::OUString COMMAND_FINDTEXT   = ::rtl::OUString::createFromAscii(".uno:FindText")  ;
-static const ::rtl::OUString COMMAND_DOWNSEARCH = ::rtl::OUString::createFromAscii(".uno:DownSearch");
-static const ::rtl::OUString COMMAND_UPSEARCH   = ::rtl::OUString::createFromAscii(".uno:UpSearch")  ;
-static const ::rtl::OUString COMMAND_APPENDSEARCHHISTORY   = ::rtl::OUString::createFromAscii("AppendSearchHistory");
+static const ::rtl::OUString COMMAND_EXECUTESEARCH( RTL_CONSTASCII_USTRINGPARAM( ".uno:ExecuteSearch" ) );
+static const ::rtl::OUString COMMAND_FINDTEXT( RTL_CONSTASCII_USTRINGPARAM( ".uno:FindText" ) );
+static const ::rtl::OUString COMMAND_DOWNSEARCH( RTL_CONSTASCII_USTRINGPARAM(".uno:DownSearch") );
+static const ::rtl::OUString COMMAND_UPSEARCH( RTL_CONSTASCII_USTRINGPARAM(".uno:UpSearch") );
+static const ::rtl::OUString COMMAND_APPENDSEARCHHISTORY( RTL_CONSTASCII_USTRINGPARAM( "AppendSearchHistory") );
 
-static const ::rtl::OUString SERVICENAME_URLTRANSFORMER = ::rtl::OUString::createFromAscii("com.sun.star.util.URLTransformer");
+static const ::rtl::OUString SERVICENAME_URLTRANSFORMER( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.util.URLTransformer") );
 static const sal_Int32       REMEMBER_SIZE = 10;
 
 void impl_executeSearch( const css::uno::Reference< css::lang::XMultiServiceFactory >& rSMgr, const css::uno::Reference< css::frame::XFrame >& xFrame, const css::uno::Sequence< css::beans::PropertyValue >& lArgs )
@@ -97,14 +97,14 @@ void FindTextFieldControl::InitControls_Impl()
     SetText( SVX_RESSTR( RID_SVXSTR_FINDBAR_FIND ) );
     SetControlForeground(GetSettings().GetStyleSettings().GetDisableColor());
 
-    EnableAutocomplete(TRUE, TRUE);
+    EnableAutocomplete(sal_True, sal_True);
 }
 
 void FindTextFieldControl::Remember_Impl(const String& rStr)
 {
-    USHORT nCount = GetEntryCount();
+    sal_uInt16 nCount = GetEntryCount();
 
-    for (USHORT i=0; i<nCount; ++i)
+    for (sal_uInt16 i=0; i<nCount; ++i)
     {
         if ( rStr == GetEntry(i))
             return;
@@ -132,15 +132,28 @@ long FindTextFieldControl::PreNotify( NotifyEvent& rNEvt )
         case EVENT_KEYINPUT:
         {
             const KeyEvent* pKeyEvent = rNEvt.GetKeyEvent();
-            sal_Bool bCtrl = pKeyEvent->GetKeyCode().IsMod1();
-            sal_Bool bAlt = pKeyEvent->GetKeyCode().IsMod2();
             sal_Bool bShift = pKeyEvent->GetKeyCode().IsShift();
             sal_uInt16 nCode = pKeyEvent->GetKeyCode().GetCode();
 
-            if ( (bCtrl && bAlt && KEY_F == nCode) || KEY_ESCAPE == nCode )
+            if ( KEY_ESCAPE == nCode )
             {
                 nRet = 1;
                 GrabFocusToDocument();
+
+                // hide the findbar
+                css::uno::Reference< css::beans::XPropertySet > xPropSet(m_xFrame, css::uno::UNO_QUERY);
+                if (xPropSet.is())
+                {
+                    css::uno::Reference< css::frame::XLayoutManager > xLayoutManager;
+                    css::uno::Any aValue = xPropSet->getPropertyValue( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "LayoutManager" ) ) );
+                    aValue >>= xLayoutManager;
+                    if (xLayoutManager.is())
+                    {
+                        const ::rtl::OUString sResourceURL( RTL_CONSTASCII_USTRINGPARAM( "private:resource/toolbar/findbar" ) );
+                        xLayoutManager->hideElement( sResourceURL );
+                        xLayoutManager->destroyElement( sResourceURL );
+                    }
+                }
             }
 
             if ( KEY_RETURN == nCode )
@@ -358,8 +371,8 @@ void SAL_CALL FindTextToolbarController::initialize( const css::uno::Sequence< :
     ToolBox* pToolBox = (ToolBox*)pWindow;
     if ( pToolBox )
     {
-        USHORT nItemCount = pToolBox->GetItemCount();
-        for ( USHORT i=0; i<nItemCount; ++i )
+        sal_uInt16 nItemCount = pToolBox->GetItemCount();
+        for ( sal_uInt16 i=0; i<nItemCount; ++i )
         {
             ::rtl::OUString sItemCommand = pToolBox->GetItemCommand(i);
             if ( sItemCommand.equals( COMMAND_DOWNSEARCH ) )
@@ -388,7 +401,7 @@ css::uno::Reference< css::awt::XWindow > SAL_CALL FindTextToolbarController::cre
         ToolBox* pToolbar =  ( ToolBox* )pParent;
         m_pFindTextFieldControl = new FindTextFieldControl( pToolbar, WinBits( WB_DROPDOWN | WB_VSCROLL), m_xFrame, m_xServiceManager );
 
-        Size aSize(100, m_pFindTextFieldControl->GetTextHeight() + 200);
+        Size aSize(250, m_pFindTextFieldControl->GetTextHeight() + 200);
         m_pFindTextFieldControl->SetSizePixel( aSize );
         m_pFindTextFieldControl->SetModifyHdl(LINK(this, FindTextToolbarController, EditModifyHdl));
     }
@@ -405,7 +418,7 @@ void SAL_CALL FindTextToolbarController::statusChanged( const css::frame::Featur
         return;
 
     ::rtl::OUString aFeatureURL = rEvent.FeatureURL.Complete;
-    if (aFeatureURL.equalsAscii("AppendSearchHistory"))
+    if (aFeatureURL.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("AppendSearchHistory")))
     {
         m_pFindTextFieldControl->Remember_Impl(m_pFindTextFieldControl->GetText());
     }
@@ -529,8 +542,8 @@ void SAL_CALL DownSearchToolboxController::execute( sal_Int16 /*KeyModifier*/ )
     ToolBox* pToolBox = (ToolBox*)pWindow;
     if ( pToolBox )
     {
-        USHORT nItemCount = pToolBox->GetItemCount();
-        for ( USHORT i=0; i<nItemCount; ++i )
+        sal_uInt16 nItemCount = pToolBox->GetItemCount();
+        for ( sal_uInt16 i=0; i<nItemCount; ++i )
         {
             ::rtl::OUString sItemCommand = pToolBox->GetItemCommand(i);
             if ( sItemCommand.equals( COMMAND_FINDTEXT ) )
@@ -658,8 +671,8 @@ void SAL_CALL UpSearchToolboxController::execute( sal_Int16 /*KeyModifier*/ ) th
     ToolBox* pToolBox = (ToolBox*)pWindow;
     if ( pToolBox )
     {
-        USHORT nItemCount = pToolBox->GetItemCount();
-        for ( USHORT i=0; i<nItemCount; ++i )
+        sal_uInt16 nItemCount = pToolBox->GetItemCount();
+        for ( sal_uInt16 i=0; i<nItemCount; ++i )
         {
             ::rtl::OUString sItemCommand = pToolBox->GetItemCommand(i);
             if ( sItemCommand.equals( COMMAND_FINDTEXT ) )
@@ -743,8 +756,8 @@ void SAL_CALL FindbarDispatcher::release() throw()
 sal_Bool SAL_CALL FindbarDispatcher::supportsService( const ::rtl::OUString& ServiceName ) throw( css::uno::RuntimeException )
 {	
     return (
-        ServiceName.equalsAscii("com.sun.star.comp.svx.FindbarDispatcher") ||
-        ServiceName.equalsAscii("com.sun.star.frame.ProtocolHandler")
+        ServiceName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.comp.svx.FindbarDispatcher")) ||
+        ServiceName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.frame.ProtocolHandler"))
         );
 }
 
@@ -773,7 +786,7 @@ css::uno::Reference< css::frame::XDispatch > SAL_CALL FindbarDispatcher::queryDi
 {
     css::uno::Reference< css::frame::XDispatch > xDispatch;
 
-    if ( aURL.Protocol.equalsAscii("vnd.sun.star.findbar:") )
+    if ( aURL.Protocol.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("vnd.sun.star.findbar:")) )
         xDispatch = this;
 
     return xDispatch;
@@ -794,33 +807,40 @@ css::uno::Sequence < css::uno::Reference< css::frame::XDispatch > > SAL_CALL Fin
 void SAL_CALL FindbarDispatcher::dispatch( const css::util::URL& aURL, const css::uno::Sequence < css::beans::PropertyValue >& /*lArgs*/ ) throw( css::uno::RuntimeException )
 {
     //vnd.sun.star.findbar:FocusToFindbar  - set cursor to the FindTextFieldControl of the findbar
-    if ( aURL.Path.equalsAscii("FocusToFindbar") )
+    if ( aURL.Path.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("FocusToFindbar")) )
     {
         css::uno::Reference< css::beans::XPropertySet > xPropSet(m_xFrame, css::uno::UNO_QUERY);
         if(!xPropSet.is())
             return;
 
         css::uno::Reference< css::frame::XLayoutManager > xLayoutManager;
-        css::uno::Any aValue = xPropSet->getPropertyValue( ::rtl::OUString::createFromAscii("LayoutManager") );
+        css::uno::Any aValue = xPropSet->getPropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "LayoutManager" )) );
         aValue >>= xLayoutManager;
         if (!xLayoutManager.is())
             return;
 
-        const ::rtl::OUString sResourceURL = ::rtl::OUString::createFromAscii("private:resource/toolbar/findbar");
+        const ::rtl::OUString sResourceURL( RTL_CONSTASCII_USTRINGPARAM( "private:resource/toolbar/findbar" ) );
         css::uno::Reference< css::ui::XUIElement > xUIElement = xLayoutManager->getElement(sResourceURL);
         if (!xUIElement.is())
-            return;
+        {
+            // show the findbar if necessary
+            xLayoutManager->createElement( sResourceURL );
+            xLayoutManager->showElement( sResourceURL );
+            xUIElement = xLayoutManager->getElement( sResourceURL );
+            if ( !xUIElement.is() )
+                return;
+        }
 
         css::uno::Reference< css::awt::XWindow > xWindow(xUIElement->getRealInterface(), css::uno::UNO_QUERY);
         Window* pWindow = VCLUnoHelper::GetWindow( xWindow );
         ToolBox* pToolBox = (ToolBox*)pWindow;
         if ( pToolBox )
         {
-            USHORT nItemCount = pToolBox->GetItemCount();
-            for ( USHORT i=0; i<nItemCount; ++i )
+            sal_uInt16 nItemCount = pToolBox->GetItemCount();
+            for ( sal_uInt16 i=0; i<nItemCount; ++i )
             {
                 ::rtl::OUString sItemCommand = pToolBox->GetItemCommand(i);
-                if ( sItemCommand.equalsAscii(".uno:FindText") )
+                if ( sItemCommand.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(".uno:FindText")) )
                 {
                     Window* pItemWin = pToolBox->GetItemWindow( i );
                     if ( pItemWin )
