@@ -43,6 +43,7 @@
 #include <docary.hxx>
 #include <swundo.hxx>
 #include <undobj.hxx>
+#include <numrule.hxx>
 #include <doc.hxx>
 #include <frmfmt.hxx>
 #include <fmtanchr.hxx>
@@ -112,21 +113,22 @@ SW_DLLPUBLIC const char * dbg_out(const String & aStr)
 
 SW_DLLPUBLIC const char * dbg_out(const ::rtl::OUString & aStr)
 {
-    return OUStringToOString(aStr, RTL_TEXTENCODING_ASCII_US).getStr();
+    aDbgOutResult = ByteString( rtl::OUStringToOString( aStr, RTL_TEXTENCODING_ASCII_US ) );
+    return aDbgOutResult.GetBuffer();
 }
 
 
 struct CompareUShort
 {
-    bool operator()(USHORT a, USHORT b) const
+    bool operator()(sal_uInt16 a, sal_uInt16 b) const
     {
         return a < b;
     }
 };
 
-map<USHORT,String,CompareUShort> & GetItemWhichMap()
+map<sal_uInt16,String,CompareUShort> & GetItemWhichMap()
 {
-    static map<USHORT,String,CompareUShort> aItemWhichMap;
+    static map<sal_uInt16,String,CompareUShort> aItemWhichMap;
     static bool bInitialized = false;
 
     if (! bInitialized)
@@ -342,7 +344,7 @@ const String lcl_dbg_out(const SwpHints & rHints)
 {
     String aStr("[ SwpHints\n", RTL_TEXTENCODING_ASCII_US);
 
-    for (USHORT i = 0; i < rHints.Count(); i++)
+    for (sal_uInt16 i = 0; i < rHints.Count(); i++)
     {
         aStr += String("  ", RTL_TEXTENCODING_ASCII_US);
         aStr += lcl_dbg_out(*rHints[i]);
@@ -473,7 +475,7 @@ const String lcl_AnchoredFrames(const SwNode & rNode)
         if (pFrmFmts)
         {
             bool bFirst = true;
-            for (USHORT nI = 0; nI < pFrmFmts->Count(); nI++)
+            for (sal_uInt16 nI = 0; nI < pFrmFmts->Count(); nI++)
             {
                 const SwFmtAnchor & rAnchor = (*pFrmFmts)[nI]->GetAnchor();
                 const SwPosition * pPos = rAnchor.GetCntntAnchor();
@@ -602,7 +604,7 @@ String lcl_dbg_out(const SwNode & rNode)
             const SfxPoolItem * pItem = NULL;
 
             if (pAttrSet && SFX_ITEM_SET ==
-                pAttrSet->GetItemState(RES_PARATR_NUMRULE, FALSE, &pItem))
+                pAttrSet->GetItemState(RES_PARATR_NUMRULE, sal_False, &pItem))
             {
                 aTmpStr += String("(", RTL_TEXTENCODING_ASCII_US);
                 aTmpStr +=
@@ -615,7 +617,7 @@ String lcl_dbg_out(const SwNode & rNode)
             aTmpStr += String("</rule>", RTL_TEXTENCODING_ASCII_US);
 
             if (pTxtNode->GetActualListLevel() > 0)
-                pNumFmt = pNumRule->GetNumFmt( static_cast< USHORT >(pTxtNode->GetActualListLevel()) );
+                pNumFmt = pNumRule->GetNumFmt( static_cast< sal_uInt16 >(pTxtNode->GetActualListLevel()) );
 
             if (pNumFmt)
             {
@@ -638,7 +640,6 @@ String lcl_dbg_out(const SwNode & rNode)
 
             aTmpStr += String("(", RTL_TEXTENCODING_ASCII_US);
             aTmpStr += String::CreateFromInt32
-                //(static_cast<SwTxtFmtColl *>(pColl)->GetOutlineLevel());//#outline level,zhaojianwei
                 (static_cast<SwTxtFmtColl *>(pColl)->GetAssignedOutlineStyleLevel());//<-end,zhaojianwei
 
             const SwNumRuleItem & rItem =
@@ -722,7 +723,7 @@ SW_DLLPUBLIC const char * dbg_out(const SwTxtNode * pNode)
         return NULL;
 }
 
-BOOL lcl_dbg_add_node(const SwNodePtr & pNode, void * pArgs)
+sal_Bool lcl_dbg_add_node(const SwNodePtr & pNode, void * pArgs)
 {
     if (pNode)
     {
@@ -731,10 +732,10 @@ BOOL lcl_dbg_add_node(const SwNodePtr & pNode, void * pArgs)
     }
 
     //MBA: this code didn't compile, needed to add a return value
-    return TRUE;
+    return sal_True;
 }
 
-void lcl_dbg_nodes_inner(String & aStr, SwNodes & rNodes, ULONG & nIndex)
+void lcl_dbg_nodes_inner(String & aStr, SwNodes & rNodes, sal_uLong & nIndex)
 {
     SwNode * pNode = rNodes[nIndex];
     SwStartNode * pStartNode = dynamic_cast<SwStartNode *> (pNode);
@@ -743,8 +744,8 @@ void lcl_dbg_nodes_inner(String & aStr, SwNodes & rNodes, ULONG & nIndex)
     if (pStartNode != NULL)
         pEndNode = pStartNode->EndOfSectionNode();
 
-    ULONG nCount = rNodes.Count();
-    ULONG nStartIndex = nIndex;
+    sal_uLong nCount = rNodes.Count();
+    sal_uLong nStartIndex = nIndex;
 
     bool bDone = false;
     
@@ -787,8 +788,8 @@ String lcl_dbg_out(SwNodes & rNodes)
 {
     String aStr("<nodes-array>", RTL_TEXTENCODING_ASCII_US);
     
-    ULONG nIndex = 0;
-    ULONG nCount = rNodes.Count();
+    sal_uLong nIndex = 0;
+    sal_uLong nCount = rNodes.Count();
     
     while (nIndex < nCount)
     {
@@ -809,43 +810,10 @@ String lcl_dbg_out(const SwUndo & rUndo)
 {
     String aStr("[ ", RTL_TEXTENCODING_ASCII_US);
 
-    aStr += String::CreateFromInt32(rUndo.GetId());
+    aStr += String::CreateFromInt32(
+                static_cast<SfxUndoAction const&>(rUndo).GetId());
     aStr += String(": ", RTL_TEXTENCODING_ASCII_US);
 
-    switch(rUndo.GetId())
-    {
-    case UNDO_START:
-        aStr += String(", ", RTL_TEXTENCODING_ASCII_US);
-        aStr +=
-            String::CreateFromInt32(dynamic_cast
-                                    <const SwUndoStart &>(rUndo).
-                                    GetUserId());
-        aStr += String(", ", RTL_TEXTENCODING_ASCII_US);
-        aStr += String::CreateFromInt32(dynamic_cast
-                                        <const SwUndoStart &>(rUndo).
-                                        GetEndOffset());
-        aStr += String(" ", RTL_TEXTENCODING_ASCII_US);
-
-        break;
-
-    case UNDO_END:
-        aStr += String(", ", RTL_TEXTENCODING_ASCII_US);
-        aStr +=
-            String::CreateFromInt32(dynamic_cast
-                                    <const SwUndoEnd &>(rUndo).
-                                    GetId());
-        aStr += String(", ", RTL_TEXTENCODING_ASCII_US);
-        aStr += String::CreateFromInt32(dynamic_cast
-                                        <const SwUndoEnd &>(rUndo).
-                                        GetSttOffset());
-        aStr += String(" ", RTL_TEXTENCODING_ASCII_US);
-
-        break;
-
-    default:
-        break;
-    }
-
     aStr += rUndo.GetComment();
     aStr += String(" ]", RTL_TEXTENCODING_ASCII_US);
 
@@ -861,7 +829,7 @@ String lcl_dbg_out(SwOutlineNodes & rNodes)
 {
     String aStr("[\n", RTL_TEXTENCODING_ASCII_US);
 
-    for (USHORT i = 0; i < rNodes.Count(); i++)
+    for (sal_uInt16 i = 0; i < rNodes.Count(); i++)
     {
         aStr += lcl_dbg_out(*rNodes[i]);
         aStr += String("\n", RTL_TEXTENCODING_ASCII_US);
@@ -877,39 +845,6 @@ SW_DLLPUBLIC const char * dbg_out(SwOutlineNodes & rNodes)
     return dbg_out(lcl_dbg_out(rNodes));
 }
 
-String lcl_dbg_out(const SwUndos & rUndos)
-{
-    USHORT nIndent = 0;
-
-    String aStr("[\n", RTL_TEXTENCODING_ASCII_US);
-
-    for (USHORT n = 0; n < rUndos.Count(); n++)
-    {
-        SwUndo * pUndo = rUndos[n];
-
-        if (pUndo->GetId() == UNDO_END)
-            nIndent--;
-
-        for (USHORT nI = 0; n < nIndent; nI++)
-            aStr += String("  ", RTL_TEXTENCODING_ASCII_US);
-
-        aStr += lcl_dbg_out(*pUndo);
-        aStr += String("\n", RTL_TEXTENCODING_ASCII_US);
-
-        if (pUndo->GetId() == UNDO_START)
-            nIndent++;
-    }
-
-    aStr += String("]\n", RTL_TEXTENCODING_ASCII_US);
-
-    return aStr;
-}
-
-SW_DLLPUBLIC const char * dbg_out(const SwUndos & rUndos)
-{
-    return dbg_out(lcl_dbg_out(rUndos));
-}
-
 String lcl_dbg_out(const SwRewriter & rRewriter)
 {
     (void) rRewriter;
@@ -941,7 +876,7 @@ String lcl_dbg_out(const SwNumRule & rRule)
     aResult += rRule.GetName();
     aResult += String(" [", RTL_TEXTENCODING_ASCII_US);
 
-    for (BYTE n = 0; n < MAXLEVEL; n++)
+    for (sal_uInt8 n = 0; n < MAXLEVEL; n++)
     {
         if (n > 0)
             aResult += String(", ", RTL_TEXTENCODING_ASCII_US);
@@ -991,7 +926,7 @@ String lcl_dbg_out(const SwNumRuleTbl & rTbl)
 {
     String aResult("[", RTL_TEXTENCODING_ASCII_US);
 
-    for (USHORT n = 0; n < rTbl.Count(); n++)
+    for (sal_uInt16 n = 0; n < rTbl.Count(); n++)
     {
         if (n > 0)
             aResult += String(", ", RTL_TEXTENCODING_ASCII_US);
@@ -1043,7 +978,7 @@ String lcl_TokenType2Str(FormTokenType nType)
         return String("??", RTL_TEXTENCODING_ASCII_US);
     }
 
-    OSL_ENSURE(false, "should not be reached");
+    OSL_FAIL("should not be reached");
 
     return  String("??", RTL_TEXTENCODING_ASCII_US);
 }
@@ -1064,7 +999,7 @@ String lcl_dbg_out(const SwFormTokens & rTokens)
 
     SwFormTokens::const_iterator aIt;
 
-    for (aIt = rTokens.begin(); aIt != rTokens.end(); aIt++)
+    for (aIt = rTokens.begin(); aIt != rTokens.end(); ++aIt)
     {
         if (aIt != rTokens.begin())
             aStr += String(", ", RTL_TEXTENCODING_ASCII_US);
