@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -28,8 +28,8 @@
 
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
+
 #include <hintids.hxx>
-#include <tools/list.hxx>
 #include <tools/urlobj.hxx>
 #include <vcl/cmdevt.hxx>
 #include <unotools/charclass.hxx>
@@ -42,6 +42,7 @@
 #include <frmfmt.hxx>
 #include <charfmt.hxx>
 #include <doc.hxx>
+#include <IDocumentUndoRedo.hxx>
 #include <docary.hxx>
 #include <editsh.hxx>
 #include <frame.hxx>
@@ -67,7 +68,7 @@
 #include <numrule.hxx>
 #include <SwNodeNum.hxx>
 #include <unocrsr.hxx>
-
+#include <switerator.hxx>
 
 using namespace com::sun::star;
 
@@ -79,7 +80,7 @@ SV_IMPL_PTRARR(SwGetINetAttrs, SwGetINetAttr*)
  ******************************************************************************/
 
 
-void SwEditShell::Insert( sal_Unicode c, BOOL bOnlyCurrCrsr )
+void SwEditShell::Insert( sal_Unicode c, sal_Bool bOnlyCurrCrsr )
 {
     StartAllAction();
     FOREACHPAM_START(this)
@@ -129,7 +130,7 @@ void SwEditShell::Insert2(const String &rStr, const bool bForceExpandHints )
 
     // calculate cursor bidi level
     SwCursor* pTmpCrsr = _GetCrsr();
-    const BOOL bDoNotSetBidiLevel = ! pTmpCrsr ||
+    const sal_Bool bDoNotSetBidiLevel = ! pTmpCrsr ||
                                 ( 0 != dynamic_cast<SwUnoCrsr*>(pTmpCrsr) );
 
     if ( ! bDoNotSetBidiLevel )
@@ -146,13 +147,13 @@ void SwEditShell::Insert2(const String &rStr, const bool bForceExpandHints )
             SwScriptInfo* pSI = SwScriptInfo::GetScriptInfo( ((SwTxtNode&)rNode),
                                                               sal_True );
 
-            BYTE nLevel = 0;
+            sal_uInt8 nLevel = 0;
             if ( ! pSI )
             {
                 // seems to be an empty paragraph.
                 Point aPt;
                 SwCntntFrm* pFrm =
-                        ((SwTxtNode&)rNode).GetFrm( &aPt, pTmpCrsr->GetPoint(),
+                        ((SwTxtNode&)rNode).getLayoutFrm( GetLayout(), &aPt, pTmpCrsr->GetPoint(),
                                                     sal_False );
 
                 SwScriptInfo aScriptInfo;
@@ -170,7 +171,7 @@ void SwEditShell::Insert2(const String &rStr, const bool bForceExpandHints )
         }
     }
 
-    SetInFrontOfLabel( FALSE ); // #i27615#
+    SetInFrontOfLabel( sal_False ); // #i27615#
 
     EndAllAction();
 }
@@ -187,7 +188,7 @@ void SwEditShell::Overwrite(const String &rStr)
     FOREACHPAM_START(this)
         if( !GetDoc()->Overwrite(*PCURCRSR, rStr ) )
         {
-            OSL_ENSURE( FALSE, "Doc->Overwrite(Str) failed." );
+            OSL_FAIL( "Doc->Overwrite(Str) failed." );
         }
         SaveTblBoxCntnt( PCURCRSR->GetPoint() );
     FOREACHPAM_END()
@@ -199,10 +200,10 @@ void SwEditShell::Overwrite(const String &rStr)
  *						long SwEditShell::SplitNode()
  ******************************************************************************/
 
-long SwEditShell::SplitNode( BOOL bAutoFormat, BOOL bCheckTableStart )
+long SwEditShell::SplitNode( sal_Bool bAutoFormat, sal_Bool bCheckTableStart )
 {
     StartAllAction();
-    GetDoc()->StartUndo(UNDO_EMPTY, NULL);
+    GetDoc()->GetIDocumentUndoRedo().StartUndo(UNDO_EMPTY, NULL);
 
     FOREACHPAM_START(this)
         // eine Tabellen Zelle wird jetzt zu einer normalen Textzelle!
@@ -210,7 +211,7 @@ long SwEditShell::SplitNode( BOOL bAutoFormat, BOOL bCheckTableStart )
         GetDoc()->SplitNode( *PCURCRSR->GetPoint(), bCheckTableStart );
     FOREACHPAM_END()
 
-    GetDoc()->EndUndo(UNDO_EMPTY, NULL);
+    GetDoc()->GetIDocumentUndoRedo().EndUndo(UNDO_EMPTY, NULL);
 
     if( bAutoFormat )
         AutoFmtBySplitNode();
@@ -221,21 +222,18 @@ long SwEditShell::SplitNode( BOOL bAutoFormat, BOOL bCheckTableStart )
     return(1L);
 }
 
-/*-- 11.05.2004 09:41:20---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 sal_Bool SwEditShell::AppendTxtNode()
 {
     sal_Bool bRet = sal_False;
     StartAllAction();
-    GetDoc()->StartUndo(UNDO_EMPTY, NULL);
+    GetDoc()->GetIDocumentUndoRedo().StartUndo(UNDO_EMPTY, NULL);
 
     FOREACHPAM_START(this)
         GetDoc()->ClearBoxNumAttrs( PCURCRSR->GetPoint()->nNode );
         bRet = GetDoc()->AppendTxtNode( *PCURCRSR->GetPoint()) || bRet;
     FOREACHPAM_END()
 
-    GetDoc()->EndUndo(UNDO_EMPTY, NULL);
+    GetDoc()->GetIDocumentUndoRedo().EndUndo(UNDO_EMPTY, NULL);
 
     ClearTblBoxCntnt();
 
@@ -265,17 +263,15 @@ SwGrfNode * SwEditShell::_GetGrfNode() const
  * 					 oder auf die gleiche Graphic zeigt)
  ******************************************************************************/
 
-// --> OD 2005-02-09 #119353# - robust
-const Graphic* SwEditShell::GetGraphic( BOOL bWait ) const
+const Graphic* SwEditShell::GetGraphic( sal_Bool bWait ) const
 {
     SwGrfNode* pGrfNode = _GetGrfNode();
-    // --> OD 2005-02-09 #119353# - robust
     const Graphic* pGrf( 0L );
     if ( pGrfNode )
     {
         pGrf = &(pGrfNode->GetGrf());
-        // --> OD 2007-03-01 #i73788#
-        // no load of linked graphic, if its not needed now (bWait = FALSE).
+        // --> #i73788#
+        // no load of linked graphic, if its not needed now (bWait = sal_False).
         if ( bWait )
         {
             if( pGrf->IsSwapOut() ||
@@ -305,7 +301,7 @@ const Graphic* SwEditShell::GetGraphic( BOOL bWait ) const
     // <--
 }
 
-BOOL SwEditShell::IsGrfSwapOut( BOOL bOnlyLinked ) const
+sal_Bool SwEditShell::IsGrfSwapOut( sal_Bool bOnlyLinked ) const
 {
     SwGrfNode *pGrfNode = _GetGrfNode();
     return pGrfNode &&
@@ -315,19 +311,16 @@ BOOL SwEditShell::IsGrfSwapOut( BOOL bOnlyLinked ) const
                      : pGrfNode->GetGrfObj().IsSwappedOut());
 }
 
-// --> OD 2005-02-09 #119353# - robust
 const GraphicObject* SwEditShell::GetGraphicObj() const
 {
     SwGrfNode* pGrfNode = _GetGrfNode();
-    // --> OD 2005-02-09 #119353# - robust
     return pGrfNode ? &(pGrfNode->GetGrfObj()) : 0L;
-    // <--
 }
 
-USHORT SwEditShell::GetGraphicType() const
+sal_uInt16 SwEditShell::GetGraphicType() const
 {
     SwGrfNode *pGrfNode = _GetGrfNode();
-    return static_cast<USHORT>(pGrfNode ? pGrfNode->GetGrfObj().GetType() : GRAPHIC_NONE);
+    return static_cast<sal_uInt16>(pGrfNode ? pGrfNode->GetGrfObj().GetType() : GRAPHIC_NONE);
 }
 
 /******************************************************************************
@@ -336,7 +329,7 @@ USHORT SwEditShell::GetGraphicType() const
  * 					oder auf die gleiche Graphic zeigt)
  ******************************************************************************/
 
-BOOL SwEditShell::GetGrfSize(Size& rSz) const
+sal_Bool SwEditShell::GetGrfSize(Size& rSz) const
 {
     SwNoTxtNode* pNoTxtNd;
     SwPaM* pCurrentCrsr = GetCrsr();
@@ -345,9 +338,9 @@ BOOL SwEditShell::GetGrfSize(Size& rSz) const
          && 0 != ( pNoTxtNd = pCurrentCrsr->GetNode()->GetNoTxtNode() ) )
     {
         rSz = pNoTxtNd->GetTwipSize();
-        return TRUE;
+        return sal_True;
     }
-    return FALSE;
+    return sal_False;
 
 }
 /******************************************************************************
@@ -386,30 +379,6 @@ void SwEditShell::GetGrfNms( String* pGrfName, String* pFltName,
 }
 
 
-// alternativen Text abfragen/setzen
-//const String& SwEditShell::GetAlternateText() const
-//{
-//    SwPaM* pCrsr = GetCrsr();
-//    const SwNoTxtNode* pNd;
-//    if( !pCrsr->HasMark() && 0 != ( pNd = pCrsr->GetNode()->GetNoTxtNode()) )
-//        return pNd->GetAlternateText();
-
-//    return aEmptyStr;
-//}
-
-
-//void SwEditShell::SetAlternateText( const String& rTxt )
-//{
-//    SwPaM* pCrsr = GetCrsr();
-//    SwNoTxtNode* pNd;
-//    if( !pCrsr->HasMark() && 0 != ( pNd = pCrsr->GetNode()->GetNoTxtNode()) )
-//    {
-//        pNd->SetAlternateText( rTxt, sal_True );
-//        GetDoc()->SetModified();
-//    }
-//}
-
-
 const PolyPolygon *SwEditShell::GetGraphicPolygon() const
 {
     SwNoTxtNode *pNd = GetCrsr()->GetNode()->GetNoTxtNode();
@@ -422,10 +391,9 @@ void SwEditShell::SetGraphicPolygon( const PolyPolygon *pPoly )
     SwNoTxtNode *pNd = GetCrsr()->GetNode()->GetNoTxtNode();
     StartAllAction();
     pNd->SetContour( pPoly );
-    SwFlyFrm *pFly = (SwFlyFrm*)pNd->GetFrm()->GetUpper();
+    SwFlyFrm *pFly = (SwFlyFrm*)pNd->getLayoutFrm(GetLayout())->GetUpper();
     const SwFmtSurround &rSur = pFly->GetFmt()->GetSurround();
-    pFly->GetFmt()->SwModify::Modify( (SwFmtSurround*)&rSur,
-                                      (SwFmtSurround*)&rSur );
+    pFly->GetFmt()->NotifyClients( (SwFmtSurround*)&rSur, (SwFmtSurround*)&rSur );
     GetDoc()->SetModified();
     EndAllAction();
 }
@@ -437,11 +405,10 @@ void SwEditShell::ClearAutomaticContour()
     if( pNd->HasAutomaticContour() )
     {
         StartAllAction();
-        pNd->SetContour( NULL, FALSE );
-        SwFlyFrm *pFly = (SwFlyFrm*)pNd->GetFrm()->GetUpper();
+        pNd->SetContour( NULL, sal_False );
+        SwFlyFrm *pFly = (SwFlyFrm*)pNd->getLayoutFrm(GetLayout())->GetUpper();
         const SwFmtSurround &rSur = pFly->GetFmt()->GetSurround();
-        pFly->GetFmt()->SwModify::Modify( (SwFmtSurround*)&rSur,
-                                          (SwFmtSurround*)&rSur );
+        pFly->GetFmt()->NotifyClients( (SwFmtSurround*)&rSur, (SwFmtSurround*)&rSur );
         GetDoc()->SetModified();
         EndAllAction();
     }
@@ -470,7 +437,7 @@ svt::EmbeddedObjectRef& SwEditShell::GetOLEObject() const
 }
 
 
-BOOL SwEditShell::HasOLEObj( const String &rName ) const
+sal_Bool SwEditShell::HasOLEObj( const String &rName ) const
 {
     SwStartNode *pStNd;
     SwNodeIndex aIdx( *GetNodes().GetEndOfAutotext().StartOfSectionNode(), 1 );
@@ -480,12 +447,12 @@ BOOL SwEditShell::HasOLEObj( const String &rName ) const
         SwNode& rNd = aIdx.GetNode();
         if( rNd.IsOLENode() &&
             rName == ((SwOLENode&)rNd).GetChartTblName() &&
-            ((SwOLENode&)rNd).GetFrm() )
-            return TRUE;
+            ((SwOLENode&)rNd).getLayoutFrm( GetLayout() ) )
+            return sal_True;
 
         aIdx.Assign( *pStNd->EndOfSectionNode(), + 1 );
     }
-    return FALSE;
+    return sal_False;
 }
 
 
@@ -545,7 +512,7 @@ const SwFmtRefMark* SwEditShell::GetRefMark( const String& rName ) const
 }
 
     // returne die Namen aller im Doc gesetzten Referenzen
-USHORT SwEditShell::GetRefMarks( SvStringsDtor* pStrings ) const
+sal_uInt16 SwEditShell::GetRefMarks( SvStringsDtor* pStrings ) const
 {
     return GetDoc()->GetRefMarks( pStrings );
 }
@@ -555,7 +522,7 @@ USHORT SwEditShell::GetRefMarks( SvStringsDtor* pStrings ) const
  ******************************************************************************/
 
 
-String SwEditShell::GetDropTxt( const USHORT nChars ) const
+String SwEditShell::GetDropTxt( const sal_uInt16 nChars ) const
 {
     /**
      * pb: made changes for #i74939#
@@ -569,7 +536,7 @@ String SwEditShell::GetDropTxt( const USHORT nChars ) const
     {
         // if a multi selection exists, search for the first line
         // -> it is the cursor with the lowest index
-        ULONG nIndex = pCrsr->GetMark()->nNode.GetIndex();
+        sal_uLong nIndex = pCrsr->GetMark()->nNode.GetIndex();
         bool bPrev = true;
         SwPaM* pLast = pCrsr;
         SwPaM* pTemp = pCrsr;
@@ -580,7 +547,7 @@ String SwEditShell::GetDropTxt( const USHORT nChars ) const
             if ( bPrev )
             {
                 pTemp = pPrev2;
-                ULONG nTemp = pPrev2->GetMark()->nNode.GetIndex();
+                sal_uLong nTemp = pPrev2->GetMark()->nNode.GetIndex();
                 if ( nTemp < nIndex )
                 {
                     nIndex = nTemp;
@@ -613,19 +580,13 @@ void SwEditShell::ReplaceDropTxt( const String &rStr )
         SwPaM aPam( rNd, rStr.Len(), rNd, 0 );
         if( !GetDoc()->Overwrite( aPam, rStr ) )
         {
-            OSL_ENSURE( FALSE, "Doc->Overwrite(Str) failed." );
+            OSL_FAIL( "Doc->Overwrite(Str) failed." );
         }
 
         EndAllAction();
     }
 }
 
-/******************************************************************************
- *	Methode		:
- *	Beschreibung:
- *	Erstellt	:	OK 25.04.94 13:45
- *	Aenderung	:
- ******************************************************************************/
 
 String SwEditShell::Calculate()
 {
@@ -647,7 +608,7 @@ String SwEditShell::Calculate()
             rCC.toLower( aStr );
 
             sal_Unicode ch;
-            BOOL 	bValidFlds = FALSE;
+            sal_Bool 	bValidFlds = sal_False;
             xub_StrLen nPos = 0;
 
             while( nPos < aStr.Len() )
@@ -675,7 +636,7 @@ String SwEditShell::Calculate()
                             GetDoc()->FldsToCalc( aCalc,
                                                   pStart->nNode.GetIndex(),
                                                   pStart->nContent.GetIndex() );
-                            bValidFlds = TRUE;
+                            bValidFlds = sal_True;
                         }
                         (( aFormel += '(' ) +=
                                 aCalc.GetStrResult( aCalc.VarLook( sVar )
@@ -725,9 +686,9 @@ Graphic SwEditShell::GetIMapGraphic() const
                                     GRAPHIC_DEFAULT == rGrf.GetType() ) )
             {
 #if OSL_DEBUG_LEVEL > 1
-                OSL_ENSURE( ((SwGrfNode*)pNd)->SwapIn( TRUE ) || !TRUE, "Grafik konnte nicht geladen werden" );
+                OSL_ENSURE( ((SwGrfNode*)pNd)->SwapIn( sal_True ), "Grafik konnte nicht geladen werden" );
 #else
-                ((SwGrfNode*)pNd)->SwapIn( TRUE );
+                ((SwGrfNode*)pNd)->SwapIn( sal_True );
 #endif
             }
             aRet = rGrf;
@@ -738,7 +699,7 @@ Graphic SwEditShell::GetIMapGraphic() const
         }
         else
         {
-            SwFlyFrm* pFlyFrm = pNd->GetCntntNode()->GetFrm()->FindFlyFrm();
+            SwFlyFrm* pFlyFrm = pNd->GetCntntNode()->getLayoutFrm( GetLayout() )->FindFlyFrm();
             if(pFlyFrm)
                 aRet = pFlyFrm->GetFmt()->MakeGraphic();
         }
@@ -747,14 +708,14 @@ Graphic SwEditShell::GetIMapGraphic() const
 }
 
 
-BOOL SwEditShell::InsertURL( const SwFmtINetFmt& rFmt, const String& rStr, BOOL bKeepSelection )
+sal_Bool SwEditShell::InsertURL( const SwFmtINetFmt& rFmt, const String& rStr, sal_Bool bKeepSelection )
 {
     // URL und Hinweistext (direkt oder via Selektion) notwendig
     if( !rFmt.GetValue().Len() ||	( !rStr.Len() && !HasSelection() ) )
-        return FALSE;
+        return sal_False;
     StartAllAction();
-    GetDoc()->StartUndo( UNDO_UI_INSERT_URLTXT, NULL);
-    BOOL bInsTxt = TRUE;
+    GetDoc()->GetIDocumentUndoRedo().StartUndo( UNDO_UI_INSERT_URLTXT, NULL);
+    sal_Bool bInsTxt = sal_True;
 
     if( rStr.Len() )
     {
@@ -762,33 +723,33 @@ BOOL SwEditShell::InsertURL( const SwFmtINetFmt& rFmt, const String& rStr, BOOL
         if( pCrsr->HasMark() && *pCrsr->GetPoint() != *pCrsr->GetMark() )
         {
             // Selection vorhanden, MehrfachSelektion?
-            BOOL bDelTxt = TRUE;
+            sal_Bool bDelTxt = sal_True;
             if( pCrsr->GetNext() == pCrsr )
             {
                 // einfach Selection -> Text ueberpruefen
                 String sTxt( GetSelTxt() );
                 sTxt.EraseTrailingChars();
                 if( sTxt == rStr )
-                    bDelTxt = bInsTxt = FALSE;
+                    bDelTxt = bInsTxt = sal_False;
             }
             else if( rFmt.GetValue() == rStr )		// Name und URL gleich?
-                bDelTxt = bInsTxt = FALSE;
+                bDelTxt = bInsTxt = sal_False;
 
             if( bDelTxt )
                 Delete();
         }
         else if( pCrsr->GetNext() != pCrsr && rFmt.GetValue() == rStr )
-            bInsTxt = FALSE;
+            bInsTxt = sal_False;
 
         if( bInsTxt )
         {
             Insert2( rStr );
             SetMark();
-            ExtendSelection( FALSE, rStr.Len() );
+            ExtendSelection( sal_False, rStr.Len() );
         }
     }
     else
-        bInsTxt = FALSE;
+        bInsTxt = sal_False;
 
     SetAttr( rFmt );
     if (bInsTxt && !IsCrsrPtAtEnd())
@@ -797,29 +758,28 @@ BOOL SwEditShell::InsertURL( const SwFmtINetFmt& rFmt, const String& rStr, BOOL
         ClearMark();
     if( bInsTxt )
         DontExpandFmt();
-    GetDoc()->EndUndo( UNDO_UI_INSERT_URLTXT, NULL );
+    GetDoc()->GetIDocumentUndoRedo().EndUndo( UNDO_UI_INSERT_URLTXT, NULL );
     EndAllAction();
-    return TRUE;
+    return sal_True;
 }
 
 
-USHORT SwEditShell::GetINetAttrs( SwGetINetAttrs& rArr )
+sal_uInt16 SwEditShell::GetINetAttrs( SwGetINetAttrs& rArr )
 {
     if( rArr.Count() )
         rArr.DeleteAndDestroy( 0, rArr.Count() );
 
     const SwTxtNode* pTxtNd;
     const SwCharFmts* pFmts = GetDoc()->GetCharFmts();
-    for( USHORT n = pFmts->Count(); 1 < n; )
+    for( sal_uInt16 n = pFmts->Count(); 1 < n; )
     {
-        SwClientIter aIter( *(*pFmts)[  --n ] );
-
-        for( SwClient* pFnd = aIter.First(TYPE( SwTxtINetFmt ));
-                pFnd; pFnd = aIter.Next() )
-            if( 0 != ( pTxtNd = ((SwTxtINetFmt*)pFnd)->GetpTxtNode()) &&
+        SwIterator<SwTxtINetFmt,SwCharFmt> aIter(*(*pFmts)[--n]);
+        for( SwTxtINetFmt* pFnd = aIter.First(); pFnd; pFnd = aIter.Next() )
+        {
+            if( 0 != ( pTxtNd = pFnd->GetpTxtNode()) &&
                 pTxtNd->GetNodes().IsDocNodes() )
             {
-                SwTxtINetFmt& rAttr = *(SwTxtINetFmt*)pFnd;
+                SwTxtINetFmt& rAttr = *pFnd;
                 String sTxt( pTxtNd->GetExpandTxt( *rAttr.GetStart(),
                                     *rAttr.GetEnd() - *rAttr.GetStart() ) );
 
@@ -833,15 +793,16 @@ USHORT SwEditShell::GetINetAttrs( SwGetINetAttrs& rArr )
                 }
             }
     }
+    }
     return rArr.Count();
 }
 
 
     // ist der Cursor in eine INetAttribut, dann wird das komplett
     // geloescht; inclusive des Hinweistextes (wird beim Drag&Drop gebraucht)
-BOOL SwEditShell::DelINetAttrWithText()
+sal_Bool SwEditShell::DelINetAttrWithText()
 {
-    BOOL bRet = SelectTxtAttr( RES_TXTATR_INETFMT, FALSE );
+    sal_Bool bRet = SelectTxtAttr( RES_TXTATR_INETFMT, sal_False );
     if( bRet )
         DeleteSel( *GetCrsr() );
     return bRet;
@@ -849,12 +810,12 @@ BOOL SwEditShell::DelINetAttrWithText()
 
 
 // setzen an den Textzeichenattributen das DontExpand-Flag
-BOOL SwEditShell::DontExpandFmt()
+sal_Bool SwEditShell::DontExpandFmt()
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
     if( !IsTableMode() && GetDoc()->DontExpandFmt( *GetCrsr()->GetPoint() ))
     {
-        bRet = TRUE;
+        bRet = sal_True;
         CallChgLnk();
     }
     return bRet;
@@ -865,17 +826,17 @@ SvNumberFormatter* SwEditShell::GetNumberFormatter()
     return GetDoc()->GetNumberFormatter();
 }
 
-BOOL SwEditShell::RemoveInvisibleContent()
+sal_Bool SwEditShell::RemoveInvisibleContent()
 {
     StartAllAction();
-    BOOL bRet = GetDoc()->RemoveInvisibleContent();
+    sal_Bool bRet = GetDoc()->RemoveInvisibleContent();
     EndAllAction();
     return bRet;
 }
-BOOL SwEditShell::ConvertFieldsToText()
+sal_Bool SwEditShell::ConvertFieldsToText()
 {
     StartAllAction();
-    BOOL bRet = GetDoc()->ConvertFieldsToText();
+    sal_Bool bRet = GetDoc()->ConvertFieldsToText();
     EndAllAction();
     return bRet;
 }
@@ -892,8 +853,8 @@ void SwEditShell::SetNumberingRestart()
         else
             MakeFindRange(DOCPOS_OTHERSTART, DOCPOS_OTHEREND, pCrsr); //extra content
         SwPosition* pSttPos = pCrsr->Start(), *pEndPos = pCrsr->End();
-        ULONG nCurrNd = pSttPos->nNode.GetIndex();
-        ULONG nEndNd = pEndPos->nNode.GetIndex();
+        sal_uLong nCurrNd = pSttPos->nNode.GetIndex();
+        sal_uLong nEndNd = pEndPos->nNode.GetIndex();
         if( nCurrNd <= nEndNd )
         {
             SwCntntFrm* pCntFrm;
@@ -905,7 +866,7 @@ void SwEditShell::SetNumberingRestart()
                 switch( pNd->GetNodeType() )
                 {
                 case ND_TEXTNODE:
-                    if( 0 != ( pCntFrm = ((SwTxtNode*)pNd)->GetFrm()) )
+                    if( 0 != ( pCntFrm = ((SwTxtNode*)pNd)->getLayoutFrm( GetLayout() )) )
                     {
                         //jump over hidden frames - ignore protection!
                         if( !((SwTxtFrm*)pCntFrm)->IsHiddenNow() )
@@ -923,7 +884,7 @@ void SwEditShell::SetNumberingRestart()
                                  pTxtNd->IsCountedInList() &&
                                  !pTxtNd->IsListRestart() &&
                                  pTxtNd->GetNum()->GetNumber() ==
-                                    pNumRule->Get( static_cast<USHORT>(pTxtNd->GetActualListLevel()) ).GetStart() )
+                                    pNumRule->Get( static_cast<sal_uInt16>(pTxtNd->GetActualListLevel()) ).GetStart() )
                             {
                                 //now set a the start value as attribute
                                 SwPosition aCurrentNode(*pNd);
@@ -950,20 +911,20 @@ void SwEditShell::SetNumberingRestart()
     }
 
 
-    Pop(FALSE);
+    Pop(sal_False);
     EndAllAction();
 }
 
-USHORT SwEditShell::GetLineCount( BOOL bActPos )
+sal_uInt16 SwEditShell::GetLineCount( sal_Bool bActPos )
 {
-    USHORT nRet = 0;
+    sal_uInt16 nRet = 0;
     CalcLayout();
     SwPaM* pPam = GetCrsr();
     SwNodeIndex& rPtIdx = pPam->GetPoint()->nNode;
     SwNodeIndex aStart( rPtIdx );
     SwCntntNode* pCNd;
     SwCntntFrm *pCntFrm = 0;
-    ULONG nTmpPos;
+    sal_uLong nTmpPos;
 
     if( !bActPos )
         aStart = 0;
@@ -973,7 +934,7 @@ USHORT SwEditShell::GetLineCount( BOOL bActPos )
     else
     {
         if( 0 != ( pCNd = pPam->GetCntntNode() ) &&
-            0 != ( pCntFrm = pCNd->GetFrm() ) )
+            0 != ( pCntFrm = pCNd->getLayoutFrm( GetLayout() ) ) )
         {
             const SwStartNode *pTmp;
             if( pCntFrm->IsInFly() )						// Fly
@@ -982,7 +943,7 @@ USHORT SwEditShell::GetLineCount( BOOL bActPos )
                 pTmp = pCNd->FindFootnoteStartNode();
             else
             {												// Footer/Header
-                const USHORT nTyp = FRM_HEADER | FRM_FOOTER;
+                const sal_uInt16 nTyp = FRM_HEADER | FRM_FOOTER;
                 SwFrm* pFrm = pCntFrm;
                 while( pFrm && !(pFrm->GetType() & nTyp) )
                     pFrm = pFrm->GetUpper();
@@ -999,9 +960,9 @@ USHORT SwEditShell::GetLineCount( BOOL bActPos )
     }
 
     while( 0 != ( pCNd = GetDoc()->GetNodes().GoNextSection(
-                &aStart, TRUE, FALSE )) && ( !bActPos || aStart <= rPtIdx ) )
+                &aStart, sal_True, sal_False )) && ( !bActPos || aStart <= rPtIdx ) )
     {
-        if( 0 != ( pCntFrm = pCNd->GetFrm() ) && pCntFrm->IsTxtFrm() )
+        if( 0 != ( pCntFrm = pCNd->getLayoutFrm( GetLayout() ) ) && pCntFrm->IsTxtFrm() )
         {
             xub_StrLen nActPos = bActPos && aStart == rPtIdx ?
                 pPam->GetPoint()->nContent.GetIndex() : USHRT_MAX;
@@ -1069,12 +1030,12 @@ void SwEditShell::SetLineNumberInfo(const SwLineNumberInfo& rInfo)
     EndAllAction();
 }
 
-USHORT SwEditShell::GetLinkUpdMode(BOOL bDocSettings) const
+sal_uInt16 SwEditShell::GetLinkUpdMode(sal_Bool bDocSettings) const
 {
     return getIDocumentSettingAccess()->getLinkUpdateMode( !bDocSettings );
 }
 
-void SwEditShell::SetLinkUpdMode( USHORT nMode )
+void SwEditShell::SetLinkUpdMode( sal_uInt16 nMode )
 {
     getIDocumentSettingAccess()->setLinkUpdateMode( nMode );
 }
@@ -1090,7 +1051,7 @@ SwExtTextInput* SwEditShell::CreateExtTextInput(LanguageType eInputLanguage)
     return pRet;
 }
 
-String SwEditShell::DeleteExtTextInput( SwExtTextInput* pDel, BOOL bInsText )
+String SwEditShell::DeleteExtTextInput( SwExtTextInput* pDel, sal_Bool bInsText )
 {
     if( !pDel )
     {
@@ -1170,14 +1131,14 @@ void SwEditShell::TransliterateText( sal_uInt32 nType )
     SwPaM* pCrsr = GetCrsr();
     if( pCrsr->GetNext() != pCrsr )
     {
-        GetDoc()->StartUndo(UNDO_EMPTY, NULL);
+        GetDoc()->GetIDocumentUndoRedo().StartUndo(UNDO_EMPTY, NULL);
         FOREACHPAM_START( this )
 
         if( PCURCRSR->HasMark() )
             GetDoc()->TransliterateText( *PCURCRSR, aTrans );
 
         FOREACHPAM_END()
-        GetDoc()->EndUndo(UNDO_EMPTY, NULL);
+        GetDoc()->GetIDocumentUndoRedo().EndUndo(UNDO_EMPTY, NULL);
     }
     else
         GetDoc()->TransliterateText( *pCrsr, aTrans );
@@ -1195,4 +1156,12 @@ void SwEditShell::CountWords( SwDocStat& rStat ) const
     FOREACHPAM_END()
 }
 
+void SwEditShell::ApplyViewOptions( const SwViewOption &rOpt )
+{
+    SwCrsrShell::StartAction();
+    ViewShell::ApplyViewOptions( rOpt );
+    SwEditShell::EndAction();
+}
+
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
