@@ -58,9 +58,7 @@
 #include <flyfrm.hxx>
 #include <pagedesc.hxx>
 #include <IMark.hxx>
-// --> OD 2007-10-18 #i81002#
 #include <crossrefbookmark.hxx>
-// <--
 #include <ftnidx.hxx>
 #include <viewsh.hxx>
 #include <unofldmid.h>
@@ -71,13 +69,14 @@
 #include <comcore.hrc>
 #include <numrule.hxx>
 #include <SwNodeNum.hxx>
+#include <switerator.hxx>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::text;
 using namespace ::com::sun::star::lang;
 using ::rtl::OUString;
 
-extern void InsertSort( SvUShorts& rArr, USHORT nIdx, USHORT* pInsPos = 0 );
+extern void InsertSort( SvUShorts& rArr, sal_uInt16 nIdx, sal_uInt16* pInsPos = 0 );
 
 void lcl_GetLayTree( const SwFrm* pFrm, SvPtrarr& rArr )
 {
@@ -103,11 +102,11 @@ void lcl_GetLayTree( const SwFrm* pFrm, SvPtrarr& rArr )
 }
 
 
-BOOL IsFrameBehind( const SwTxtNode& rMyNd, USHORT nMySttPos,
-                    const SwTxtNode& rBehindNd, USHORT nSttPos )
+sal_Bool IsFrameBehind( const SwTxtNode& rMyNd, sal_uInt16 nMySttPos,
+                    const SwTxtNode& rBehindNd, sal_uInt16 nSttPos )
 {
-    const SwTxtFrm *pMyFrm = (SwTxtFrm*)rMyNd.GetFrm(0,0,FALSE),
-                   *pFrm = (SwTxtFrm*)rBehindNd.GetFrm(0,0,FALSE);
+    const SwTxtFrm *pMyFrm = (SwTxtFrm*)rMyNd.getLayoutFrm( rMyNd.GetDoc()->GetCurrentLayout(), 0,0,sal_False),
+                   *pFrm = (SwTxtFrm*)rBehindNd.getLayoutFrm( rBehindNd.GetDoc()->GetCurrentLayout(), 0,0,sal_False);
 
     while( pFrm && !pFrm->IsInside( nSttPos ) )
         pFrm = (SwTxtFrm*)pFrm->GetFollow();
@@ -115,15 +114,15 @@ BOOL IsFrameBehind( const SwTxtNode& rMyNd, USHORT nMySttPos,
         pMyFrm = (SwTxtFrm*)pMyFrm->GetFollow();
 
     if( !pFrm || !pMyFrm || pFrm == pMyFrm )
-        return FALSE;
+        return sal_False;
 
     SvPtrarr aRefArr( 10, 10 ), aArr( 10, 10 );
     ::lcl_GetLayTree( pFrm, aRefArr );
     ::lcl_GetLayTree( pMyFrm, aArr );
 
-    USHORT nRefCnt = aRefArr.Count() - 1, nCnt = aArr.Count() - 1;
-    BOOL bVert = FALSE;
-    BOOL bR2L = FALSE;
+    sal_uInt16 nRefCnt = aRefArr.Count() - 1, nCnt = aArr.Count() - 1;
+    sal_Bool bVert = sal_False;
+    sal_Bool bR2L = sal_False;
 
     // solange bis ein Frame ungleich ist ?
     while( nRefCnt && nCnt && aRefArr[ nRefCnt ] == aArr[ nCnt ] )
@@ -147,7 +146,7 @@ BOOL IsFrameBehind( const SwTxtNode& rMyNd, USHORT nMySttPos,
     const SwFrm* pFldFrm = (const SwFrm*)aArr[ nCnt ];
 
     // unterschiedliche Frames, dann ueberpruefe deren Y-/X-Position
-    BOOL bRefIsLower = FALSE;
+    sal_Bool bRefIsLower = sal_False;
     if( ( FRM_COLUMN | FRM_CELL ) & pFldFrm->GetType() ||
         ( FRM_COLUMN | FRM_CELL ) & pRefFrm->GetType() )
     {
@@ -212,8 +211,8 @@ BOOL IsFrameBehind( const SwTxtNode& rMyNd, USHORT nMySttPos,
 
 
 SwGetRefField::SwGetRefField( SwGetRefFieldType* pFldType,
-                              const String& rSetRef, USHORT nSubTyp,
-                              USHORT nSeqenceNo, ULONG nFmt )
+                              const String& rSetRef, sal_uInt16 nSubTyp,
+                              sal_uInt16 nSeqenceNo, sal_uLong nFmt )
     : SwField( pFldType, nFmt ),
       sSetRefName( rSetRef ),
       nSubType( nSubTyp ),
@@ -230,12 +229,12 @@ String SwGetRefField::GetDescription() const
     return SW_RES(STR_REFERENCE);
 }
 
-USHORT SwGetRefField::GetSubType() const
+sal_uInt16 SwGetRefField::GetSubType() const
 {
     return nSubType;
 }
 
-void SwGetRefField::SetSubType( USHORT n )
+void SwGetRefField::SetSubType( sal_uInt16 n )
 {
     nSubType = n;
 }
@@ -256,7 +255,7 @@ bool SwGetRefField::IsRefToNumItemCrossRefBookmark() const
 const SwTxtNode* SwGetRefField::GetReferencedTxtNode() const
 {
     SwDoc* pDoc = dynamic_cast<SwGetRefFieldType*>(GetTyp())->GetDoc();
-    USHORT nDummy = USHRT_MAX;
+    sal_uInt16 nDummy = USHRT_MAX;
     return SwGetRefFieldType::FindAnchor( pDoc, sSetRefName, nSubType, nSeqNo, &nDummy );
 }
 // <--
@@ -275,11 +274,8 @@ String SwGetRefField::Expand() const
 }
 
 
-String SwGetRefField::GetCntnt(BOOL bName) const
+String SwGetRefField::GetFieldName() const
 {
-    if( !bName )
-        return Expand();
-
     String aStr(GetTyp()->GetName());
     aStr += ' ';
     aStr += sSetRefName;
@@ -292,8 +288,8 @@ void SwGetRefField::UpdateField( const SwTxtFld* pFldTxtAttr )
     sTxt.Erase();
 
     SwDoc* pDoc = ((SwGetRefFieldType*)GetTyp())->GetDoc();
-    USHORT nStt = USHRT_MAX;
-    USHORT nEnd = USHRT_MAX;
+    sal_uInt16 nStt = USHRT_MAX;
+    sal_uInt16 nEnd = USHRT_MAX;
     SwTxtNode* pTxtNd = SwGetRefFieldType::FindAnchor( pDoc, sSetRefName,
                                         nSubType, nSeqNo, &nStt, &nEnd );
     if ( !pTxtNd )
@@ -360,7 +356,7 @@ void SwGetRefField::UpdateField( const SwTxtFld* pFldTxtAttr )
             case REF_ENDNOTE:
                 {
                     // die Nummer oder den NumString besorgen
-                    USHORT n, nFtnCnt = pDoc->GetFtnIdxs().Count();
+                    sal_uInt16 n, nFtnCnt = pDoc->GetFtnIdxs().Count();
                     SwTxtFtn* pFtnIdx;
                     for( n = 0; n < nFtnCnt; ++n )
                         if( nSeqNo == (pFtnIdx = pDoc->GetFtnIdxs()[ n ])->GetSeqRefNo() )
@@ -396,14 +392,14 @@ void SwGetRefField::UpdateField( const SwTxtFld* pFldTxtAttr )
     case REF_PAGE:
     case REF_PAGE_PGDESC:
         {
-            const SwTxtFrm* pFrm = (SwTxtFrm*)pTxtNd->GetFrm(0,0,FALSE),
+            const SwTxtFrm* pFrm = (SwTxtFrm*)pTxtNd->getLayoutFrm( pDoc->GetCurrentLayout(), 0,0,sal_False),
                         *pSave = pFrm;
             while( pFrm && !pFrm->IsInside( nStt ) )
                 pFrm = (SwTxtFrm*)pFrm->GetFollow();
 
             if( pFrm || 0 != ( pFrm = pSave ))
             {
-                USHORT nPageNo = pFrm->GetVirtPageNum();
+                sal_uInt16 nPageNo = pFrm->GetVirtPageNum();
                 const SwPageFrm *pPage;
                 if( REF_PAGE_PGDESC == GetFormat() &&
                     0 != ( pPage = pFrm->FindPageFrm() ) &&
@@ -418,13 +414,13 @@ void SwGetRefField::UpdateField( const SwTxtFld* pFldTxtAttr )
     case REF_CHAPTER:
         {
             // ein bischen trickreich: suche irgend einen Frame
-            const SwFrm* pFrm = pTxtNd->GetFrm();
+            const SwFrm* pFrm = pTxtNd->getLayoutFrm( pDoc->GetCurrentLayout() );
             if( pFrm )
             {
                 SwChapterFieldType aFldTyp;
                 SwChapterField aFld( &aFldTyp, 0 );
                 aFld.SetLevel( MAXLEVEL - 1 );
-                aFld.ChangeExpansion( pFrm, pTxtNd, TRUE );
+                aFld.ChangeExpansion( pFrm, pTxtNd, sal_True );
                 sTxt = aFld.GetNumber();
             }
         }
@@ -470,7 +466,7 @@ void SwGetRefField::UpdateField( const SwTxtFld* pFldTxtAttr )
         break;
     // <--
     default:
-        DBG_ERROR("<SwGetRefField::UpdateField(..)> - unknown format type");
+        OSL_FAIL("<SwGetRefField::UpdateField(..)> - unknown format type");
     }
 }
 
@@ -581,10 +577,7 @@ String SwGetRefField::GetPar2() const
     return Expand();
 }
 
-/*-----------------06.03.98 13:34-------------------
-
---------------------------------------------------*/
-bool SwGetRefField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
+bool SwGetRefField::QueryValue( uno::Any& rAny, sal_uInt16 nWhichId ) const
 {
     switch( nWhichId )
     {
@@ -618,7 +611,7 @@ bool SwGetRefField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
             case  REF_SETREFATTR : nSource = ReferenceFieldSource::REFERENCE_MARK; break;
             case  REF_SEQUENCEFLD: nSource = ReferenceFieldSource::SEQUENCE_FIELD; break;
             case  REF_BOOKMARK   : nSource = ReferenceFieldSource::BOOKMARK; break;
-            case  REF_OUTLINE    : DBG_ERROR("not implemented"); break;
+            case  REF_OUTLINE    : OSL_FAIL("not implemented"); break;
             case  REF_FOOTNOTE   : nSource = ReferenceFieldSource::FOOTNOTE; break;
             case  REF_ENDNOTE    : nSource = ReferenceFieldSource::ENDNOTE; break;
             }
@@ -651,14 +644,12 @@ bool SwGetRefField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
         rAny <<= (sal_Int16)nSeqNo;
         break;
     default:
-        DBG_ERROR("illegal property");
+        OSL_FAIL("illegal property");
     }
     return true;
 }
-/*-----------------06.03.98 13:34-------------------
 
---------------------------------------------------*/
-bool SwGetRefField::PutValue( const uno::Any& rAny, USHORT nWhichId )
+bool SwGetRefField::PutValue( const uno::Any& rAny, sal_uInt16 nWhichId )
 {
     String sTmp;
     switch( nWhichId )
@@ -728,13 +719,11 @@ bool SwGetRefField::PutValue( const uno::Any& rAny, USHORT nWhichId )
         }
         break;
     default:
-        DBG_ERROR("illegal property");
+        OSL_FAIL("illegal property");
     }
     return true;
 }
-/* -----------------------------11.01.2002 12:50------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwGetRefField::ConvertProgrammaticToUIName()
 {
     if(GetTyp() && REF_SEQUENCEFLD == nSubType)
@@ -745,7 +734,7 @@ void SwGetRefField::ConvertProgrammaticToUIName()
         if(!pDoc->GetFldType(RES_SETEXPFLD, rPar1, false))
         {
             sal_uInt16 nPoolId = SwStyleNameMapper::GetPoolIdFromProgName( rPar1, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
-            USHORT nResId = USHRT_MAX;
+            sal_uInt16 nResId = USHRT_MAX;
             switch( nPoolId )
             {
                 case RES_POOLCOLL_LABEL_ABB:
@@ -766,10 +755,6 @@ void SwGetRefField::ConvertProgrammaticToUIName()
         }
     }
 }
-/*-----------------JP: 18.06.93 -------------------
- Get-Referenz-Type
- --------------------------------------------------*/
-
 
 SwGetRefFieldType::SwGetRefFieldType( SwDoc* pDc )
     : SwFieldType( RES_GETREFFLD ), pDoc( pDc )
@@ -782,14 +767,13 @@ SwFieldType* SwGetRefFieldType::Copy() const
 }
 
 
-void SwGetRefFieldType::Modify( SfxPoolItem* pOld, SfxPoolItem* pNew )
+void SwGetRefFieldType::Modify( const SfxPoolItem* pOld, const SfxPoolItem* pNew )
 {
     // Update auf alle GetReferenz-Felder
     if( !pNew && !pOld )
     {
-        SwClientIter aIter( *this );
-        for( SwFmtFld* pFld = (SwFmtFld*)aIter.First( TYPE(SwFmtFld) );
-                        pFld; pFld = (SwFmtFld*)aIter.Next() )
+        SwIterator<SwFmtFld,SwFieldType> aIter( *this );
+        for( SwFmtFld* pFld = aIter.First(); pFld; pFld = aIter.Next() )
         {
             // nur die GetRef-Felder Updaten
             //JP 3.4.2001: Task 71231 - we need the correct language
@@ -809,12 +793,12 @@ void SwGetRefFieldType::Modify( SfxPoolItem* pOld, SfxPoolItem* pNew )
         }
     }
     // weiter an die Text-Felder, diese "Expandieren" den Text
-    SwModify::Modify( pOld, pNew );
+    NotifyClients( pOld, pNew );
 }
 
 SwTxtNode* SwGetRefFieldType::FindAnchor( SwDoc* pDoc, const String& rRefMark,
-                                        USHORT nSubType, USHORT nSeqNo,
-                                        USHORT* pStt, USHORT* pEnd )
+                                        sal_uInt16 nSubType, sal_uInt16 nSeqNo,
+                                        sal_uInt16* pStt, sal_uInt16* pEnd )
 {
     OSL_ENSURE( pStt, "warum wird keine StartPos abgefragt?" );
 
@@ -840,9 +824,8 @@ SwTxtNode* SwGetRefFieldType::FindAnchor( SwDoc* pDoc, const String& rRefMark,
             if( pFldType && pFldType->GetDepends() &&
                 nsSwGetSetExpType::GSE_SEQ & ((SwSetExpFieldType*)pFldType)->GetType() )
             {
-                SwClientIter aIter( *pFldType );
-                for( SwFmtFld* pFld = (SwFmtFld*)aIter.First( TYPE(SwFmtFld) );
-                                pFld; pFld = (SwFmtFld*)aIter.Next() )
+                SwIterator<SwFmtFld,SwFieldType> aIter( *pFldType );
+                for( SwFmtFld* pFld = aIter.First(); pFld; pFld = aIter.Next() )
                 {
                     if( pFld->GetTxtFld() && nSeqNo ==
                         ((SwSetExpField*)pFld->GetFld())->GetSeqNumber() )
@@ -867,7 +850,7 @@ SwTxtNode* SwGetRefFieldType::FindAnchor( SwDoc* pDoc, const String& rRefMark,
                 const ::sw::mark::IMark* pBkmk = ppMark->get();
                 const SwPosition* pPos = &pBkmk->GetMarkStart();
 
-                pTxtNd = pDoc->GetNodes()[ pPos->nNode ]->GetTxtNode();
+                pTxtNd = pPos->nNode.GetNode().GetTxtNode();
                 *pStt = pPos->nContent.GetIndex();
                 if(pEnd)
                 {
@@ -898,7 +881,7 @@ SwTxtNode* SwGetRefFieldType::FindAnchor( SwDoc* pDoc, const String& rRefMark,
     case REF_FOOTNOTE:
     case REF_ENDNOTE:
         {
-            USHORT n, nFtnCnt = pDoc->GetFtnIdxs().Count();
+            sal_uInt16 n, nFtnCnt = pDoc->GetFtnIdxs().Count();
             SwTxtFtn* pFtnIdx;
             for( n = 0; n < nFtnCnt; ++n )
                 if( nSeqNo == (pFtnIdx = pDoc->GetFtnIdxs()[ n ])->GetSeqRefNo() )
@@ -928,24 +911,24 @@ struct _RefIdsMap
     String aName;
     SvUShortsSort aIds, aDstIds, aIdsMap;
     SvUShorts aMap;
-    BOOL bInit;
+    sal_Bool bInit;
 
     _RefIdsMap( const String& rName )
         : aName( rName ), aIds( 16, 16 ), aIdsMap( 16, 16 ), aMap( 16, 16 ),
-        bInit( FALSE )
+        bInit( sal_False )
     {}
 
     void Check( SwDoc& rDoc, SwDoc& rDestDoc, SwGetRefField& rFld,
-                    BOOL bField = TRUE );
+                    sal_Bool bField = sal_True );
 
-    BOOL IsInit() const { return bInit; }
+    sal_Bool IsInit() const { return bInit; }
 };
 
 SV_DECL_PTRARR_DEL( _RefIdsMaps, _RefIdsMap*, 5, 5 )
 SV_IMPL_PTRARR( _RefIdsMaps, _RefIdsMap* )
 
 void _RefIdsMap::Check( SwDoc& rDoc, SwDoc& rDestDoc, SwGetRefField& rFld,
-                        BOOL bField )
+                        sal_Bool bField )
 {
 
     if( !bInit )
@@ -953,22 +936,20 @@ void _RefIdsMap::Check( SwDoc& rDoc, SwDoc& rDestDoc, SwGetRefField& rFld,
         if( bField )
         {
             const SwTxtNode* pNd;
-            SwModify* pMod;
-            if( 0 != ( pMod = rDestDoc.GetFldType( RES_SETEXPFLD, aName, false ) ))
+            SwFieldType* pType;
+            if( 0 != ( pType = rDestDoc.GetFldType( RES_SETEXPFLD, aName, false ) ))
             {
-                SwClientIter aIter( *pMod );
-                for( SwFmtFld* pF = (SwFmtFld*)aIter.First( TYPE( SwFmtFld )); pF;
-                    pF = (SwFmtFld*)aIter.Next() )
+                SwIterator<SwFmtFld,SwFieldType> aIter( *pType );
+                for( SwFmtFld* pF = aIter.First(); pF; pF = aIter.Next() )
                     if( pF->GetTxtFld() &&
                         0 != ( pNd = pF->GetTxtFld()->GetpTxtNode() ) &&
                         pNd->GetNodes().IsDocNodes() )
                         aIds.Insert( ((SwSetExpField*)pF->GetFld())->GetSeqNumber() );
             }
-            if( 0 != ( pMod = rDoc.GetFldType( RES_SETEXPFLD, aName, false ) ))
+            if( 0 != ( pType = rDoc.GetFldType( RES_SETEXPFLD, aName, false ) ))
             {
-                SwClientIter aIter( *pMod );
-                for( SwFmtFld* pF = (SwFmtFld*)aIter.First( TYPE( SwFmtFld )); pF;
-                        pF = (SwFmtFld*)aIter.Next() )
+                SwIterator<SwFmtFld,SwFieldType> aIter( *pType );
+                for( SwFmtFld* pF = aIter.First(); pF; pF = aIter.Next() )
                     if( pF->GetTxtFld() &&
                         0 != ( pNd = pF->GetTxtFld()->GetpTxtNode() ) &&
                         pNd->GetNodes().IsDocNodes() )
@@ -977,19 +958,19 @@ void _RefIdsMap::Check( SwDoc& rDoc, SwDoc& rDestDoc, SwGetRefField& rFld,
         }
         else
         {
-            USHORT n;
+            sal_uInt16 n;
 
             for( n = rDestDoc.GetFtnIdxs().Count(); n; )
                 aIds.Insert( rDestDoc.GetFtnIdxs()[ --n ]->GetSeqRefNo() );
             for( n = rDoc.GetFtnIdxs().Count(); n; )
                 aDstIds.Insert( rDoc.GetFtnIdxs()[ --n ]->GetSeqRefNo() );
         }
-        bInit = TRUE;
+        bInit = sal_True;
     }
 
     // dann teste mal, ob die Nummer schon vergeben ist
     // oder ob eine neue bestimmt werden muss.
-    USHORT nPos, nSeqNo = rFld.GetSeqNo();
+    sal_uInt16 nPos, nSeqNo = rFld.GetSeqNo();
     if( aIds.Seek_Entry( nSeqNo ) && aDstIds.Seek_Entry( nSeqNo ))
     {
         // ist schon vergeben, also muss eine neue
@@ -998,7 +979,7 @@ void _RefIdsMap::Check( SwDoc& rDoc, SwDoc& rDestDoc, SwGetRefField& rFld,
             rFld.SetSeqNo( aMap[ nPos ] );
         else
         {
-            USHORT n;
+            sal_uInt16 n;
 
             for( n = 0; n < aIds.Count(); ++n )
                 if( n != aIds[ n ] )
@@ -1014,12 +995,11 @@ void _RefIdsMap::Check( SwDoc& rDoc, SwDoc& rDestDoc, SwGetRefField& rFld,
             // Id umsetzen
             if( bField )
             {
-                SwModify* pMod = rDoc.GetFldType( RES_SETEXPFLD, aName, false );
-                if( pMod )
+                SwFieldType* pType = rDoc.GetFldType( RES_SETEXPFLD, aName, false );
+                if( pType )
                 {
-                    SwClientIter aIter( *pMod );
-                    for( SwFmtFld* pF = (SwFmtFld*)aIter.First( TYPE( SwFmtFld )); pF;
-                            pF = (SwFmtFld*)aIter.Next() )
+                    SwIterator<SwFmtFld,SwFieldType> aIter( *pType );
+                    for( SwFmtFld* pF = aIter.First(); pF; pF = aIter.Next() )
                         if( pF->GetTxtFld() && nSeqNo ==
                             ((SwSetExpField*)pF->GetFld())->GetSeqNumber() )
                             ((SwSetExpField*)pF->GetFld())->SetSeqNumber( n );
@@ -1028,7 +1008,7 @@ void _RefIdsMap::Check( SwDoc& rDoc, SwDoc& rDestDoc, SwGetRefField& rFld,
             else
             {
                 SwTxtFtn* pFtnIdx;
-                for( USHORT i = 0, nCnt = rDoc.GetFtnIdxs().Count(); i < nCnt; ++i )
+                for( sal_uInt16 i = 0, nCnt = rDoc.GetFtnIdxs().Count(); i < nCnt; ++i )
                     if( nSeqNo == (pFtnIdx = rDoc.GetFtnIdxs()[ i ])->GetSeqRefNo() )
                     {
                         pFtnIdx->SetSeqNo( n );
@@ -1057,17 +1037,16 @@ void SwGetRefFieldType::MergeWithOtherDoc( SwDoc& rDestDoc )
         _RefIdsMap aFntMap( aEmptyStr );
         _RefIdsMaps aFldMap;
 
-        SwClientIter aIter( *this );
-        for( SwClient* pFld = aIter.First( TYPE( SwFmtFld ));
-                pFld; pFld = aIter.Next() )
+        SwIterator<SwFmtFld,SwFieldType> aIter( *this );
+        for( SwFmtFld* pFld = aIter.First(); pFld; pFld = aIter.Next() )
         {
-            SwGetRefField& rRefFld = *(SwGetRefField*)((SwFmtFld*)pFld)->GetFld();
+            SwGetRefField& rRefFld = *(SwGetRefField*)pFld->GetFld();
             switch( rRefFld.GetSubType() )
             {
             case REF_SEQUENCEFLD:
                 {
                     _RefIdsMap* pMap = 0;
-                    for( USHORT n = aFldMap.Count(); n; )
+                    for( sal_uInt16 n = aFldMap.Count(); n; )
                         if( aFldMap[ --n ]->aName == rRefFld.GetSetRefName() )
                         {
                             pMap = aFldMap[ n ];
@@ -1079,13 +1058,13 @@ void SwGetRefFieldType::MergeWithOtherDoc( SwDoc& rDestDoc )
                         aFldMap.C40_INSERT( _RefIdsMap, pMap, aFldMap.Count() );
                     }
 
-                    pMap->Check( *pDoc, rDestDoc, rRefFld, TRUE );
+                    pMap->Check( *pDoc, rDestDoc, rRefFld, sal_True );
                 }
                 break;
 
             case REF_FOOTNOTE:
             case REF_ENDNOTE:
-                aFntMap.Check( *pDoc, rDestDoc, rRefFld, FALSE );
+                aFntMap.Check( *pDoc, rDestDoc, rRefFld, sal_False );
                 break;
             }
         }
