@@ -39,7 +39,6 @@
 #include "ftnfrm.hxx"
 #include "frmtool.hxx"
 #include "frmfmt.hxx"
-#include "errhdl.hxx"
 #include "hints.hxx"
 #include "pam.hxx"
 #include "sectfrm.hxx"
@@ -53,11 +52,10 @@
 #include "ndole.hxx"
 #include "tabfrm.hxx"
 #include "flyfrms.hxx"
-// OD 22.09.2003 #i18732#
+// #i18732#
 #include <fmtfollowtextflow.hxx>
-// OD 29.10.2003 #113049#
 #include <environmentofanchoredobject.hxx>
-// OD 2004-05-24 #i28701#
+// #i28701#
 #include <sortedobjs.hxx>
 #include <viewsh.hxx>
 #include <viewimp.hxx>
@@ -70,32 +68,27 @@ using namespace ::com::sun::star;
 |*
 |*	SwFlyFreeFrm::SwFlyFreeFrm(), ~SwFlyFreeFrm()
 |*
-|*	Ersterstellung		MA 03. Dec. 92
-|*	Letzte Aenderung	MA 09. Apr. 99
-|*
 |*************************************************************************/
 
-SwFlyFreeFrm::SwFlyFreeFrm( SwFlyFrmFmt *pFmt, SwFrm *pAnch ) :
-    SwFlyFrm( pFmt, pAnch ),
+SwFlyFreeFrm::SwFlyFreeFrm( SwFlyFrmFmt *pFmt, SwFrm* pSib, SwFrm *pAnch ) :
+    SwFlyFrm( pFmt, pSib, pAnch ),
     pPage( 0 ),
-    // --> OD 2004-11-15 #i34753#
+    // #i34753#
     mbNoMakePos( false ),
-    // <--
-    // --> OD 2004-11-12 #i37068#
+    // #i37068#
     mbNoMoveOnCheckClip( false )
-    // <--
 {
 }
 
 SwFlyFreeFrm::~SwFlyFreeFrm()
 {
     //und Tschuess.
-    // --> OD 2004-06-30 #i28701# - use new method <GetPageFrm()>
+    // #i28701# - use new method <GetPageFrm()>
     if( GetPageFrm() )
     {
         if( GetFmt()->GetDoc()->IsInDtor() )
         {
-            // --> OD 2004-06-04 #i29879# - remove also to-frame anchored Writer
+            // #i29879# - remove also to-frame anchored Writer
             // fly frame from page.
             const bool bRemoveFromPage =
                     GetPageFrm()->GetSortedObjs() &&
@@ -114,9 +107,8 @@ SwFlyFreeFrm::~SwFlyFreeFrm()
     }
 }
 
-// --> OD 2004-06-29 #i28701#
+// #i28701#
 TYPEINIT1(SwFlyFreeFrm,SwFlyFrm);
-// <--
 /*************************************************************************
 |*
 |*	SwFlyFreeFrm::NotifyBackground()
@@ -127,29 +119,23 @@ TYPEINIT1(SwFlyFreeFrm,SwFlyFrm);
 |*		ueberlappt werden.
 |* 		Es werden auch die CntntFrms innerhalb von anderen Flys
 |*		beruecksichtigt.
-|*	Ersterstellung		MA 03. Dec. 92
-|*	Letzte Aenderung	MA 26. Aug. 93
 |*
 |*************************************************************************/
 
 void SwFlyFreeFrm::NotifyBackground( SwPageFrm *pPageFrm,
                                      const SwRect& rRect, PrepareHint eHint )
 {
-    ::Notify_Background( GetVirtDrawObj(), pPageFrm, rRect, eHint, TRUE );
+    ::Notify_Background( GetVirtDrawObj(), pPageFrm, rRect, eHint, sal_True );
 }
 
 /*************************************************************************
 |*
 |*	SwFlyFreeFrm::MakeAll()
 |*
-|*	Ersterstellung		MA 18. Feb. 94
-|*	Letzte Aenderung	MA 03. Mar. 97
-|*
 |*************************************************************************/
 
 void SwFlyFreeFrm::MakeAll()
 {
-    // OD 2004-01-19 #110582#
     if ( !GetFmt()->GetDoc()->IsVisibleLayerId( GetVirtDrawObj()->GetLayer() ) )
     {
         return;
@@ -157,7 +143,7 @@ void SwFlyFreeFrm::MakeAll()
 
     if ( !GetAnchorFrm() || IsLocked() || IsColLocked() )
         return;
-    // --> OD 2004-06-30 #i28701# - use new method <GetPageFrm()>
+    // #i28701# - use new method <GetPageFrm()>
     if( !GetPageFrm() && GetAnchorFrm() && GetAnchorFrm()->IsInFly() )
     {
         SwFlyFrm* pFly = AnchorFrm()->FindFlyFrm();
@@ -175,26 +161,24 @@ void SwFlyFreeFrm::MakeAll()
 
     if ( IsClipped() )
     {
-        bValidSize = bHeightClipped = bWidthClipped = FALSE;
-        // --> OD 2004-11-03 #114798# - no invalidation of position,
+        bValidSize = bHeightClipped = bWidthClipped = sal_False;
+        // no invalidation of position,
         // if anchored object is anchored inside a Writer fly frame,
         // its position is already locked, and it follows the text flow.
-        // --> OD 2004-11-15 #i34753# - add condition:
+        // #i34753# - add condition:
         // no invalidation of position, if no direct move is requested in <CheckClip(..)>
         if ( !IsNoMoveOnCheckClip() &&
              !( PositionLocked() &&
                 GetAnchorFrm()->IsInFly() &&
                 GetFrmFmt().GetFollowTextFlow().GetValue() ) )
-        // <--
         {
-            bValidPos = FALSE;
+            bValidPos = sal_False;
         }
-        // <--
     }
 
-    // FME 2007-08-30 #i81146# new loop control
-    USHORT nLoopControlRuns = 0;
-    const USHORT nLoopControlMax = 10;
+    // #i81146# new loop control
+    sal_uInt16 nLoopControlRuns = 0;
+    const sal_uInt16 nLoopControlMax = 10;
 
     while ( !bValidPos || !bValidSize || !bValidPrtArea || bFormatHeightOnly )
     {
@@ -209,22 +193,7 @@ void SwFlyFreeFrm::MakeAll()
             //Nur einstellen wenn das Flag gesetzt ist!!
             if ( !bValidSize )
             {
-                bValidPrtArea = FALSE;
-/*
-                // This is also done in the Format function, so I think
-                // this code is not necessary anymore:
-                const Size aRelSize( CalcRel( *pSz ) );
-                const SwTwips nMin = MINFLY + rAttrs.CalcLeftLine()+rAttrs.CalcRightLine();
-                long nDiff = bVert ? aRelSize.Height() : aRelSize.Width();
-                if( nDiff < nMin )
-                    nDiff = nMin;
-                nDiff -= (aFrm.*fnRect->fnGetWidth)();
-                if( nDiff )
-                {
-                    (aFrm.*fnRect->fnAddRight)( nDiff );
-                    bValidPos = FALSE;
-                }
-*/
+                bValidPrtArea = sal_False;
             }
 
             if ( !bValidPrtArea )
@@ -232,30 +201,29 @@ void SwFlyFreeFrm::MakeAll()
 
             if ( !bValidSize || bFormatHeightOnly )
             {
-                bValidSize = FALSE;
+                bValidSize = sal_False;
                 Format( &rAttrs );
-                bFormatHeightOnly = FALSE;
+                bFormatHeightOnly = sal_False;
             }
 
             if ( !bValidPos )
             {
                 const Point aOldPos( (Frm().*fnRect->fnGetPos)() );
-                // OD 2004-03-23 #i26791# - use new method <MakeObjPos()>
-                // --> OD 2004-11-15 #i34753# - no positioning, if requested.
+                // #i26791# - use new method <MakeObjPos()>
+                // #i34753# - no positioning, if requested.
                 if ( IsNoMakePos() )
-                    bValidPos = TRUE;
+                    bValidPos = sal_True;
                 else
-                    // OD 2004-03-23 #i26791# - use new method <MakeObjPos()>
+                    // #i26791# - use new method <MakeObjPos()>
                     MakeObjPos();
-                // <--
                 if( aOldPos == (Frm().*fnRect->fnGetPos)() )
                 {
                     if( !bValidPos && GetAnchorFrm()->IsInSct() &&
                         !GetAnchorFrm()->FindSctFrm()->IsValid() )
-                        bValidPos = TRUE;
+                        bValidPos = sal_True;
                 }
                 else
-                    bValidSize = FALSE;
+                    bValidSize = sal_False;
             }
         }
 
@@ -286,14 +254,12 @@ void SwFlyFreeFrm::MakeAll()
 
 /** determines, if direct environment of fly frame has 'auto' size
 
-    OD 07.08.2003 #i17297#, #111066#, #111070#
+    #i17297#
     start with anchor frame and search via <GetUpper()> for a header, footer,
     row or fly frame stopping at page frame.
     return <true>, if such a frame is found and it has 'auto' size.
     otherwise <false> is returned.
 
-    @author OD
-
     @return boolean indicating, that direct environment has 'auto' size
 */
 bool SwFlyFreeFrm::HasEnvironmentAutoSize() const
@@ -326,9 +292,6 @@ bool SwFlyFreeFrm::HasEnvironmentAutoSize() const
 |*
 |*	SwFlyFreeFrm::CheckClip()
 |*
-|*	Ersterstellung		MA 21. Feb. 94
-|*	Letzte Aenderung	MA 03. Mar. 97
-|*
 |*************************************************************************/
 
 void SwFlyFreeFrm::CheckClip( const SwFmtFrmSize &rSz )
@@ -342,8 +305,8 @@ void SwFlyFreeFrm::CheckClip( const SwFmtFrmSize &rSz )
 
     const SwVirtFlyDrawObj *pObj = GetVirtDrawObj();
     SwRect aClip, aTmpStretch;
-    ::CalcClipRect( pObj, aClip, TRUE );
-    ::CalcClipRect( pObj, aTmpStretch, FALSE );
+    ::CalcClipRect( pObj, aClip, sal_True );
+    ::CalcClipRect( pObj, aTmpStretch, sal_False );
     aClip._Intersection( aTmpStretch );
 
     const long nBot = Frm().Top() + Frm().Height();
@@ -351,15 +314,14 @@ void SwFlyFreeFrm::CheckClip( const SwFmtFrmSize &rSz )
     const long nClipBot = aClip.Top() + aClip.Height();
     const long nClipRig = aClip.Left() + aClip.Width();
 
-    const BOOL bBot = nBot > nClipBot;
-    const BOOL bRig = nRig > nClipRig;
+    const sal_Bool bBot = nBot > nClipBot;
+    const sal_Bool bRig = nRig > nClipRig;
     if ( bBot || bRig )
     {
-        BOOL bAgain = FALSE;
-        // --> OD 2004-11-12 #i37068# - no move, if it's requested
+        sal_Bool bAgain = sal_False;
+        // #i37068# - no move, if it's requested
         if ( bBot && !IsNoMoveOnCheckClip() &&
              !GetDrawObjs() && !GetAnchorFrm()->IsInTab() )
-        // <--
         {
             SwFrm* pHeader = FindFooterOrHeader();
             // In a header, correction of the position is no good idea.
@@ -371,8 +333,8 @@ void SwFlyFreeFrm::CheckClip( const SwFmtFrmSize &rSz )
                 const long nOld = Frm().Top();
                 Frm().Pos().Y() = Max( aClip.Top(), nClipBot - Frm().Height() );
                 if ( Frm().Top() != nOld )
-                    bAgain = TRUE;
-                bHeightClipped = TRUE;
+                    bAgain = sal_True;
+                bHeightClipped = sal_True;
             }
         }
         if ( bRig )
@@ -387,12 +349,12 @@ void SwFlyFreeFrm::CheckClip( const SwFmtFrmSize &rSz )
                 if( rH.GetHoriOrient() == text::HoriOrientation::LEFT )
                     Frm().Pos().X() = nOld;
                 else
-                    bAgain = TRUE;
+                    bAgain = sal_True;
             }
-            bWidthClipped = TRUE;
+            bWidthClipped = sal_True;
         }
         if ( bAgain )
-            bValidSize = FALSE;
+            bValidSize = sal_False;
         else
         {
             //Wenn wir hier ankommen ragt der Frm in unerlaubte Bereiche
@@ -413,7 +375,7 @@ void SwFlyFreeFrm::CheckClip( const SwFmtFrmSize &rSz )
                 nDiff -= aFrmRect.Top(); //nDiff ist die verfuegbare Strecke.
                 nDiff = aFrmRect.Height() - nDiff;
                 aFrmRect.Height( aFrmRect.Height() - nDiff );
-                bHeightClipped = TRUE;
+                bHeightClipped = sal_True;
             }
             if ( bRig )
             {
@@ -421,10 +383,10 @@ void SwFlyFreeFrm::CheckClip( const SwFmtFrmSize &rSz )
                 nDiff -= aFrmRect.Left();//nDiff ist die verfuegbare Strecke.
                 nDiff = aFrmRect.Width() - nDiff;
                 aFrmRect.Width( aFrmRect.Width() - nDiff );
-                bWidthClipped = TRUE;
+                bWidthClipped = sal_True;
             }
 
-            // OD 06.08.2003 #i17297#, #111066#, #111070# - no proportional
+            // #i17297# - no proportional
             // scaling of graphics in environments, which determines its size
             // by its content ('auto' size). Otherwise layout loops can occur and
             // layout sizes of the environment can be incorrect.
@@ -455,19 +417,20 @@ void SwFlyFreeFrm::CheckClip( const SwFmtFrmSize &rSz )
                 {
                     aFrmRect.Height( aFrmRect.Width() * aOldSize.Height() /
                                      aOldSize.Width() );
-                    bHeightClipped = TRUE;
+                    bHeightClipped = sal_True;
                 }
                 //Hoehe angepasst? - Breite dann proportional verkleinern
                 else if( aFrmRect.Height() != aOldSize.Height() )
                 {
                     aFrmRect.Width( aFrmRect.Height() * aOldSize.Width() /
                                     aOldSize.Height() );
-                    bWidthClipped = TRUE;
+                    bWidthClipped = sal_True;
                 }
 
-                // OD 07.08.2003 #i17297#, #111066#, #111070# - reactivate change
+                // #i17297# - reactivate change
                 // of size attribute for fly frames containing an ole object.
-                // FME: 2004-05-19 Added the aFrmRect.HasArea() hack, because
+
+                // Added the aFrmRect.HasArea() hack, because
                 // the environment of the ole object does not have to be valid
                 // at this moment, or even worse, it does not have to have a
                 // resonable size. In this case we do not want to change to
@@ -511,7 +474,7 @@ void SwFlyFreeFrm::CheckClip( const SwFmtFrmSize &rSz )
                 ::CalcCntnt( this );
                 ColUnlock();
                 if ( !bValidSize && !bWidthClipped )
-                    bFormatHeightOnly = bValidSize = TRUE;
+                    bFormatHeightOnly = bValidSize = sal_True;
             }
             else
             {
@@ -521,17 +484,13 @@ void SwFlyFreeFrm::CheckClip( const SwFmtFrmSize &rSz )
         }
     }
 
-    // --> OD 2004-10-14 #i26945#
+    // #i26945#
     OSL_ENSURE( Frm().Height() >= 0,
             "<SwFlyFreeFrm::CheckClip(..)> - fly frame has negative height now." );
-    // <--
 }
 
 /** method to determine, if a <MakeAll()> on the Writer fly frame is possible
-
-    OD 2005-03-03 #i43771#
-
-    @author OD
+    #i43771#
 */
 bool SwFlyFreeFrm::IsFormatPossible() const
 {
@@ -544,36 +503,29 @@ bool SwFlyFreeFrm::IsFormatPossible() const
 |*
 |*	SwFlyLayFrm::SwFlyLayFrm()
 |*
-|*	Ersterstellung		MA 25. Aug. 92
-|*	Letzte Aenderung	MA 09. Apr. 99
-|*
 |*************************************************************************/
 
-SwFlyLayFrm::SwFlyLayFrm( SwFlyFrmFmt *pFmt, SwFrm *pAnch ) :
-    SwFlyFreeFrm( pFmt, pAnch )
+SwFlyLayFrm::SwFlyLayFrm( SwFlyFrmFmt *pFmt, SwFrm* pSib, SwFrm *pAnch ) :
+    SwFlyFreeFrm( pFmt, pSib, pAnch )
 {
-    bLayout = TRUE;
+    bLayout = sal_True;
 }
 
-// --> OD 2004-06-29 #i28701#
+// #i28701#
 TYPEINIT1(SwFlyLayFrm,SwFlyFreeFrm);
-// <--
 /*************************************************************************
 |*
 |*	SwFlyLayFrm::Modify()
 |*
-|*	Ersterstellung		MA 08. Feb. 93
-|*	Letzte Aenderung	MA 28. Aug. 93
-|*
 |*************************************************************************/
 
-void SwFlyLayFrm::Modify( SfxPoolItem *pOld, SfxPoolItem *pNew )
+void SwFlyLayFrm::Modify( const SfxPoolItem* pOld, const SfxPoolItem *pNew )
 {
-    USHORT nWhich = pNew ? pNew->Which() : 0;
+    sal_uInt16 nWhich = pNew ? pNew->Which() : 0;
 
     SwFmtAnchor *pAnch = 0;
     if( RES_ATTRSET_CHG == nWhich && SFX_ITEM_SET ==
-        ((SwAttrSetChg*)pNew)->GetChgSet()->GetItemState( RES_ANCHOR, FALSE,
+        ((SwAttrSetChg*)pNew)->GetChgSet()->GetItemState( RES_ANCHOR, sal_False,
             (const SfxPoolItem**)&pAnch ))
         ;		// Beim GetItemState wird der AnkerPointer gesetzt !
 
@@ -594,23 +546,22 @@ void SwFlyLayFrm::Modify( SfxPoolItem *pOld, SfxPoolItem *pNew )
         //Abmelden, Seite besorgen, an den entsprechenden LayoutFrm
         //haengen.
         SwRect aOld( GetObjRectWithSpaces() );
-        // --> OD 2004-06-30 #i28701# - use new method <GetPageFrm()>
+        // #i28701# - use new method <GetPageFrm()>
         SwPageFrm *pOldPage = GetPageFrm();
         AnchorFrm()->RemoveFly( this );
 
         if ( FLY_AT_PAGE == pAnch->GetAnchorId() )
         {
-            USHORT nPgNum = pAnch->GetPageNum();
-            SwRootFrm *pRoot = FindRootFrm();
+            sal_uInt16 nPgNum = pAnch->GetPageNum();
+            SwRootFrm *pRoot = getRootFrm();
             SwPageFrm *pTmpPage = (SwPageFrm*)pRoot->Lower();
-            for ( USHORT i = 1; (i <= nPgNum) && pTmpPage; ++i,
+            for ( sal_uInt16 i = 1; (i <= nPgNum) && pTmpPage; ++i,
                                 pTmpPage = (SwPageFrm*)pTmpPage->GetNext() )
             {
                 if ( i == nPgNum )
                 {
-                    // --> OD 2005-06-09 #i50432# - adjust synopsis of <PlaceFly(..)>
+                    // #i50432# - adjust synopsis of <PlaceFly(..)>
                     pTmpPage->PlaceFly( this, 0 );
-                    // <--
                 }
             }
             if( !pTmpPage )
@@ -623,7 +574,7 @@ void SwFlyLayFrm::Modify( SfxPoolItem *pOld, SfxPoolItem *pNew )
         {
             SwNodeIndex aIdx( pAnch->GetCntntAnchor()->nNode );
             SwCntntFrm *pCntnt = GetFmt()->GetDoc()->GetNodes().GoNext( &aIdx )->
-                         GetCntntNode()->GetFrm( 0, 0, FALSE );
+                         GetCntntNode()->getLayoutFrm( getRootFrm(), 0, 0, sal_False );
             if( pCntnt )
             {
                 SwFlyFrm *pTmp = pCntnt->FindFlyFrm();
@@ -631,7 +582,7 @@ void SwFlyLayFrm::Modify( SfxPoolItem *pOld, SfxPoolItem *pNew )
                     pTmp->AppendFly( this );
             }
         }
-        // --> OD 2004-06-30 #i28701# - use new method <GetPageFrm()>
+        // #i28701# - use new method <GetPageFrm()>
         if ( pOldPage && pOldPage != GetPageFrm() )
             NotifyBackground( pOldPage, aOld, PREP_FLY_LEAVE );
         SetCompletePaint();
@@ -646,15 +597,12 @@ void SwFlyLayFrm::Modify( SfxPoolItem *pOld, SfxPoolItem *pNew )
 |*
 |*	SwPageFrm::AppendFly()
 |*
-|*	Ersterstellung		MA 10. Oct. 92
-|*	Letzte Aenderung	MA 08. Jun. 96
-|*
 |*************************************************************************/
 
 void SwPageFrm::AppendFlyToPage( SwFlyFrm *pNew )
 {
     if ( !pNew->GetVirtDrawObj()->IsInserted() )
-        FindRootFrm()->GetDrawPage()->InsertObject(
+        getRootFrm()->GetDrawPage()->InsertObject(
                 (SdrObject*)pNew->GetVirtDrawObj(),
                 pNew->GetVirtDrawObj()->GetReferencedObj().GetOrdNumDirect() );
 
@@ -674,7 +622,7 @@ void SwPageFrm::AppendFlyToPage( SwFlyFrm *pNew )
     const SwFlyFrm* pFly = pNew->GetAnchorFrm()->FindFlyFrm();
     if ( pFly && pObj->GetOrdNum() < pFly->GetVirtDrawObj()->GetOrdNum() )
     {
-        UINT32 nNewNum = pFly->GetVirtDrawObj()->GetOrdNumDirect();
+        sal_uInt32 nNewNum = pFly->GetVirtDrawObj()->GetOrdNumDirect();
         if ( pObj->GetPage() )
             pObj->GetPage()->SetObjectOrdNum( pObj->GetOrdNumDirect(), nNewNum);
         else
@@ -700,14 +648,13 @@ void SwPageFrm::AppendFlyToPage( SwFlyFrm *pNew )
         (void) bSucessInserted;
 #endif
 
-        // --> OD 2008-04-22 #i87493#
+        // #i87493#
         OSL_ENSURE( pNew->GetPageFrm() == 0 || pNew->GetPageFrm() == this,
                 "<SwPageFrm::AppendFlyToPage(..)> - anchored fly frame seems to be registered at another page frame. Serious defect -> please inform OD." );
-        // <--
-        // --> OD 2004-06-30 #i28701# - use new method <SetPageFrm(..)>
+        // #i28701# - use new method <SetPageFrm(..)>
         pNew->SetPageFrm( this );
         pNew->InvalidatePage( this );
-        // OD 2004-05-17 #i28701#
+        // #i28701#
         pNew->UnlockPosition();
 
         // Notify accessible layout. That's required at this place for
@@ -722,24 +669,23 @@ void SwPageFrm::AppendFlyToPage( SwFlyFrm *pNew )
         }
     }
 
-    // --> OD 2004-06-09 #i28701# - correction: consider also drawing objects
+    // #i28701# - correction: consider also drawing objects
     if ( pNew->GetDrawObjs() )
     {
         SwSortedObjs &rObjs = *pNew->GetDrawObjs();
-        for ( USHORT i = 0; i < rObjs.Count(); ++i )
+        for ( sal_uInt16 i = 0; i < rObjs.Count(); ++i )
         {
             SwAnchoredObject* pTmpObj = rObjs[i];
             if ( pTmpObj->ISA(SwFlyFrm) )
             {
                 SwFlyFrm* pTmpFly = static_cast<SwFlyFrm*>(pTmpObj);
-                // --> OD 2004-06-30 #i28701# - use new method <GetPageFrm()>
+                // #i28701# - use new method <GetPageFrm()>
                 if ( pTmpFly->IsFlyFreeFrm() && !pTmpFly->GetPageFrm() )
                     AppendFlyToPage( pTmpFly );
             }
             else if ( pTmpObj->ISA(SwAnchoredDrawObject) )
             {
-                // --> OD 2008-04-22 #i87493#
-//                AppendDrawObjToPage( *pTmpObj );
+                // #i87493#
                 if ( pTmpObj->GetPageFrm() != this )
                 {
                     if ( pTmpObj->GetPageFrm() != 0 )
@@ -748,7 +694,6 @@ void SwPageFrm::AppendFlyToPage( SwFlyFrm *pNew )
                     }
                     AppendDrawObjToPage( *pTmpObj );
                 }
-                // <--
             }
         }
     }
@@ -758,15 +703,12 @@ void SwPageFrm::AppendFlyToPage( SwFlyFrm *pNew )
 |*
 |*	SwPageFrm::RemoveFly()
 |*
-|*	Ersterstellung		MA 10. Oct. 92
-|*	Letzte Aenderung	MA 26. Aug. 96
-|*
 |*************************************************************************/
 
 void SwPageFrm::RemoveFlyFromPage( SwFlyFrm *pToRemove )
 {
-    const UINT32 nOrdNum = pToRemove->GetVirtDrawObj()->GetOrdNum();
-    FindRootFrm()->GetDrawPage()->RemoveObject( nOrdNum );
+    const sal_uInt32 nOrdNum = pToRemove->GetVirtDrawObj()->GetOrdNum();
+    getRootFrm()->GetDrawPage()->RemoveObject( nOrdNum );
     pToRemove->GetVirtDrawObj()->ReferencedObj().SetOrdNum( nOrdNum );
 
     if ( GetUpper() )
@@ -803,7 +745,7 @@ void SwPageFrm::RemoveFlyFromPage( SwFlyFrm *pToRemove )
         {	DELETEZ( pSortedObjs );
         }
     }
-    // --> OD 2004-06-30 #i28701# - use new method <SetPageFrm(..)>
+    // #i28701# - use new method <SetPageFrm(..)>
     pToRemove->SetPageFrm( 0L );
 }
 
@@ -811,9 +753,6 @@ void SwPageFrm::RemoveFlyFromPage( SwFlyFrm *pToRemove )
 |*
 |*	SwPageFrm::MoveFly
 |*
-|*	Ersterstellung		MA 25. Jan. 97
-|*	Letzte Aenderung	MA 25. Jan. 97
-|*
 |*************************************************************************/
 
 void SwPageFrm::MoveFly( SwFlyFrm *pToMove, SwPageFrm *pDest )
@@ -871,12 +810,12 @@ void SwPageFrm::MoveFly( SwFlyFrm *pToMove, SwPageFrm *pDest )
     (void) bSucessInserted;
 #endif
 
-    // --> OD 2004-06-30 #i28701# - use new method <SetPageFrm(..)>
+    // #i28701# - use new method <SetPageFrm(..)>
     pToMove->SetPageFrm( pDest );
     pToMove->InvalidatePage( pDest );
     pToMove->SetNotifyBack();
     pDest->InvalidateFlyCntnt();
-    // OD 2004-05-17 #i28701#
+    // #i28701#
     pToMove->UnlockPosition();
 
     // Notify accessible layout. That's required at this place for
@@ -890,7 +829,7 @@ void SwPageFrm::MoveFly( SwFlyFrm *pToMove, SwPageFrm *pDest )
                                   ->AddAccessibleFrm( pToMove );
     }
 
-    // --> OD 2004-06-09 #i28701# - correction: move lowers of Writer fly frame
+    // #i28701# - correction: move lowers of Writer fly frame
     if ( pToMove->GetDrawObjs() )
     {
         SwSortedObjs &rObjs = *pToMove->GetDrawObjs();
@@ -902,7 +841,7 @@ void SwPageFrm::MoveFly( SwFlyFrm *pToMove, SwPageFrm *pDest )
                 SwFlyFrm* pFly = static_cast<SwFlyFrm*>(pObj);
                 if ( pFly->IsFlyFreeFrm() )
                 {
-                    // --> OD 2004-06-30 #i28701# - use new method <GetPageFrm()>
+                    // #i28701# - use new method <GetPageFrm()>
                     SwPageFrm* pPageFrm = pFly->GetPageFrm();
                     if ( pPageFrm )
                         pPageFrm->MoveFly( pFly, pDest );
@@ -923,15 +862,14 @@ void SwPageFrm::MoveFly( SwFlyFrm *pToMove, SwPageFrm *pDest )
 |*
 |*  SwPageFrm::AppendDrawObjToPage(), RemoveDrawObjFromPage()
 |*
-|*  --> OD 2004-07-02 #i28701# - new methods
+|*  #i28701# - new methods
 |*
 |*************************************************************************/
 void SwPageFrm::AppendDrawObjToPage( SwAnchoredObject& _rNewObj )
 {
     if ( !_rNewObj.ISA(SwAnchoredDrawObject) )
     {
-        OSL_ENSURE( false,
-                "SwPageFrm::AppendDrawObjToPage(..) - anchored object of unexcepted type -> object not appended" );
+        OSL_FAIL( "SwPageFrm::AppendDrawObjToPage(..) - anchored object of unexcepted type -> object not appended" );
         return;
     }
 
@@ -945,7 +883,7 @@ void SwPageFrm::AppendDrawObjToPage( SwAnchoredObject& _rNewObj )
     if ( pFlyFrm &&
          _rNewObj.GetDrawObj()->GetOrdNum() < pFlyFrm->GetVirtDrawObj()->GetOrdNum() )
     {
-        UINT32 nNewNum = pFlyFrm->GetVirtDrawObj()->GetOrdNumDirect();
+        sal_uInt32 nNewNum = pFlyFrm->GetVirtDrawObj()->GetOrdNumDirect();
         if ( _rNewObj.GetDrawObj()->GetPage() )
             _rNewObj.DrawObj()->GetPage()->SetObjectOrdNum(
                             _rNewObj.GetDrawObj()->GetOrdNumDirect(), nNewNum);
@@ -969,10 +907,9 @@ void SwPageFrm::AppendDrawObjToPage( SwAnchoredObject& _rNewObj )
                 "Drawing object not appended into list <pSortedObjs>." );
 #endif
     }
-    // --> OD 2008-04-22 #i87493#
+    // #i87493#
     OSL_ENSURE( _rNewObj.GetPageFrm() == 0 || _rNewObj.GetPageFrm() == this,
             "<SwPageFrm::AppendDrawObjToPage(..)> - anchored draw object seems to be registered at another page frame. Serious defect -> please inform OD." );
-    // <--
     _rNewObj.SetPageFrm( this );
 
     // invalidate page in order to force a reformat of object layout of the page.
@@ -983,8 +920,7 @@ void SwPageFrm::RemoveDrawObjFromPage( SwAnchoredObject& _rToRemoveObj )
 {
     if ( !_rToRemoveObj.ISA(SwAnchoredDrawObject) )
     {
-        OSL_ENSURE( false,
-                "SwPageFrm::RemoveDrawObjFromPage(..) - anchored object of unexcepted type -> object not removed" );
+        OSL_FAIL( "SwPageFrm::RemoveDrawObjFromPage(..) - anchored object of unexcepted type -> object not removed" );
         return;
     }
 
@@ -1013,15 +949,12 @@ void SwPageFrm::RemoveDrawObjFromPage( SwAnchoredObject& _rToRemoveObj )
 |*
 |*	SwPageFrm::PlaceFly
 |*
-|*	Ersterstellung		MA 08. Feb. 93
-|*	Letzte Aenderung	MA 27. Feb. 93
-|*
 |*************************************************************************/
 
-// --> OD 2005-06-09 #i50432# - adjust method description and synopsis.
+// #i50432# - adjust method description and synopsis.
 void SwPageFrm::PlaceFly( SwFlyFrm* pFly, SwFlyFrmFmt* pFmt )
 {
-    // --> OD 2005-06-09 #i50432# - consider the case that page is an empty page:
+    // #i50432# - consider the case that page is an empty page:
     // In this case append the fly frame at the next page
     OSL_ENSURE( !IsEmptyPage() || GetNext(),
             "<SwPageFrm::PlaceFly(..)> - empty page with no next page! -> fly frame appended at empty page" );
@@ -1037,50 +970,45 @@ void SwPageFrm::PlaceFly( SwFlyFrm* pFly, SwFlyFrmFmt* pFmt )
             AppendFly( pFly );
         else
         {   OSL_ENSURE( pFmt, ":-( kein Format fuer Fly uebergeben." );
-            pFly = new SwFlyLayFrm( (SwFlyFrmFmt*)pFmt, this );
+            pFly = new SwFlyLayFrm( (SwFlyFrmFmt*)pFmt, this, this );
             AppendFly( pFly );
             ::RegistFlys( this, pFly );
         }
     }
-    // <--
 }
 
 /*************************************************************************
 |*
 |*	::CalcClipRect
 |*
-|*	Ersterstellung		AMA 24. Sep. 96
-|*	Letzte Aenderung	MA  18. Dec. 96
-|*
 |*************************************************************************/
-// OD 22.09.2003 #i18732# - adjustments for following text flow or not
+// #i18732# - adjustments for following text flow or not
 // AND alignment at 'page areas' for to paragraph/to character anchored objects
-// OD 06.11.2003 #i22305# - adjustment for following text flow
+// #i22305# - adjustment for following text flow
 // for to frame anchored objects
-// OD 2004-06-02 #i29778# - Because the calculation of the position of the
+// #i29778# - Because the calculation of the position of the
 // floating screen object (Writer fly frame or drawing object) doesn't perform
 // a calculation on its upper frames and its anchor frame, a calculation of
 // the upper frames in this method no longer sensible.
-// --> OD 2004-07-06 #i28701# - if document compatibility option 'Consider
+// #i28701# - if document compatibility option 'Consider
 // wrapping style influence on object positioning' is ON, the clip area
 // corresponds to the one as the object doesn't follows the text flow.
-BOOL CalcClipRect( const SdrObject *pSdrObj, SwRect &rRect, BOOL bMove )
+sal_Bool CalcClipRect( const SdrObject *pSdrObj, SwRect &rRect, sal_Bool bMove )
 {
-    BOOL bRet = TRUE;
+    sal_Bool bRet = sal_True;
     if ( pSdrObj->ISA(SwVirtFlyDrawObj) )
     {
         const SwFlyFrm* pFly = ((const SwVirtFlyDrawObj*)pSdrObj)->GetFlyFrm();
         const bool bFollowTextFlow = pFly->GetFmt()->GetFollowTextFlow().GetValue();
-        // --> OD 2004-07-06 #i28701#
+        // #i28701#
         const bool bConsiderWrapOnObjPos =
                                 pFly->GetFmt()->getIDocumentSettingAccess()->get(IDocumentSettingAccess::CONSIDER_WRAP_ON_OBJECT_POSITION);
-        // <--
         const SwFmtVertOrient &rV = pFly->GetFmt()->GetVertOrient();
         if( pFly->IsFlyLayFrm() )
         {
             const SwFrm* pClip;
-            // OD 06.11.2003 #i22305#
-            // --> OD 2004-07-06 #i28701#
+            // #i22305#
+            // #i28701#
             if ( !bFollowTextFlow || bConsiderWrapOnObjPos )
             {
                 pClip = pFly->GetAnchorFrm()->FindPageFrm();
@@ -1111,13 +1039,12 @@ BOOL CalcClipRect( const SdrObject *pSdrObj, SwRect &rRect, BOOL bMove )
         }
         else if( pFly->IsFlyAtCntFrm() )
         {
-            // OD 22.09.2003 #i18732# - consider following text flow or not
+            // #i18732# - consider following text flow or not
             // AND alignment at 'page areas'
             const SwFrm* pVertPosOrientFrm = pFly->GetVertPosOrientFrm();
             if ( !pVertPosOrientFrm )
             {
-                OSL_ENSURE( false,
-                        "::CalcClipRect(..) - frame, vertical position is oriented at, is missing .");
+                OSL_FAIL( "::CalcClipRect(..) - frame, vertical position is oriented at, is missing .");
                 pVertPosOrientFrm = pFly->GetAnchorFrm();
             }
 
@@ -1126,9 +1053,9 @@ BOOL CalcClipRect( const SdrObject *pSdrObj, SwRect &rRect, BOOL bMove )
                 const SwLayoutFrm* pClipFrm = pVertPosOrientFrm->FindPageFrm();
                 rRect = bMove ? pClipFrm->GetUpper()->Frm()
                               : pClipFrm->Frm();
-                // --> OD 2004-10-14 #i26945# - consider that a table, during
+                // #i26945# - consider that a table, during
                 // its format, can exceed its upper printing area bottom.
-                // Thus, enlarge the clip rectangle, if such a case occured
+                // Thus, enlarge the clip rectangle, if such a case occurred
                 if ( pFly->GetAnchorFrm()->IsInTab() )
                 {
                     const SwTabFrm* pTabFrm = const_cast<SwFlyFrm*>(pFly)
@@ -1136,7 +1063,7 @@ BOOL CalcClipRect( const SdrObject *pSdrObj, SwRect &rRect, BOOL bMove )
                     SwRect aTmp( pTabFrm->Prt() );
                     aTmp += pTabFrm->Frm().Pos();
                     rRect.Union( aTmp );
-                    // --> OD 2005-03-30 #i43913# - consider also the cell frame
+                    // #i43913# - consider also the cell frame
                     const SwFrm* pCellFrm = const_cast<SwFlyFrm*>(pFly)
                                 ->GetAnchorFrmContainingAnchPos()->GetUpper();
                     while ( pCellFrm && !pCellFrm->IsCellFrm() )
@@ -1149,13 +1076,12 @@ BOOL CalcClipRect( const SdrObject *pSdrObj, SwRect &rRect, BOOL bMove )
                         aTmp += pCellFrm->Frm().Pos();
                         rRect.Union( aTmp );
                     }
-                    // <--
                 }
             }
             else if ( rV.GetRelationOrient() == text::RelOrientation::PAGE_FRAME ||
                       rV.GetRelationOrient() == text::RelOrientation::PAGE_PRINT_AREA )
             {
-                // OD 29.10.2003 #113049# - new class <SwEnvironmentOfAnchoredObject>
+                // new class <SwEnvironmentOfAnchoredObject>
                 objectpositioning::SwEnvironmentOfAnchoredObject
                                                 aEnvOfObj( bFollowTextFlow );
                 const SwLayoutFrm& rVertClipFrm =
@@ -1183,14 +1109,13 @@ BOOL CalcClipRect( const SdrObject *pSdrObj, SwRect &rRect, BOOL bMove )
             }
             else
             {
-                // --> OD 2004-10-11 #i26945#
+                // #i26945#
                 const SwFrm *pClip =
                         const_cast<SwFlyFrm*>(pFly)->GetAnchorFrmContainingAnchPos();
-                // <--
                 SWRECTFN( pClip )
                 const SwLayoutFrm *pUp = pClip->GetUpper();
                 const SwFrm *pCell = pUp->IsCellFrm() ? pUp : 0;
-                USHORT nType = bMove ? FRM_ROOT   | FRM_FLY | FRM_HEADER |
+                sal_uInt16 nType = bMove ? FRM_ROOT   | FRM_FLY | FRM_HEADER |
                                        FRM_FOOTER | FRM_FTN
                                      : FRM_BODY   | FRM_FLY | FRM_HEADER |
                                        FRM_FOOTER | FRM_CELL| FRM_FTN;
@@ -1261,8 +1186,7 @@ BOOL CalcClipRect( const SdrObject *pSdrObj, SwRect &rRect, BOOL bMove )
                             const SwFrm *pTab = pUp->FindTabFrm();
                             (rRect.*fnRect->fnSetBottom)(
                                         (pTab->GetUpper()->*fnRect->fnGetPrtBottom)() );
-                            // OD 08.08.2003 #110978# - expand to left and right
-                            // cell border
+                            // expand to left and right cell border
                             rRect.Left ( pUp->Frm().Left() );
                             rRect.Width( pUp->Frm().Width() );
                         }
@@ -1298,7 +1222,7 @@ BOOL CalcClipRect( const SdrObject *pSdrObj, SwRect &rRect, BOOL bMove )
             }
             else if ( pUp->GetUpper()->IsPageFrm() )
             {
-                // #111909# Objects anchored as character may exceed right margin
+                // Objects anchored as character may exceed right margin
                 // of body frame:
                 (rRect.*fnRect->fnSetRight)( (pUp->GetUpper()->Frm().*fnRect->fnGetRight)() );
             }
@@ -1337,7 +1261,7 @@ BOOL CalcClipRect( const SdrObject *pSdrObj, SwRect &rRect, BOOL bMove )
             const SwFrm* pAnchorFrm = pC->GetAnchorFrm( pSdrObj );
             if( !pAnchorFrm )
             {
-                OSL_ENSURE( false, "<::CalcClipRect(..)> - missing anchor frame." );
+                OSL_FAIL( "<::CalcClipRect(..)> - missing anchor frame." );
                 ((SwDrawContact*)pC)->ConnectToLayout();
                 pAnchorFrm = pC->GetAnchorFrm();
             }
@@ -1361,7 +1285,7 @@ BOOL CalcClipRect( const SdrObject *pSdrObj, SwRect &rRect, BOOL bMove )
             }
             else
             {
-                // OD 2004-04-13 #i26791# - value of <nTmpH> is needed to
+                // #i26791# - value of <nTmpH> is needed to
                 // calculate value of <nTop>.
                 nTmpH = bVert ? pSdrObj->GetCurrentBoundRect().GetWidth() :
                                 pSdrObj->GetCurrentBoundRect().GetHeight();
@@ -1373,9 +1297,9 @@ BOOL CalcClipRect( const SdrObject *pSdrObj, SwRect &rRect, BOOL bMove )
         }
         else
         {
-            // OD 23.06.2003 #108784# - restrict clip rectangle for drawing
+            // restrict clip rectangle for drawing
             // objects in header/footer to the page frame.
-            // OD 2004-03-29 #i26791#
+            // #i26791#
             const SwFrm* pAnchorFrm = pC->GetAnchorFrm( pSdrObj );
             if ( pAnchorFrm && pAnchorFrm->FindFooterOrHeader() )
             {
@@ -1385,7 +1309,7 @@ BOOL CalcClipRect( const SdrObject *pSdrObj, SwRect &rRect, BOOL bMove )
             }
             else
             {
-                bRet = FALSE;
+                bRet = sal_False;
             }
         }
     }
