@@ -33,13 +33,11 @@
 #include <hintids.hxx>
 
 #include <com/sun/star/i18n/ScriptType.hdl>
-
 #include <vcl/graph.hxx>
 #include <editeng/brshitem.hxx>
 #include <vcl/metric.hxx>
 #include <vcl/outdev.hxx>
 #include <viewopt.hxx>	// SwViewOptions
-#include <txtcfg.hxx>
 #include <SwPortionHandler.hxx>
 #include <porlay.hxx>
 #include <porfld.hxx>
@@ -49,6 +47,7 @@
 #include <viewsh.hxx>
 #include <docsh.hxx>
 #include <doc.hxx>
+#include "rootfrm.hxx"
 #include <breakit.hxx>
 #include <porrst.hxx>
 #include <porftn.hxx>   // SwFtnPortion
@@ -213,8 +212,8 @@ void SwFldPortion::CheckScript( const SwTxtSizeInfo &rInf )
     String aTxt;
     if( GetExpTxt( rInf, aTxt ) && aTxt.Len() && pBreakIt->GetBreakIter().is() )
     {
-        BYTE nActual = pFnt ? pFnt->GetActual() : rInf.GetFont()->GetActual();
-        USHORT nScript;
+        sal_uInt8 nActual = pFnt ? pFnt->GetActual() : rInf.GetFont()->GetActual();
+        sal_uInt16 nScript;
         {
             nScript = pBreakIt->GetBreakIter()->getScriptType( aTxt, 0 );
             xub_StrLen nChg = 0;
@@ -234,7 +233,7 @@ void SwFldPortion::CheckScript( const SwTxtSizeInfo &rInf )
                 nNextScriptChg = aTxt.Len();
 
         }
-        BYTE nTmp;
+        sal_uInt8 nTmp;
         switch ( nScript ) {
             case i18n::ScriptType::LATIN : nTmp = SW_LATIN; break;
             case i18n::ScriptType::ASIAN : nTmp = SW_CJK; break;
@@ -245,8 +244,8 @@ void SwFldPortion::CheckScript( const SwTxtSizeInfo &rInf )
         // #i16354# Change script type for RTL text to CTL.
         const SwScriptInfo& rSI = rInf.GetParaPortion()->GetScriptInfo();
         // --> OD 2009-01-29 #i98418#
-//        const BYTE nFldDir = IsNumberPortion() ?
-        const BYTE nFldDir = ( IsNumberPortion() || IsFtnNumPortion() ) ?
+//        const sal_uInt8 nFldDir = IsNumberPortion() ?
+        const sal_uInt8 nFldDir = ( IsNumberPortion() || IsFtnNumPortion() ) ?
                              rSI.GetDefaultDir() :
                              rSI.DirType( IsFollow() ? rInf.GetIdx() - 1 : rInf.GetIdx() );
         // <--
@@ -539,7 +538,6 @@ sal_Bool SwHiddenPortion::GetExpTxt( const SwTxtSizeInfo &rInf, XubString &rTxt
  *                      class SwNumberPortion
  *************************************************************************/
 
-// --> OD 2008-01-23 #newlistlevelattrs#
 SwNumberPortion::SwNumberPortion( const XubString &rExpand,
                                   SwFont *pFont,
                                   const sal_Bool bLft,
@@ -549,9 +547,7 @@ SwNumberPortion::SwNumberPortion( const XubString &rExpand,
         : SwFldPortion( rExpand, pFont ),
           nFixWidth(0),
           nMinDist( nMinDst ),
-          // --> OD 2008-01-23 #newlistlevelattrs#
           mbLabelAlignmentPosAndSpaceModeActive( bLabelAlignmentPosAndSpaceModeActive )
-          // <--
 {
     SetWhichPor( POR_NUMBER );
     SetLeft( bLft );
@@ -569,10 +565,9 @@ SwFldPortion *SwNumberPortion::Clone( const XubString &rExpand ) const
     SwFont *pNewFnt;
     if( 0 != ( pNewFnt = pFnt ) )
         pNewFnt = new SwFont( *pFnt );
-    // --> OD 2008-01-23 #newlistlevelattrs#
+
     return new SwNumberPortion( rExpand, pNewFnt, IsLeft(), IsCenter(),
                                 nMinDist, mbLabelAlignmentPosAndSpaceModeActive );
-    // <--
 }
 
 /*************************************************************************
@@ -598,7 +593,7 @@ sal_Bool SwNumberPortion::Format( SwTxtFormatInfo &rInf )
         OSL_ENSURE( Height() && nAscent, "NumberPortions without Height | Ascent" );
 
         long nDiff( 0 );
-        // --> OD 2008-01-23 #newlistlevelattrs#
+
         if ( !mbLabelAlignmentPosAndSpaceModeActive )
         {
             if ( !rInf.GetTxtFrm()->GetTxtNode()->getIDocumentSettingAccess()->get(IDocumentSettingAccess::IGNORE_FIRST_LINE_INDENT_IN_NUMBERING) &&
@@ -617,7 +612,6 @@ sal_Bool SwNumberPortion::Format( SwTxtFormatInfo &rInf )
                 nDiff = rInf.Left() - rInf.First() + rInf.ForcedLeftMargin();
             }
         }
-        // <--
         // Ein Vorschlag von Juergen und Volkmar:
         // Der Textteil hinter der Numerierung sollte immer
         // mindestens beim linken Rand beginnen.
@@ -691,8 +685,8 @@ void SwNumberPortion::Paint( const SwTxtPaintInfo &rInf ) const
 
     // calculate the width of the number portion, including follows
     const KSHORT nOldWidth = Width();
-    USHORT nSumWidth = 0;
-    USHORT nOffset = 0;
+    sal_uInt16 nSumWidth = 0;
+    sal_uInt16 nOffset = 0;
 
     const SwLinePortion* pTmp = this;
     while ( pTmp && pTmp->InNumberGrp() )
@@ -771,7 +765,7 @@ void SwNumberPortion::Paint( const SwTxtPaintInfo &rInf ) const
             if( bPaintSpace && nOldWidth > nSpaceOffs )
             {
                 SwTxtPaintInfo aInf( rInf );
-static sal_Char __READONLY_DATA sDoubleSpace[] = "  ";
+static sal_Char const sDoubleSpace[] = "  ";
                 aInf.X( aInf.X() + nSpaceOffs );
 
                 // --> FME 2005-08-12 #i53199# Adjust position of underline:
@@ -798,7 +792,6 @@ static sal_Char __READONLY_DATA sDoubleSpace[] = "  ";
  *                      class SwBulletPortion
  *************************************************************************/
 
-// --> OD 2008-01-23 #newlistlevelattrs#
 SwBulletPortion::SwBulletPortion( const xub_Unicode cBullet,
                                   const XubString& rBulletFollowedBy,
                                   SwFont *pFont,
@@ -809,7 +802,6 @@ SwBulletPortion::SwBulletPortion( const xub_Unicode cBullet,
     : SwNumberPortion( XubString( rBulletFollowedBy ).Insert( cBullet, 0 ) ,
                        pFont, bLft, bCntr, nMinDst,
                        bLabelAlignmentPosAndSpaceModeActive )
-// <--
 {
     SetWhichPor( POR_BULLET );
 }
@@ -820,7 +812,6 @@ SwBulletPortion::SwBulletPortion( const xub_Unicode cBullet,
 
 #define GRFNUM_SECURE 10
 
-// --> OD 2008-01-23 #newlistlevelattrs#
 SwGrfNumPortion::SwGrfNumPortion(
         SwFrm*,
         const XubString& rGraphicFollowedBy,
@@ -830,7 +821,6 @@ SwGrfNumPortion::SwGrfNumPortion(
         const bool bLabelAlignmentPosAndSpaceModeActive ) :
     SwNumberPortion( rGraphicFollowedBy, NULL, bLft, bCntr, nMinDst,
                      bLabelAlignmentPosAndSpaceModeActive ),
-// <--
     pBrush( new SvxBrushItem(RES_BACKGROUND) ), nId( 0 )
 {
     SetWhichPor( POR_GRFNUM );
@@ -855,7 +845,7 @@ SwGrfNumPortion::SwGrfNumPortion(
         nYPos = 0;
         eOrient = text::VertOrientation::TOP;
     }
-    Width( static_cast<USHORT>(rGrfSize.Width() + 2 * GRFNUM_SECURE) );
+    Width( static_cast<sal_uInt16>(rGrfSize.Width() + 2 * GRFNUM_SECURE) );
     nFixWidth = Width();
     nGrfHeight = rGrfSize.Height() + 2 * GRFNUM_SECURE;
     Height( KSHORT(nGrfHeight) );
@@ -878,7 +868,6 @@ void SwGrfNumPortion::StopAnimation( OutputDevice* pOut )
 sal_Bool SwGrfNumPortion::Format( SwTxtFormatInfo &rInf )
 {
     SetHide( sal_False );
-    // --> OD 2008-01-29 #newlistlevelattrs#
 //    Width( nFixWidth );
     KSHORT nFollowedByWidth( 0 );
     if ( mbLabelAlignmentPosAndSpaceModeActive )
@@ -892,7 +881,7 @@ sal_Bool SwGrfNumPortion::Format( SwTxtFormatInfo &rInf )
     const sal_Bool bFull = rInf.Width() < rInf.X() + Width();
     const sal_Bool bFly = rInf.GetFly() ||
         ( rInf.GetLast() && rInf.GetLast()->IsFlyPortion() );
-    SetAscent( static_cast<USHORT>(GetRelPos() > 0 ? GetRelPos() : 0) );
+    SetAscent( static_cast<sal_uInt16>(GetRelPos() > 0 ? GetRelPos() : 0) );
     if( GetAscent() > Height() )
         Height( GetAscent() );
 
@@ -908,7 +897,6 @@ sal_Bool SwGrfNumPortion::Format( SwTxtFormatInfo &rInf )
         }
     }
     rInf.SetNumDone( sal_True );
-    // --> OD 2008-01-23 #newlistlevelattrs#
 //    long nDiff = rInf.Left() - rInf.First() + rInf.ForcedLeftMargin();
     long nDiff = mbLabelAlignmentPosAndSpaceModeActive
                  ? 0
@@ -958,11 +946,9 @@ void SwGrfNumPortion::Paint( const SwTxtPaintInfo &rInf ) const
     long nTmpWidth = Max( (long)0, (long)(nFixWidth - 2 * GRFNUM_SECURE) );
     Size aSize( nTmpWidth, GetGrfHeight() - 2 * GRFNUM_SECURE );
 
-    // --> OD 2008-02-05 #newlistlevelattrs#
     const sal_Bool bTmpLeft = mbLabelAlignmentPosAndSpaceModeActive ||
                               ( IsLeft() && ! rInf.GetTxtFrm()->IsRightToLeft() ) ||
                               ( ! IsLeft() && ! IsCenter() && rInf.GetTxtFrm()->IsRightToLeft() );
-    // <--
 
     if( nFixWidth < Width() && !bTmpLeft )
     {
@@ -1011,7 +997,7 @@ void SwGrfNumPortion::Paint( const SwTxtPaintInfo &rInf ) const
                 pViewShell && pViewShell->GetWin()  )
             {
                 ( (Graphic*) pBrush->GetGraphic() )->StopAnimation(0,nId);
-                rInf.GetTxtFrm()->GetShell()->InvalidateWindows( aTmp );
+                rInf.GetTxtFrm()->getRootFrm()->GetCurrShell()->InvalidateWindows( aTmp );
             }
 
 
@@ -1130,10 +1116,10 @@ SwCombinedPortion::SwCombinedPortion( const XubString &rTxt )
     // the arrays of width and position are filled by the format function
     if(	pBreakIt->GetBreakIter().is() )
     {
-        BYTE nScr = SW_SCRIPTS;
-        for( USHORT i = 0; i < rTxt.Len(); ++i )
+        sal_uInt8 nScr = SW_SCRIPTS;
+        for( sal_uInt16 i = 0; i < rTxt.Len(); ++i )
         {
-            USHORT nScript = pBreakIt->GetBreakIter()->getScriptType( rTxt, i );
+            sal_uInt16 nScript = pBreakIt->GetBreakIter()->getScriptType( rTxt, i );
             switch ( nScript ) {
                 case i18n::ScriptType::LATIN : nScr = SW_LATIN; break;
                 case i18n::ScriptType::ASIAN : nScr = SW_CJK; break;
@@ -1144,7 +1130,7 @@ SwCombinedPortion::SwCombinedPortion( const XubString &rTxt )
     }
     else
     {
-        for( USHORT i = 0; i < 6; aScrType[i++] = 0 )
+        for( sal_uInt16 i = 0; i < 6; aScrType[i++] = 0 )
             ; // nothing
     }
     memset( &aWidth, 0, sizeof(aWidth) );
@@ -1166,19 +1152,19 @@ void SwCombinedPortion::Paint( const SwTxtPaintInfo &rInf ) const
         if( rInf.OnWin() && pPortion && !pPortion->Width() )
             pPortion->PrePaint( rInf, this );
 
-        USHORT nCount = aExpand.Len();
+        sal_uInt16 nCount = aExpand.Len();
         if( !nCount )
             return;
         OSL_ENSURE( nCount < 7, "Too much combined characters" );
 
         // the first character of the second row
-        USHORT nTop = ( nCount + 1 ) / 2;
+        sal_uInt16 nTop = ( nCount + 1 ) / 2;
 
         SwFont aTmpFont( *rInf.GetFont() );
         aTmpFont.SetProportion( nProportion );	// a smaller font
         SwFontSave aFontSave( rInf, &aTmpFont );
 
-        USHORT i = 0;
+        sal_uInt16 i = 0;
         Point aOldPos = rInf.GetPos();
         Point aOutPos( aOldPos.X(), aOldPos.Y() - nUpPos );// Y of the first row
         while( i < nCount )
@@ -1186,7 +1172,7 @@ void SwCombinedPortion::Paint( const SwTxtPaintInfo &rInf ) const
             if( i == nTop ) // change the row
                 aOutPos.Y() = aOldPos.Y() + nLowPos;	// Y of the second row
             aOutPos.X() = aOldPos.X() + aPos[i];		// X position
-            const BYTE nAct = aScrType[i];				// script type
+            const sal_uInt8 nAct = aScrType[i];				// script type
             aTmpFont.SetActual( nAct );
             // if there're more than 4 characters to display, we choose fonts
             // with 2/3 of the original font width.
@@ -1214,7 +1200,7 @@ void SwCombinedPortion::Paint( const SwTxtPaintInfo &rInf ) const
 
 sal_Bool SwCombinedPortion::Format( SwTxtFormatInfo &rInf )
 {
-    USHORT nCount = aExpand.Len();
+    sal_uInt16 nCount = aExpand.Len();
     if( !nCount )
     {
         Width( 0 );
@@ -1224,7 +1210,7 @@ sal_Bool SwCombinedPortion::Format( SwTxtFormatInfo &rInf )
     OSL_ENSURE( nCount < 7, "Too much combined characters" );
     // If there are leading "weak"-scripttyped characters in this portion,
     // they get the actual scripttype.
-    USHORT i = 0;
+    sal_uInt16 i = 0;
     while( i < nCount && SW_SCRIPTS == aScrType[i] )
         aScrType[i++] = rInf.GetFont()->GetActual();
     if( nCount > 4 )
@@ -1238,22 +1224,22 @@ sal_Bool SwCombinedPortion::Format( SwTxtFormatInfo &rInf )
             {
                 rInf.GetOut()->SetFont( rInf.GetFont()->GetFnt( aScrType[i] ) );
                 aWidth[ aScrType[i] ] =
-                        static_cast<USHORT>(2 * rInf.GetOut()->GetFontMetric().GetSize().Width() / 3);
+                        static_cast<sal_uInt16>(2 * rInf.GetOut()->GetFontMetric().GetSize().Width() / 3);
             }
             ++i;
         }
     }
 
-    USHORT nTop = ( nCount + 1 ) / 2; // the first character of the second line
-    ViewShell *pSh = rInf.GetTxtFrm()->GetShell();
+    sal_uInt16 nTop = ( nCount + 1 ) / 2; // the first character of the second line
+    ViewShell *pSh = rInf.GetTxtFrm()->getRootFrm()->GetCurrShell();
     SwFont aTmpFont( *rInf.GetFont() );
     SwFontSave aFontSave( rInf, &aTmpFont );
     nProportion = 55;
     // In nMainAscent/Descent we store the ascent and descent
     // of the original surrounding font
-    USHORT nMaxDescent, nMaxAscent, nMaxWidth;
-    USHORT nMainDescent = rInf.GetFont()->GetHeight( pSh, *rInf.GetOut() );
-    const USHORT nMainAscent = rInf.GetFont()->GetAscent( pSh, *rInf.GetOut() );
+    sal_uInt16 nMaxDescent, nMaxAscent, nMaxWidth;
+    sal_uInt16 nMainDescent = rInf.GetFont()->GetHeight( pSh, *rInf.GetOut() );
+    const sal_uInt16 nMainAscent = rInf.GetFont()->GetAscent( pSh, *rInf.GetOut() );
     nMainDescent = nMainDescent - nMainAscent;
     // we start with a 50% font, but if we notice that the combined portion
     // becomes bigger than the surrounding font, we check 45% and maybe 40%.
@@ -1275,7 +1261,7 @@ sal_Bool SwCombinedPortion::Format( SwTxtFormatInfo &rInf )
         // local nMaxAscent, nMaxDescent and nMaxWidth variables.
         while( i < nCount )
         {
-            BYTE nScrp = aScrType[i];
+            sal_uInt8 nScrp = aScrType[i];
             aTmpFont.SetActual( nScrp );
             if( aWidth[ nScrp ] )
             {
@@ -1286,8 +1272,8 @@ sal_Bool SwCombinedPortion::Format( SwTxtFormatInfo &rInf )
 
             SwDrawTextInfo aDrawInf( pSh, *rInf.GetOut(), 0, aExpand, i, 1 );
             Size aSize = aTmpFont._GetTxtSize( aDrawInf );
-            USHORT nAsc = aTmpFont.GetAscent( pSh, *rInf.GetOut() );
-            aPos[ i ] = (USHORT)aSize.Width();
+            sal_uInt16 nAsc = aTmpFont.GetAscent( pSh, *rInf.GetOut() );
+            aPos[ i ] = (sal_uInt16)aSize.Width();
             if( i == nTop ) // enter the second line
             {
                 nLowPos = nMaxDescent;
@@ -1302,7 +1288,7 @@ sal_Bool SwCombinedPortion::Format( SwTxtFormatInfo &rInf )
             if( nAsc > nMaxAscent )
                 nMaxAscent = nAsc;
             if( aSize.Height() - nAsc > nMaxDescent )
-                nMaxDescent = static_cast<USHORT>(aSize.Height() - nAsc);
+                nMaxDescent = static_cast<sal_uInt16>(aSize.Height() - nAsc);
         }
         // for one or two characters we double the width of the portion
         if( nCount < 3 )
@@ -1331,8 +1317,8 @@ sal_Bool SwCombinedPortion::Format( SwTxtFormatInfo &rInf )
         Height( nMainAscent + nMainDescent );
 
     // We calculate the x positions of the characters in both lines..
-    USHORT nTopDiff = 0;
-    USHORT nBotDiff = 0;
+    sal_uInt16 nTopDiff = 0;
+    sal_uInt16 nBotDiff = 0;
     if( nMaxWidth > Width() )
     {
         nTopDiff = ( nMaxWidth - Width() ) / 2;
@@ -1361,7 +1347,7 @@ sal_Bool SwCombinedPortion::Format( SwTxtFormatInfo &rInf )
     {
         if( rInf.GetLineStart() == rInf.GetIdx() &&	(!rInf.GetLast()->InFldGrp()
             || !((SwFldPortion*)rInf.GetLast())->IsFollow() ) )
-            Width( (USHORT)( rInf.Width() - rInf.X() ) );
+            Width( (sal_uInt16)( rInf.Width() - rInf.X() ) );
         else
         {
             Truncate();
