@@ -45,7 +45,6 @@
 #include "flyfrm.hxx"	//IsInBody()
 #include "viewimp.hxx"
 #include "txtatr.hxx"   // SwTxtFld
-#include "txtcfg.hxx"
 #include "swfont.hxx"   // NewFldPortion, new SwFont
 #include "fntcache.hxx"   // NewFldPortion, SwFntAccess
 #include "porfld.hxx"
@@ -107,6 +106,8 @@ SwExpandPortion *SwTxtFormatter::NewFldPortion( SwTxtFormatInfo &rInf,
     }
 
     ViewShell *pSh = rInf.GetVsh();
+    SwDoc *const pDoc( (pSh) ? pSh->GetDoc() : 0 );
+    bool const bInClipboard( (pDoc) ? pDoc->IsClipBoard() : true );
     sal_Bool bPlaceHolder = sal_False;
 
     switch( pFld->GetTyp()->Which() )
@@ -118,16 +119,26 @@ SwExpandPortion *SwTxtFormatter::NewFldPortion( SwTxtFormatInfo &rInf,
 
         case RES_COMBINED_CHARS:
             {
-                String sStr( pFld->GetCntnt( bName ));
                 if( bName )
-                    pRet = new SwFldPortion( sStr );
+                {
+                    String const sName( pFld->GetFieldName() );
+                    pRet = new SwFldPortion(sName);
+                }
                 else
-                    pRet = new SwCombinedPortion( sStr );
+                {
+                    String const sContent( pFld->ExpandField(bInClipboard) );
+                    pRet = new SwCombinedPortion(sContent);
+                }
             }
             break;
 
         case RES_HIDDENTXTFLD:
-            pRet = new SwHiddenPortion(pFld->GetCntnt( bName ));
+            {
+                String const str( (bName)
+                        ? pFld->GetFieldName()
+                        : pFld->ExpandField(bInClipboard) );
+                pRet = new SwHiddenPortion(str);
+            }
             break;
 
         case RES_CHAPTERFLD:
@@ -136,25 +147,36 @@ SwExpandPortion *SwTxtFormatter::NewFldPortion( SwTxtFormatInfo &rInf,
                 ((SwChapterField*)pFld)->ChangeExpansion( pFrame,
                                         &((SwTxtFld*)pHint)->GetTxtNode() );
             }
-            pRet = new SwFldPortion( pFld->GetCntnt( bName ) );
+            {
+                String const str( (bName)
+                        ? pFld->GetFieldName()
+                        : pFld->ExpandField(bInClipboard) );
+                pRet = new SwFldPortion( str );
+            }
             break;
 
         case RES_DOCSTATFLD:
             if( !bName && pSh && !pSh->Imp()->IsUpdateExpFlds() )
+            {
                 ((SwDocStatField*)pFld)->ChangeExpansion( pFrame );
-            pRet = new SwFldPortion( pFld->GetCntnt( bName ) );
+            }
+            {
+                String const str( (bName)
+                        ? pFld->GetFieldName()
+                        : pFld->ExpandField(bInClipboard) );
+                pRet = new SwFldPortion( str );
+            }
             break;
 
         case RES_PAGENUMBERFLD:
         {
-            if( !bName && pSh && !pSh->Imp()->IsUpdateExpFlds() )
+            if( !bName && pSh && pSh->GetLayout() && !pSh->Imp()->IsUpdateExpFlds() )//swmod 080122
             {
                 SwPageNumberFieldType *pPageNr = (SwPageNumberFieldType *)pFld->GetTyp();
 
                 const SwRootFrm* pTmpRootFrm = pSh->GetLayout();
                 const sal_Bool bVirt = pTmpRootFrm->IsVirtPageNum();
 
-                SwDoc* pDoc = pSh->GetDoc();
                 MSHORT nVirtNum = pFrame->GetVirtPageNum();
                 MSHORT nNumPages = pTmpRootFrm->GetPageNum();
                 sal_Int16 nNumFmt = -1;
@@ -164,7 +186,12 @@ SwExpandPortion *SwTxtFormatter::NewFldPortion( SwTxtFormatInfo &rInf,
                 pPageNr->ChangeExpansion( pDoc, nVirtNum, nNumPages,
                                             bVirt, nNumFmt > -1 ? &nNumFmt : 0);
             }
-            pRet = new SwFldPortion( pFld->GetCntnt( bName ) );
+            {
+                String const str( (bName)
+                        ? pFld->GetFieldName()
+                        : pFld->ExpandField(bInClipboard) );
+                pRet = new SwFldPortion( str );
+            }
             break;
         }
         case RES_GETEXPFLD:
@@ -184,7 +211,12 @@ SwExpandPortion *SwTxtFormatter::NewFldPortion( SwTxtFormatInfo &rInf,
                     pExpFld->ChgBodyTxtFlag( sal_True );
                 }
             }
-            pRet = new SwFldPortion( pFld->GetCntnt( bName ) );
+            {
+                String const str( (bName)
+                        ? pFld->GetFieldName()
+                        : pFld->ExpandField(bInClipboard) );
+                pRet = new SwFldPortion( str );
+            }
             break;
         }
         case RES_DBFLD:
@@ -193,28 +225,26 @@ SwExpandPortion *SwTxtFormatter::NewFldPortion( SwTxtFormatInfo &rInf,
             {
                 SwDBField* pDBFld = (SwDBField*)pFld;
                 pDBFld->ChgBodyTxtFlag( ::lcl_IsInBody( pFrame ) );
-/* Solange das ChangeExpansion auskommentiert ist.
- * Aktualisieren in Kopf/Fuszeilen geht aktuell nicht.
-                if( !::lcl_IsInBody( pFrame ) )
-                {
-                    pDBFld->ChgBodyTxtFlag( sal_False );
-                    pDBFld->ChangeExpansion( pFrame, (SwTxtFld*)pHint );
-                }
-                else if( !pDBFld->IsInBodyTxt() )
-                {
-                    // war vorher anders, also erst expandieren, dann umsetzen!!
-                    pDBFld->ChangeExpansion( pFrame, (SwTxtFld*)pHint );
-                    pDBFld->ChgBodyTxtFlag( sal_True );
-                }
-*/
             }
-            pRet = new SwFldPortion( pFld->GetCntnt( bName ) );
+            {
+                String const str( (bName)
+                        ? pFld->GetFieldName()
+                        : pFld->ExpandField(bInClipboard) );
+                pRet = new SwFldPortion(str);
+            }
             break;
         }
         case RES_REFPAGEGETFLD:
             if( !bName && pSh && !pSh->Imp()->IsUpdateExpFlds() )
+            {
                 ((SwRefPageGetField*)pFld)->ChangeExpansion( pFrame, (SwTxtFld*)pHint );
-            pRet = new SwFldPortion( pFld->GetCntnt( bName ) );
+            }
+            {
+                String const str( (bName)
+                        ? pFld->GetFieldName()
+                        : pFld->ExpandField(bInClipboard) );
+                pRet = new SwFldPortion(str);
+            }
             break;
 
         case RES_JUMPEDITFLD:
@@ -225,9 +255,12 @@ SwExpandPortion *SwTxtFormatter::NewFldPortion( SwTxtFormatInfo &rInf,
             break;
 
         default:
-        {
-            pRet = new SwFldPortion(pFld->GetCntnt( bName ) );
-        }
+            {
+                String const str( (bName)
+                        ? pFld->GetFieldName()
+                        : pFld->ExpandField(bInClipboard) );
+                pRet = new SwFldPortion(str);
+            }
     }
 
     if( bNewFlyPor )
@@ -250,7 +283,12 @@ SwExpandPortion *SwTxtFormatter::NewFldPortion( SwTxtFormatInfo &rInf,
             else
                 pTmpFnt->SetDiffFnt( &pChFmt->GetAttrSet(), pFrm->GetTxtNode()->getIDocumentSettingAccess() );
         }
-        pRet = new SwFldPortion( pFld->GetCntnt( bName ), pTmpFnt, bPlaceHolder );
+        {
+            String const str( (bName)
+                    ? pFld->GetFieldName()
+                    : pFld->ExpandField(bInClipboard) );
+            pRet = new SwFldPortion(str, pTmpFnt, bPlaceHolder);
+        }
     }
 
     return pRet;
@@ -321,9 +359,6 @@ SwLinePortion *SwTxtFormatter::NewExtraPortion( SwTxtFormatInfo &rInf )
     SwLinePortion *pRet = 0;
     if( !pHint )
     {
-#if OSL_DEBUG_LEVEL > 1
-//        aDbstream << "NewExtraPortion: hint not found?" << endl;
-#endif
         pRet = new SwTxtPortion;
         pRet->SetLen( 1 );
         rInf.SetLen( 1 );
@@ -366,9 +401,6 @@ SwLinePortion *SwTxtFormatter::NewExtraPortion( SwTxtFormatInfo &rInf )
     }
     if( !pRet )
     {
-#if OSL_DEBUG_LEVEL > 1
-//        aDbstream << "NewExtraPortion: unknown hint" << endl;
-#endif
         const XubString aNothing;
         pRet = new SwFldPortion( aNothing );
         rInf.SetLen( 1 );
@@ -394,19 +426,16 @@ SwNumberPortion *SwTxtFormatter::NewNumberPortion( SwTxtFormatInfo &rInf ) const
     // hat ein "gueltige" Nummer ?
     if( pTxtNd->IsNumbered() && pTxtNd->IsCountedInList())
     {
-        const SwNumFmt &rNumFmt = pNumRule->Get( static_cast<USHORT>(pTxtNd->GetActualListLevel()) );
+        const SwNumFmt &rNumFmt = pNumRule->Get( static_cast<sal_uInt16>(pTxtNd->GetActualListLevel()) );
         const sal_Bool bLeft = SVX_ADJUST_LEFT == rNumFmt.GetNumAdjust();
         const sal_Bool bCenter = SVX_ADJUST_CENTER == rNumFmt.GetNumAdjust();
-        // --> OD 2008-01-23 #newlistlevelattrs#
         const bool bLabelAlignmentPosAndSpaceModeActive(
                 rNumFmt.GetPositionAndSpaceMode() == SvxNumberFormat::LABEL_ALIGNMENT );
         const KSHORT nMinDist = bLabelAlignmentPosAndSpaceModeActive
                                 ? 0 : rNumFmt.GetCharTextDistance();
-        // <--
 
         if( SVX_NUM_BITMAP == rNumFmt.GetNumberingType() )
         {
-            // --> OD 2008-01-23 #newlistlevelattrs#
             pRet = new SwGrfNumPortion( (SwFrm*)GetTxtFrm(),
                                         pTxtNd->GetLabelFollowedBy(),
                                         rNumFmt.GetBrush(),
@@ -414,7 +443,6 @@ SwNumberPortion *SwTxtFormatter::NewNumberPortion( SwTxtFormatInfo &rInf ) const
                                         rNumFmt.GetGraphicSize(),
                                         bLeft, bCenter, nMinDist,
                                         bLabelAlignmentPosAndSpaceModeActive );
-            // <--
             long nTmpA = rInf.GetLast()->GetAscent();
             long nTmpD = rInf.GetLast()->Height() - nTmpA;
             if( !rInf.IsTest() )
@@ -467,7 +495,7 @@ SwNumberPortion *SwTxtFormatter::NewNumberPortion( SwTxtFormatInfo &rInf ) const
 
                 if ( pFmtFnt )
                 {
-                    const BYTE nAct = pNumFnt->GetActual();
+                    const sal_uInt8 nAct = pNumFnt->GetActual();
                     pNumFnt->SetFamily( pFmtFnt->GetFamily(), nAct );
                     pNumFnt->SetName( pFmtFnt->GetName(), nAct );
                     pNumFnt->SetStyleName( pFmtFnt->GetStyleName(), nAct );
@@ -489,19 +517,11 @@ SwNumberPortion *SwTxtFormatter::NewNumberPortion( SwTxtFormatInfo &rInf ) const
             }
             else
             {
-                // --> OD 2006-06-02 #b6432095#
-                // use method <SwNumRule::MakeNumString(..)> instead of
-                // method <SwTxtNode::GetNumString()>, because for levels with
-                // numbering none the prefix and the suffix strings have to be provided.
-//                XubString aTxt( pTxtNd->GetNumString() );
-                XubString aTxt( pNumRule->MakeNumString( *(pTxtNd->GetNum()) ) );
-                // <--
-                // --> OD 2008-01-23 #newlistlevelattrs#
+                XubString aTxt( pTxtNd->GetNumString() );
                 if ( aTxt.Len() > 0 )
                 {
                     aTxt.Insert( pTxtNd->GetLabelFollowedBy() );
                 }
-                // <--
 
                 // 7974: Nicht nur eine Optimierung...
                 // Eine Numberportion ohne Text wird die Breite von 0
@@ -536,11 +556,9 @@ SwNumberPortion *SwTxtFormatter::NewNumberPortion( SwTxtFormatInfo &rInf ) const
                     // we do not allow a vertical font
                     pNumFnt->SetVertical( pNumFnt->GetOrientation(), pFrm->IsVertical() );
 
-                    // --> OD 2008-01-23 #newlistlevelattrs#
                     pRet = new SwNumberPortion( aTxt, pNumFnt,
                                                 bLeft, bCenter, nMinDist,
                                                 bLabelAlignmentPosAndSpaceModeActive );
-                    // <--
                 }
             }
         }
