@@ -31,6 +31,7 @@
 #include "viewsh.hxx"
 #include "doc.hxx"
 #include "pagefrm.hxx"
+#include "rootfrm.hxx"
 #include "ndtxt.hxx"
 #include "txtatr.hxx"
 #include <SwPortionHandler.hxx>
@@ -49,7 +50,6 @@
 // OD 2004-05-24 #i28701#
 #include <sortedobjs.hxx>
 
-#include "txtcfg.hxx"
 #include "swfont.hxx"	// new SwFont
 #include "porftn.hxx"
 #include "porfly.hxx"
@@ -114,7 +114,7 @@ void SwTxtFrm::CalcFtnFlag()
     if( !pHints )
         return;
 
-    const USHORT nSize = pHints->Count();
+    const sal_uInt16 nSize = pHints->Count();
 
 #if OSL_DEBUG_LEVEL > 1
     const xub_StrLen nEnd = nStop != STRING_LEN ? nStop
@@ -123,7 +123,7 @@ void SwTxtFrm::CalcFtnFlag()
     const xub_StrLen nEnd = GetFollow() ? GetFollow()->GetOfst() : STRING_LEN;
 #endif
 
-    for ( USHORT i = 0; i < nSize; ++i )
+    for ( sal_uInt16 i = 0; i < nSize; ++i )
     {
         const SwTxtAttr *pHt = (*pHints)[i];
         if ( pHt->Which() == RES_TXTATR_FTN )
@@ -224,7 +224,7 @@ SwTwips lcl_GetFtnLower( const SwTxtFrm* pFrm, SwTwips nLower )
         OSL_ENSURE( pTabFrm && pRow &&
                 pRow->GetUpper()->IsTabFrm(), "Upper of row should be tab" );
 
-        const BOOL bDontSplit = !pTabFrm->IsFollow() &&
+        const sal_Bool bDontSplit = !pTabFrm->IsFollow() &&
                                 !pTabFrm->IsLayoutSplitAllowed();
 
         SwTwips nMin = 0;
@@ -260,7 +260,7 @@ SwTwips lcl_GetFtnLower( const SwTxtFrm* pFrm, SwTwips nLower )
         if ( pStartFrm->GetDrawObjs() )
         {
             const SwSortedObjs &rObjs = *pStartFrm->GetDrawObjs();
-            for ( USHORT i = 0; i < rObjs.Count(); ++i )
+            for ( sal_uInt16 i = 0; i < rObjs.Count(); ++i )
             {
                 SwAnchoredObject* pAnchoredObj = rObjs[i];
                 SwRect aRect( pAnchoredObj->GetObjRect() );
@@ -448,7 +448,7 @@ void SwTxtFrm::RemoveFtn( const xub_StrLen nStart, const xub_StrLen nLen )
         return;
 
     sal_Bool bRollBack = nLen != STRING_LEN;
-    USHORT nSize = pHints->Count();
+    sal_uInt16 nSize = pHints->Count();
     xub_StrLen nEnd;
     SwTxtFrm* pSource;
     if( bRollBack )
@@ -472,7 +472,7 @@ void SwTxtFrm::RemoveFtn( const xub_StrLen nStart, const xub_StrLen nLen )
         SwFtnBossFrm *pEndBoss = 0;
         sal_Bool bFtnEndDoc
             = FTNPOS_CHAPTER == GetNode()->GetDoc()->GetFtnInfo().ePos;
-        for ( USHORT i = nSize; i; )
+        for ( sal_uInt16 i = nSize; i; )
         {
             SwTxtAttr *pHt = pHints->GetTextHint(--i);
             if ( RES_TXTATR_FTN != pHt->Which() )
@@ -691,7 +691,7 @@ void SwTxtFrm::ConnectFtn( SwTxtFtn *pFtn, const SwTwips nDeadLine )
         {
             if( !pSrcFrm )
             {
-                SwFtnFrm *pNew = new SwFtnFrm(pDoc->GetDfltFrmFmt(),this,pFtn);
+                SwFtnFrm *pNew = new SwFtnFrm(pDoc->GetDfltFrmFmt(),this,this,pFtn);
                  SwNodeIndex aIdx( *pFtn->GetStartNode(), 1 );
                  ::_InsertCnt( pNew, pDoc, aIdx.GetIndex() );
                 GetNode()->getIDocumentLayoutAccess()->GetLayouter()->CollectEndnote( pNew );
@@ -756,7 +756,7 @@ void SwTxtFrm::ConnectFtn( SwTxtFtn *pFtn, const SwTwips nDeadLine )
                     pBoss->RearrangeFtns( nDeadLine, sal_False, pFtn );
                     ValidateBodyFrm();
                     ValidateFrm();
-                    ViewShell *pSh = GetShell();
+                    ViewShell *pSh = getRootFrm()->GetCurrShell();
                     if ( pSh && nHeight == (pCont->Frm().*fnRect->fnGetHeight)() )
                         //Damit uns nix durch die Lappen geht.
                         pSh->InvalidateWindows( pCont->Frm() );
@@ -1158,7 +1158,7 @@ xub_StrLen SwTxtFormatter::FormatQuoVadis( const xub_StrLen nOffset )
     pQuo->SetAscent( rInf.GetAscent()  );
     pQuo->Height( rInf.GetTxtHeight() );
     pQuo->Format( rInf );
-    USHORT nQuoWidth = pQuo->Width();
+    sal_uInt16 nQuoWidth = pQuo->Width();
     SwLinePortion* pCurrPor = pQuo;
 
     while ( rInf.GetRest() )
@@ -1237,12 +1237,12 @@ xub_StrLen SwTxtFormatter::FormatQuoVadis( const xub_StrLen nOffset )
                     if( nDiff < 0 )
                     {
                         nLastLeft = pQuo->GetAscent();
-                        nQuoWidth = (USHORT)(-nDiff + nLastLeft);
+                        nQuoWidth = (sal_uInt16)(-nDiff + nLastLeft);
                     }
                     else
                     {
                         nQuoWidth = 0;
-                        nLastLeft = USHORT(( pQuo->GetAscent() + nDiff ) / 2);
+                        nLastLeft = sal_uInt16(( pQuo->GetAscent() + nDiff ) / 2);
                     }
                     break;
                 }
@@ -1329,7 +1329,7 @@ public:
     SwFtnSave( const SwTxtSizeInfo &rInf,
                const SwTxtFtn *pTxtFtn,
                const bool bApplyGivenScriptType,
-               const BYTE nGivenScriptType );
+               const sal_uInt8 nGivenScriptType );
    ~SwFtnSave();
 };
 
@@ -1340,7 +1340,7 @@ public:
 SwFtnSave::SwFtnSave( const SwTxtSizeInfo &rInf,
                       const SwTxtFtn* pTxtFtn,
                       const bool bApplyGivenScriptType,
-                      const BYTE nGivenScriptType )
+                      const sal_uInt8 nGivenScriptType )
     : pInf( &((SwTxtSizeInfo&)rInf) )
     , pFnt( 0 )
     , pOld( 0 )
@@ -1498,7 +1498,7 @@ SwPosSize SwFtnPortion::GetTxtSize( const SwTxtSizeInfo &rInfo ) const
 }
 
 // --> OD 2009-01-29 #i98418#
-void SwFtnPortion::SetPreferredScriptType( BYTE nPreferredScriptType )
+void SwFtnPortion::SetPreferredScriptType( sal_uInt8 nPreferredScriptType )
 {
     mbPreferredScriptTypeSet = true;
     mnPreferredScriptType = nPreferredScriptType;
@@ -1538,7 +1538,7 @@ sal_Bool SwQuoVadisPortion::Format( SwTxtFormatInfo &rInf )
         SetLen( 0 );
         if( bFull  )
             // dritter Versuch, es langt: jetzt wird gestaucht:
-            Width( USHORT(rInf.Width() - rInf.X()) );
+            Width( sal_uInt16(rInf.Width() - rInf.X()) );
 
         // 8317: keine mehrzeiligen Felder bei QuoVadis und ErgoSum
         if( rInf.GetRest() )
@@ -1650,7 +1650,6 @@ void SwParaPortion::SetErgoSumNum( const XubString& rErgo )
     SwLineLayout *pLay = this;
     while( pLay->GetNext() )
     {
-        DBG_LOOP;
         pLay = pLay->GetNext();
     }
     SwLinePortion	  *pPor = pLay;
@@ -1676,7 +1675,6 @@ sal_Bool SwParaPortion::UpdateQuoVadis( const XubString &rQuo )
     SwLineLayout *pLay = this;
     while( pLay->GetNext() )
     {
-        DBG_LOOP;
         pLay = pLay->GetNext();
     }
     SwLinePortion	  *pPor = pLay;
