@@ -29,13 +29,9 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
 
-
-
-
 #include <tools/resid.hxx>
 #include <hintids.hxx>
 #include <swtypes.hxx>
-#include <errhdl.hxx>
 #include <txtatr.hxx>
 #include <ndtxt.hxx>
 #include <txttxmrk.hxx>
@@ -47,13 +43,11 @@
 #include <editeng/tstpitem.hxx>
 #include <SwStyleNameMapper.hxx>
 #include <hints.hxx> // SwPtrMsgPoolItem
-
-// -> #i21237#
 #include <algorithm>
 #include <functional>
+#include <switerator.hxx>
 
 using namespace std;
-// <- #i21237#
 
 const sal_Char* SwForm::aFormEntry      = "<E>";
 const sal_Char* SwForm::aFormTab        = "<T>";
@@ -65,31 +59,28 @@ const sal_Char* SwForm::aFormEntryTxt   = "<ET>";
 const sal_Char* SwForm::aFormChapterMark= "<C>";
 const sal_Char* SwForm::aFormText       = "<X>";
 const sal_Char* SwForm::aFormAuth       = "<A>";
-BYTE SwForm::nFormTabLen            = 3;
-BYTE SwForm::nFormEntryLen          = 3;
-BYTE SwForm::nFormPageNumsLen       = 3;
-BYTE SwForm::nFormLinkSttLen        = 4;
-BYTE SwForm::nFormLinkEndLen        = 4;
-BYTE SwForm::nFormEntryNumLen       = 4;
-BYTE SwForm::nFormEntryTxtLen       = 4;
-BYTE SwForm::nFormChapterMarkLen    = 3;
-BYTE SwForm::nFormTextLen           = 3;
-BYTE SwForm::nFormAuthLen           = 5;
+sal_uInt8 SwForm::nFormTabLen            = 3;
+sal_uInt8 SwForm::nFormEntryLen          = 3;
+sal_uInt8 SwForm::nFormPageNumsLen       = 3;
+sal_uInt8 SwForm::nFormLinkSttLen        = 4;
+sal_uInt8 SwForm::nFormLinkEndLen        = 4;
+sal_uInt8 SwForm::nFormEntryNumLen       = 4;
+sal_uInt8 SwForm::nFormEntryTxtLen       = 4;
+sal_uInt8 SwForm::nFormChapterMarkLen    = 3;
+sal_uInt8 SwForm::nFormTextLen           = 3;
+sal_uInt8 SwForm::nFormAuthLen           = 5;
 
 SV_IMPL_PTRARR(SwTOXMarks, SwTOXMark*)
 
 TYPEINIT2( SwTOXMark, SfxPoolItem, SwClient );    // fuers rtti
 
-/* -----------------23.09.99 13:59-------------------
-
- --------------------------------------------------*/
 struct PatternIni
 {
-    USHORT n1;
-    USHORT n2;
-    USHORT n3;
-    USHORT n4;
-    USHORT n5;
+    sal_uInt16 n1;
+    sal_uInt16 n2;
+    sal_uInt16 n3;
+    sal_uInt16 n4;
+    sal_uInt16 n5;
 };
 const PatternIni aPatternIni[] =
 {
@@ -125,17 +116,13 @@ const PatternIni aPatternIni[] =
     {AUTH_FIELD_AUTHOR, AUTH_FIELD_TITLE, AUTH_FIELD_YEAR, USHRT_MAX, USHRT_MAX},     //AUTH_FIELD_CUSTOM5,
     {USHRT_MAX, USHRT_MAX, USHRT_MAX, USHRT_MAX, USHRT_MAX}
 };
-/* -----------------23.09.99 13:58-------------------
 
- --------------------------------------------------*/
-// -> #i21237#
-SwFormTokens lcl_GetAuthPattern(USHORT nTypeId)
+SwFormTokens lcl_GetAuthPattern(sal_uInt16 nTypeId)
 {
-    SwFormTokens aRet; // #i21237#
-
+    SwFormTokens aRet;
 
     PatternIni aIni = aPatternIni[nTypeId];
-    USHORT nVals[5];
+    sal_uInt16 nVals[5];
     nVals[0] = aIni.n1;
     nVals[1] = aIni.n2;
     nVals[2] = aIni.n3;
@@ -151,7 +138,7 @@ SwFormTokens lcl_GetAuthPattern(USHORT nTypeId)
     SwFormToken aTextToken( TOKEN_TEXT );
     aTextToken.sText = String::CreateFromAscii( ", " );
 
-    for(USHORT i = 0; i < 5 ; i++)
+    for(sal_uInt16 i = 0; i < 5 ; i++)
     {
         if(nVals[i] == USHRT_MAX)
             break;
@@ -179,8 +166,8 @@ SwTOXMark::SwTOXMark()
     , SwModify( 0 )
     ,
     pTxtAttr( 0 ),
-    bAutoGenerated(FALSE),
-    bMainEntry(FALSE)
+    bAutoGenerated(sal_False),
+    bMainEntry(sal_False)
 {
 }
 
@@ -190,15 +177,15 @@ SwTOXMark::SwTOXMark( const SwTOXType* pTyp )
     , SwModify( const_cast<SwTOXType*>(pTyp) )
     ,
     pTxtAttr( 0 ), nLevel( 0 ),
-    bAutoGenerated(FALSE),
-    bMainEntry(FALSE)
+    bAutoGenerated(sal_False),
+    bMainEntry(sal_False)
 {
 }
 
 
 SwTOXMark::SwTOXMark( const SwTOXMark& rCopy )
     : SfxPoolItem( RES_TXTATR_TOXMARK )
-    , SwModify(rCopy.pRegisteredIn)
+    , SwModify(rCopy.GetRegisteredInNonConst())
     ,
     aPrimaryKey( rCopy.aPrimaryKey ), aSecondaryKey( rCopy.aSecondaryKey ),
     aTextReading( rCopy.aTextReading ),
@@ -218,6 +205,11 @@ SwTOXMark::~SwTOXMark()
 }
 
 
+void SwTOXMark::RegisterToTOXType( SwTOXType& rMark )
+{ 
+    rMark.Add(this); 
+}
+
 int SwTOXMark::operator==( const SfxPoolItem& rAttr ) const
 {
     OSL_ENSURE( SfxPoolItem::operator==( rAttr ), "keine gleichen Attribute" );
@@ -230,9 +222,9 @@ SfxPoolItem* SwTOXMark::Clone( SfxItemPool* ) const
     return new SwTOXMark( *this );
 }
 
-void SwTOXMark::Modify(SfxPoolItem* pOld, SfxPoolItem* pNew)
+void SwTOXMark::Modify( const SfxPoolItem* pOld, const SfxPoolItem* pNew)
 {
-    SwModify::Modify(pOld, pNew);
+    NotifyClients(pOld, pNew);
     if (pOld && (RES_REMOVE_UNO_OBJECT == pOld->Which()))
     {   // invalidate cached uno object
         SetXTOXMark(::com::sun::star::uno::Reference<
@@ -244,7 +236,7 @@ void SwTOXMark::InvalidateTOXMark()
 {
     SwPtrMsgPoolItem aMsgHint( RES_REMOVE_UNO_OBJECT,
         &static_cast<SwModify&>(*this) ); // cast to base class!
-    Modify(&aMsgHint, &aMsgHint);
+    NotifyClients(&aMsgHint, &aMsgHint);
 }
 
 String SwTOXMark::GetText() const
@@ -265,6 +257,18 @@ String SwTOXMark::GetText() const
     return aStr;
 }
 
+void SwTOXMark::InsertTOXMarks( SwTOXMarks& aMarks, const SwTOXType& rType )
+{
+    SwIterator<SwTOXMark,SwTOXType> aIter(rType);
+    SwTOXMark* pMark = aIter.First();
+    while( pMark )
+    {
+        if(pMark->GetTxtTOXMark())
+            aMarks.C40_INSERT(SwTOXMark, pMark, aMarks.Count());
+        pMark = aIter.Next();
+    }
+}
+
 /*--------------------------------------------------------------------
      Beschreibung: Typen von Verzeichnissen verwalten
  --------------------------------------------------------------------*/
@@ -291,18 +295,18 @@ SwTOXType::SwTOXType(const SwTOXType& rCopy)
 SwForm::SwForm( TOXTypes eTyp ) // #i21237#
     : eType( eTyp ), nFormMaxLevel( SwForm::GetFormMaxLevel( eTyp )),
 //  nFirstTabPos( lNumIndent ),
-    bCommaSeparated(FALSE)
+    bCommaSeparated(sal_False)
 {
     //bHasFirstTabPos =
-    bGenerateTabPos = FALSE;
-    bIsRelTabPos = TRUE;
+    bGenerateTabPos = sal_False;
+    bIsRelTabPos = sal_True;
 
     // Inhaltsverzeichnis hat entsprechend Anzahl Headlines + Ueberschrift
     // Benutzer hat 10 Ebenen + Ueberschrift
     // Stichwort hat 3 Ebenen + Ueberschrift + Trenner
     // indexes of tables, objects illustrations and authorities consist of a heading and one level
 
-    USHORT nPoolId;
+    sal_uInt16 nPoolId;
     switch( eType )
     {
     case TOX_INDEX:         nPoolId = STR_POOLCOLL_TOX_IDXH;    break;
@@ -344,7 +348,7 @@ SwForm::SwForm( TOXTypes eTyp ) // #i21237#
 
     if(TOX_INDEX == eType)
     {
-        for( USHORT i = 1; i < 5; ++i  )
+        for( sal_uInt16 i = 1; i < 5; ++i  )
         {
             if(1 == i)
             {
@@ -363,7 +367,7 @@ SwForm::SwForm( TOXTypes eTyp ) // #i21237#
         }
     }
     else
-        for( USHORT i = 1; i < GetFormMax(); ++i, ++nPoolId )    // Nr 0 ist der Titel
+        for( sal_uInt16 i = 1; i < GetFormMax(); ++i, ++nPoolId )    // Nr 0 ist der Titel
         {
             if(TOX_AUTHORITIES == eType)
                 SetPattern(i, lcl_GetAuthPattern(i));
@@ -397,7 +401,7 @@ SwForm& SwForm::operator=(const SwForm& rForm)
     bGenerateTabPos = rForm.bGenerateTabPos;
     bIsRelTabPos = rForm.bIsRelTabPos;
     bCommaSeparated = rForm.bCommaSeparated;
-    for(USHORT i=0; i < nFormMaxLevel; ++i)
+    for(sal_uInt16 i=0; i < nFormMaxLevel; ++i)
     {
         aPattern[i] = rForm.aPattern[i];
         aTemplate[i] = rForm.aTemplate[i];
@@ -405,9 +409,9 @@ SwForm& SwForm::operator=(const SwForm& rForm)
     return *this;
 }
 
-USHORT SwForm::GetFormMaxLevel( TOXTypes eTOXType )
+sal_uInt16 SwForm::GetFormMaxLevel( TOXTypes eTOXType )
 {
-    USHORT nRet = 0;
+    sal_uInt16 nRet = 0;
     switch( eTOXType )
     {
         case TOX_INDEX:         nRet = 5;                   break;
@@ -428,34 +432,34 @@ bool operator == (const SwFormToken & rToken, FormTokenType eType)
 }
 
 //-----------------------------------------------------------------------------
-void SwForm::AdjustTabStops(SwDoc& rDoc, BOOL bInsertNewTapStops) // #i21237#
+void SwForm::AdjustTabStops(SwDoc& rDoc, sal_Bool bInsertNewTapStops) // #i21237#
 {
-    for(USHORT nLevel = 1; nLevel < GetFormMax(); nLevel++)
+    for(sal_uInt16 nLevel = 1; nLevel < GetFormMax(); nLevel++)
     {
         const String& sTemplateName = GetTemplate(nLevel);
 
         SwTxtFmtColl* pColl = rDoc.FindTxtFmtCollByName( sTemplateName );
         if( !pColl )
         {
-            USHORT nId = SwStyleNameMapper::GetPoolIdFromUIName
+            sal_uInt16 nId = SwStyleNameMapper::GetPoolIdFromUIName
                 ( sTemplateName, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL ); // #i21237#
             if( USHRT_MAX != nId )
                 pColl = rDoc.GetTxtCollFromPool( nId );
         }
 
         const SvxTabStopItem* pTabStops = 0;
-        USHORT nTabCount = 0;
+        sal_uInt16 nTabCount = 0;
         if( pColl &&
-            0 != ( pTabStops = &pColl->GetTabStops(FALSE) ) &&
+            0 != ( pTabStops = &pColl->GetTabStops(sal_False) ) &&
             0 != ( nTabCount = pTabStops->Count() ) )
         {
             // #i21237#
             SwFormTokens aCurrentPattern = GetPattern(nLevel);
             SwFormTokens::iterator aIt = aCurrentPattern.begin();
 
-            BOOL bChanged = FALSE;
+            sal_Bool bChanged = sal_False;
 
-            for(USHORT nTab = 0; nTab < nTabCount; ++nTab)
+            for(sal_uInt16 nTab = 0; nTab < nTabCount; ++nTab)
             {
                 const SvxTabStop& rTab = (*pTabStops)[nTab];
 
@@ -466,9 +470,9 @@ void SwForm::AdjustTabStops(SwDoc& rDoc, BOOL bInsertNewTapStops) // #i21237#
                 {
                     if ( SVX_TAB_ADJUST_DEFAULT != rTab.GetAdjustment() )
                     {
-                        bChanged = TRUE;
+                        bChanged = sal_True;
                         SwFormToken aToken(TOKEN_TAB_STOP);
-                        aToken.bWithTab = FALSE;
+                        aToken.bWithTab = sal_False;
                         aToken.nTabStopPosition = rTab.GetTabPos();
                         aToken.eTabAlign = rTab.GetAdjustment();
                         aToken.cTabFillChar = rTab.GetFill();
@@ -483,7 +487,7 @@ void SwForm::AdjustTabStops(SwDoc& rDoc, BOOL bInsertNewTapStops) // #i21237#
                                   (TOKEN_TAB_STOP));
                     if ( aIt != aCurrentPattern.end() )
                     {
-                        bChanged = TRUE;
+                        bChanged = sal_True;
                         aIt->nTabStopPosition = rTab.GetTabPos();
                         aIt->eTabAlign = nTab == nTabCount - 1 &&
                                          SVX_TAB_ADJUST_RIGHT == rTab.GetAdjustment() ?
@@ -509,7 +513,7 @@ void SwForm::AdjustTabStops(SwDoc& rDoc, BOOL bInsertNewTapStops) // #i21237#
 
 
 SwTOXBase::SwTOXBase(const SwTOXType* pTyp, const SwForm& rForm,
-                     USHORT nCreaType, const String& rTitle )
+                     sal_uInt16 nCreaType, const String& rTitle )
     : SwClient((SwModify*)pTyp),
     aForm(rForm),
     aTitle(rTitle),
@@ -517,21 +521,26 @@ SwTOXBase::SwTOXBase(const SwTOXType* pTyp, const SwForm& rForm,
     nCreateType(nCreaType),
     nOLEOptions(0),
     eCaptionDisplay(CAPTION_COMPLETE),
-    bProtected( TRUE ),
-    bFromChapter(FALSE),
-    bFromObjectNames(FALSE),
-    bLevelFromChapter(FALSE)
+    bProtected( sal_True ),
+    bFromChapter(sal_False),
+    bFromObjectNames(sal_False),
+    bLevelFromChapter(sal_False)
 {
     aData.nOptions = 0;
 }
 
 
 SwTOXBase::SwTOXBase( const SwTOXBase& rSource, SwDoc* pDoc )
-    : SwClient( rSource.pRegisteredIn )
+    : SwClient( rSource.GetRegisteredInNonConst() )
 {
     CopyTOXBase( pDoc, rSource );
 }
 
+void SwTOXBase::RegisterToTOXType( SwTOXType& rType )
+{
+    rType.Add( this );
+}
+
 SwTOXBase& SwTOXBase::CopyTOXBase( SwDoc* pDoc, const SwTOXBase& rSource )
 {
     SwTOXType* pType = (SwTOXType*)rSource.GetTOXType();
@@ -539,15 +548,15 @@ SwTOXBase& SwTOXBase::CopyTOXBase( SwDoc* pDoc, const SwTOXBase& rSource )
     {
         // type not in pDoc, so create it now
         const SwTOXTypes& rTypes = pDoc->GetTOXTypes();
-        BOOL bFound = FALSE;
-        for( USHORT n = rTypes.Count(); n; )
+        sal_Bool bFound = sal_False;
+        for( sal_uInt16 n = rTypes.Count(); n; )
         {
             const SwTOXType* pCmp = rTypes[ --n ];
             if( pCmp->GetType() == pType->GetType() &&
                 pCmp->GetTypeName() == pType->GetTypeName() )
             {
                 pType = (SwTOXType*)pCmp;
-                bFound = TRUE;
+                bFound = sal_True;
                 break;
             }
         }
@@ -570,7 +579,7 @@ SwTOXBase& SwTOXBase::CopyTOXBase( SwDoc* pDoc, const SwTOXBase& rSource )
     eLanguage = rSource.eLanguage;
     sSortAlgorithm = rSource.sSortAlgorithm;
 
-    for( USHORT i = 0; i < MAXLEVEL; ++i )
+    for( sal_uInt16 i = 0; i < MAXLEVEL; ++i )
         aStyleNames[i] = rSource.aStyleNames[i];
 
     // its the same data type!
@@ -607,7 +616,7 @@ SwTOXBase & SwTOXBase::operator = (const SwTOXBase & rSource)
     aName = rSource.aName;
     aTitle = rSource.aTitle;
     sMainEntryCharStyle = rSource.sMainEntryCharStyle;
-    for(USHORT nLevel = 0; nLevel < MAXLEVEL; nLevel++)
+    for(sal_uInt16 nLevel = 0; nLevel < MAXLEVEL; nLevel++)
         aStyleNames[nLevel] = rSource.aStyleNames[nLevel];
     sSequenceName = rSource.sSequenceName;
     eLanguage = rSource.eLanguage;
@@ -627,39 +636,11 @@ SwTOXBase & SwTOXBase::operator = (const SwTOXBase & rSource)
     return *this;
 }
 
-/* -----------------16.07.99 16:02-------------------
-
-SwTOXBase & SwTOXBase::operator = (const SwTOXBase & rSource)
-{
-    aForm = rSource.aForm;
-    aName = rSource.aName;
-    aTitle = rSource.aTitle;
-    sMainEntryCharStyle = rSource.sMainEntryCharStyle;
-    sSequenceName = rSource.sSequenceName;
-    eLanguage = rSource.eLanguage;
-    sSortAlgorithm = rSource.sSortAlgorithm;
-    aData = rSource.aData;
-    nCreateType = rSource.nCreateType;
-    nOLEOptions = rSource.nOLEOptions;
-    eCaptionDisplay = rSource.eCaptionDisplay;
-    bProtected = rSource.bProtected;
-    bFromChapter = rSource.bFromChapter;
-    bFromObjectNames = rSource.bFromObjectNames;
-    bLevelFromChapter = rSource.bLevelFromChapter;
-
-    if (rSource.GetAttrSet())
-        SetAttrSet(*rSource.GetAttrSet());
-
-    return *this;
-}
-
- --------------------------------------------------*/
-
 String SwFormToken::GetString() const
 {
     String sRet;
 
-    BOOL bAppend = TRUE;
+    sal_Bool bAppend = sal_True;
     switch( eTokenType )
     {
         case TOKEN_ENTRY_NO:
@@ -738,7 +719,7 @@ String SwFormToken::GetString() const
             sRet += TOX_STYLE_DELIMITER;
         }
         else
-            bAppend = FALSE;
+            bAppend = sal_False;
     }
     else if(TOKEN_ENTRY_NO == eTokenType)
     {
@@ -795,16 +776,16 @@ SwFormToken SwFormTokensHelper::BuildToken( const String & sPattern,
     eRet.sCharStyleName = sToken.GetToken( 0, ',');
     String sTmp( sToken.GetToken( 1, ',' ));
     if( sTmp.Len() )
-        eRet.nPoolId = static_cast<USHORT>(sTmp.ToInt32());
+        eRet.nPoolId = static_cast<sal_uInt16>(sTmp.ToInt32());
 
     switch( eTokenType )
     {
 //i53420
     case TOKEN_ENTRY_NO:
         if( (sTmp = sToken.GetToken( 2, ',' ) ).Len() )
-            eRet.nChapterFormat = static_cast<USHORT>(sTmp.ToInt32());
+            eRet.nChapterFormat = static_cast<sal_uInt16>(sTmp.ToInt32());
         if( (sTmp = sToken.GetToken( 3, ',' ) ).Len() )
-            eRet.nOutlineLevel = static_cast<USHORT>(sTmp.ToInt32()); //the maximum outline level to examine
+            eRet.nOutlineLevel = static_cast<sal_uInt16>(sTmp.ToInt32()); //the maximum outline level to examine
         break;
 
     case TOKEN_TEXT:
@@ -839,15 +820,15 @@ SwFormToken SwFormTokensHelper::BuildToken( const String & sPattern,
 
     case TOKEN_CHAPTER_INFO:
         if( (sTmp = sToken.GetToken( 2, ',' ) ).Len() )
-            eRet.nChapterFormat = static_cast<USHORT>(sTmp.ToInt32()); //SwChapterFormat;
+            eRet.nChapterFormat = static_cast<sal_uInt16>(sTmp.ToInt32()); //SwChapterFormat;
  //i53420
         if( (sTmp = sToken.GetToken( 3, ',' ) ).Len() )
-            eRet.nOutlineLevel = static_cast<USHORT>(sTmp.ToInt32()); //the maximum outline level to examine
+            eRet.nOutlineLevel = static_cast<sal_uInt16>(sTmp.ToInt32()); //the maximum outline level to examine
 
         break;
 
     case TOKEN_AUTHORITY:
-        eRet.nAuthorityField = static_cast<USHORT>(sAuthFieldEnum.ToInt32());
+        eRet.nAuthorityField = static_cast<sal_uInt16>(sAuthFieldEnum.ToInt32());
         break;
     default: break;
     }
@@ -858,7 +839,7 @@ String SwFormTokensHelper::SearchNextToken( const String & sPattern,
                                             xub_StrLen nStt ) const
 {
     //it's not so easy - it doesn't work if the text part contains a '>'
-    //USHORT nTokenEnd = sPattern.Search('>');
+    //sal_uInt16 nTokenEnd = sPattern.Search('>');
 
     String aResult;
 
@@ -893,10 +874,10 @@ FormTokenType SwFormTokensHelper::GetTokenType(const String & sToken,
     static struct
     {
         const sal_Char* pNm;
-        USHORT nLen;
-        USHORT nOffset;
+        sal_uInt16 nLen;
+        sal_uInt16 nOffset;
         FormTokenType eToken;
-    } __READONLY_DATA aTokenArr[] = {
+    } const aTokenArr[] = {
         { SwForm::aFormTab,       SwForm::nFormEntryLen,      1, TOKEN_TAB_STOP },
         { SwForm::aFormPageNums,  SwForm::nFormPageNumsLen,   1, TOKEN_PAGE_NUMS },
         { SwForm::aFormLinkStt,   SwForm::nFormLinkSttLen,    1, TOKEN_LINK_START },
@@ -931,13 +912,13 @@ FormTokenType SwFormTokensHelper::GetTokenType(const String & sToken,
 
 // <- #i21237#
 
-void SwForm::SetPattern(USHORT nLevel, const SwFormTokens& rTokens)
+void SwForm::SetPattern(sal_uInt16 nLevel, const SwFormTokens& rTokens)
 {
     OSL_ENSURE(nLevel < GetFormMax(), "Index >= FORM_MAX");
     aPattern[nLevel] = rTokens;
 }
 
-void SwForm::SetPattern(USHORT nLevel, const String & rStr)
+void SwForm::SetPattern(sal_uInt16 nLevel, const String & rStr)
 {
     OSL_ENSURE(nLevel < GetFormMax(), "Index >= FORM_MAX");
 
@@ -945,7 +926,7 @@ void SwForm::SetPattern(USHORT nLevel, const String & rStr)
     aPattern[nLevel] = aHelper.GetTokens();
 }
 
-const SwFormTokens& SwForm::GetPattern(USHORT nLevel) const
+const SwFormTokens& SwForm::GetPattern(sal_uInt16 nLevel) const
 {
     OSL_ENSURE(nLevel < GetFormMax(), "Index >= FORM_MAX");
     return aPattern[nLevel];
