@@ -29,25 +29,31 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
 
+#include <UndoDraw.hxx>
+
 #include <rtl/string.h>
 #include <rtl/memory.h>
-#include <hintids.hxx>
 
+#include <rtl/string.h>
 #include <svx/svdogrp.hxx>
 #include <svx/svdundo.hxx>
 #include <svx/svdpage.hxx>
 #include <svx/svdmark.hxx>
+
+#include <hintids.hxx>
+#include <hints.hxx>
 #include <fmtanchr.hxx>
 #include <fmtflcnt.hxx>
 #include <txtflcnt.hxx>
 #include <frmfmt.hxx>
 #include <doc.hxx>
+#include <IDocumentUndoRedo.hxx>
 #include <docary.hxx>
 #include <frame.hxx>
 #include <swundo.hxx>			// fuer die UndoIds
 #include <pam.hxx>
 #include <ndtxt.hxx>
-#include <undobj.hxx>
+#include <UndoCore.hxx>
 #include <dcontact.hxx>
 #include <dview.hxx>
 #include <rootfrm.hxx>
@@ -58,34 +64,29 @@ struct SwUndoGroupObjImpl
 {
     SwDrawFrmFmt* pFmt;
     SdrObject* pObj;
-    ULONG nNodeIdx;
-
-    // OD 2004-04-15 #i26791# - keeping the anchor and the relative position
-    // of drawing objects no longer needed
+    sal_uLong nNodeIdx;
 };
 
 
-inline SwDoc& SwUndoIter::GetDoc() const { return *pAktPam->GetDoc(); }
-
 // Draw-Objecte
 
 IMPL_LINK( SwDoc, AddDrawUndo, SdrUndoAction *, pUndo )
 {
 #if OSL_DEBUG_LEVEL > 1
-    USHORT nId = pUndo->GetId();
+    sal_uInt16 nId = pUndo->GetId();
     (void)nId;
     String sComment( pUndo->GetComment() );
 #endif
 
-    if( DoesUndo() && !IsNoDrawUndoObj() )
+    if (GetIDocumentUndoRedo().DoesUndo() &&
+        GetIDocumentUndoRedo().DoesDrawUndo())
     {
-        ClearRedo();
         const SdrMarkList* pMarkList = 0;
-        ViewShell* pSh = GetRootFrm() ? GetRootFrm()->GetCurrShell() : 0;
+        ViewShell* pSh = GetCurrentViewShell();
         if( pSh && pSh->HasDrawView() )
             pMarkList = &pSh->GetDrawView()->GetMarkedObjectList();
 
-        AppendUndo( new SwSdrUndo( pUndo, pMarkList ) );
+        GetIDocumentUndoRedo().AppendUndo( new SwSdrUndo(pUndo, pMarkList) );
     }
     else
         delete pUndo;
@@ -107,16 +108,16 @@ SwSdrUndo::~SwSdrUndo()
     delete pMarkList;
 }
 
-void SwSdrUndo::Undo( SwUndoIter& rUndoIter )
+void SwSdrUndo::UndoImpl(::sw::UndoRedoContext & rContext)
 {
     pSdrUndo->Undo();
-    rUndoIter.pMarkList = pMarkList;
+    rContext.SetSelections(0, pMarkList);
 }
 
-void SwSdrUndo::Redo( SwUndoIter& rUndoIter )
+void SwSdrUndo::RedoImpl(::sw::UndoRedoContext & rContext)
 {
     pSdrUndo->Redo();
-    rUndoIter.pMarkList = pMarkList;
+    rContext.SetSelections(0, pMarkList);
 }
 
 String SwSdrUndo::GetComment() const
@@ -129,10 +130,10 @@ String SwSdrUndo::GetComment() const
 void lcl_SendRemoveToUno( SwFmt& rFmt )
 {
     SwPtrMsgPoolItem aMsgHint( RES_REMOVE_UNO_OBJECT, &rFmt );
-    rFmt.Modify( &aMsgHint, &aMsgHint );
+    rFmt.ModifyNotification( &aMsgHint, &aMsgHint );
 }
 
-void lcl_SaveAnchor( SwFrmFmt* pFmt, ULONG& rNodePos )
+void lcl_SaveAnchor( SwFrmFmt* pFmt, sal_uLong& rNodePos )
 {
     const SwFmtAnchor& rAnchor = pFmt->GetAnchor();
     if ((FLY_AT_PARA == rAnchor.GetAnchorId()) ||
@@ -147,15 +148,15 @@ void lcl_SaveAnchor( SwFrmFmt* pFmt, ULONG& rNodePos )
         {
             nCntntPos = rAnchor.GetCntntAnchor()->nContent.GetIndex();
 
-            // TextAttribut zerstoeren
+            // destroy TextAttribute
             SwTxtNode *pTxtNd = pFmt->GetDoc()->GetNodes()[ rNodePos ]->GetTxtNode();
-            OSL_ENSURE( pTxtNd, "Kein Textnode gefunden" );
+            OSL_ENSURE( pTxtNd, "No text node found!" );
             SwTxtFlyCnt* pAttr = static_cast<SwTxtFlyCnt*>(
                 pTxtNd->GetTxtAttrForCharAt( nCntntPos, RES_TXTATR_FLYCNT ));
-            // Attribut steht noch im TextNode, loeschen
+            // attribute still in text node, delete
             if( pAttr && pAttr->GetFlyCnt().GetFrmFmt() == pFmt )
             {
-                // Pointer auf 0, nicht loeschen
+                // just set pointer to 0, don't delete
                 ((SwFmtFlyCnt&)pAttr->GetFlyCnt()).SetFlyFmt();
                 SwIndex aIdx( pTxtNd, nCntntPos );
                 pTxtNd->EraseText( aIdx, 1 );
@@ -170,7 +171,7 @@ void lcl_SaveAnchor( SwFrmFmt* pFmt, ULONG& rNodePos )
     }
 }
 
-void lcl_RestoreAnchor( SwFrmFmt* pFmt, ULONG& rNodePos )
+void lcl_RestoreAnchor( SwFrmFmt* pFmt, sal_uLong& rNodePos )
 {
     const SwFmtAnchor& rAnchor = pFmt->GetAnchor();
     if ((FLY_AT_PARA == rAnchor.GetAnchorId()) ||
@@ -203,8 +204,8 @@ void lcl_RestoreAnchor( SwFrmFmt* pFmt, ULONG& rNodePos )
     }
 }
 
-SwUndoDrawGroup::SwUndoDrawGroup( USHORT nCnt )
-    : SwUndo( UNDO_DRAWGROUP ), nSize( nCnt + 1 ), bDelFmt( TRUE )
+SwUndoDrawGroup::SwUndoDrawGroup( sal_uInt16 nCnt )
+    : SwUndo( UNDO_DRAWGROUP ), nSize( nCnt + 1 ), bDelFmt( sal_True )
 {
     pObjArr = new SwUndoGroupObjImpl[ nSize ];
 }
@@ -214,40 +215,40 @@ SwUndoDrawGroup::~SwUndoDrawGroup()
     if( bDelFmt )
     {
         SwUndoGroupObjImpl* pTmp = pObjArr + 1;
-        for( USHORT n = 1; n < nSize; ++n, ++pTmp )
+        for( sal_uInt16 n = 1; n < nSize; ++n, ++pTmp )
             delete pTmp->pFmt;
     }
     else
-        delete pObjArr->pFmt;		// das GroupObject-Format
+        delete pObjArr->pFmt;
 
     delete [] pObjArr;
 }
 
-void SwUndoDrawGroup::Undo( SwUndoIter& )
+void SwUndoDrawGroup::UndoImpl(::sw::UndoRedoContext &)
 {
-    bDelFmt = FALSE;
+    bDelFmt = sal_False;
 
-    // das Group-Object sichern
+    // save group object 
     SwDrawFrmFmt* pFmt = pObjArr->pFmt;
     SwDrawContact* pDrawContact = (SwDrawContact*)pFmt->FindContactObj();
     SdrObject* pObj	= pDrawContact->GetMaster();
     pObjArr->pObj = pObj;
 
-    //loescht sich selbst!
+    // object will destroy itself
     pDrawContact->Changed( *pObj, SDRUSERCALL_DELETE, pObj->GetLastBoundRect() );
     pObj->SetUserCall( 0 );
 
     ::lcl_SaveAnchor( pFmt, pObjArr->nNodeIdx );
 
-    // alle Uno-Objecte sollten sich jetzt abmelden
+    // notify UNO objects to decouple
     ::lcl_SendRemoveToUno( *pFmt );
 
-    // aus dem Array austragen
+    // remove from array
     SwDoc* pDoc = pFmt->GetDoc();
     SwSpzFrmFmts& rFlyFmts = *(SwSpzFrmFmts*)pDoc->GetSpzFrmFmts();
     rFlyFmts.Remove( rFlyFmts.GetPos( pFmt ));
 
-    for( USHORT n = 1; n < nSize; ++n )
+    for( sal_uInt16 n = 1; n < nSize; ++n )
     {
         SwUndoGroupObjImpl& rSave = *( pObjArr + n );
 
@@ -258,83 +259,76 @@ void SwUndoDrawGroup::Undo( SwUndoIter& )
 
         SwDrawContact *pContact = new SwDrawContact( rSave.pFmt, pObj );
         pContact->ConnectToLayout();
-        // --> OD 2005-03-22 #i45718# - follow-up of #i35635#
-        // move object to visible layer
+        // #i45718# - follow-up of #i35635# move object to visible layer
         pContact->MoveObjToVisibleLayer( pObj );
-        // <--
-        // --> OD 2005-05-10 #i45952# - notify that position attributes
-        // are already set
+        // #i45952# - notify that position attributes are already set
         OSL_ENSURE( rSave.pFmt->ISA(SwDrawFrmFmt),
                 "<SwUndoDrawGroup::Undo(..)> - wrong type of frame format for drawing object" );
         if ( rSave.pFmt->ISA(SwDrawFrmFmt) )
         {
             static_cast<SwDrawFrmFmt*>(rSave.pFmt)->PosAttrSet();
         }
-        // <--
     }
 }
 
-void SwUndoDrawGroup::Redo( SwUndoIter& )
+void SwUndoDrawGroup::RedoImpl(::sw::UndoRedoContext &)
 {
-    bDelFmt = TRUE;
+    bDelFmt = sal_True;
 
-    // aus dem Array austragen
+    // remove from array
     SwDoc* pDoc = pObjArr->pFmt->GetDoc();
     SwSpzFrmFmts& rFlyFmts = *(SwSpzFrmFmts*)pDoc->GetSpzFrmFmts();
     SdrObject* pObj;
 
-    for( USHORT n = 1; n < nSize; ++n )
+    for( sal_uInt16 n = 1; n < nSize; ++n )
     {
         SwUndoGroupObjImpl& rSave = *( pObjArr + n );
 
         pObj = rSave.pObj;
 
         SwDrawContact *pContact = (SwDrawContact*)GetUserCall(pObj);
-        //loescht sich selbst!
+
+        // object will destroy itself
         pContact->Changed( *pObj, SDRUSERCALL_DELETE, pObj->GetLastBoundRect() );
         pObj->SetUserCall( 0 );
 
         ::lcl_SaveAnchor( rSave.pFmt, rSave.nNodeIdx );
 
-        // alle Uno-Objecte sollten sich jetzt abmelden
+        // notify UNO objects to decouple
         ::lcl_SendRemoveToUno( *rSave.pFmt );
 
         rFlyFmts.Remove( rFlyFmts.GetPos( rSave.pFmt ));
     }
 
-    // das Group-Object wieder einfuegen
+    // re-insert group object
     ::lcl_RestoreAnchor( pObjArr->pFmt, pObjArr->nNodeIdx );
     rFlyFmts.Insert( pObjArr->pFmt, rFlyFmts.Count() );
 
     SwDrawContact *pContact = new SwDrawContact( pObjArr->pFmt, pObjArr->pObj );
-    // OD 2004-04-15 #i26791# - correction: connect object to layout
+    // #i26791# - correction: connect object to layout
     pContact->ConnectToLayout();
-    // --> OD 2005-03-22 #i45718# - follow-up of #i35635#
-    // move object to visible layer
+    // #i45718# - follow-up of #i35635# move object to visible layer
     pContact->MoveObjToVisibleLayer( pObjArr->pObj );
-    // <--
-    // --> OD 2005-05-10 #i45952# - notify that position attributes
-    // are already set
+    // #i45952# - notify that position attributes are already set
     OSL_ENSURE( pObjArr->pFmt->ISA(SwDrawFrmFmt),
             "<SwUndoDrawGroup::Undo(..)> - wrong type of frame format for drawing object" );
     if ( pObjArr->pFmt->ISA(SwDrawFrmFmt) )
     {
         static_cast<SwDrawFrmFmt*>(pObjArr->pFmt)->PosAttrSet();
     }
-    // <--
 }
 
-void SwUndoDrawGroup::AddObj( USHORT nPos, SwDrawFrmFmt* pFmt, SdrObject* pObj )
+void SwUndoDrawGroup::AddObj( sal_uInt16 nPos, SwDrawFrmFmt* pFmt, SdrObject* pObj )
 {
     SwUndoGroupObjImpl& rSave = *( pObjArr + nPos + 1 );
     rSave.pObj = pObj;
     rSave.pFmt = pFmt;
     ::lcl_SaveAnchor( pFmt, rSave.nNodeIdx );
 
-    // alle Uno-Objecte sollten sich jetzt abmelden
+       // notify UNO objects to decouple
     ::lcl_SendRemoveToUno( *pFmt );
 
-    // aus dem Array austragen
+    // remove from array 
     SwSpzFrmFmts& rFlyFmts = *(SwSpzFrmFmts*)pFmt->GetDoc()->GetSpzFrmFmts();
     rFlyFmts.Remove( rFlyFmts.GetPos( pFmt ));
 }
@@ -349,9 +343,9 @@ void SwUndoDrawGroup::SetGroupFmt( SwDrawFrmFmt* pFmt )
 // ------------------------------
 
 SwUndoDrawUnGroup::SwUndoDrawUnGroup( SdrObjGroup* pObj )
-    : SwUndo( UNDO_DRAWUNGROUP ), bDelFmt( FALSE )
+    : SwUndo( UNDO_DRAWUNGROUP ), bDelFmt( sal_False )
 {
-    nSize = (USHORT)pObj->GetSubList()->GetObjCount() + 1;
+    nSize = (sal_uInt16)pObj->GetSubList()->GetObjCount() + 1;
     pObjArr = new SwUndoGroupObjImpl[ nSize ];
 
     SwDrawContact *pContact = (SwDrawContact*)GetUserCall(pObj);
@@ -360,16 +354,16 @@ SwUndoDrawUnGroup::SwUndoDrawUnGroup( SdrObjGroup* pObj )
     pObjArr->pObj = pObj;
     pObjArr->pFmt = pFmt;
 
-    //loescht sich selbst!
+    // object will destroy itself
     pContact->Changed( *pObj, SDRUSERCALL_DELETE, pObj->GetLastBoundRect() );
     pObj->SetUserCall( 0 );
 
     ::lcl_SaveAnchor( pFmt, pObjArr->nNodeIdx );
 
-    // alle Uno-Objecte sollten sich jetzt abmelden
+       // notify UNO objects to decouple
     ::lcl_SendRemoveToUno( *pFmt );
 
-    // aus dem Array austragen
+    // remove from array 
     SwSpzFrmFmts& rFlyFmts = *(SwSpzFrmFmts*)pFmt->GetDoc()->GetSpzFrmFmts();
     rFlyFmts.Remove( rFlyFmts.GetPos( pFmt ));
 }
@@ -379,128 +373,99 @@ SwUndoDrawUnGroup::~SwUndoDrawUnGroup()
     if( bDelFmt )
     {
         SwUndoGroupObjImpl* pTmp = pObjArr + 1;
-        for( USHORT n = 1; n < nSize; ++n, ++pTmp )
+        for( sal_uInt16 n = 1; n < nSize; ++n, ++pTmp )
             delete pTmp->pFmt;
     }
     else
-        delete pObjArr->pFmt;		// das GroupObject-Format
+        delete pObjArr->pFmt;
 
     delete [] pObjArr;
 }
 
-void SwUndoDrawUnGroup::Undo( SwUndoIter& rIter )
+void SwUndoDrawUnGroup::UndoImpl(::sw::UndoRedoContext & rContext)
 {
-    bDelFmt = TRUE;
+    bDelFmt = sal_True;
 
-    // aus dem Array austragen
-    SwDoc* pDoc = &rIter.GetDoc();
+    SwDoc *const pDoc = & rContext.GetDoc();
     SwSpzFrmFmts& rFlyFmts = *(SwSpzFrmFmts*)pDoc->GetSpzFrmFmts();
 
-    for( USHORT n = 1; n < nSize; ++n )
+    // remove from array
+    for( sal_uInt16 n = 1; n < nSize; ++n )
     {
         SwUndoGroupObjImpl& rSave = *( pObjArr + n );
 
-        // --> OD 2006-11-01 #130889# - taken over by <SwUndoDrawUnGroupConnectToLayout>
-//        SwDrawContact* pContact = (SwDrawContact*)rSave.pFmt->FindContactObj();
-
-//        rSave.pObj = pContact->GetMaster();
-
-//        //loescht sich selbst!
-//        pContact->Changed( *rSave.pObj, SDRUSERCALL_DELETE,
-//                           rSave.pObj->GetLastBoundRect() );
-//        rSave.pObj->SetUserCall( 0 );
-        // <--
-
         ::lcl_SaveAnchor( rSave.pFmt, rSave.nNodeIdx );
 
-        // alle Uno-Objecte sollten sich jetzt abmelden
+           // notify UNO objects to decouple
         ::lcl_SendRemoveToUno( *rSave.pFmt );
 
         rFlyFmts.Remove( rFlyFmts.GetPos( rSave.pFmt ));
     }
 
-    // das Group-Object wieder einfuegen
+    // re-insert group object
     ::lcl_RestoreAnchor( pObjArr->pFmt, pObjArr->nNodeIdx );
     rFlyFmts.Insert( pObjArr->pFmt, rFlyFmts.Count() );
 
     SwDrawContact *pContact = new SwDrawContact( pObjArr->pFmt, pObjArr->pObj );
     pContact->ConnectToLayout();
-    // --> OD 2005-03-22 #i45718# - follow-up of #i35635#
-    // move object to visible layer
+    // #i45718# - follow-up of #i35635# move object to visible layer
     pContact->MoveObjToVisibleLayer( pObjArr->pObj );
-    // <--
-    // --> OD 2005-05-10 #i45952# - notify that position attributes
-    // are already set
+    // #i45952# - notify that position attributes are already set
     OSL_ENSURE( pObjArr->pFmt->ISA(SwDrawFrmFmt),
             "<SwUndoDrawGroup::Undo(..)> - wrong type of frame format for drawing object" );
     if ( pObjArr->pFmt->ISA(SwDrawFrmFmt) )
     {
         static_cast<SwDrawFrmFmt*>(pObjArr->pFmt)->PosAttrSet();
     }
-    // <--
 }
 
-void SwUndoDrawUnGroup::Redo( SwUndoIter& )
+void SwUndoDrawUnGroup::RedoImpl(::sw::UndoRedoContext &)
 {
-    bDelFmt = FALSE;
+    bDelFmt = sal_False;
 
-    // das Group-Object sichern
+    // save group object
     SwDrawFrmFmt* pFmt = pObjArr->pFmt;
     SwDrawContact* pContact = (SwDrawContact*)pFmt->FindContactObj();
 
-    //loescht sich selbst!
+        // object will destroy itself
     pContact->Changed( *pObjArr->pObj, SDRUSERCALL_DELETE,
         pObjArr->pObj->GetLastBoundRect() );
     pObjArr->pObj->SetUserCall( 0 );
 
     ::lcl_SaveAnchor( pFmt, pObjArr->nNodeIdx );
 
-    // alle Uno-Objecte sollten sich jetzt abmelden
+       // notify UNO objects to decouple
     ::lcl_SendRemoveToUno( *pFmt );
 
-    // aus dem Array austragen
+    // remove from array
     SwDoc* pDoc = pFmt->GetDoc();
     SwSpzFrmFmts& rFlyFmts = *(SwSpzFrmFmts*)pDoc->GetSpzFrmFmts();
     rFlyFmts.Remove( rFlyFmts.GetPos( pFmt ));
 
-    for( USHORT n = 1; n < nSize; ++n )
+    for( sal_uInt16 n = 1; n < nSize; ++n )
     {
         SwUndoGroupObjImpl& rSave = *( pObjArr + n );
 
         ::lcl_RestoreAnchor( rSave.pFmt, rSave.nNodeIdx );
         rFlyFmts.Insert( rSave.pFmt, rFlyFmts.Count() );
 
-        // --> OD 2006-11-01 #130889# - taken over by <SwUndoDrawUnGroupConnectToLayout>
-//        SdrObject* pObj = rSave.pObj;
-
-//        SwDrawContact *pContact = new SwDrawContact( rSave.pFmt, rSave.pObj );
-//        pContact->ConnectToLayout();
-//        // --> OD 2005-03-22 #i45718# - follow-up of #i35635#
-//        // move object to visible layer
-//        pContact->MoveObjToVisibleLayer( rSave.pObj );
-//        // <--
-        // <--
-        // --> OD 2005-05-10 #i45952# - notify that position attributes
-        // are already set
+        // #i45952# - notify that position attributes are already set
         OSL_ENSURE( rSave.pFmt->ISA(SwDrawFrmFmt),
                 "<SwUndoDrawGroup::Undo(..)> - wrong type of frame format for drawing object" );
         if ( rSave.pFmt->ISA(SwDrawFrmFmt) )
         {
             static_cast<SwDrawFrmFmt*>(rSave.pFmt)->PosAttrSet();
         }
-        // <--
     }
 }
 
-void SwUndoDrawUnGroup::AddObj( USHORT nPos, SwDrawFrmFmt* pFmt )
+void SwUndoDrawUnGroup::AddObj( sal_uInt16 nPos, SwDrawFrmFmt* pFmt )
 {
     SwUndoGroupObjImpl& rSave = *( pObjArr + nPos + 1 );
     rSave.pFmt = pFmt;
     rSave.pObj = 0;
 }
 
-//-------------------------------------
-// --> OD 2006-11-01 #130889#
 SwUndoDrawUnGroupConnectToLayout::SwUndoDrawUnGroupConnectToLayout()
     : SwUndo( UNDO_DRAWUNGROUP )
 {
@@ -510,7 +475,8 @@ SwUndoDrawUnGroupConnectToLayout::~SwUndoDrawUnGroupConnectToLayout()
 {
 }
 
-void SwUndoDrawUnGroupConnectToLayout::Undo( SwUndoIter& )
+void
+SwUndoDrawUnGroupConnectToLayout::UndoImpl(::sw::UndoRedoContext &)
 {
     for ( std::vector< SdrObject >::size_type i = 0;
           i < aDrawFmtsAndObjs.size(); ++i )
@@ -529,7 +495,8 @@ void SwUndoDrawUnGroupConnectToLayout::Undo( SwUndoIter& )
     }
 }
 
-void SwUndoDrawUnGroupConnectToLayout::Redo( SwUndoIter& )
+void
+SwUndoDrawUnGroupConnectToLayout::RedoImpl(::sw::UndoRedoContext &)
 {
     for ( std::vector< std::pair< SwDrawFrmFmt*, SdrObject* > >::size_type i = 0;
           i < aDrawFmtsAndObjs.size(); ++i )
@@ -548,12 +515,11 @@ void SwUndoDrawUnGroupConnectToLayout::AddFmtAndObj( SwDrawFrmFmt* pDrawFrmFmt,
     aDrawFmtsAndObjs.push_back(
             std::pair< SwDrawFrmFmt*, SdrObject* >( pDrawFrmFmt, pDrawObject ) );
 }
-// <--
 
 //-------------------------------------
 
-SwUndoDrawDelete::SwUndoDrawDelete( USHORT nCnt )
-    : SwUndo( UNDO_DRAWDELETE ), nSize( nCnt ), bDelFmt( TRUE )
+SwUndoDrawDelete::SwUndoDrawDelete( sal_uInt16 nCnt )
+    : SwUndo( UNDO_DRAWDELETE ), nSize( nCnt ), bDelFmt( sal_True )
 {
     pObjArr = new SwUndoGroupObjImpl[ nSize ];
     pMarkLst = new SdrMarkList();
@@ -564,18 +530,18 @@ SwUndoDrawDelete::~SwUndoDrawDelete()
     if( bDelFmt )
     {
         SwUndoGroupObjImpl* pTmp = pObjArr;
-        for( USHORT n = 0; n < pMarkLst->GetMarkCount(); ++n, ++pTmp )
+        for( sal_uInt16 n = 0; n < pMarkLst->GetMarkCount(); ++n, ++pTmp )
             delete pTmp->pFmt;
     }
     delete [] pObjArr;
     delete pMarkLst;
 }
 
-void SwUndoDrawDelete::Undo( SwUndoIter &rIter )
+void SwUndoDrawDelete::UndoImpl(::sw::UndoRedoContext & rContext)
 {
-    bDelFmt = FALSE;
-    SwSpzFrmFmts& rFlyFmts = *rIter.GetDoc().GetSpzFrmFmts();
-    for( USHORT n = 0; n < pMarkLst->GetMarkCount(); ++n )
+    bDelFmt = sal_False;
+    SwSpzFrmFmts & rFlyFmts = *rContext.GetDoc().GetSpzFrmFmts();
+    for( sal_uInt16 n = 0; n < pMarkLst->GetMarkCount(); ++n )
     {
         SwUndoGroupObjImpl& rSave = *( pObjArr + n );
         ::lcl_RestoreAnchor( rSave.pFmt, rSave.nNodeIdx );
@@ -583,12 +549,9 @@ void SwUndoDrawDelete::Undo( SwUndoIter &rIter )
         SdrObject *pObj = rSave.pObj;
         SwDrawContact *pContact = new SwDrawContact( rSave.pFmt, pObj );
         pContact->_Changed( *pObj, SDRUSERCALL_INSERTED, NULL );
-        // --> OD 2005-03-22 #i45718# - follow-up of #i35635#
-        // move object to visible layer
+        // #i45718# - follow-up of #i35635# move object to visible layer
         pContact->MoveObjToVisibleLayer( pObj );
-        // <--
-        // --> OD 2005-05-10 #i45952# - notify that position attributes
-        // are already set
+        // #i45952# - notify that position attributes are already set
         OSL_ENSURE( rSave.pFmt->ISA(SwDrawFrmFmt),
                 "<SwUndoDrawGroup::Undo(..)> - wrong type of frame format for drawing object" );
         if ( rSave.pFmt->ISA(SwDrawFrmFmt) )
@@ -597,24 +560,25 @@ void SwUndoDrawDelete::Undo( SwUndoIter &rIter )
         }
         // <--
     }
-    rIter.pMarkList = pMarkLst;
+    rContext.SetSelections(0, pMarkLst);
 }
 
-void SwUndoDrawDelete::Redo( SwUndoIter &rIter )
+void SwUndoDrawDelete::RedoImpl(::sw::UndoRedoContext & rContext)
 {
-    bDelFmt = TRUE;
-    SwSpzFrmFmts& rFlyFmts = *rIter.GetDoc().GetSpzFrmFmts();
-    for( USHORT n = 0; n < pMarkLst->GetMarkCount(); ++n )
+    bDelFmt = sal_True;
+    SwSpzFrmFmts & rFlyFmts = *rContext.GetDoc().GetSpzFrmFmts();
+    for( sal_uInt16 n = 0; n < pMarkLst->GetMarkCount(); ++n )
     {
         SwUndoGroupObjImpl& rSave = *( pObjArr + n );
         SdrObject *pObj = rSave.pObj;
         SwDrawContact *pContact = (SwDrawContact*)GetUserCall(pObj);
         SwDrawFrmFmt *pFmt = (SwDrawFrmFmt*)pContact->GetFmt();
-        //loescht sich selbst!
+
+        // object will destroy itself
         pContact->Changed( *pObj, SDRUSERCALL_DELETE, pObj->GetLastBoundRect() );
         pObj->SetUserCall( 0 );
 
-        // alle Uno-Objecte sollten sich jetzt abmelden
+           // notify UNO objects to decouple
         ::lcl_SendRemoveToUno( *pFmt );
 
         rFlyFmts.Remove( rFlyFmts.GetPos( pFmt ));
@@ -622,7 +586,7 @@ void SwUndoDrawDelete::Redo( SwUndoIter &rIter )
     }
 }
 
-void SwUndoDrawDelete::AddObj( USHORT , SwDrawFrmFmt* pFmt,
+void SwUndoDrawDelete::AddObj( sal_uInt16 , SwDrawFrmFmt* pFmt,
                                 const SdrMark& rMark )
 {
     SwUndoGroupObjImpl& rSave = *( pObjArr + pMarkLst->GetMarkCount() );
@@ -630,10 +594,10 @@ void SwUndoDrawDelete::AddObj( USHORT , SwDrawFrmFmt* pFmt,
     rSave.pFmt = pFmt;
     ::lcl_SaveAnchor( pFmt, rSave.nNodeIdx );
 
-    // alle Uno-Objecte sollten sich jetzt abmelden
+       // notify UNO objects to decouple
     ::lcl_SendRemoveToUno( *pFmt );
 
-    // aus dem Array austragen
+    // remove from array
     SwDoc* pDoc = pFmt->GetDoc();
     SwSpzFrmFmts& rFlyFmts = *(SwSpzFrmFmts*)pDoc->GetSpzFrmFmts();
     rFlyFmts.Remove( rFlyFmts.GetPos( pFmt ));
