@@ -32,7 +32,6 @@
 
 #include <com/sun/star/uno/Sequence.hxx>
 #include <com/sun/star/uno/Any.hxx>
-#include <com/sun/star/uno/Any.hxx>
 #include <com/sun/star/view/XRenderable.hpp>
 
 #include <hintids.hxx>
@@ -61,6 +60,7 @@
 #include <pagefrm.hxx>
 #include <cntfrm.hxx>
 #include <doc.hxx>
+#include <IDocumentUndoRedo.hxx>
 #include <wdocsh.hxx>
 #include <fesh.hxx>
 #include <pam.hxx>
@@ -72,7 +72,7 @@
 #include <docufld.hxx>      // PostItFld /-Type
 #include <shellres.hxx>
 #include <viewopt.hxx>
-#include <swprtopt.hxx>     // SwPrtOptions
+#include <printdata.hxx>    // SwPrintData
 #include <pagedesc.hxx>
 #include <poolfmt.hxx>
 #include <mdiexp.hxx>
@@ -192,7 +192,7 @@ void SwPaintQueue::Remove( ViewShell *pSh )
     }
 }
 
-void SetSwVisArea( ViewShell *pSh, const SwRect &rRect, BOOL /*bPDFExport*/ )
+void SetSwVisArea( ViewShell *pSh, const SwRect &rRect, sal_Bool /*bPDFExport*/ )
 {
     OSL_ENSURE( !pSh->GetWin(), "Drucken mit Window?" );
     pSh->aVisArea = rRect;
@@ -239,15 +239,15 @@ void ViewShell::InitPrt( OutputDevice *pOutDev )
         pOut = pOutDev;    //Oder was sonst?
 }
 
-void ViewShell::ChgAllPageOrientation( USHORT eOri )
+void ViewShell::ChgAllPageOrientation( sal_uInt16 eOri )
 {
     OSL_ENSURE( nStartAction, "missing an Action" );
     SET_CURR_SHELL( this );
 
-    USHORT nAll = GetDoc()->GetPageDescCnt();
-    BOOL bNewOri = Orientation(eOri) == ORIENTATION_PORTRAIT ? FALSE : TRUE;
+    sal_uInt16 nAll = GetDoc()->GetPageDescCnt();
+    sal_Bool bNewOri = Orientation(eOri) == ORIENTATION_PORTRAIT ? sal_False : sal_True;
 
-    for( USHORT i = 0; i < nAll; ++ i )
+    for( sal_uInt16 i = 0; i < nAll; ++ i )
     {
         const SwPageDesc& rOld =
             const_cast<const SwDoc *>(GetDoc())->GetPageDesc( i );
@@ -255,10 +255,10 @@ void ViewShell::ChgAllPageOrientation( USHORT eOri )
         if( rOld.GetLandscape() != bNewOri )
         {
             SwPageDesc aNew( rOld );
-            const sal_Bool bDoesUndo( GetDoc()->DoesUndo() );
-            GetDoc()->DoUndo( sal_False );
-            GetDoc()->CopyPageDesc(rOld, aNew);
-            GetDoc()->DoUndo( bDoesUndo );
+            {
+                ::sw::UndoGuard const ug(GetDoc()->GetIDocumentUndoRedo());
+                GetDoc()->CopyPageDesc(rOld, aNew);
+            }
             aNew.SetLandscape( bNewOri );
             SwFrmFmt& rFmt = aNew.GetMaster();
             SwFmtFrmSize aSz( rFmt.GetFrmSize() );
@@ -281,19 +281,19 @@ void ViewShell::ChgAllPageSize( Size &rSz )
     SET_CURR_SHELL( this );
 
     SwDoc* pMyDoc = GetDoc();
-    USHORT nAll = pMyDoc->GetPageDescCnt();
+    sal_uInt16 nAll = pMyDoc->GetPageDescCnt();
 
-    for( USHORT i = 0; i < nAll; ++i )
+    for( sal_uInt16 i = 0; i < nAll; ++i )
     {
         const SwPageDesc &rOld = const_cast<const SwDoc *>(pMyDoc)->GetPageDesc( i );
         SwPageDesc aNew( rOld );
-        const sal_Bool bDoesUndo( GetDoc()->DoesUndo() );
-        GetDoc()->DoUndo( sal_False );
-        GetDoc()->CopyPageDesc( rOld, aNew );
-        GetDoc()->DoUndo( bDoesUndo );
+        {
+            ::sw::UndoGuard const ug(GetDoc()->GetIDocumentUndoRedo());
+            GetDoc()->CopyPageDesc( rOld, aNew );
+        }
         SwFrmFmt& rPgFmt = aNew.GetMaster();
         Size aSz( rSz );
-        const BOOL bOri = aNew.GetLandscape();
+        const sal_Bool bOri = aNew.GetLandscape();
         if( bOri  ? aSz.Height() > aSz.Width()
                   : aSz.Height() < aSz.Width() )
         {
@@ -310,26 +310,26 @@ void ViewShell::ChgAllPageSize( Size &rSz )
 }
 
 
-void ViewShell::CalcPagesForPrint( USHORT nMax )
+void ViewShell::CalcPagesForPrint( sal_uInt16 nMax )
 {
     SET_CURR_SHELL( this );
 
-    SwRootFrm* pLayout = GetLayout();
+    SwRootFrm* pMyLayout = GetLayout();
 
-    const SwFrm *pPage = pLayout->Lower();
-    SwLayAction aAction( pLayout, Imp() );
+    const SwFrm *pPage = pMyLayout->Lower();
+    SwLayAction aAction( pMyLayout, Imp() );
 
-    pLayout->StartAllAction();
-    for ( USHORT i = 1; pPage && i <= nMax; pPage = pPage->GetNext(), ++i )
+    pMyLayout->StartAllAction();
+    for ( sal_uInt16 i = 1; pPage && i <= nMax; pPage = pPage->GetNext(), ++i )
     {
         pPage->Calc();
         SwRect aOldVis( VisArea() );
         aVisArea = pPage->Frm();
         Imp()->SetFirstVisPageInvalid();
         aAction.Reset();
-        aAction.SetPaint( FALSE );
-        aAction.SetWaitAllowed( FALSE );
-        aAction.SetReschedule( TRUE );
+        aAction.SetPaint( sal_False );
+        aAction.SetWaitAllowed( sal_False );
+        aAction.SetReschedule( sal_True );
 
         aAction.Action();
 
@@ -337,105 +337,12 @@ void ViewShell::CalcPagesForPrint( USHORT nMax )
         Imp()->SetFirstVisPageInvalid();
 
     }
-    pLayout->EndAllAction();
+
+    pMyLayout->EndAllAction();
 }
 
 /******************************************************************************/
 
-SwDoc * ViewShell::CreatePrtDoc( SfxObjectShellRef &rDocShellRef)
-{
-    OSL_ENSURE( this->IsA( TYPE(SwFEShell) ),"ViewShell::Prt for FEShell only");
-    SwFEShell* pFESh = (SwFEShell*)this;
-
-    SwDoc *pPrtDoc = new SwDoc;
-    pPrtDoc->acquire();
-    pPrtDoc->SetRefForDocShell( (SfxObjectShellRef*)&(long&)rDocShellRef );
-    pPrtDoc->LockExpFlds();
-
-    const SfxPoolItem* pCpyItem;
-    const SfxItemPool& rPool = GetAttrPool();
-    for( USHORT nWh = POOLATTR_BEGIN; nWh < POOLATTR_END; ++nWh )
-        if( 0 != ( pCpyItem = rPool.GetPoolDefaultItem( nWh ) ) )
-            pPrtDoc->GetAttrPool().SetPoolDefaultItem( *pCpyItem );
-
-    pPrtDoc->ReplaceStyles( *GetDoc() );
-
-    SwShellCrsr *pActCrsr = pFESh->_GetCrsr();
-    SwShellCrsr *pFirstCrsr = dynamic_cast<SwShellCrsr*>(pActCrsr->GetNext());
-    if( !pActCrsr->HasMark() )
-    {
-        pActCrsr = dynamic_cast<SwShellCrsr*>(pActCrsr->GetPrev());
-    }
-
-    Point aSelPoint;
-    if( pFESh->IsTableMode() )
-    {
-        SwShellTableCrsr* pShellTblCrsr = pFESh->GetTableCrsr();
-        
-        const SwCntntNode* pCntntNode = pShellTblCrsr->GetNode()->GetCntntNode();
-        const SwCntntFrm *pCntntFrm = pCntntNode ? pCntntNode->GetFrm( 0, pShellTblCrsr->Start() ) : 0;
-        if( pCntntFrm )
-        {
-            SwRect aCharRect;
-            SwCrsrMoveState aTmpState( MV_NONE );
-            pCntntFrm->GetCharRect( aCharRect, *pShellTblCrsr->Start(), &aTmpState );
-            aSelPoint = Point( aCharRect.Left(), aCharRect.Top() );
-        }
-    }
-    else
-    {
-       aSelPoint = pFirstCrsr->GetSttPos();
-    }
-
-    const SwPageFrm* pPage = GetLayout()->GetPageAtPos( aSelPoint );
-    OSL_ENSURE( pPage, "no page found!" );
-
-    // get page descriptor - fall back to the first one if pPage could not be found
-    const SwPageDesc* pPageDesc = pPage ? pPrtDoc->FindPageDescByName(
-        pPage->GetPageDesc()->GetName() ) : &pPrtDoc->_GetPageDesc( (sal_uInt16)0 );
-
-    if( !pFESh->IsTableMode() && pActCrsr->HasMark() )
-    {
-        SwNodeIndex aNodeIdx( *pPrtDoc->GetNodes().GetEndOfContent().StartOfSectionNode() );
-        SwTxtNode* pTxtNd = pPrtDoc->GetNodes().GoNext( &aNodeIdx )->GetTxtNode();
-        SwCntntNode *pLastNd =
-            pActCrsr->GetCntntNode( (*pActCrsr->GetMark()) <= (*pActCrsr->GetPoint()) );
-
-        if( pLastNd && pLastNd->IsTxtNode() )
-            ((SwTxtNode*)pLastNd)->CopyCollFmt( *pTxtNd );
-    }
-
-
-    pFESh->Copy( pPrtDoc );
-
-    {
-        SwNodeIndex aNodeIdx( *pPrtDoc->GetNodes().GetEndOfContent().StartOfSectionNode() );
-        SwCntntNode* pCNd = pPrtDoc->GetNodes().GoNext( &aNodeIdx );
-        if( pFESh->IsTableMode() )
-        {
-            SwTableNode* pTNd = pCNd->FindTableNode();
-            if( pTNd )
-                pTNd->GetTable().GetFrmFmt()->SetFmtAttr( SwFmtPageDesc( pPageDesc ) );
-        }
-        else
-        {
-            pCNd->SetAttr( SwFmtPageDesc( pPageDesc ) );
-            if( pFirstCrsr->HasMark() )
-            {
-                SwTxtNode *pTxtNd = pCNd->GetTxtNode();
-                if( pTxtNd )
-                {
-                    SwCntntNode *pFirstNd =
-                        pFirstCrsr->GetCntntNode( (*pFirstCrsr->GetMark()) > (*pFirstCrsr->GetPoint()) );
-                    if( pFirstNd && pFirstNd->IsTxtNode() )
-                        ((SwTxtNode*)pFirstNd)->CopyCollFmt( *pTxtNd );
-                }
-            }
-        }
-    }
-    return pPrtDoc;
-}
-
 SwDoc * ViewShell::FillPrtDoc( SwDoc *pPrtDoc, const SfxPrinter* pPrt)
 {
     OSL_ENSURE( this->IsA( TYPE(SwFEShell) ),"ViewShell::Prt for FEShell only");
@@ -449,7 +356,7 @@ SwDoc * ViewShell::FillPrtDoc( SwDoc *pPrtDoc, const SfxPrinter* pPrt)
 
     const SfxPoolItem* pCpyItem;
     const SfxItemPool& rPool = GetAttrPool();
-    for( USHORT nWh = POOLATTR_BEGIN; nWh < POOLATTR_END; ++nWh )
+    for( sal_uInt16 nWh = POOLATTR_BEGIN; nWh < POOLATTR_END; ++nWh )
         if( 0 != ( pCpyItem = rPool.GetPoolDefaultItem( nWh ) ) )
             pPrtDoc->GetAttrPool().SetPoolDefaultItem( *pCpyItem );
 
@@ -468,7 +375,7 @@ SwDoc * ViewShell::FillPrtDoc( SwDoc *pPrtDoc, const SfxPrinter* pPrt)
         SwShellTableCrsr* pShellTblCrsr = pFESh->GetTableCrsr();
         
         const SwCntntNode* pCntntNode = pShellTblCrsr->GetNode()->GetCntntNode();
-        const SwCntntFrm *pCntntFrm = pCntntNode ? pCntntNode->GetFrm( 0, pShellTblCrsr->Start() ) : 0;
+        const SwCntntFrm *pCntntFrm = pCntntNode ? pCntntNode->getLayoutFrm( GetLayout(), 0, pShellTblCrsr->Start() ) : 0;
         if( pCntntFrm )
         {
             SwRect aCharRect;
@@ -534,7 +441,7 @@ SwDoc * ViewShell::FillPrtDoc( SwDoc *pPrtDoc, const SfxPrinter* pPrt)
 
 sal_Bool ViewShell::PrintOrPDFExport( 
     OutputDevice *pOutDev,
-    const SwPrtOptions &rPrintData,
+    SwPrintData const& rPrintData,
     sal_Int32 nRenderer     /* the index in the vector of pages to be printed */ )
 {
 
@@ -552,33 +459,15 @@ sal_Bool ViewShell::PrintOrPDFExport(
     ViewShell *pShell;
     SwDoc *pOutDevDoc;
 
-    SfxObjectShellRef aDocShellRef;
-
-    //! Note: Since for PDF export of (multi-)selection a temporary
-    //! document is created that contains only the selects parts,
-    //! and thus that document is to printed in whole the,
-    //! rPrintData.bPrintSelection parameter will be false.
-    BOOL bSelection = rPrintData.bPrintSelection;
-
-    // PDF export for (multi-)selection has already generated a temporary document
-    // with the selected text. (see XRenderable implementation in unotxdoc.cxx)
-    // Thus we like to go in the 'else' part here in that case.
-    // Is is implemented this way because PDF export calls this Prt function
+    // Print/PDF export for (multi-)selection has already generated a
+    // temporary document with the selected text.
+    // (see XRenderable implementation in unotxdoc.cxx)
+    // It is implemented this way because PDF export calls this Prt function
     // once per page and we do not like to always have the temporary document
-    // to be created that often here in the 'then' part.
-    if ( bSelection )
-    {
-        pOutDevDoc = CreatePrtDoc( aDocShellRef );
+    // to be created that often here.
+    pOutDevDoc = GetDoc();
+    pShell = new ViewShell( *this, 0, pOutDev );
 
-        pShell = new ViewShell( *pOutDevDoc, 0, pOpt, pOutDev );
-        pOutDevDoc->SetRefForDocShell( 0 );
-    }
-    else
-    {
-        pOutDevDoc = GetDoc();
-        pShell = new ViewShell( *this, 0, pOutDev );
-    }
-    
     SdrView *pDrawView = pShell->GetDrawView();
     if (pDrawView)
     {
@@ -591,7 +480,7 @@ sal_Bool ViewShell::PrintOrPDFExport(
 
 
         if( pOpt->IsReadonly() )
-            pShell->pOpt->SetReadonly( TRUE );
+            pShell->pOpt->SetReadonly( sal_True );
 
         // save options at draw view:
         SwDrawViewSave aDrawViewSave( pShell->GetDrawView() );
@@ -625,7 +514,8 @@ sal_Bool ViewShell::PrintOrPDFExport(
                 rPrintData.GetRenderData().m_pPostItShell : pShell;
         ::SetSwVisArea( pViewSh2, pStPage->Frm() );
 
-
+// FIXME disabled because rPrintData.aOffset is always (0,0)
+#if 0
         if( pStPage->GetFmt()->GetPoolFmtId() == RES_POOLPAGE_JAKET )
         {
             Point aNewOrigin = pOutDev->GetMapMode().GetOrigin();
@@ -634,6 +524,7 @@ sal_Bool ViewShell::PrintOrPDFExport(
             aTmp.SetOrigin( aNewOrigin );
             pOutDev->SetMapMode( aTmp );
         }
+#endif
 
         pShell->InitPrt( pOutDev );
 
@@ -648,12 +539,6 @@ sal_Bool ViewShell::PrintOrPDFExport(
 
     delete pShell;
 
-    if (bSelection )
-    {
-        if ( !pOutDevDoc->release() )
-            delete pOutDevDoc;
-    }
-
     // restore settings of OutputDevice (should be done always now since the
     // output device is now provided by a call from outside the Writer)
     pOutDev->Pop();
@@ -665,27 +550,26 @@ void ViewShell::PrtOle2( SwDoc *pDoc, const SwViewOption *pOpt, const SwPrintDat
                          OutputDevice* pOleOut, const Rectangle& rRect )
 {
     ViewShell *pSh;
-    if( pDoc->GetRootFrm() && pDoc->GetRootFrm()->GetCurrShell() )
-        pSh = new ViewShell( *pDoc->GetRootFrm()->GetCurrShell(), 0, pOleOut );
-    else
-        pSh = new ViewShell( *pDoc, 0, pOpt, pOleOut );
+    if( pDoc->GetCurrentViewShell() )
+        pSh = new ViewShell( *pDoc->GetCurrentViewShell(), 0, pOleOut,VSHELLFLAG_SHARELAYOUT );//swmod 080129
+    else	//swmod 071108//swmod 071225
+        pSh = new ViewShell( *pDoc, 0, pOpt, pOleOut);//swmod 080129
 
     {
         SET_CURR_SHELL( pSh );
         pSh->PrepareForPrint( rOptions );
-        pSh->SetPrtFormatOption( TRUE );
+        pSh->SetPrtFormatOption( sal_True );
 
         SwRect aSwRect( rRect );
         pSh->aVisArea = aSwRect;
 
-        if ( pSh->getIDocumentSettingAccess()->get(IDocumentSettingAccess::BROWSE_MODE) &&
+        if ( pSh->GetViewOptions()->getBrowseMode() &&
              pSh->GetNext() == pSh )
         {
-            pSh->CheckBrowseView( FALSE );
-            pDoc->GetRootFrm()->Lower()->InvalidateSize();
+            pSh->CheckBrowseView( sal_False );
+            pSh->GetLayout()->Lower()->InvalidateSize();
         }
 
-        // --> FME 2005-02-10 #119474#
         // CalcPagesForPrint() should not be necessary here. The pages in the
         // visible area will be formatted in SwRootFrm::Paint().
         // Removing this gives us a performance gain during saving the
@@ -693,7 +577,6 @@ void ViewShell::PrtOle2( SwDoc *pDoc, const SwViewOption *pOpt, const SwPrintDat
         // formatting of the document.
         // Seiten fuers Drucken formatieren
         // pSh->CalcPagesForPrint( SHRT_MAX );
-        // <--
         pOleOut->Push( PUSH_CLIPREGION );
         pOleOut->IntersectClipRegion( aSwRect.SVRect() );
         pSh->GetLayout()->Paint( aSwRect );
@@ -704,21 +587,21 @@ void ViewShell::PrtOle2( SwDoc *pDoc, const SwViewOption *pOpt, const SwPrintDat
     delete pSh;
 }
 
-BOOL ViewShell::IsAnyFieldInDoc() const
+sal_Bool ViewShell::IsAnyFieldInDoc() const
 {
     const SfxPoolItem* pItem;
-    USHORT nMaxItems = pDoc->GetAttrPool().GetItemCount( RES_TXTATR_FIELD );
-    for( USHORT n = 0; n < nMaxItems; ++n )
-        if( 0 != (pItem = pDoc->GetAttrPool().GetItem( RES_TXTATR_FIELD, n )))
+    sal_uInt32 nMaxItems = pDoc->GetAttrPool().GetItemCount2( RES_TXTATR_FIELD );
+    for( sal_uInt32 n = 0; n < nMaxItems; ++n )
+        if( 0 != (pItem = pDoc->GetAttrPool().GetItem2( RES_TXTATR_FIELD, n )))
         {
             const SwFmtFld* pFmtFld = (SwFmtFld*)pItem;
             const SwTxtFld* pTxtFld = pFmtFld->GetTxtFld();
             //#i101026# do not include postits in field check
             const SwField* pFld = pFmtFld->GetFld();
             if( pTxtFld && pTxtFld->GetTxtNode().GetNodes().IsDocNodes() && (pFld->Which() != RES_POSTITFLD))
-                return TRUE;
+                return sal_True;
         }
-    return FALSE;
+    return sal_False;
 }
 
 SwDrawViewSave::SwDrawViewSave( SdrView* pSdrView )
@@ -743,12 +626,12 @@ SwDrawViewSave::~SwDrawViewSave()
 // #i6467# - method also called for page preview
 void ViewShell::PrepareForPrint( const SwPrintData &rOptions )
 {
-    pOpt->SetGraphic ( TRUE == rOptions.bPrintGraphic );
-    pOpt->SetTable	 ( TRUE == rOptions.bPrintTable );
-    pOpt->SetDraw	 ( TRUE == rOptions.bPrintDraw  );
-    pOpt->SetControl ( TRUE == rOptions.bPrintControl );
-    pOpt->SetPageBack( TRUE == rOptions.bPrintPageBackground );
-    pOpt->SetBlackFont( TRUE == rOptions.bPrintBlackFont );
+    pOpt->SetGraphic ( sal_True == rOptions.bPrintGraphic );
+    pOpt->SetTable	 ( sal_True == rOptions.bPrintTable );
+    pOpt->SetDraw	 ( sal_True == rOptions.bPrintDraw  );
+    pOpt->SetControl ( sal_True == rOptions.bPrintControl );
+    pOpt->SetPageBack( sal_True == rOptions.bPrintPageBackground );
+    pOpt->SetBlackFont( sal_True == rOptions.bPrintBlackFont );
 
     if ( HasDrawView() )
     {
