@@ -29,9 +29,6 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
 
-#ifdef WTC
-#define private public
-#endif
 #include <hintids.hxx>
 #include <editeng/lrspitem.hxx>
 #include <editeng/boxitem.hxx>
@@ -50,6 +47,7 @@
 #include <tblenum.hxx>
 #include <frmatr.hxx>
 #include <fmtrowsplt.hxx>
+#include <vector>
 
 using namespace ::com::sun::star;
 
@@ -58,13 +56,13 @@ SV_DECL_PTRARR( SwBoxFrmFmts, SwTableBoxFmtPtr, 25, 50 )
 
 class SwShareBoxFmts;
 extern void _DeleteBox( SwTable& rTbl, SwTableBox* pBox, SwUndo* = 0,
-                    BOOL = TRUE, const BOOL = TRUE, SwShareBoxFmts* = 0 );
+                    sal_Bool = sal_True, const sal_Bool = sal_True, SwShareBoxFmts* = 0 );
 
 struct Row
 {
     bool mbUseLeftRowPad, mbUseRightRowPad, mbUseTopRowPad, mbUseBottomRowPad;
     long mnLeftRowPad, mnRightRowPad, mnTopRowPad, mnBottomRowPad;
-    USHORT mnBrdDist;
+    sal_uInt16 mnBrdDist;
     Row() :
         mbUseLeftRowPad(false), mbUseRightRowPad(false),
         mbUseTopRowPad(false), mbUseBottomRowPad(false),
@@ -77,22 +75,22 @@ static void SetRowBorder(SfxItemSet& rSet, const Row &rRow)
 {
 #if 1
     SvxBoxItem aBox((const SvxBoxItem&)rSet.Get(RES_BOX, false));
-    aBox.SetDistance( static_cast< USHORT >(rRow.mbUseLeftRowPad ? rRow.mnLeftRowPad : rRow.mnBrdDist),
+    aBox.SetDistance( static_cast< sal_uInt16 >(rRow.mbUseLeftRowPad ? rRow.mnLeftRowPad : rRow.mnBrdDist),
             BOX_LINE_LEFT);
 
-    aBox.SetDistance( static_cast< USHORT >(rRow.mbUseRightRowPad ? rRow.mnRightRowPad : rRow.mnBrdDist),
+    aBox.SetDistance( static_cast< sal_uInt16 >(rRow.mbUseRightRowPad ? rRow.mnRightRowPad : rRow.mnBrdDist),
             BOX_LINE_RIGHT);
 
-    aBox.SetDistance( static_cast< USHORT >(rRow.mbUseTopRowPad ? rRow.mnTopRowPad : 0),
+    aBox.SetDistance( static_cast< sal_uInt16 >(rRow.mbUseTopRowPad ? rRow.mnTopRowPad : 0),
             BOX_LINE_TOP);
 
-    aBox.SetDistance( static_cast< USHORT >(rRow.mbUseBottomRowPad ? rRow.mnBottomRowPad : 0),
+    aBox.SetDistance( static_cast< sal_uInt16 >(rRow.mbUseBottomRowPad ? rRow.mnBottomRowPad : 0),
             BOX_LINE_BOTTOM);
 
     rSet.Put(aBox);
 #else
     const SfxPoolItem* pItem;
-    if (SFX_ITEM_SET == rSet.GetItemState(RES_BOX, FALSE, &pItem))
+    if (SFX_ITEM_SET == rSet.GetItemState(RES_BOX, sal_False, &pItem))
     {
         SvxBoxItem aBox( *(SvxBoxItem*)pItem );
         aBox.SetDistance(rRow.mbUseLeftRowPad ? rRow.mnLeftRowPad : rRow.mnBrdDist,
@@ -160,15 +158,12 @@ void SwRTFParser::ReadTable( int nToken )
 
     // verhinder Tabelle in Tabelle/Footnote
     SwTwips nTblSz = 0;
-    int bReadNewCell = FALSE, bChkExistTbl = FALSE;
+    int bReadNewCell = sal_False, bChkExistTbl = sal_False;
 
 
     enum Limits {eMAXCELLS=64000};
 
-    SvBools aMergeBackup;
-    int nCount = aMergeBoxes.Count();
-    for (USHORT i = 0; i < nCount; ++i)
-        aMergeBackup.Insert(aMergeBoxes[i], i);
+    std::vector<bool> aMergeBackup(aMergeBoxes);
 
     // kein TROWD aber ein TabellenToken -> zwischen TROWD und Tab.Token
     // waren andere Zeichen (siehe Bug 27445.rtf)
@@ -177,28 +172,28 @@ void SwRTFParser::ReadTable( int nToken )
         if( RTF_TROWD == nToken )
             nToken = GetNextToken();		// RTF_TROWD ueberlesen
 
-        // Flags fuer die gemergten Boxen loeschen
-        aMergeBoxes.Remove( 0, aMergeBoxes.Count() );
-        aMergeBoxes.Insert( (BOOL)FALSE, USHORT(0) );
-        nAktBox = 0;
+        // Flag for delete merged boxes
+        aMergeBoxes.clear();
+        aMergeBoxes.push_back(false);
+        m_nCurrentBox = 0;
 
         // wenn schon in einer Tabellen, dann splitte oder benutze
         // die bisherigen Boxen weiter
-        bChkExistTbl = 0 != pDoc->GetNodes()[ pPam->GetPoint()->nNode ]->FindTableNode();
+        bChkExistTbl = 0 != pPam->GetPoint()->nNode.GetNode().FindTableNode();
     }
     else
     {
-        bReadNewCell = TRUE;
+        bReadNewCell = sal_True;
         SwTableLines& rLns = pTableNode->GetTable().GetTabLines();
         SwTableLine* pLine = rLns[ rLns.Count()-1 ];
         // very robust to avoid crashes like bug 127425 + crash reports 118743
         if( pLine )
         {
-            USHORT nTmpBox = nAktBox;
+            sal_uInt16 nTmpBox = m_nCurrentBox;
             if( nTmpBox > pLine->GetTabBoxes().Count() )
                 nTmpBox = pLine->GetTabBoxes().Count();
 
-            for( USHORT n = nTmpBox; n; )
+            for (sal_uInt16 n = nTmpBox; n; )
             {
                 const SwTableBox *pTmp = pLine->GetTabBoxes()[ --n ];
                 if( pTmp )
@@ -223,13 +218,12 @@ void SwRTFParser::ReadTable( int nToken )
 
     sal_Int16 eVerOrient = text::VertOrientation::NONE;
     long nLineHeight = 0;
-    USHORT nBoxCnt = aMergeBoxes.Count()-1;
     SwBoxFrmFmts aBoxFmts;
     SwTableBoxFmt* pBoxFmt = pDoc->MakeTableBoxFmt();
     SvxFrameDirection eDir = FRMDIR_HORI_LEFT_TOP;
     bool bCantSplit = false;
 
-    int bWeiter = TRUE;
+    int bWeiter = sal_True;
     do {
         switch( nToken )
         {
@@ -290,17 +284,18 @@ void SwRTFParser::ReadTable( int nToken )
         case RTF_CLMRG:
             // would crash later on reading \cellx (#i112657#):
             // the first cell cannot be merged with earlier ones.
-            if (nBoxCnt != 0)
+            if (aMergeBoxes.size() > 1)
             {
-                aMergeBoxes[ nBoxCnt ] = TRUE;
+                aMergeBoxes.back() = sal_True;
             }
             break;
 
         case RTF_CELLX:
-            if (!bTrowdRead) {
+            if (!bTrowdRead && (aMergeBoxes.size() < (SAL_MAX_UINT16 - 1)))
+            {
                 SwTableBoxFmt* pFmt = pBoxFmt;
                 SwTwips nSize = nTokenValue - nTblSz;
-                if( aMergeBoxes[ nBoxCnt ] )
+                if( aMergeBoxes.back() )
                 {
                     // neue Zellen lesen und noch keine Formate vorhanden,
                     // dann benutze das der vorhergebende
@@ -308,16 +303,19 @@ void SwRTFParser::ReadTable( int nToken )
                     {
                         SwTableLines& rLns = pTableNode->GetTable().GetTabLines();
                         SwTableLine* pLine = rLns[ rLns.Count()-1 ];
-                        if(nAktBox!=0)
-                            --nAktBox;
-                        pFmt = (SwTableBoxFmt*)pLine->GetTabBoxes()[ nAktBox ]->GetFrmFmt();
+                        if (m_nCurrentBox != 0)
+                        {
+                            --m_nCurrentBox;
+                        }
+                        pFmt = static_cast<SwTableBoxFmt*>(
+                            pLine->GetTabBoxes()[ m_nCurrentBox ]->GetFrmFmt());
                     }
                     else
                         pFmt = aBoxFmts[ aBoxFmts.Count()-1 ];
 
-                    // --> OD 2007-01-25 #i73790# - method renamed
+                    // #i73790# - method renamed
                     pBoxFmt->ResetAllFmtAttr();
-                    // <--
+
                     nSize += pFmt->GetFrmSize().GetWidth();
                 }
                 else
@@ -325,7 +323,7 @@ void SwRTFParser::ReadTable( int nToken )
                   //
                   if (nSize<=2*aRow.mnBrdDist) {
                     aRow.mnRightRowPad=0;
-                    aRow.mbUseRightRowPad=TRUE;
+                    aRow.mbUseRightRowPad=sal_True;
                   }
                     SetRowBorder((SfxItemSet&)pBoxFmt->GetAttrSet(), aRow);
                     aBoxFmts.Insert( pBoxFmt, aBoxFmts.Count() );
@@ -336,90 +334,23 @@ void SwRTFParser::ReadTable( int nToken )
                     nSize = COL_DFLT_WIDTH;
                 pFmt->SetFmtAttr( SwFmtFrmSize( ATT_VAR_SIZE, nSize, 0 ));
                 nTblSz = nTokenValue;
-                aMergeBoxes.Insert( (BOOL)FALSE, ++nBoxCnt );
+                aMergeBoxes.push_back(sal_False);
 
                 SvxBoxItem aBox(pFmt->GetBox());
 
                 if (bUseRightCellPad)
-                    aBox.SetDistance( static_cast< USHORT >(nRightCellPad), BOX_LINE_RIGHT);
+                    aBox.SetDistance( static_cast< sal_uInt16 >(nRightCellPad), BOX_LINE_RIGHT);
                 if (bUseBottomCellPad)
-                    aBox.SetDistance( static_cast< USHORT >(nBottomCellPad), BOX_LINE_BOTTOM);
+                    aBox.SetDistance( static_cast< sal_uInt16 >(nBottomCellPad), BOX_LINE_BOTTOM);
 
                 //Yes, these are the wrong way around, there appears to
                 //be a bug in word where these are swapped.
                 if (bUseLeftCellPad)
-                    aBox.SetDistance( static_cast< USHORT >(nLeftCellPad), BOX_LINE_TOP);
+                    aBox.SetDistance( static_cast< sal_uInt16 >(nLeftCellPad), BOX_LINE_TOP);
                 if (bUseTopCellPad)
-                    aBox.SetDistance( static_cast< USHORT >(nTopCellPad), BOX_LINE_LEFT);
+                    aBox.SetDistance( static_cast< sal_uInt16 >(nTopCellPad), BOX_LINE_LEFT);
 
 
-                /*#106415# The Cell Borders are now balanced on import to
-                improve the layout of tables.
-                */
-/*
-                if ( aBoxFmts.Count()>1)
-                {
-
-                    SwTableBoxFmt* prevpFmt = aBoxFmts[ aBoxFmts.Count()-2 ];
-                    SvxBoxItem prevaBox(prevpFmt->GetBox());
-                    USHORT prevWidthRight=0;
-                    USHORT currWidthLeft=0;
-                    bool bDoubleLine=false;
-                    const SvxBorderLine*   brdrline ;
-                    const Color* pPrevRightColor;
-                    if(prevaBox.GetRight())
-                    {
-                        brdrline=prevaBox.GetRight();
-                        prevWidthRight = brdrline->GetOutWidth();
-                        pPrevRightColor = &brdrline->GetColor();
-                        if(brdrline->GetInWidth())
-                            bDoubleLine=true;
-                    }
-                    if(aBox.GetLeft())
-                    {
-                        brdrline=aBox.GetLeft();
-                        currWidthLeft = brdrline->GetOutWidth();
-                        if(brdrline->GetInWidth())
-                            bDoubleLine=true;
-                    }
-
-                    if((currWidthLeft >0 || prevWidthRight >0) &&
-                        !bDoubleLine)
-                    {
-                        USHORT newBorderWidth=(currWidthLeft+prevWidthRight)/2 ;
-                        if(newBorderWidth /2 ==DEF_LINE_WIDTH_0 )
-                        {
-                            newBorderWidth =DEF_LINE_WIDTH_0;
-                        }
-                        else if(newBorderWidth /2 >=(DEF_LINE_WIDTH_4-DEF_LINE_WIDTH_3))
-                        {
-                            newBorderWidth =DEF_LINE_WIDTH_4;
-                        }
-                        else if(newBorderWidth /2 >=(DEF_LINE_WIDTH_3-DEF_LINE_WIDTH_2))
-                        {
-                            newBorderWidth =DEF_LINE_WIDTH_3;
-                        }
-                        else if(newBorderWidth /2>=(DEF_LINE_WIDTH_2-DEF_LINE_WIDTH_1))
-                        {
-                            newBorderWidth =DEF_LINE_WIDTH_2;
-                        }
-                        else if(newBorderWidth /2>=(DEF_LINE_WIDTH_1 - DEF_LINE_WIDTH_0)  )
-                        {
-                            newBorderWidth =DEF_LINE_WIDTH_1;
-                        }
-                        else
-                        {
-                            newBorderWidth =DEF_LINE_WIDTH_0;
-                        }
-                        const SvxBorderLine  newbrdrline(pPrevRightColor, newBorderWidth,0,0);
-                        aBox.SetLine(&newbrdrline,BOX_LINE_LEFT);
-                        prevaBox.SetLine(&newbrdrline,BOX_LINE_RIGHT);
-                        prevpFmt->SetAttr(prevaBox);
-                    }
-
-                }
-*/
-
                 pFmt->SetFmtAttr(aBox);
 
                 bUseLeftCellPad = false;
@@ -430,8 +361,8 @@ void SwRTFParser::ReadTable( int nToken )
             break;
 
         case RTF_TRGAPH:
-                //$flr bug #117887#: RTF: wrong internal table cell margin imported (A13)
-                aRow.mnBrdDist = (nTokenValue>0?(USHORT)nTokenValue:0); // filter out negative values of \trgaph
+                //bug: RTF: wrong internal table cell margin imported (A13)
+                aRow.mnBrdDist = (nTokenValue>0?(sal_uInt16)nTokenValue:0); // filter out negative values of \trgaph
             break;
 
         case RTF_TRQL:          eAdjust = text::HoriOrientation::LEFT;    break;
@@ -439,7 +370,6 @@ void SwRTFParser::ReadTable( int nToken )
         case RTF_TRQC:          eAdjust = text::HoriOrientation::CENTER;  break;
 
                                 // mit text::VertOrientation::TOP kommt der Dialog nicht klar!
-                                // Bug #65126#
         case RTF_CLVERTALT:     eVerOrient = text::VertOrientation::NONE;     break;
 
         case RTF_CLVERTALC:     eVerOrient = text::VertOrientation::CENTER;   break;
@@ -483,20 +413,20 @@ void SwRTFParser::ReadTable( int nToken )
         default:
             if( ( nToken & ~(0xff | RTF_TABLEDEF)) == RTF_SHADINGDEF )
             {
-                if( aMergeBoxes[ nBoxCnt ] )
+                if( aMergeBoxes.back() )
                     break;
                 ReadBackgroundAttr( nToken,
-                        (SfxItemSet&)pBoxFmt->GetAttrSet(), TRUE );
+                        (SfxItemSet&)pBoxFmt->GetAttrSet(), sal_True );
             }
             else if( ( nToken & ~(0xff | RTF_TABLEDEF) ) == RTF_BRDRDEF ||
                       IsBorderToken(nToken))
             {
-                if( aMergeBoxes[ nBoxCnt ] )
+                if( aMergeBoxes.back() )
                     break;
 
                 SfxItemSet& rSet = (SfxItemSet&)pBoxFmt->GetAttrSet();
                 if(!IsBorderToken( nToken ))
-                    ReadBorderAttr( nToken, rSet, TRUE );
+                    ReadBorderAttr( nToken, rSet, sal_True );
                 else
                     NextToken( nToken );
             }
@@ -505,14 +435,14 @@ void SwRTFParser::ReadTable( int nToken )
                 if( RTF_UNKNOWNCONTROL == nToken )
                     NextToken( nToken );
                 else
-                    bWeiter = FALSE;
+                    bWeiter = sal_False;
             }
             break;
         }
 
         if( text::VertOrientation::NONE != eVerOrient )
         {
-            if( !aMergeBoxes[ nBoxCnt ] )
+            if( !aMergeBoxes.back() )
                 pBoxFmt->SetFmtAttr( SwFmtVertOrient( 0, eVerOrient ));
             eVerOrient = text::VertOrientation::NONE;
         }
@@ -523,19 +453,16 @@ void SwRTFParser::ReadTable( int nToken )
     // das letzte temp. BoxFmt loeschen
     delete pBoxFmt;
 
-    // es wurde keine einzige Box erkannt
-    if( nAktBox == nBoxCnt || ( bReadNewCell && !pTableNode ))
+    // It has been recognized as not single box
+    if( m_nCurrentBox == aMergeBoxes.size()-1 || ( bReadNewCell && !pTableNode ))
     {
-        int nC = aMergeBackup.Count();
-        for (USHORT i = 0; i < nC; ++i)
-            aMergeBoxes.Insert(aMergeBackup[i], i);
-        SkipToken( -1 );			// zum Letzen gueltigen zurueck
+        aMergeBoxes.insert(aMergeBoxes.begin(), aMergeBackup.begin(), aMergeBackup.end());
         return;
     }
 
     nTblSz -= nLSpace;
 
-    int bNewTbl = TRUE;
+    int bNewTbl = sal_True;
     SwTableLine* pNewLine;
     bTrowdRead=true;
 
@@ -604,7 +531,7 @@ void SwRTFParser::ReadTable( int nToken )
                 pBox = (*pLns)[ 0 ]->GetTabBoxes()[ 0 ];
 
             SwNodeIndex aTmpIdx( *pBox->GetSttNd() );
-            pDoc->GetNodes().SplitTable( aTmpIdx, HEADLINE_NONE, FALSE );
+            pDoc->GetNodes().SplitTable( aTmpIdx, HEADLINE_NONE, sal_False );
             pTableNode = pPam->GetNode()->FindTableNode();
             pFmt = pTableNode->GetTable().GetFrmFmt();
 
@@ -624,8 +551,8 @@ void SwRTFParser::ReadTable( int nToken )
         pNewLine = (*pLns)[ pLns->Count() - 1 ];
 
         // jetzt die Boxen abgleichen
-        USHORT nBoxes = Min( pNewLine->GetTabBoxes().Count(), aBoxFmts.Count() );
-        USHORT n;
+        sal_uInt16 nBoxes = Min( pNewLine->GetTabBoxes().Count(), aBoxFmts.Count() );
+        sal_uInt16 n;
 
         for( n = 0; n < nBoxes; ++n )
         {
@@ -636,21 +563,23 @@ void SwRTFParser::ReadTable( int nToken )
         aBoxFmts.Remove( 0, n );
 
         if( aBoxFmts.Count() )		// es muessen noch neue zugefuegt werden
-            nAktBox = n;
+        {
+            m_nCurrentBox = n;
+        }
         else						// es mussen noch Boxen geloescht werden
         {
             // remove ContentIndex of other Bound
             pPam->SetMark(); pPam->DeleteMark();
             while( n < pNewLine->GetTabBoxes().Count() )
                 _DeleteBox( pTableNode->GetTable(),
-                            pNewLine->GetTabBoxes()[ n ], 0, FALSE, FALSE );
+                            pNewLine->GetTabBoxes()[ n ], 0, sal_False, sal_False );
         }
 
         pOldTblNd = pTableNode;
-        bNewTbl = FALSE;
+        bNewTbl = sal_False;
 
         {
-            // JP 13.08.98: TabellenUmrandungen optimieren - Bug 53525
+            //TabellenUmrandungen optimieren
             void* p = pFmt;
             aTblFmts.Insert( p, aTblFmts.Count() );
         }
@@ -708,7 +637,7 @@ void SwRTFParser::ReadTable( int nToken )
                 pNewLine->GetFrmFmt()->ResetFmtAttr( RES_FRM_SIZE );
                 rLns.C40_INSERT( SwTableLine, pNewLine, rLns.Count() );
             }
-            bNewTbl = FALSE;
+            bNewTbl = sal_False;
         }
         else
         {
@@ -716,8 +645,8 @@ void SwRTFParser::ReadTable( int nToken )
             const SwTable *pTable =
                 pDoc->InsertTable(
                     SwInsertTableOptions( tabopts::HEADLINE_NO_BORDER, 0 ),
-                    *pPam->GetPoint(), 1, 1, eAdjust, 0, 0, FALSE, FALSE );
-            bContainsTablePara=true; //#117881#
+                    *pPam->GetPoint(), 1, 1, eAdjust, 0, 0, sal_False, sal_False );
+            bContainsTablePara=true;
             pTableNode = pTable ? pTable->GetTableNode() : 0;
 
             if (pTableNode)
@@ -746,11 +675,11 @@ void SwRTFParser::ReadTable( int nToken )
                 ((SfxItemSet&)pFmt->GetAttrSet()).Put( aL );
             }
 
-            nAktBox = 0;
+            m_nCurrentBox = 0;
             pOldTblNd = pTableNode;
 
             {
-                // JP 13.08.98: TabellenUmrandungen optimieren - Bug 53525
+                // TabellenUmrandungen optimieren
                 void* p = pFmt;
                 aTblFmts.Insert( p, aTblFmts.Count() );
             }
@@ -776,14 +705,14 @@ void SwRTFParser::ReadTable( int nToken )
         if( !pColl )
             pColl = pDoc->GetTxtCollFromPool( RES_POOLCOLL_STANDARD, false );
 
-        USHORT nStt = 0;
+        sal_uInt16 nStt = 0;
         if( bNewTbl )
         {
             SwTableBox* pBox = pNewLine->GetTabBoxes()[0];
             pBoxFmt = (SwTableBoxFmt*)pBox->GetFrmFmt();
-            pBoxFmt->Remove( pBox );
+            pBox->ForgetFrmFmt();
             delete pBoxFmt;
-            aBoxFmts[0]->Add( pBox );
+            pBox->RegisterToFormat( *aBoxFmts[0] );
             SwTxtNode* pTNd = pDoc->GetNodes()[ pBox->GetSttIdx()+1 ]
                                             ->GetTxtNode();
             OSL_ENSURE( pTNd, "wo ist der Textnode dieser Box?" );
@@ -798,12 +727,14 @@ void SwRTFParser::ReadTable( int nToken )
                     aBoxFmts[ nStt ],
                     // Formate fuer den TextNode der Box
                     pColl, 0,
-                    nAktBox + nStt, 1 );
+                    m_nCurrentBox + nStt, 1 );
         }
     }
 
     if( bChkExistTbl )
-        nAktBox = 0;
+    {
+        m_nCurrentBox = 0;
+    }
 
     maInsertedTables.InsertTable(*pTableNode, *pPam);
 
@@ -815,7 +746,8 @@ void SwRTFParser::ReadTable( int nToken )
     if (pNewLine)
     {
         SwTableBoxes &rBoxes = pNewLine->GetTabBoxes();
-        if (SwTableBox* pBox = (nAktBox < rBoxes.Count() ? rBoxes[nAktBox] : 0))
+        if (SwTableBox* pBox = ((m_nCurrentBox < rBoxes.Count())
+                ? rBoxes[m_nCurrentBox] : 0))
         {
             if (const SwStartNode *pStart = pBox->GetSttNd())
             {
@@ -838,7 +770,7 @@ void SwRTFParser::ReadTable( int nToken )
 
     //It might be that there was content at this point which is not already in
     //a table, but which is being followed by properties to place it into the
-    //table. e.g. #109199#. If this is the case then move the para/char
+    //table. If this is the case then move the para/char
     //properties inside the table, and move any content of that paragraph into
     //the table
     bool bInTable = aRg.GetPoint()->nNode.GetNode().FindTableNode();
@@ -861,7 +793,7 @@ void SwRTFParser::ReadTable( int nToken )
         //which were intended to be inside the tablerow are now left outside
         //the table after the row was placed before the current insertion point
         SvxRTFItemStack& rAttrStk = GetAttrStack();
-        for (USHORT n = 0; n < rAttrStk.Count(); ++n)
+        for (size_t n = 0; n < rAttrStk.size(); ++n)
         {
             SvxRTFItemStackType* pStk = rAttrStk[n];
             pStk->MoveFullNode(aOldPos, aNewPos);
@@ -885,16 +817,16 @@ void SwRTFParser::GotoNextBox()
     SwTableBoxes& rBoxes = pLine->GetTabBoxes();
     SwTableBox* pBox = rBoxes[ rBoxes.Count()-1 ];
 
-    if( ++nAktBox >= aMergeBoxes.Count() )
-        nAktBox = aMergeBoxes.Count()-1;
+    if( ++m_nCurrentBox >= aMergeBoxes.size() )
+        m_nCurrentBox = aMergeBoxes.size()-1;
 
-    if( !aMergeBoxes[ nAktBox ] )
+    if (!aMergeBoxes[ m_nCurrentBox ])
     {
-        int bMove = TRUE;
+        int bMove = sal_True;
         if( pBox->GetSttIdx() > pPam->GetPoint()->nNode.GetIndex() )
         {
-            USHORT nRealBox = 0;
-            for( USHORT nTmp = 0; nTmp < nAktBox; ++nTmp )
+            sal_uInt16 nRealBox = 0;
+            for (sal_uInt16 nTmp = 0; nTmp < m_nCurrentBox; ++nTmp)
                 if( !aMergeBoxes[ nTmp ] )
                     ++nRealBox;
 
@@ -902,15 +834,15 @@ void SwRTFParser::GotoNextBox()
             {
                 pPam->GetPoint()->nNode = *rBoxes[ nRealBox ]->GetSttNd()->EndOfSectionNode();
                 pPam->Move( fnMoveBackward, fnGoCntnt );
-                bMove = FALSE;
+                bMove = sal_False;
             }
         }
 
-        if( bMove && nAktBox + 1 == aMergeBoxes.Count() )
+        if( bMove && m_nCurrentBox + 1U == aMergeBoxes.size() )
             // dann hinter die Tabelle
             pPam->Move( fnMoveForward, fnGoNode );
     }
-    else if( !pDoc->GetNodes()[ pPam->GetPoint()->nNode ]->IsCntntNode() )
+    else if (pPam->GetPoint()->nNode.GetNode().IsCntntNode())
         // dann in die vorherige ans Ende
         pPam->Move( fnMoveBackward, fnGoCntnt );
 }
@@ -921,7 +853,7 @@ void SwRTFParser::NewTblLine()
     nInsTblRow = USHRT_MAX;
 
     // erweiter die aktuelle um eine neue Line
-    BOOL bMakeCopy = FALSE;
+    sal_Bool bMakeCopy = sal_False;
     SwNode* pNd = pDoc->GetNodes()[ pPam->GetPoint()->nNode.GetIndex()-1 ];
     if( !pNd->IsEndNode() ||
         !(pNd = pNd->StartOfSectionNode())->IsTableNode() )
@@ -929,7 +861,7 @@ void SwRTFParser::NewTblLine()
         if( !pOldTblNd )
             return ;
 
-        bMakeCopy = TRUE;
+        bMakeCopy = sal_True;
         pNd = pOldTblNd;
     }
     pTableNode = (SwTableNode*)pNd;
@@ -945,7 +877,7 @@ void SwRTFParser::NewTblLine()
     if( !bMakeCopy &&
         64000 < pTableNode->GetTable().GetTabSortBoxes().Count() )
     {
-        bMakeCopy = TRUE;		// spaetestens jetzt eine neue anfangen!
+        bMakeCopy = sal_True;		// spaetestens jetzt eine neue anfangen!
     }
 
     if( bMakeCopy )
@@ -954,8 +886,8 @@ void SwRTFParser::NewTblLine()
         SwSelBoxes aBoxes;
         pTableNode->GetTable().SelLineFromBox( pBox, aBoxes );
         pTableNode->GetTable().MakeCopy( pDoc, *pPam->GetPoint(),
-                                        aBoxes, FALSE );
-        ULONG nNd = pPam->GetPoint()->nNode.GetIndex()-1;
+                                        aBoxes, sal_False );
+        sal_uLong nNd = pPam->GetPoint()->nNode.GetIndex()-1;
         pTableNode = pDoc->GetNodes()[ nNd ]->FindTableNode();
         pOldTblNd = pTableNode;
 
@@ -964,15 +896,14 @@ void SwRTFParser::NewTblLine()
         pLns = &pTableNode->GetTable().GetTabLines();
     }
     else
-//		pDoc->InsertRow( aBoxes );
         pTableNode->GetTable().AppendRow( pDoc );
 
     pBox = (*pLns)[ pLns->Count()-1 ]->GetTabBoxes()[0];
 
-    ULONG nOldPos = pPam->GetPoint()->nNode.GetIndex();
+    sal_uLong nOldPos = pPam->GetPoint()->nNode.GetIndex();
     pPam->GetPoint()->nNode = *pBox->GetSttNd();
     pPam->Move( fnMoveForward );
-    nAktBox = 0;
+    m_nCurrentBox = 0;
 
     // alle Nodes in den Boxen auf die "default" Vorlage setzten
     {
@@ -1002,12 +933,11 @@ void SwRTFParser::NewTblLine()
         pPam->DeleteMark();
     }
 
-    // alle Attribute, die schon auf den nachfolgen zeigen auf die neue
-    // Box umsetzen !!
+    // all attributes which will be displayed in new Box
     SvxRTFItemStack& rAttrStk = GetAttrStack();
     const SvxRTFItemStackType* pStk;
-    for( USHORT n = 0; n < rAttrStk.Count(); ++n )
-        if( ( pStk = rAttrStk[ n ])->GetSttNodeIdx() == ULONG(nOldPos) &&
+    for( size_t n = 0; n < rAttrStk.size(); ++n )
+        if( ( pStk = rAttrStk[ n ])->GetSttNodeIdx() == sal_uLong(nOldPos) &&
             !pStk->GetSttCnt() )
             ((SvxRTFItemStackType*)pStk)->SetStartPos( SwxPosition( pPam ) );
 }
