@@ -55,7 +55,6 @@
 #include <docsh.hxx>
 
 #include <unotools/ucbstreamhelper.hxx>
-#include <errhdl.hxx>
 #include <swerror.h>
 #include <wrtxml.hxx>
 #include <statstr.hrc>
@@ -81,7 +80,7 @@ SwXMLWriter::SwXMLWriter( const String& rBaseURL )
 }
 
 
-__EXPORT SwXMLWriter::~SwXMLWriter()
+SwXMLWriter::~SwXMLWriter()
 {
 }
 
@@ -171,7 +170,7 @@ pGraphicHelper = SvXMLGraphicHelper::Create( xStg,
         { "StyleFamilies", sizeof("StyleFamilies")-1, 0,
               &::getCppuType( (Sequence<sal_Int32>*)0 ),
               beans::PropertyAttribute::MAYBEVOID, 0 },
-        // --> OD 2006-09-26 #i69627#
+        // #i69627#
         { "OutlineStyleAsNormalListStyle", sizeof("OutlineStyleAsNormalListStyle")-1, 0,
               &::getBooleanCppuType(),
               beans::PropertyAttribute::MAYBEVOID, 0 },
@@ -204,35 +203,6 @@ pGraphicHelper = SvXMLGraphicHelper::Create( xStg,
                 pStatusBarItem->GetValue() >>= xStatusIndicator;
         }
 
-//		try
-//		{
-//			uno::Reference<frame::XModel> xModel( pDoc->GetDocShell()->GetModel());
-//			if (xModel.is())
-//			{
-//				uno::Sequence< beans::PropertyValue > xMediaDescr
-//				uno::Reference<frame::XController> xController(
-//					xModel->getCurrentController());
-//				if( xController.is())
-//				{
-//					uno::Reference<frame::XFrame> xFrame( xController->getFrame());
-//					if( xFrame.is())
-//					{
-//						uno::Reference<task::XStatusIndicatorFactory> xFactory(
-//							xFrame, uno::UNO_QUERY );
-//						if( xFactory.is())
-//						{
-//							xStatusIndicator =
-//								xFactory->createStatusIndicator();
-//						}
-//					}
-//				}
-//			}
-//		}
-//		catch( const RuntimeException& )
-//		{
-//			xStatusIndicator = 0;
-//		}
-
         // set progress range and start status indicator
         sal_Int32 nProgressRange(1000000);
         if (xStatusIndicator.is())
@@ -299,7 +269,7 @@ pGraphicHelper = SvXMLGraphicHelper::Create( xStg,
         xInfoSet->setPropertyValue( sAutoTextMode, aAny2 );
     }
 
-    // --> OD 2006-09-26 #i69627#
+    // #i69627#
     const sal_Bool bOASIS = ( SotStorage::GetVersion( xStg ) > SOFFICE_FILEFORMAT_60 );
     if ( bOASIS &&
          docfunc::HasOutlineStyleToBeWrittenAsNormalListStyle( *pDoc ) )
@@ -469,11 +439,9 @@ pGraphicHelper = SvXMLGraphicHelper::Create( xStg,
         }
     }
 
-    if( pDoc->GetRootFrm() && pDoc->GetDocStat().nPage > 1 &&
+    if( pDoc->GetCurrentViewShell() && pDoc->GetDocStat().nPage > 1 &&	//swmod 071108//swmod 071225
         !(bOrganizerMode || bBlock || bErr) )
     {
-//			DBG_ASSERT( !pDoc->GetDocStat().bModified,
-//						"doc stat is modified!" );
         OUString sStreamName( RTL_CONSTASCII_USTRINGPARAM("layout-cache") );
         try
         {
@@ -539,17 +507,17 @@ pGraphicHelper = SvXMLGraphicHelper::Create( xStg,
     return 0;
 }
 
-ULONG SwXMLWriter::WriteStorage()
+sal_uLong SwXMLWriter::WriteStorage()
 {
     return _Write();
 }
 
-ULONG SwXMLWriter::WriteMedium( SfxMedium& aTargetMedium )
+sal_uLong SwXMLWriter::WriteMedium( SfxMedium& aTargetMedium )
 {
     return _Write( &aTargetMedium );
 }
 
-ULONG SwXMLWriter::Write( SwPaM& rPaM, SfxMedium& rMed,
+sal_uLong SwXMLWriter::Write( SwPaM& rPaM, SfxMedium& rMed,
                                const String* pFileName )
 {
     return IsStgWriter()
