@@ -53,7 +53,7 @@
 #include <editeng/acorrcfg.hxx>
 
 #if OSL_DEBUG_LEVEL > 1
-BOOL   SwViewOption::bTest9 = FALSE;		//DrawingLayerNotLoading
+sal_Bool   SwViewOption::bTest9 = sal_False;		//DrawingLayerNotLoading
 #endif
 Color SwViewOption::aDocBoundColor(COL_LIGHTGRAY);
 Color SwViewOption::aObjectBoundColor(COL_LIGHTGRAY);
@@ -72,9 +72,10 @@ Color SwViewOption::aFieldShadingsColor(COL_LIGHTGRAY);
 Color SwViewOption::aSectionBoundColor(COL_LIGHTGRAY);
 Color SwViewOption::aPageBreakColor(COL_BLUE);
 Color SwViewOption::aScriptIndicatorColor(COL_GREEN);
+Color SwViewOption::aShadowColor(COL_GRAY);
 
 sal_Int32 SwViewOption::nAppearanceFlags = VIEWOPT_DOC_BOUNDARIES|VIEWOPT_OBJECT_BOUNDARIES;
-USHORT SwViewOption::nPixelTwips = 0;   //ein Pixel auf dem Bildschirm
+sal_uInt16 SwViewOption::nPixelTwips = 0;   // one pixel on the screen
 
 
 #define LINEBREAK_SIZE 12, 8
@@ -85,9 +86,9 @@ USHORT SwViewOption::nPixelTwips = 0;   //ein Pixel auf dem Bildschirm
 #define MIN_TABWIDTH		120
 #define MIN_TABHEIGHT		200
 
-static const char __FAR_DATA aPostItStr[] = "  ";
+static const char aPostItStr[] = "  ";
 
-BOOL SwViewOption::IsEqualFlags( const SwViewOption &rOpt ) const
+sal_Bool SwViewOption::IsEqualFlags( const SwViewOption &rOpt ) const
 {
     return	nCoreOptions == rOpt.nCoreOptions
             && nCore2Options == rOpt.nCore2Options
@@ -98,12 +99,13 @@ BOOL SwViewOption::IsEqualFlags( const SwViewOption &rOpt ) const
             && nPagePrevRow == rOpt.GetPagePrevRow()
             && nPagePrevCol == rOpt.GetPagePrevCol()
             && aRetoucheColor == rOpt.GetRetoucheColor()
-            && bFormView == rOpt.IsFormView()
+            && mbFormView == rOpt.IsFormView()
+            && mbBrowseMode == rOpt.getBrowseMode()
             && mbViewLayoutBookMode == rOpt.mbViewLayoutBookMode
             && bShowPlaceHolderFields == rOpt.bShowPlaceHolderFields
             && bIdle == rOpt.bIdle
 #if OSL_DEBUG_LEVEL > 1
-            // korrespondieren zu den Angaben in ui/config/cfgvw.src
+            // correspond to the statements in ui/config/cfgvw.src
             && bTest1 == rOpt.IsTest1()
             && bTest2 == rOpt.IsTest2()
             && bTest3 == rOpt.IsTest3()
@@ -144,10 +146,10 @@ void SwViewOption::DrawRectPrinter( OutputDevice *pOut,
     pOut->SetLineColor( aOldColor );
 }
 
-USHORT SwViewOption::GetPostItsWidth( const OutputDevice *pOut ) const
+sal_uInt16 SwViewOption::GetPostItsWidth( const OutputDevice *pOut ) const
 {
     OSL_ENSURE( pOut, "no Outdev" );
-    return USHORT(pOut->GetTextWidth( String::CreateFromAscii(aPostItStr )));
+    return sal_uInt16(pOut->GetTextWidth( String::CreateFromAscii(aPostItStr )));
 }
 
 void SwViewOption::PaintPostIts( OutputDevice *pOut, const SwRect &rRect, sal_Bool bIsScript ) const
@@ -156,8 +158,8 @@ void SwViewOption::PaintPostIts( OutputDevice *pOut, const SwRect &rRect, sal_Bo
     {
             Color aOldLineColor( pOut->GetLineColor() );
         pOut->SetLineColor( Color(COL_GRAY ) );
-        // Wir ziehen ueberall zwei Pixel ab, damit es schick aussieht
-        USHORT nPix = GetPixelTwips() * 2;
+        // to make it look nice, we subtract two pixels everywhere
+        sal_uInt16 nPix = GetPixelTwips() * 2;
         if( rRect.Width() <= 2 * nPix || rRect.Height() <= 2 * nPix )
             nPix = 0;
         const Point aTopLeft(  rRect.Left()  + nPix, rRect.Top()	+ nPix );
@@ -169,27 +171,27 @@ void SwViewOption::PaintPostIts( OutputDevice *pOut, const SwRect &rRect, sal_Bo
 }
 
 SwViewOption::SwViewOption() :
+    sSymbolFont( RTL_CONSTASCII_USTRINGPARAM( "symbol" ) ),
     aRetoucheColor( COL_TRANSPARENT ),
     mnViewLayoutColumns( 0 ),
     nPagePrevRow( 1 ),
     nPagePrevCol( 2 ),
     nShdwCrsrFillMode( FILL_TAB ),
-    bReadonly(FALSE),
-    bStarOneSetting(FALSE),
-    bIsPagePreview(FALSE),
-    bSelectionInReadonly(FALSE),
-    // #114856# Formular view
-    bFormView(FALSE),
-    bBookview(FALSE),
-    mbViewLayoutBookMode(FALSE),
+    bReadonly(sal_False),
+    bStarOneSetting(sal_False),
+    bIsPagePreview(sal_False),
+    bSelectionInReadonly(sal_False),
+    mbFormView(sal_False),
+    mbBrowseMode(sal_False),
+    mbBookView(sal_False),
+    mbViewLayoutBookMode(sal_False),
     bShowPlaceHolderFields( sal_True ),
-
     nZoom( 100 ),
     eZoom( SVX_ZOOM_PERCENT ),
     nTblDest(TBL_DEST_CELL)
 {
-    // Initialisierung ist jetzt etwas einfacher
-    // alle Bits auf 0
+    // Initialisation is a little simpler now
+    // all Bits to 0
     nCoreOptions =  VIEWOPT_1_HARDBLANK | VIEWOPT_1_SOFTHYPH |
                     VIEWOPT_1_REF |
                     VIEWOPT_1_GRAPHIC |
@@ -210,18 +212,18 @@ SwViewOption::SwViewOption() :
     bIdle = true;
 
 #if OSL_DEBUG_LEVEL > 1
-    // korrespondieren zu den Angaben in ui/config/cfgvw.src
+    // correspond to the statements in ui/config/cfgvw.src
     bTest1 = bTest2 = bTest3 = bTest4 =
-             bTest5 = bTest6 = bTest7 = bTest8 = bTest10 = FALSE;
+             bTest5 = bTest6 = bTest7 = bTest8 = bTest10 = sal_False;
 #endif
 }
 
 SwViewOption::SwViewOption(const SwViewOption& rVOpt)
 {
-    bReadonly = FALSE;
-    bSelectionInReadonly = FALSE;
+    bReadonly = sal_False;
+    bSelectionInReadonly = sal_False;
     // #114856# Formular view
-    bFormView       = rVOpt.bFormView;
+    mbFormView       = rVOpt.mbFormView;
     nZoom           = rVOpt.nZoom       ;
     aSnapSize   	= rVOpt.aSnapSize   ;
     mnViewLayoutColumns = rVOpt.mnViewLayoutColumns ;
@@ -239,7 +241,8 @@ SwViewOption::SwViewOption(const SwViewOption& rVOpt)
     sSymbolFont 	= rVOpt.sSymbolFont;
     nShdwCrsrFillMode = rVOpt.nShdwCrsrFillMode;
     bStarOneSetting = rVOpt.bStarOneSetting;
-    bBookview		= rVOpt.bBookview;
+    mbBookView	    = rVOpt.mbBookView;
+    mbBrowseMode	= rVOpt.mbBrowseMode;
     mbViewLayoutBookMode = rVOpt.mbViewLayoutBookMode;
     bShowPlaceHolderFields = rVOpt.bShowPlaceHolderFields;
     bIdle           = rVOpt.bIdle;
@@ -261,7 +264,7 @@ SwViewOption::SwViewOption(const SwViewOption& rVOpt)
 SwViewOption& SwViewOption::operator=( const SwViewOption &rVOpt )
 {
     // #114856# Formular view
-    bFormView       = rVOpt.bFormView   ;
+    mbFormView       = rVOpt.mbFormView   ;
     nZoom   		= rVOpt.nZoom   	;
     aSnapSize   	= rVOpt.aSnapSize   ;
     mnViewLayoutColumns = rVOpt.mnViewLayoutColumns ;
@@ -279,7 +282,8 @@ SwViewOption& SwViewOption::operator=( const SwViewOption &rVOpt )
     sSymbolFont 	= rVOpt.sSymbolFont;
     nShdwCrsrFillMode = rVOpt.nShdwCrsrFillMode;
     bStarOneSetting = rVOpt.bStarOneSetting;
-    bBookview		= rVOpt.bBookview;
+    mbBookView	    = rVOpt.mbBookView;
+    mbBrowseMode	= rVOpt.mbBrowseMode;
     mbViewLayoutBookMode = rVOpt.mbViewLayoutBookMode;
     bShowPlaceHolderFields = rVOpt.bShowPlaceHolderFields;
     bIdle           = rVOpt.bIdle;
@@ -307,11 +311,11 @@ void SwViewOption::Init( Window *pWin )
 {
     if( !nPixelTwips && pWin )
     {
-        nPixelTwips = (USHORT)pWin->PixelToLogic( Size(1,1) ).Height();
+        nPixelTwips = (sal_uInt16)pWin->PixelToLogic( Size(1,1) ).Height();
     }
 }
 
-BOOL SwViewOption::IsAutoCompleteWords() const
+sal_Bool SwViewOption::IsAutoCompleteWords() const
 {
     const SvxSwAutoFmtFlags& rFlags = SvxAutoCorrCfg::Get()->GetAutoCorrect()->GetSwFlags();
     return rFlags.bAutoCmpltCollectWords;
@@ -324,9 +328,9 @@ AuthorCharAttr::AuthorCharAttr() :
 {
 }
 
-USHORT		GetHtmlMode(const SwDocShell* pShell)
+sal_uInt16		GetHtmlMode(const SwDocShell* pShell)
 {
-    USHORT nRet = 0;
+    sal_uInt16 nRet = 0;
     if(!pShell || PTR_CAST(SwWebDocShell, pShell))
     {
         nRet = HTMLMODE_ON;
@@ -418,6 +422,11 @@ Color&   SwViewOption::GetSmarttagColor()
     return aSmarttagColor;
 }
 
+Color&   SwViewOption::GetShadowColor()
+{
+    return aShadowColor;
+}
+
 Color&   SwViewOption::GetFontColor()
 {
     return aFontColor;
@@ -475,6 +484,11 @@ void SwViewOption::ApplyColorConfigValues(const svtools::ColorConfig& rConfig )
     if(aValue.bIsVisible)
         nAppearanceFlags |= VIEWOPT_VISITED_LINKS;
 
+    aValue = rConfig.GetColorValue(svtools::SHADOWCOLOR);
+    aShadowColor.SetColor(aValue.nColor);
+    if(aValue.bIsVisible)
+        nAppearanceFlags |= VIEWOPT_SHADOW;
+
     aDirectCursorColor.SetColor(rConfig.GetColorValue(svtools::WRITERDIRECTCURSOR).nColor);
 
     aTextGridColor.SetColor(rConfig.GetColorValue(svtools::WRITERTEXTGRID).nColor);
@@ -501,7 +515,7 @@ void SwViewOption::ApplyColorConfigValues(const svtools::ColorConfig& rConfig )
     aScriptIndicatorColor.SetColor(rConfig.GetColorValue(svtools::WRITERSCRIPTINDICATOR).nColor);
 }
 
-void SwViewOption::SetAppearanceFlag(sal_Int32 nFlag, BOOL bSet, BOOL bSaveInConfig )
+void SwViewOption::SetAppearanceFlag(sal_Int32 nFlag, sal_Bool bSet, sal_Bool bSaveInConfig )
 {
     if(bSet)
         nAppearanceFlags |= nFlag;
@@ -526,6 +540,7 @@ void SwViewOption::SetAppearanceFlag(sal_Int32 nFlag, BOOL bSet, BOOL bSaveInCon
             { VIEWOPT_VISITED_LINKS      ,   svtools::LINKSVISITED },
             { VIEWOPT_FIELD_SHADINGS     ,   svtools::WRITERFIELDSHADINGS },
             { VIEWOPT_SECTION_BOUNDARIES ,   svtools::WRITERSECTIONBOUNDARIES },
+            { VIEWOPT_SHADOW             ,   svtools::SHADOWCOLOR },
             { 0                          ,   svtools::ColorConfigEntryCount }
         };
         sal_uInt16 nPos = 0;
@@ -542,7 +557,7 @@ void SwViewOption::SetAppearanceFlag(sal_Int32 nFlag, BOOL bSet, BOOL bSaveInCon
     }
 }
 
-BOOL SwViewOption::IsAppearanceFlag(sal_Int32 nFlag)
+sal_Bool SwViewOption::IsAppearanceFlag(sal_Int32 nFlag)
 {
     return 0 != (nAppearanceFlags & nFlag);
 }
