@@ -60,16 +60,12 @@
 #include <redline.hxx>
 #include <docary.hxx>
 #include <SwRewriter.hxx>
-#include <undobj.hxx>
 #include <tools/color.hxx>
 
 #include <swmodule.hxx>
 #include <annotation.hrc>
 #include "cmdid.h"
 
-#include <SwRewriter.hxx>
-#include <undobj.hxx>
-
 #include <sfx2/request.hxx>
 #include <sfx2/event.hxx>
 #include <svl/srchitem.hxx>
@@ -88,6 +84,7 @@
 #include <i18npool/lang.h>
 
 #include "swevent.hxx"
+#include "switerator.hxx"
 
 // distance between Anchor Y and initial note position
 #define POSTIT_INITIAL_ANCHOR_DISTANCE      20
@@ -101,34 +98,10 @@
 
 using namespace sw::sidebarwindows;
 
-/*
-bool comp_author( const SwPostItItem* a, const SwPostItItem* b)
-{
-    return a->pFmtFld->GetFld()->GetPar1() < b->pFmtFld->GetFld()->GetPar1();
-}
-
-bool comp_date( const SwPostItItem* a, const SwPostItItem* b)
-{
-    return static_cast<SwPostItField*>(a->pFmtFld->GetFld())->GetDate()  < static_cast<SwPostItField*>(b->pFmtFld->GetFld())->GetDate();
-}
-*/
-
-//
 bool comp_pos(const SwSidebarItem* a, const SwSidebarItem* b)
 {
-    // --> OD 2010-01-19 #i88070#
     // sort by anchor position
-//// if position is on the same line, sort by x (Left) position, otherwise by y(Bottom) position
-//// if two notes are at the same position, sort by logical node position
-//    return (a->maLayoutInfo.mPosition.Bottom() == b->maLayoutInfo.mPosition.Bottom())
-//            ? ( ( (a->maLayoutInfo.mPosition.Left() == b->maLayoutInfo.mPosition.Left()) &&
-//                  (a->GetBroadCaster()->ISA(SwFmtFld) && b->GetBroadCaster()->ISA(SwFmtFld)) )
-//                ? *(static_cast<SwFmtFld*>(a->GetBroadCaster())->GetTxtFld()->GetStart()) <
-//                    *(static_cast<SwFmtFld*>(b->GetBroadCaster())->GetTxtFld()->GetStart())
-//                : a->maLayoutInfo.mPosition.Left() < b->maLayoutInfo.mPosition.Left() )
-//            : a->maLayoutInfo.mPosition.Bottom() < b->maLayoutInfo.mPosition.Bottom();
     return a->GetAnchorPosition() < b->GetAnchorPosition();
-    // <--
 }
 
 SwPostItMgr::SwPostItMgr(SwView* pView)
@@ -179,7 +152,7 @@ SwPostItMgr::~SwPostItMgr()
     RemoveSidebarWin();
     EndListening( *mpView->GetDocShell() );
 
-    for(std::vector<SwPostItPageItem*>::iterator i = mPages.begin(); i!= mPages.end() ; i++)
+    for(std::vector<SwPostItPageItem*>::iterator i = mPages.begin(); i!= mPages.end() ; ++i)
         delete (*i);
     mPages.clear();
 
@@ -226,7 +199,7 @@ void SwPostItMgr::InsertItem(SfxBroadcaster* pItem, bool bCheckExistance, bool b
 {
     if (bCheckExistance)
     {
-        for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; i++)
+        for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; ++i)
         {
             if ( (*i)->GetBroadCaster() == pItem )
                 return;
@@ -235,19 +208,14 @@ void SwPostItMgr::InsertItem(SfxBroadcaster* pItem, bool bCheckExistance, bool b
     mbLayout = bFocus;
     if (pItem->ISA(SwFmtFld))
         mvPostItFlds.push_back(new SwAnnotationItem(static_cast<SwFmtFld*>(pItem), true, bFocus) );
-    /*
-    else
-    if (pItem->ISA(SwRedline))
-        mvPostItFlds.push_back(new SwRedCommentItem( static_cast<SwRedline*>(pItem), true, bFocus)) ;
-    */
-    OSL_ENSURE(pItem->ISA(SwFmtFld) /*|| pItem->ISA(SwRedline)*/,"Mgr::InsertItem: seems like new stuff was added");
+    OSL_ENSURE(pItem->ISA(SwFmtFld),"Mgr::InsertItem: seems like new stuff was added");
     StartListening(*pItem);
 }
 
 void SwPostItMgr::RemoveItem( SfxBroadcaster* pBroadcast )
 {
     EndListening(*pBroadcast);
-    for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; i++)
+    for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; ++i)
     {
         if ( (*i)->GetBroadCaster() == pBroadcast )
         {
@@ -316,42 +284,13 @@ void SwPostItMgr::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
                 if ( mpView->GetDocShell() != &rBC )
                 {
                     // field to be removed is the broadcaster
-                    OSL_ENSURE(false, "Notification for removed SwFmtFld was not sent!");
+                    OSL_FAIL("Notification for removed SwFmtFld was not sent!");
                     RemoveItem(&rBC);
                 }
                 break;
             }
         }
     }
-    /*
-    else if ( rHint.IsA(TYPE(SwRedlineHint) ) )
-    {
-        const SwRedlineHint rRedlineHint = static_cast<const SwRedlineHint&>(rHint);
-           SwRedline* pRedline = const_cast<SwRedline*>(rRedlineHint.GetRedline());
-        switch ( rRedlineHint.Which() )
-        {
-            case SWREDLINE_INSERTED :
-            {
-                bool bEmpty = !HasNotes();
-                InsertItem( pRedline, true, false );
-                if (bEmpty && !mvPostItFlds.empty())
-                    PrepareView(true);
-                break;
-            }
-            case SWREDLINE_REMOVED:
-            {
-                RemoveItem(pRedline);
-                break;
-            }
-            case SWREDLINE_FOCUS:
-            {
-                                if (rRedlineHint.GetView()== mpView)
-                    Focus(rBC);
-                break;
-            }
-        }
-    }
-    */
     else if ( rHint.IsA(TYPE(SwFmtFldHint) ) )
     {
         const SwFmtFldHint& rFmtHint = static_cast<const SwFmtFldHint&>(rHint);
@@ -375,7 +314,7 @@ void SwPostItMgr::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
                 }
                 else
                 {
-                    OSL_ENSURE(false, "Inserted field not in document!" );
+                    OSL_FAIL("Inserted field not in document!" );
                         }
                 break;
             }
@@ -401,7 +340,7 @@ void SwPostItMgr::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
             case SWFMTFLD_CHANGED:
             {
                         SwFmtFld* pFmtFld = dynamic_cast<SwFmtFld*>(&rBC);
-                for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; i++)
+                for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; ++i)
                 {
                             if ( pFmtFld == (*i)->GetBroadCaster() )
                     {
@@ -418,14 +357,14 @@ void SwPostItMgr::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
             case SWFMTFLD_LANGUAGE:
             {
                         SwFmtFld* pFmtFld = dynamic_cast<SwFmtFld*>(&rBC);
-                for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; i++)
+                for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; ++i)
                 {
                                 if ( pFmtFld == (*i)->GetBroadCaster() )
                     {
                         if ((*i)->pPostIt)
                         {
-                            USHORT nScriptType = SvtLanguageOptions::GetScriptTypeOfLanguage( (*i)->GetFmtFld()->GetFld()->GetLanguage() );
-                            USHORT nLangWhichId = 0;
+                            sal_uInt16 nScriptType = SvtLanguageOptions::GetScriptTypeOfLanguage( (*i)->GetFmtFld()->GetFld()->GetLanguage() );
+                            sal_uInt16 nLangWhichId = 0;
                             switch (nScriptType)
                             {
                                 case SCRIPTTYPE_LATIN :    nLangWhichId = EE_CHAR_LANGUAGE ; break;
@@ -452,7 +391,7 @@ void SwPostItMgr::Focus(SfxBroadcaster& rBC)
         mpView->ExecViewOptions(aRequest);
     }
 
-    for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; i++)
+    for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; ++i)
     {
         // field to get the focus is the broadcaster
         if ( &rBC == (*i)->GetBroadCaster() )
@@ -486,12 +425,12 @@ bool SwPostItMgr::CalcRects()
     PreparePageContainer();
     if ( !mvPostItFlds.empty() )
     {
-        for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; i++)
+        for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; ++i)
         {
             SwSidebarItem* pItem = (*i);
             if ( !pItem->UseElement() )
             {
-                OSL_ENSURE(false, "PostIt is not in doc or other wrong use");
+                OSL_FAIL("PostIt is not in doc or other wrong use");
                 bRepair = true;
                 continue;
             }
@@ -518,7 +457,7 @@ bool SwPostItMgr::CalcRects()
         Sort(SORT_POS);
 
         // sort the items into the right page vector, so layout can be done by page
-        for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; i++)
+        for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; ++i)
         {
             SwSidebarItem* pItem = (*i);
             if( SwPostItHelper::INVISIBLE == pItem->mLayoutStatus )
@@ -576,7 +515,7 @@ bool SwPostItMgr::CalcRects()
 
 bool SwPostItMgr::HasScrollbars() const
 {
-    for(std::list<SwSidebarItem*>::const_iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; i++)
+    for(std::list<SwSidebarItem*>::const_iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; ++i)
     {
         if ((*i)->bShow && (*i)->pPostIt && (*i)->pPostIt->HasScrollbar())
             return true;
@@ -605,7 +544,7 @@ void SwPostItMgr::PreparePageContainer()
         }
     }
     // only clear the list, DO NOT delete the objects itself
-    for(std::vector<SwPostItPageItem*>::iterator i = mPages.begin(); i!= mPages.end() ; i++)
+    for(std::vector<SwPostItPageItem*>::iterator i = mPages.begin(); i!= mPages.end() ; ++i)
     {
         (*i)->mList->clear();
         if (mvPostItFlds.empty())
@@ -777,16 +716,6 @@ void SwPostItMgr::LayoutPostIts()
                                 OSL_ENSURE(mPages[n]->bScrollbar,"SwPostItMgr::LayoutByPage(): note overlaps, but bScrollbar is not true");
                             }
                         }
-
-                        // do some magic so we really see the focused note
-                        for(SwSidebarWin_iterator i = aVisiblePostItList.begin(); i!= aVisiblePostItList.end() ; i++)
-                        {
-                                            if ((*i)->HasChildPathFocus())
-                            {
-                                MakeVisible((*i),n+1);
-                                break;
-                            }
-                        }
                     }
                     else
                     {
@@ -814,7 +743,7 @@ void SwPostItMgr::LayoutPostIts()
                     SwSidebarItem* pItem = (*i);
                     if ( !pItem->UseElement() )
                     {
-                        OSL_ENSURE(false, "PostIt is not in doc!");
+                        OSL_FAIL("PostIt is not in doc!");
                         bRepair = true;
                         continue;
                     }
@@ -847,7 +776,7 @@ bool SwPostItMgr::BorderOverPageBorder(unsigned long aPage) const
 {
     if ( mPages[aPage-1]->mList->empty() )
     {
-        OSL_ENSURE(false, "Notes SidePane painted but no rects and page lists calculated!");
+        OSL_FAIL("Notes SidePane painted but no rects and page lists calculated!");
         return false;
     }
 
@@ -963,7 +892,7 @@ void SwPostItMgr::MakeVisible(const SwSidebarWin* pPostIt,long aPage )
         mpWrtShell->MakeVisible(SwRect(mpEditWin->PixelToLogic(aNoteRect)));
 }
 
-bool SwPostItMgr::ArrowEnabled(USHORT aDirection,unsigned long aPage) const
+bool SwPostItMgr::ArrowEnabled(sal_uInt16 aDirection,unsigned long aPage) const
 {
     switch (aDirection)
     {
@@ -979,7 +908,7 @@ bool SwPostItMgr::ArrowEnabled(USHORT aDirection,unsigned long aPage) const
     }
 }
 
-Color SwPostItMgr::GetArrowColor(USHORT aDirection,unsigned long aPage) const
+Color SwPostItMgr::GetArrowColor(sal_uInt16 aDirection,unsigned long aPage) const
 {
     if (ArrowEnabled(aDirection,aPage))
     {
@@ -1008,9 +937,7 @@ bool SwPostItMgr::LayoutByPage(std::list<SwSidebarWin*> &aVisiblePostItList,cons
     long			lTopBorder		= rBorder.Top() + 5;
     long			lBottomBorder	= rBorder.Bottom() - 5;
     const long		lVisibleHeight	= lBottomBorder - lTopBorder; //rBorder.GetHeight() ;
-    long			lSpaceUsed		= 0;
     long			lTranslatePos	= 0;
-    int				loop			= 0;
     bool			bDone			= false;
     bool			bScrollbars		= false;
 
@@ -1040,6 +967,8 @@ bool SwPostItMgr::LayoutByPage(std::list<SwSidebarWin*> &aVisiblePostItList,cons
     //start the real layout so nothing overlaps anymore
     if (aVisiblePostItList.size()>1)
     {
+        long lSpaceUsed = 0;
+        int	 loop = 0;
         // if no window is moved anymore we are finished
         while (!bDone)
         {
@@ -1113,7 +1042,6 @@ bool SwPostItMgr::LayoutByPage(std::list<SwSidebarWin*> &aVisiblePostItList,cons
                     //(*i) is the last visible item
                     SwSidebarWin_iterator aPrevPostIt = i;
                     --aPrevPostIt;
-                    //lTranslatePos = ( (*aPrevPostIt)->VirtualPos().Y() + (*aPrevPostIt)->VirtualSize().Height() + GetSpaceBetween() ) - (*i)->VirtualPos().Y();
                     lTranslatePos = ( (*aPrevPostIt)->VirtualPos().Y() + (*aPrevPostIt)->VirtualSize().Height() ) - (*i)->VirtualPos().Y();
                     if (lTranslatePos > 0)
                     {
@@ -1145,7 +1073,7 @@ bool SwPostItMgr::LayoutByPage(std::list<SwSidebarWin*> &aVisiblePostItList,cons
             // security check so we don't loop forever
             if (loop>MAX_LOOP_COUNT)
             {
-                OSL_ENSURE(false, "PostItMgr::Layout(): We are looping forever");
+                OSL_FAIL("PostItMgr::Layout(): We are looping forever");
                 break;
             }
         }
@@ -1168,37 +1096,20 @@ bool SwPostItMgr::LayoutByPage(std::list<SwSidebarWin*> &aVisiblePostItList,cons
     return bScrollbars;
  }
 
-/*
-void SwPostItMgr::AddRedlineComments(bool bCheckExistance, bool bFocus)
-{
-    bool bEmpty = mvPostItFlds.empty();
-    const SwRedlineTbl& aTable = mpView->GetDocShell()->GetDoc()->GetRedlineTbl();
-    for( USHORT i = 0; i < aTable.Count(); ++i )
-    {
-        SwRedline* pRedline = const_cast<SwRedline*>((aTable)[i]);
-        if ( pRedline->GetComment() != String(rtl::OUString::createFromAscii("")) )
-            InsertItem(pRedline, bCheckExistance, bFocus);
-    }
-    if (bEmpty && !mvPostItFlds.empty())
-        PrepareView(true);
- }
- */
-
 void SwPostItMgr::AddPostIts(bool bCheckExistance, bool bFocus)
 {
     bool bEmpty = mvPostItFlds.empty();
     SwFieldType* pType = mpView->GetDocShell()->GetDoc()->GetFldType(RES_POSTITFLD, aEmptyStr,false);
-    SwClientIter aIter( *pType );
-    SwClient * pFirst = aIter.GoStart();
-    while(pFirst)
+    SwIterator<SwFmtFld,SwFieldType> aIter( *pType );
+    SwFmtFld* pSwFmtFld = aIter.First();
+    while(pSwFmtFld)
     {
-        SwFmtFld* pSwFmtFld = static_cast<SwFmtFld*>(pFirst);
         if ( pSwFmtFld->GetTxtFld())
         {
             if ( pSwFmtFld->IsFldInDoc() )
                 InsertItem(pSwFmtFld,bCheckExistance,bFocus);
         }
-        pFirst = aIter++;
+        pSwFmtFld = aIter.Next();
     }
 
     // if we just added the first one we have to update the view for centering
@@ -1210,7 +1121,7 @@ void SwPostItMgr::RemoveSidebarWin()
 {
     if (!mvPostItFlds.empty())
     {
-        for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; i++)
+        for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; ++i)
         {
             EndListening( *((*i)->GetBroadCaster()) );
             if ((*i)->pPostIt)
@@ -1242,17 +1153,17 @@ void SwPostItMgr::Delete(String aAuthor)
 
     std::vector<SwFmtFld*> aTmp;
     aTmp.reserve( mvPostItFlds.size() );
-    for(std::list<SwSidebarItem*>::iterator pPostIt = mvPostItFlds.begin(); pPostIt!= mvPostItFlds.end() ; pPostIt++)
+    for(std::list<SwSidebarItem*>::iterator pPostIt = mvPostItFlds.begin(); pPostIt!= mvPostItFlds.end() ; ++pPostIt)
     {
         if ((*pPostIt)->GetFmtFld() && ((*pPostIt)->pPostIt->GetAuthor() == aAuthor) )
             aTmp.push_back( (*pPostIt)->GetFmtFld() );
     }
-    for(std::vector<SwFmtFld*>::iterator i = aTmp.begin(); i!= aTmp.end() ; i++)
+    for(std::vector<SwFmtFld*>::iterator i = aTmp.begin(); i!= aTmp.end() ; ++i)
     {
         mpWrtShell->GotoField( *(*i) );
         mpWrtShell->DelRight();
     }
-    mpWrtShell->EndUndo( UNDO_DELETE );
+    mpWrtShell->EndUndo();
     PrepareView();
     mpWrtShell->EndAllAction();
     mbLayout = true;
@@ -1270,35 +1181,18 @@ void SwPostItMgr::Delete()
 
     std::vector<SwFmtFld*> aTmp;
     aTmp.reserve( mvPostItFlds.size() );
-    for(std::list<SwSidebarItem*>::iterator pPostIt = mvPostItFlds.begin(); pPostIt!= mvPostItFlds.end() ; pPostIt++)
+    for(std::list<SwSidebarItem*>::iterator pPostIt = mvPostItFlds.begin(); pPostIt!= mvPostItFlds.end() ; ++pPostIt)
     {
         if ((*pPostIt)->GetFmtFld())
             aTmp.push_back( (*pPostIt)->GetFmtFld() );
     }
-    for(std::vector<SwFmtFld*>::iterator i = aTmp.begin(); i!= aTmp.end() ; i++)
+    for(std::vector<SwFmtFld*>::iterator i = aTmp.begin(); i!= aTmp.end() ; ++i)
     {
         mpWrtShell->GotoField( *(*i) );
         mpWrtShell->DelRight();
     }
 
-/*
-    for(std::list<SwPostItItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; i++)
-    {
-        SwPostItItem* pItem = (*i);
-        // stop listening, we delete ourselves
-        EndListening( *(pItem->pFmtFld) );
-        // delete the actual SwPostItField
-        mpWrtShell->GotoField(*pItem->pFmtFld);
-        mpWrtShell->DelRight();
-        // delete visual representation
-        delete pItem->pPostIt;
-        // delete struct saving the pointers
-        delete pItem;
-    }
-    mvPostItFlds.clear();
-*/
-
-    mpWrtShell->EndUndo( UNDO_DELETE );
+    mpWrtShell->EndUndo();
     PrepareView();
     mpWrtShell->EndAllAction();
     mbLayout = true;
@@ -1347,21 +1241,13 @@ void SwPostItMgr::Sort(const short aType)
             case SORT_POS:
                 mvPostItFlds.sort(comp_pos);
                 break;
-            /*
-            case SORT_AUTHOR:
-                mvPostItFlds.sort(comp_author);
-                break;
-            case SORT_DATE:
-                mvPostItFlds.sort(comp_date);
-                break;
-            */
         }
     }
 }
 
 SwSidebarWin* SwPostItMgr::GetSidebarWin( const SfxBroadcaster* pBroadcaster) const
 {
-    for(const_iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; i++)
+    for(const_iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; ++i)
     {
         if ( (*i)->GetBroadCaster() == pBroadcaster)
             return (*i)->pPostIt;
@@ -1371,7 +1257,7 @@ SwSidebarWin* SwPostItMgr::GetSidebarWin( const SfxBroadcaster* pBroadcaster) co
 
 sw::annotation::SwAnnotationWin* SwPostItMgr::GetAnnotationWin(const SwPostItField* pFld) const
 {
-    for(const_iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; i++)
+    for(const_iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; ++i)
     {
         if ( (*i)->GetFmtFld() && ((*i)->GetFmtFld()->GetFld() == pFld))
             return dynamic_cast<sw::annotation::SwAnnotationWin*>((*i)->pPostIt);
@@ -1379,7 +1265,7 @@ sw::annotation::SwAnnotationWin* SwPostItMgr::GetAnnotationWin(const SwPostItFie
     return NULL;
 }
 
-SwSidebarWin* SwPostItMgr::GetNextPostIt( USHORT aDirection,
+SwSidebarWin* SwPostItMgr::GetNextPostIt( sal_uInt16 aDirection,
                                           SwSidebarWin* aPostIt )
 {
     if (mvPostItFlds.size()>1)
@@ -1444,7 +1330,7 @@ long SwPostItMgr::GetNextBorder()
         }
     }
 
-    OSL_ENSURE(false, "SwPostItMgr::GetNextBorder(): We have to find a next border here");
+    OSL_FAIL("SwPostItMgr::GetNextBorder(): We have to find a next border here");
     return -1;
 }
 
@@ -1506,7 +1392,6 @@ void SwPostItMgr::PrepareView(bool bIgnoreCount)
     if (!HasNotes() || bIgnoreCount)
     {
         mpWrtShell->StartAllAction();
-        //mpEditWin->Invalidate(); // really not needed anymore??
         SwRootFrm* pLayout = mpWrtShell->GetLayout();
         if ( pLayout )
             SwPostItHelper::setSidebarChanged( pLayout,
@@ -1627,14 +1512,13 @@ void SwPostItMgr::CorrectPositions()
        return;
 
     // yeah, I know,    if this is a left page it could be wrong, but finding the page and the note is probably not even faster than just doing it
-    // --> OD 2010-06-03 #i111964# - check, if anchor overlay object exists.
+    // check, if anchor overlay object exists.
     const long aAnchorX = pFirstPostIt->Anchor() 
                           ? mpEditWin->LogicToPixel( Point((long)(pFirstPostIt->Anchor()->GetSixthPosition().getX()),0)).X()
                           : 0;
     const long aAnchorY = pFirstPostIt->Anchor() 
                           ? mpEditWin->LogicToPixel( Point(0,(long)(pFirstPostIt->Anchor()->GetSixthPosition().getY()))).Y() + 1
                           : 0;
-    // <-- 
     if (Point(aAnchorX,aAnchorY) != pFirstPostIt->GetPosPixel())
     {
         long aAnchorPosX = 0;
@@ -1643,9 +1527,8 @@ void SwPostItMgr::CorrectPositions()
         {
             for(SwSidebarItem_iterator i = mPages[n]->mList->begin(); i!= mPages[n]->mList->end(); i++)
             {
-                // --> OD 2010-06-03 #i111964# - check, if anchor overlay object exists.
+                // check, if anchor overlay object exists.
                 if ( (*i)->bShow && (*i)->pPostIt && (*i)->pPostIt->Anchor() )
-                // <--                                    
                 {
                     aAnchorPosX = mPages[n]->eSidebarPosition == sw::sidebarwindows::SIDEBAR_LEFT
                         ? mpEditWin->LogicToPixel( Point((long)((*i)->pPostIt->Anchor()->GetSeventhPosition().getX()),0)).X()
@@ -1765,7 +1648,7 @@ IMPL_LINK( SwPostItMgr, CalcHdl, void*, /* pVoid*/  )
     mnEventId = 0;
     if ( mbLayouting )
     {
-        OSL_ENSURE(false, "Reentrance problem in Layout Manager!");
+        OSL_FAIL("Reentrance problem in Layout Manager!");
         mbWaitingForCalcRects = false;
         return 0;
     }
@@ -1781,7 +1664,7 @@ IMPL_LINK( SwPostItMgr, CalcHdl, void*, /* pVoid*/  )
 
 void SwPostItMgr::Rescale()
 {
-    for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; i++)
+    for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; ++i)
         if ( (*i)->pPostIt )
             (*i)->pPostIt->Rescale();
 }
@@ -1818,21 +1701,21 @@ sal_Int32 SwPostItMgr::GetSidebarScrollerHeight() const
 
 void SwPostItMgr::SetSpellChecking()
 {
-    for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; i++)
+    for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; ++i)
         if ( (*i)->pPostIt )
             (*i)->pPostIt->SetSpellChecking();
 }
 
 void SwPostItMgr::SetReadOnlyState()
 {
-    for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; i++)
+    for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; ++i)
         if ( (*i)->pPostIt )
             (*i)->pPostIt->SetReadonly( mbReadOnly );
 }
 
 void SwPostItMgr::CheckMetaText()
 {
-        for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; i++)
+        for(std::list<SwSidebarItem*>::iterator i = mvPostItFlds.begin(); i!= mvPostItFlds.end() ; ++i)
                 if ( (*i)->pPostIt )
                        (*i)->pPostIt->CheckMetaText();
 
@@ -1887,7 +1770,6 @@ sal_uInt16 SwPostItMgr::SearchReplace(const SwFmtFld &pFld, const ::com::sun::st
 
 void SwPostItMgr::AssureStdModeAtShell()
 {
-    //#i103373# #i103645#
         // deselect any drawing or frame and leave editing mode
           SdrView* pSdrView = mpWrtShell->GetDrawView();
         if ( pSdrView && pSdrView->IsTextEdit() )
