@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -42,7 +42,7 @@
 #include <editeng/opaqitem.hxx>
 #include <editeng/ulspitem.hxx>
 #include <editeng/lrspitem.hxx>
-// OD 18.09.2003 #i18732#
+// #i18732#
 #include <fmtfollowtextflow.hxx>
 #include <svx/swframevalidation.hxx>
 
@@ -61,21 +61,21 @@
 
 using namespace ::com::sun::star;
 
-static USHORT __FAR_DATA aWrapPageRg[] = {
+static sal_uInt16 aWrapPageRg[] = {
     RES_LR_SPACE, RES_UL_SPACE,
     RES_PROTECT, RES_SURROUND,
     RES_PRINT, RES_PRINT,
     0
 };
 
-SwWrapDlg::SwWrapDlg(Window* pParent, SfxItemSet& rSet, SwWrtShell* pSh, BOOL bDrawMode) :
+SwWrapDlg::SwWrapDlg(Window* pParent, SfxItemSet& rSet, SwWrtShell* pSh, sal_Bool bDrawMode) :
     SfxSingleTabDialog(pParent, rSet, 0),
     pWrtShell(pSh)
 
 {
-    // TabPage erzeugen
+    // create TabPage 
     SwWrapTabPage* pNewPage = (SwWrapTabPage*) SwWrapTabPage::Create(this, rSet);
-    pNewPage->SetFormatUsed(FALSE, bDrawMode);
+    pNewPage->SetFormatUsed(sal_False, bDrawMode);
     pNewPage->SetShell(pWrtShell);
     SetTabPage(pNewPage);
 
@@ -116,17 +116,16 @@ SwWrapTabPage::SwWrapTabPage(Window *pParent, const SfxItemSet &rSet) :
     aWrapOutsideCB		(this, SW_RES(CB_ONLYOUTSIDE)),
 
     aWrapIL             (SW_RES(IL_WRAP)),
-    aWrapILH            (SW_RES(ILH_WRAP)),
 
     nAnchorId(FLY_AT_PARA),
     nHtmlMode(0),
 
     pWrtSh(0),
 
-    bFormat(FALSE),
-    bNew(TRUE),
-    bHtmlMode(FALSE),
-    bContourImage(FALSE)
+    bFormat(sal_False),
+    bNew(sal_True),
+    bHtmlMode(sal_False),
+    bContourImage(sal_False)
 
 {
     FreeResource();
@@ -179,7 +178,7 @@ SfxTabPage* SwWrapTabPage::Create(Window *pParent, const SfxItemSet &rSet)
 
 void SwWrapTabPage::Reset(const SfxItemSet &rSet)
 {
-    //Contour fuer Draw, Grafik und OLE (Einfuegen/Grafik/Eigenschaften fehlt noch!)
+    // contour for Draw, Graphic and OLE (Insert/Graphic/Properties still missing!)
     if( bDrawMode )
     {
         aWrapOutlineCB.Show();
@@ -191,14 +190,14 @@ void SwWrapTabPage::Reset(const SfxItemSet &rSet)
     }
     else
     {
-        BOOL bShowCB = bFormat;
+        sal_Bool bShowCB = bFormat;
         if( !bFormat )
         {
             int nSelType = pWrtSh->GetSelectionType();
             if( ( nSelType & nsSelectionType::SEL_GRF ) ||
                 ( nSelType & nsSelectionType::SEL_OLE && GRAPHIC_NONE !=
                             pWrtSh->GetIMapGraphic().GetType() ))
-                bShowCB = TRUE;
+                bShowCB = sal_True;
         }
         if( bShowCB )
         {
@@ -208,7 +207,7 @@ void SwWrapTabPage::Reset(const SfxItemSet &rSet)
     }
 
     nHtmlMode = ::GetHtmlMode((const SwDocShell*)SfxObjectShell::Current());
-    bHtmlMode = nHtmlMode & HTMLMODE_ON ? TRUE : FALSE;
+    bHtmlMode = nHtmlMode & HTMLMODE_ON ? sal_True : sal_False;
 
     FieldUnit aMetric = ::GetDfltMetric(bHtmlMode);
     SetMetric( aLeftMarginED  , aMetric );
@@ -229,10 +228,10 @@ void SwWrapTabPage::Reset(const SfxItemSet &rSet)
     }
     else
     {
-        aWrapAnchorOnlyCB.Enable( FALSE );
+        aWrapAnchorOnlyCB.Enable( sal_False );
     }
 
-    BOOL bContour = rSurround.IsContour();
+    sal_Bool bContour = rSurround.IsContour();
     aWrapOutlineCB.Check( bContour );
     aWrapOutsideCB.Check( rSurround.IsOutside() );
     aWrapThroughRB.Enable(!aWrapOutlineCB.IsChecked());
@@ -285,9 +284,9 @@ void SwWrapTabPage::Reset(const SfxItemSet &rSet)
     {
         pBtn->Check();
         WrapTypeHdl(pBtn);
-        // Hier wird fuer Zeichenobjekte, die im Moment auf Durchlauf stehen,
-        // schon mal der Default "Kontur an" vorbereitet, falls man spaeter auf
-        // irgendeinen Umlauf umschaltet.
+        // For character objects that currently are in passage, the default
+        // "contour on" is prepared here, in case we switch to any other
+        // passage later. 
         if (bDrawMode && !aWrapOutlineCB.IsEnabled())
             aWrapOutlineCB.Check();
     }
@@ -296,7 +295,7 @@ void SwWrapTabPage::Reset(const SfxItemSet &rSet)
     const SvxULSpaceItem& rUL = (const SvxULSpaceItem&)rSet.Get(RES_UL_SPACE);
     const SvxLRSpaceItem& rLR = (const SvxLRSpaceItem&)rSet.Get(RES_LR_SPACE);
 
-    // Abstand zum Text
+    // gap to text
     aLeftMarginED.SetValue(aLeftMarginED.Normalize(rLR.GetLeft()), FUNIT_TWIP);
     aRightMarginED.SetValue(aRightMarginED.Normalize(rLR.GetRight()), FUNIT_TWIP);
     aTopMarginED.SetValue(aTopMarginED.Normalize(rUL.GetUpper()), FUNIT_TWIP);
@@ -307,11 +306,11 @@ void SwWrapTabPage::Reset(const SfxItemSet &rSet)
 }
 
 /*--------------------------------------------------------------------
-    Beschreibung:	Attribute in den Set stopfen bei OK
+    Description:	stuff attributes into the set when OK
  --------------------------------------------------------------------*/
-BOOL SwWrapTabPage::FillItemSet(SfxItemSet &rSet)
+sal_Bool SwWrapTabPage::FillItemSet(SfxItemSet &rSet)
 {
-    BOOL bModified = FALSE;
+    sal_Bool bModified = sal_False;
     const SfxPoolItem* pOldItem;
 
     const SwFmtSurround& rOldSur = (const SwFmtSurround&)GetItemSet().Get(RES_SURROUND);
@@ -323,7 +322,7 @@ BOOL SwWrapTabPage::FillItemSet(SfxItemSet &rSet)
     {
         const SvxOpaqueItem& rOpaque = (const SvxOpaqueItem&)GetItemSet().Get(RES_OPAQUE);
         aOp = rOpaque;
-        aOp.SetValue(TRUE);
+        aOp.SetValue(sal_True);
     }
 
     if (aNoWrapRB.IsChecked())
@@ -338,13 +337,13 @@ BOOL SwWrapTabPage::FillItemSet(SfxItemSet &rSet)
     {
         aSur.SetSurround(SURROUND_THROUGHT);
         if (aWrapTransparentCB.IsChecked() && !bDrawMode)
-            aOp.SetValue(FALSE);
+            aOp.SetValue(sal_False);
     }
     else if (aIdealWrapRB.IsChecked())
         aSur.SetSurround(SURROUND_IDEAL);
 
     aSur.SetAnchorOnly( aWrapAnchorOnlyCB.IsChecked() );
-    BOOL bContour = aWrapOutlineCB.IsChecked() && aWrapOutlineCB.IsEnabled();
+    sal_Bool bContour = aWrapOutlineCB.IsChecked() && aWrapOutlineCB.IsEnabled();
     aSur.SetContour( bContour );
 
     if ( bContour )
@@ -354,7 +353,7 @@ BOOL SwWrapTabPage::FillItemSet(SfxItemSet &rSet)
                 aSur != *pOldItem )
     {
         rSet.Put(aSur);
-        bModified = TRUE;
+        bModified = sal_True;
     }
 
     if (!bDrawMode)
@@ -363,16 +362,16 @@ BOOL SwWrapTabPage::FillItemSet(SfxItemSet &rSet)
                     aOp != *pOldItem )
         {
             rSet.Put(aOp);
-            bModified = TRUE;
+            bModified = sal_True;
         }
     }
 
-    BOOL bTopMod = aTopMarginED.IsValueModified();
-    BOOL bBottomMod = aBottomMarginED.IsValueModified();
+    sal_Bool bTopMod = aTopMarginED.IsValueModified();
+    sal_Bool bBottomMod = aBottomMarginED.IsValueModified();
 
     SvxULSpaceItem aUL( RES_UL_SPACE );
-    aUL.SetUpper((USHORT)aTopMarginED.Denormalize(aTopMarginED.GetValue(FUNIT_TWIP)));
-    aUL.SetLower((USHORT)aBottomMarginED.Denormalize(aBottomMarginED.GetValue(FUNIT_TWIP)));
+    aUL.SetUpper((sal_uInt16)aTopMarginED.Denormalize(aTopMarginED.GetValue(FUNIT_TWIP)));
+    aUL.SetLower((sal_uInt16)aBottomMarginED.Denormalize(aBottomMarginED.GetValue(FUNIT_TWIP)));
 
     if ( bTopMod || bBottomMod )
     {
@@ -380,16 +379,16 @@ BOOL SwWrapTabPage::FillItemSet(SfxItemSet &rSet)
                 aUL != *pOldItem )
         {
             rSet.Put( aUL, RES_UL_SPACE );
-            bModified = TRUE;
+            bModified = sal_True;
         }
     }
 
-    BOOL bLeftMod = aLeftMarginED.IsValueModified();
-    BOOL bRightMod = aRightMarginED.IsValueModified();
+    sal_Bool bLeftMod = aLeftMarginED.IsValueModified();
+    sal_Bool bRightMod = aRightMarginED.IsValueModified();
 
     SvxLRSpaceItem aLR( RES_LR_SPACE );
-    aLR.SetLeft((USHORT)aLeftMarginED.Denormalize(aLeftMarginED.GetValue(FUNIT_TWIP)));
-    aLR.SetRight((USHORT)aRightMarginED.Denormalize(aRightMarginED.GetValue(FUNIT_TWIP)));
+    aLR.SetLeft((sal_uInt16)aLeftMarginED.Denormalize(aLeftMarginED.GetValue(FUNIT_TWIP)));
+    aLR.SetRight((sal_uInt16)aRightMarginED.Denormalize(aRightMarginED.GetValue(FUNIT_TWIP)));
 
     if ( bLeftMod || bRightMod )
     {
@@ -397,13 +396,13 @@ BOOL SwWrapTabPage::FillItemSet(SfxItemSet &rSet)
                 aLR != *pOldItem )
         {
             rSet.Put(aLR, RES_LR_SPACE);
-            bModified = TRUE;
+            bModified = sal_True;
         }
     }
 
     if ( bDrawMode )
     {
-        BOOL bChecked = aWrapTransparentCB.IsChecked() & aWrapTransparentCB.IsEnabled();
+        sal_Bool bChecked = aWrapTransparentCB.IsChecked() & aWrapTransparentCB.IsEnabled();
         if (aWrapTransparentCB.GetSavedValue() != bChecked)
             bModified |= 0 != rSet.Put(SfxInt16Item(FN_DRAW_WRAP_DLG, bChecked ? 0 : 1));
     }
@@ -412,14 +411,14 @@ BOOL SwWrapTabPage::FillItemSet(SfxItemSet &rSet)
 }
 
 /*--------------------------------------------------------------------
-    Beschreibung:	Bsp - Update
+    Description:	example update
  --------------------------------------------------------------------*/
 void SwWrapTabPage::ActivatePage(const SfxItemSet& rSet)
 {
-    // Anchor
+    // anchor
     const SwFmtAnchor &rAnch = (const SwFmtAnchor&)rSet.Get(RES_ANCHOR);
     nAnchorId = rAnch.GetAnchorId();
-    BOOL bEnable = (nAnchorId != FLY_AS_CHAR);
+    sal_Bool bEnable = (nAnchorId != FLY_AS_CHAR);
 
     if (!bDrawMode)
     {
@@ -427,19 +426,19 @@ void SwWrapTabPage::ActivatePage(const SfxItemSet& rSet)
         SwFlyFrmAttrMgr aMgr( bNew, pSh, (const SwAttrSet&)GetItemSet() );
         SvxSwFrameValidation aVal;
 
-        // Size
+        // size
         const SwFmtFrmSize& rFrmSize = (const SwFmtFrmSize&)rSet.Get(RES_FRM_SIZE);
         Size aSize = rFrmSize.GetSize();
 
-        // Rand
+        // margin
         const SvxULSpaceItem& rUL = (const SvxULSpaceItem&)rSet.Get(RES_UL_SPACE);
         const SvxLRSpaceItem& rLR = (const SvxLRSpaceItem&)rSet.Get(RES_LR_SPACE);
-        nOldLeftMargin  = static_cast< USHORT >(rLR.GetLeft());
-        nOldRightMargin = static_cast< USHORT >(rLR.GetRight());
-        nOldUpperMargin = static_cast< USHORT >(rUL.GetUpper());
-        nOldLowerMargin = static_cast< USHORT >(rUL.GetLower());
+        nOldLeftMargin  = static_cast< sal_uInt16 >(rLR.GetLeft());
+        nOldRightMargin = static_cast< sal_uInt16 >(rLR.GetRight());
+        nOldUpperMargin = static_cast< sal_uInt16 >(rUL.GetUpper());
+        nOldLowerMargin = static_cast< sal_uInt16 >(rUL.GetLower());
 
-        // Position
+        // position
         const SwFmtHoriOrient& rHori = (const SwFmtHoriOrient&)rSet.Get(RES_HORI_ORIENT);
         const SwFmtVertOrient& rVert = (const SwFmtVertOrient&)rSet.Get(RES_VERT_ORIENT);
 
@@ -447,7 +446,7 @@ void SwWrapTabPage::ActivatePage(const SfxItemSet& rSet)
         aVal.bAutoHeight = rFrmSize.GetHeightSizeType() == ATT_MIN_SIZE;
         aVal.bAutoWidth = rFrmSize.GetWidthSizeType() == ATT_MIN_SIZE;
         aVal.bMirror = rHori.IsPosToggle();
-        // OD 18.09.2003 #i18732#
+        // #i18732#
         aVal.bFollowTextFlow =
             static_cast<const SwFmtFollowTextFlow&>(rSet.Get(RES_FOLLOW_TEXT_FLOW)).GetValue();
 
@@ -497,7 +496,7 @@ void SwWrapTabPage::ActivatePage(const SfxItemSet& rSet)
                     if (aVal.nVPos <= aVal.nMaxHeight)
                         nTop = aVal.nMaxVPos - aVal.nHeight;
                     else
-                        nTop = nBottom = 0;	// Kein Umlauf
+                        nTop = nBottom = 0;	// no passage
                 }
                 else
                     nTop = aVal.nMaxVPos - aVal.nHeight - aVal.nVPos;
@@ -528,7 +527,7 @@ void SwWrapTabPage::ActivatePage(const SfxItemSet& rSet)
     aWrapTransparentCB.Enable( bEnable && !bHtmlMode && nSur == SURROUND_THROUGHT );
     if(bHtmlMode)
     {
-        BOOL bSomeAbsPos = 0 != (nHtmlMode & HTMLMODE_SOME_ABS_POS);
+        sal_Bool bSomeAbsPos = 0 != (nHtmlMode & HTMLMODE_SOME_ABS_POS);
         const SwFmtHoriOrient& rHori = (const SwFmtHoriOrient&)rSet.Get(RES_HORI_ORIENT);
         sal_Int16 eHOrient = rHori.GetHoriOrient();
         sal_Int16 eHRelOrient = rHori.GetRelationOrient();
@@ -538,12 +537,12 @@ void SwWrapTabPage::ActivatePage(const SfxItemSet& rSet)
                             (eHOrient == text::HoriOrientation::RIGHT || eHOrient == text::HoriOrientation::LEFT);
         aWrapAnchorOnlyCB.Enable( bAllHtmlModes && nSur != SURROUND_NONE );
         aWrapOutsideCB.Hide();
-        aIdealWrapRB.Enable( FALSE );
+        aIdealWrapRB.Enable( sal_False );
 
 
-        aWrapTransparentCB.Enable( FALSE );
+        aWrapTransparentCB.Enable( sal_False );
         aNoWrapRB.Enable( FLY_AT_PARA == nAnchorId );
-        aWrapParallelRB.Enable( FALSE  );
+        aWrapParallelRB.Enable( sal_False  );
         aWrapLeftRB       .Enable
                     (  (FLY_AT_PARA == nAnchorId)
                     || (   (FLY_AT_CHAR == nAnchorId)
@@ -565,7 +564,7 @@ void SwWrapTabPage::ActivatePage(const SfxItemSet& rSet)
         if(aNoWrapRB.IsChecked() && !aNoWrapRB.IsEnabled())
         {
             if(aWrapThroughRB.IsEnabled())
-                aWrapThroughRB.Check(TRUE);
+                aWrapThroughRB.Check(sal_True);
             else if(aWrapLeftRB.IsEnabled())
                 aWrapLeftRB.Check();
             else if(aWrapRightRB.IsEnabled())
@@ -613,11 +612,11 @@ int SwWrapTabPage::DeactivatePage(SfxItemSet* _pSet)
     if(_pSet)
         FillItemSet(*_pSet);
 
-    return TRUE;
+    return sal_True;
 }
 
 /*--------------------------------------------------------------------
-    Beschreibung:	Bereichspruefung
+    Description:	range check
  --------------------------------------------------------------------*/
 IMPL_LINK( SwWrapTabPage, RangeModifyHdl, MetricField *, pEdit )
 {
@@ -647,10 +646,15 @@ IMPL_LINK( SwWrapTabPage, RangeModifyHdl, MetricField *, pEdit )
         else if (pEdit == &aBottomMarginED)
             pOpposite = &aTopMarginED;
 
-        sal_Int64 nOpposite = pOpposite->GetValue();
+        OSL_ASSERT(pOpposite);
 
-        if (nValue + nOpposite > Max(pEdit->GetMax(), pOpposite->GetMax()))
-            pOpposite->SetValue(pOpposite->GetMax() - nValue);
+        if (pOpposite)
+        {
+            sal_Int64 nOpposite = pOpposite->GetValue();
+
+            if (nValue + nOpposite > Max(pEdit->GetMax(), pOpposite->GetMax()))
+                pOpposite->SetValue(pOpposite->GetMax() - nValue);
+        }
     }
 
     return 0;
@@ -658,7 +662,7 @@ IMPL_LINK( SwWrapTabPage, RangeModifyHdl, MetricField *, pEdit )
 
 IMPL_LINK( SwWrapTabPage, WrapTypeHdl, ImageRadioButton *, pBtn )
 {
-    BOOL bWrapThrough = (pBtn == &aWrapThroughRB);
+    sal_Bool bWrapThrough = (pBtn == &aWrapThroughRB);
     aWrapTransparentCB.Enable( bWrapThrough && !bHtmlMode );
     bWrapThrough |= ( nAnchorId == FLY_AS_CHAR );
     aWrapOutlineCB.Enable( !bWrapThrough && pBtn != &aNoWrapRB);
@@ -673,12 +677,12 @@ IMPL_LINK( SwWrapTabPage, WrapTypeHdl, ImageRadioButton *, pBtn )
 
 IMPL_LINK( SwWrapTabPage, ContourHdl, CheckBox *, EMPTYARG )
 {
-    BOOL bEnable = !(aWrapOutlineCB.IsChecked() && aWrapOutlineCB.IsEnabled());
+    sal_Bool bEnable = !(aWrapOutlineCB.IsChecked() && aWrapOutlineCB.IsEnabled());
 
     aWrapOutsideCB.Enable(!bEnable);
 
     bEnable =  !aWrapOutlineCB.IsChecked();
-    if (bEnable == bContourImage) // damit es nicht immer flackert
+    if (bEnable == bContourImage) // so that it doesn't always flicker
     {
         bContourImage = !bEnable;
         ApplyImageList();
@@ -687,7 +691,7 @@ IMPL_LINK( SwWrapTabPage, ContourHdl, CheckBox *, EMPTYARG )
     return 0;
 }
 
-USHORT* SwWrapTabPage::GetRanges()
+sal_uInt16* SwWrapTabPage::GetRanges()
 {
     return aWrapPageRg;
 }
@@ -703,26 +707,25 @@ void SwWrapTabPage::DataChanged( const DataChangedEvent& rDCEvt )
 
 void SwWrapTabPage::ApplyImageList()
 {
-    ImageList& rImgLst = GetSettings().GetStyleSettings().GetHighContrastMode() ?
-        aWrapILH : aWrapIL;
+    ImageList& rImgLst = aWrapIL;
 
     aWrapThroughRB.SetModeRadioImage(rImgLst.GetImage(IMG_THROUGH));
-    BOOL bWrapOutline =  !aWrapOutlineCB.IsChecked();
+    sal_Bool bWrapOutline =  !aWrapOutlineCB.IsChecked();
     if(bWrapOutline)
     {
-        aNoWrapRB.SetModeRadioImage(rImgLst.GetImage(IMG_NONE));
-        aWrapLeftRB.SetModeRadioImage(rImgLst.GetImage(IMG_LEFT));
-        aWrapRightRB.SetModeRadioImage(rImgLst.GetImage(IMG_RIGHT));
-        aWrapParallelRB.SetModeRadioImage(rImgLst.GetImage(IMG_PARALLEL));
-        aIdealWrapRB.SetModeRadioImage(rImgLst.GetImage(IMG_IDEAL));
+        aNoWrapRB.SetModeRadioImage(       rImgLst.GetImage( IMG_NONE     ));
+        aWrapLeftRB.SetModeRadioImage(     rImgLst.GetImage( IMG_LEFT     ));
+        aWrapRightRB.SetModeRadioImage(    rImgLst.GetImage( IMG_RIGHT    ));
+        aWrapParallelRB.SetModeRadioImage( rImgLst.GetImage( IMG_PARALLEL ));
+        aIdealWrapRB.SetModeRadioImage(    rImgLst.GetImage( IMG_IDEAL    ));
     }
     else
     {
-        aNoWrapRB.SetModeRadioImage(rImgLst.GetImage( IMG_KON_NONE ));
-        aWrapLeftRB.SetModeRadioImage(rImgLst.GetImage( IMG_KON_LEFT ));
-        aWrapRightRB.SetModeRadioImage(rImgLst.GetImage( IMG_KON_RIGHT ));
-        aWrapParallelRB.SetModeRadioImage(rImgLst.GetImage(IMG_KON_PARALLEL ));
-        aIdealWrapRB.SetModeRadioImage(rImgLst.GetImage( IMG_KON_IDEAL ));
+        aNoWrapRB.SetModeRadioImage(       rImgLst.GetImage( IMG_KON_NONE     ));
+        aWrapLeftRB.SetModeRadioImage(     rImgLst.GetImage( IMG_KON_LEFT     ));
+        aWrapRightRB.SetModeRadioImage(    rImgLst.GetImage( IMG_KON_RIGHT    ));
+        aWrapParallelRB.SetModeRadioImage( rImgLst.GetImage( IMG_KON_PARALLEL ));
+        aIdealWrapRB.SetModeRadioImage(    rImgLst.GetImage( IMG_KON_IDEAL    ));
     }
 }
 
