@@ -47,7 +47,6 @@
 #include <view.hxx>
 #include <docsh.hxx>
 #include <uitool.hxx>
-#include <errhdl.hxx>
 #include <wrtsh.hxx>
 #include <swmodule.hxx>
 #include <fmtcol.hxx>
@@ -71,15 +70,19 @@
 #include <IDocumentOutlineNodes.hxx>
 #include <app.hrc>
 
+#ifndef _COM_SUN_STAR_ACCESSIBILITY_ACCESSIBLEROLE_HPP_
+#include <com/sun/star/accessibility/AccessibleRole.hpp>
+#endif
+
 using namespace ::com::sun::star;
 
 DBG_NAME(outlinehdl)
 
 class SwNumNamesDlg: public ModalDialog
 {
+    FixedLine    aFormFL;
     Edit         aFormEdit;
     ListBox      aFormBox;
-    FixedLine    aFormFL;
     OKButton     aOKBtn;
     CancelButton aCancelBtn;
     HelpButton   aHelpBtn;
@@ -93,7 +96,7 @@ public:
     ~SwNumNamesDlg();
     void SetUserNames(const String *pList[]);
     String GetName() const { return aFormEdit.GetText(); }
-    USHORT GetCurEntryPos() const { return aFormBox.GetSelectEntryPos(); }
+    sal_uInt16 GetCurEntryPos() const { return aFormBox.GetSelectEntryPos(); }
 };
 
 /*------------------------------------------------------------------------
@@ -114,8 +117,8 @@ IMPL_LINK_INLINE_END( SwNumNamesDlg, SelectHdl, ListBox *, pBox )
 ------------------------------------------------------------------------*/
 void SwNumNamesDlg::SetUserNames(const String *pList[])
 {
-    USHORT nSelect = 0;
-    for(USHORT i = 0; i < SwBaseNumRules::nMaxRules; ++i)
+    sal_uInt16 nSelect = 0;
+    for(sal_uInt16 i = 0; i < SwBaseNumRules::nMaxRules; ++i)
     {
         if(pList[i])
         {
@@ -151,9 +154,9 @@ IMPL_LINK_INLINE_END( SwNumNamesDlg, DoubleClickHdl, ListBox *, EMPTYARG )
 
 SwNumNamesDlg::SwNumNamesDlg(Window *pParent)
     : ModalDialog(pParent, SW_RES(DLG_NUM_NAMES)),
+    aFormFL(this, SW_RES(FL_FORM)),
     aFormEdit(this, SW_RES(ED_FORM)),
     aFormBox(this, SW_RES(LB_FORM)),
-    aFormFL(this, SW_RES(FL_FORM)),
     aOKBtn(this, SW_RES(BT_OK)),
     aCancelBtn(this, SW_RES(BT_CANCEL)),
     aHelpBtn(this, SW_RES(BT_HELP))
@@ -165,23 +168,23 @@ SwNumNamesDlg::SwNumNamesDlg(Window *pParent)
     SelectHdl(&aFormBox);
 }
 
-__EXPORT SwNumNamesDlg::~SwNumNamesDlg() {}
+SwNumNamesDlg::~SwNumNamesDlg() {}
 
-USHORT lcl_BitToLevel(USHORT nActLevel)
+sal_uInt16 lcl_BitToLevel(sal_uInt16 nActLevel)
 {
-    USHORT nTmp = nActLevel;
-    USHORT nTmpLevel = 0;
+    sal_uInt16 nTmp = nActLevel;
+    sal_uInt16 nTmpLevel = 0;
     while( 0 != (nTmp >>= 1) )
         nTmpLevel++;
     return nTmpLevel;
 }
 
-USHORT SwOutlineTabDialog::nNumLevel = 1;
+sal_uInt16 SwOutlineTabDialog::nNumLevel = 1;
 SwOutlineTabDialog::SwOutlineTabDialog(Window* pParent,
                     const SfxItemSet* pSwItemSet,
                     SwWrtShell &rSh) :
                                     //der UserString wird danach richtig gesetzt
-        SfxTabDialog(pParent, SW_RES(DLG_TAB_OUTLINE), pSwItemSet, FALSE, &aEmptyStr),
+        SfxTabDialog(pParent, SW_RES(DLG_TAB_OUTLINE), pSwItemSet, sal_False, &aEmptyStr),
         aNullStr(C2S("____")),
         aFormMenu(SW_RES(MN_FORM)),
         rWrtSh(rSh),
@@ -195,6 +198,7 @@ SwOutlineTabDialog::SwOutlineTabDialog(Window* pParent,
     pUserButton->SetText(SW_RES(ST_FORM));
     pUserButton->SetHelpId(HID_OUTLINE_FORM);
     pUserButton->SetClickHdl(LINK(this, SwOutlineTabDialog, FormHdl));
+    pUserButton->SetAccessibleRole( com::sun::star::accessibility::AccessibleRole::BUTTON_MENU );
 
     FreeResource();
     pNumRule = new SwNumRule( *rSh.GetOutlineNumRule() );
@@ -204,7 +208,7 @@ SwOutlineTabDialog::SwOutlineTabDialog(Window* pParent,
     AddTabPage(TP_OUTLINE_NUM	 , &SwOutlineSettingsTabPage::Create, 0);
 
     String sHeadline;
-    USHORT i;
+    sal_uInt16 i;
 
     for( i = 0; i < MAXLEVEL; ++i )
     {
@@ -216,14 +220,12 @@ SwOutlineTabDialog::SwOutlineTabDialog(Window* pParent,
     }
 
     // Erfragen der Gliederungsebenen der Textvorlagen
-    const USHORT nCount = rWrtSh.GetTxtFmtCollCount();
+    const sal_uInt16 nCount = rWrtSh.GetTxtFmtCollCount();
     for(i = 0; i < nCount; ++i )
     {
         SwTxtFmtColl &rTxtColl = rWrtSh.GetTxtFmtColl(i);
         if(!rTxtColl.IsDefault())
         {
-            //BYTE nOutLevel = rTxtColl.GetOutlineLevel();	//<-#outline level, removed out by zhaojianwei
-            //if(nOutLevel != NO_NUMBERING)
             //->added by zhaojianwei
             if(rTxtColl.IsAssignedToListLevelOfOutlineStyle())
             {
@@ -240,7 +242,7 @@ SwOutlineTabDialog::~SwOutlineTabDialog()
     delete pNumRule;
 }
 
-void 	SwOutlineTabDialog::PageCreated(USHORT nPageId, SfxTabPage& rPage)
+void 	SwOutlineTabDialog::PageCreated(sal_uInt16 nPageId, SfxTabPage& rPage)
 {
     switch ( nPageId )
     {
@@ -265,7 +267,7 @@ IMPL_LINK( SwOutlineTabDialog, CancelHdl, Button *, EMPTYARG )
 IMPL_LINK( SwOutlineTabDialog, FormHdl, Button *, pBtn )
 {
     //PopupMenu auffuellen
-    for( USHORT i = 0; i < SwChapterNumRules::nMaxRules; ++i )
+    for( sal_uInt16 i = 0; i < SwChapterNumRules::nMaxRules; ++i )
     {
         const SwNumRulesWithName *pRules = pChapterNumRules->GetRules(i);
         if( pRules )
@@ -278,7 +280,7 @@ IMPL_LINK( SwOutlineTabDialog, FormHdl, Button *, pBtn )
 
 IMPL_LINK( SwOutlineTabDialog, MenuSelectHdl, Menu *, pMenu )
 {
-    BYTE nLevelNo = 0;
+    sal_uInt8 nLevelNo = 0;
     switch(pMenu->GetCurItemId())
     {
         case MN_FORM1: nLevelNo = 1;	break;
@@ -295,7 +297,7 @@ IMPL_LINK( SwOutlineTabDialog, MenuSelectHdl, Menu *, pMenu )
         {
             SwNumNamesDlg *pDlg = new SwNumNamesDlg(this);
             const String *aStrArr[SwChapterNumRules::nMaxRules];
-            for(USHORT i = 0; i < SwChapterNumRules::nMaxRules; ++i)
+            for(sal_uInt16 i = 0; i < SwChapterNumRules::nMaxRules; ++i)
             {
                 const SwNumRulesWithName *pRules = pChapterNumRules->GetRules(i);
                 if(pRules)
@@ -330,16 +332,16 @@ IMPL_LINK( SwOutlineTabDialog, MenuSelectHdl, Menu *, pMenu )
             *pNumRule = *rWrtSh.GetOutlineNumRule();
     }
 
-    USHORT	nPageId = GetCurPageId();
+    sal_uInt16	nPageId = GetCurPageId();
     SfxTabPage*	pPage = GetTabPage( nPageId );
     pPage->Reset(*GetOutputItemSet());
 
     return 0;
 }
 
-USHORT 	SwOutlineTabDialog::GetLevel(const String &rFmtName) const
+sal_uInt16 	SwOutlineTabDialog::GetLevel(const String &rFmtName) const
 {
-    for(USHORT i = 0; i < MAXLEVEL; ++i)
+    for(sal_uInt16 i = 0; i < MAXLEVEL; ++i)
     {
         if(aCollNames[i] == rFmtName)
             return i;
@@ -363,35 +365,17 @@ short SwOutlineTabDialog::Ok()
 
     const SwNumRule * pOutlineRule = rWrtSh.GetOutlineNumRule();
 
-    USHORT i, nCount = rWrtSh.GetTxtFmtCollCount();
+    sal_uInt16 i, nCount = rWrtSh.GetTxtFmtCollCount();
     for( i = 0; i < nCount; ++i )
     {
         SwTxtFmtColl &rTxtColl = rWrtSh.GetTxtFmtColl(i);
         if( !rTxtColl.IsDefault() )
         {
-            //rTxtColl.SetOutlineLevel( (BYTE)GetLevel(rTxtColl.GetName()));//#outline level,removed by zhaojianwei
 
             const SfxPoolItem & rItem =
-                rTxtColl.GetFmtAttr(RES_PARATR_NUMRULE, FALSE);
+                rTxtColl.GetFmtAttr(RES_PARATR_NUMRULE, sal_False);
 
-            //if ((BYTE)GetLevel(rTxtColl.GetName()) == NO_NUMBERING)	//#outline level,removed by zhaojianwei
-            //{
-            //	if (static_cast<const SwNumRuleItem &>(rItem).GetValue() ==
-            //		pOutlineRule->GetName())
-            //	{
-            //		rTxtColl.ResetFmtAttr(RES_PARATR_NUMRULE);
-            //	}
-            //}
-            //else
-            //{
-            //	if (static_cast<const SwNumRuleItem &>(rItem).GetValue() !=
-            //		pOutlineRule->GetName())
-            //	{
-            //		SwNumRuleItem aItem(pOutlineRule->GetName());
-            //		rTxtColl.SetFmtAttr(aItem);
-            //	}
-            //}
-           if ((BYTE)GetLevel(rTxtColl.GetName()) == MAXLEVEL) //add by zhaojianwei
+           if ((sal_uInt8)GetLevel(rTxtColl.GetName()) == MAXLEVEL) //add by zhaojianwei
             {
                 if(rTxtColl.IsAssignedToListLevelOfOutlineStyle())
                 {
@@ -425,29 +409,10 @@ short SwOutlineTabDialog::Ok()
         SwTxtFmtColl* pColl = rWrtSh.FindTxtFmtCollByName( sHeadline );
         if( !pColl )
         {
-            //if( !aCollNames[i].Len() )			//#outline level,removed by zhaojianwei
-            //{
-            //	SwTxtFmtColl* pTxtColl = rWrtSh.GetTxtCollFromPool(
-            //		static_cast< USHORT >(RES_POOLCOLL_HEADLINE1 + i) );
-            //	pTxtColl->SetOutlineLevel( NO_NUMBERING );
-            //	pTxtColl->ResetFmtAttr(RES_PARATR_NUMRULE);
-            //}
-            //else if(aCollNames[i] != sHeadline)
-            //{
-            //	SwTxtFmtColl* pTxtColl = rWrtSh.GetParaStyle(
-            //		aCollNames[i], SwWrtShell::GETSTYLE_CREATESOME);
-            //	if(pTxtColl)
-            //	{
-            //		pTxtColl->SetOutlineLevel( static_cast< BYTE >(i) );
-
-            //		SwNumRuleItem aItem(pOutlineRule->GetName());
-            //		pTxtColl->SetFmtAttr(aItem);
-            //	}
-            //}
             if(aCollNames[i] != sHeadline)//->added by zhaojianwei
             {
                 SwTxtFmtColl* pTxtColl = rWrtSh.GetTxtCollFromPool(
-                    static_cast< USHORT >(RES_POOLCOLL_HEADLINE1 + i) );
+                    static_cast< sal_uInt16 >(RES_POOLCOLL_HEADLINE1 + i) );
                 pTxtColl->DeleteAssignmentToListLevelOfOutlineStyle();	
                 pTxtColl->ResetFmtAttr(RES_PARATR_NUMRULE);
 
@@ -477,8 +442,9 @@ short SwOutlineTabDialog::Ok()
 
 SwOutlineSettingsTabPage::SwOutlineSettingsTabPage(Window* pParent, const SfxItemSet& rSet) :
     SfxTabPage(pParent, SW_RES(TP_OUTLINE_NUM), rSet),
-    aLevelLB(       this, SW_RES(LB_LEVEL   )),
     aLevelFL(       this, SW_RES(FL_LEVEL    )),
+    aLevelLB(       this, SW_RES(LB_LEVEL   )),
+    aNumberFL(this, SW_RES(FL_NUMBER)),
     aCollLbl(this, SW_RES(FT_COLL)),
     aCollBox(this, SW_RES(LB_COLL)),
     aNumberLbl(this, SW_RES(FT_NUMBER)),
@@ -494,7 +460,6 @@ SwOutlineSettingsTabPage::SwOutlineSettingsTabPage(Window* pParent, const SfxIte
     aSuffixED(this, SW_RES(ED_SUFFIX)),
     aStartLbl(this, SW_RES(FT_START)),
     aStartEdit(this, SW_RES(ED_START)),
-    aNumberFL(this, SW_RES(FL_NUMBER)),
     aPreviewWIN(    this, SW_RES(WIN_PREVIEW )),
 
     aNoFmtName(SW_RES(ST_NO_COLL)),
@@ -525,17 +490,17 @@ void   	SwOutlineSettingsTabPage::Update()
     aCollBox.Enable(USHRT_MAX != nActLevel);
     if(USHRT_MAX == nActLevel)
     {
-        BOOL bSamePrefix = TRUE;
-        BOOL bSameSuffix = TRUE;
-        BOOL bSameType = TRUE;
-        BOOL bSameComplete = TRUE;
-        BOOL bSameStart = TRUE;
-        BOOL bSameCharFmt = TRUE;
+        sal_Bool bSamePrefix = sal_True;
+        sal_Bool bSameSuffix = sal_True;
+        sal_Bool bSameType = sal_True;
+        sal_Bool bSameComplete = sal_True;
+        sal_Bool bSameStart = sal_True;
+        sal_Bool bSameCharFmt = sal_True;
 
         const SwNumFmt* aNumFmtArr[MAXLEVEL];
         const SwCharFmt* pFirstFmt = 0;
 
-        for(USHORT i = 0; i < MAXLEVEL; i++)
+        for(sal_uInt16 i = 0; i < MAXLEVEL; i++)
         {
 
             aNumFmtArr[ i ] = &pNumRule->Get(i);
@@ -549,8 +514,8 @@ void   	SwOutlineSettingsTabPage::Update()
                 bSameSuffix &= aNumFmtArr[i]->GetSuffix() == aNumFmtArr[0]->GetSuffix();
                 bSameComplete &= aNumFmtArr[i]->GetIncludeUpperLevels() == aNumFmtArr[0]->GetIncludeUpperLevels();
                 const SwCharFmt* pFmt = aNumFmtArr[i]->GetCharFmt();
-                bSameCharFmt &= 	!pFirstFmt && !pFmt
-                                    || pFirstFmt && pFmt && pFmt->GetName() == pFirstFmt->GetName();
+                bSameCharFmt &= 	(!pFirstFmt && !pFmt)
+                                    || (pFirstFmt && pFmt && pFmt->GetName() == pFirstFmt->GetName());
             }
         }
         CheckForStartValue_Impl(aNumFmtArr[0]->GetNumberingType());
@@ -581,8 +546,8 @@ void   	SwOutlineSettingsTabPage::Update()
         else
             aCharFmtLB.SetNoSelection();
 
-        aAllLevelFT.Enable(TRUE);
-        aAllLevelNF.Enable(TRUE);
+        aAllLevelFT.Enable(sal_True);
+        aAllLevelNF.Enable(sal_True);
         aAllLevelNF.SetMax(MAXLEVEL);
         if(bSameComplete)
         {
@@ -595,7 +560,7 @@ void   	SwOutlineSettingsTabPage::Update()
     }
     else
     {
-        USHORT nTmpLevel = lcl_BitToLevel(nActLevel);
+        sal_uInt16 nTmpLevel = lcl_BitToLevel(nActLevel);
         String aColl(pCollNames[nTmpLevel]);
         if(aColl.Len())
             aCollBox.SelectEntry(aColl);
@@ -614,16 +579,16 @@ void   	SwOutlineSettingsTabPage::Update()
 
         if(nTmpLevel)
         {
-            aAllLevelFT.Enable(TRUE);
-            aAllLevelNF.Enable(TRUE);
+            aAllLevelFT.Enable(sal_True);
+            aAllLevelNF.Enable(sal_True);
             aAllLevelNF.SetMax(nTmpLevel + 1);
             aAllLevelNF.SetValue(rFmt.GetIncludeUpperLevels());
         }
         else
         {
             aAllLevelNF.SetText(aEmptyStr);
-            aAllLevelNF.Enable(FALSE);
-            aAllLevelFT.Enable(FALSE);
+            aAllLevelNF.Enable(sal_False);
+            aAllLevelFT.Enable(sal_False);
         }
         CheckForStartValue_Impl(rFmt.GetNumberingType());
         aStartEdit.SetValue( rFmt.GetStart() );
@@ -640,8 +605,8 @@ IMPL_LINK( SwOutlineSettingsTabPage, LevelHdl, ListBox *, pBox )
     }
     else
     {
-        USHORT nMask = 1;
-        for( USHORT i = 0; i < MAXLEVEL; i++ )
+        sal_uInt16 nMask = 1;
+        for( sal_uInt16 i = 0; i < MAXLEVEL; i++ )
         {
             if(pBox->IsEntryPosSelected( i ))
                 nActLevel |= nMask;
@@ -654,14 +619,14 @@ IMPL_LINK( SwOutlineSettingsTabPage, LevelHdl, ListBox *, pBox )
 
 IMPL_LINK( SwOutlineSettingsTabPage, ToggleComplete, NumericField *, pFld )
 {
-    USHORT nMask = 1;
-    for(USHORT i = 0; i < MAXLEVEL; i++)
+    sal_uInt16 nMask = 1;
+    for(sal_uInt16 i = 0; i < MAXLEVEL; i++)
     {
         if(nActLevel & nMask)
         {
             SwNumFmt aNumFmt(pNumRule->Get(i));
-            aNumFmt.SetIncludeUpperLevels( Min( (BYTE)pFld->GetValue(),
-                                                (BYTE)(i + 1)) );
+            aNumFmt.SetIncludeUpperLevels( Min( (sal_uInt8)pFld->GetValue(),
+                                                (sal_uInt8)(i + 1)) );
             pNumRule->Set(i, aNumFmt);
         }
         nMask <<= 1;
@@ -672,11 +637,11 @@ IMPL_LINK( SwOutlineSettingsTabPage, ToggleComplete, NumericField *, pFld )
 
 IMPL_LINK( SwOutlineSettingsTabPage, CollSelect, ListBox *, pBox )
 {
-    BYTE i;
+    sal_uInt8 i;
 
     const String aCollName(pBox->GetSelectEntry());
     //0xFFFF darf hier nicht sein (disable)
-    USHORT nTmpLevel = lcl_BitToLevel(nActLevel);
+    sal_uInt16 nTmpLevel = lcl_BitToLevel(nActLevel);
     String sOldName( pCollNames[nTmpLevel] );
 
     for( i = 0; i < MAXLEVEL; ++i)
@@ -699,7 +664,7 @@ IMPL_LINK( SwOutlineSettingsTabPage, CollSelect, ListBox *, pBox )
             if( aSaveCollNames[ i ] == sOldName && i != nTmpLevel &&
                 !pCollNames[ i ].Len() )
             {
-                BYTE n;
+                sal_uInt8 n;
                 for( n = 0; n < MAXLEVEL; ++n )
                     if( pCollNames[ n ] == sOldName )
                         break;
@@ -715,16 +680,16 @@ IMPL_LINK( SwOutlineSettingsTabPage, CollSelect, ListBox *, pBox )
 
 IMPL_LINK( SwOutlineSettingsTabPage, CollSelectGetFocus, ListBox *, EMPTYARG )
 {
-    for( BYTE i = 0; i < MAXLEVEL; ++i)
+    for( sal_uInt8 i = 0; i < MAXLEVEL; ++i)
         aSaveCollNames[i] =  pCollNames[i];
     return 0;
 }
 
 IMPL_LINK( SwOutlineSettingsTabPage, NumberSelect, SwNumberingTypeListBox *, pBox )
 {
-    USHORT nMask = 1;
-    sal_Int16 nNumberType = pBox->GetSelectedNumberingType();//(sal_Int16)(ULONG)pBox->GetEntryData(pBox->GetSelectEntryPos());
-    for(USHORT i = 0; i < MAXLEVEL; i++)
+    sal_uInt16 nMask = 1;
+    sal_Int16 nNumberType = pBox->GetSelectedNumberingType();
+    for(sal_uInt16 i = 0; i < MAXLEVEL; i++)
     {
         if(nActLevel & nMask)
         {
@@ -741,8 +706,8 @@ IMPL_LINK( SwOutlineSettingsTabPage, NumberSelect, SwNumberingTypeListBox *, pBo
 
 IMPL_LINK( SwOutlineSettingsTabPage, DelimModify, Edit *, EMPTYARG )
 {
-    USHORT nMask = 1;
-    for(USHORT i = 0; i < MAXLEVEL; i++)
+    sal_uInt16 nMask = 1;
+    for(sal_uInt16 i = 0; i < MAXLEVEL; i++)
     {
         if(nActLevel & nMask)
         {
@@ -759,13 +724,13 @@ IMPL_LINK( SwOutlineSettingsTabPage, DelimModify, Edit *, EMPTYARG )
 
 IMPL_LINK( SwOutlineSettingsTabPage, StartModified, NumericField *, pFld )
 {
-    USHORT nMask = 1;
-    for(USHORT i = 0; i < MAXLEVEL; i++)
+    sal_uInt16 nMask = 1;
+    for(sal_uInt16 i = 0; i < MAXLEVEL; i++)
     {
         if(nActLevel & nMask)
         {
             SwNumFmt aNumFmt(pNumRule->Get(i));
-            aNumFmt.SetStart( (USHORT)pFld->GetValue() );
+            aNumFmt.SetStart( (sal_uInt16)pFld->GetValue() );
             pNumRule->Set(i, aNumFmt);
         }
         nMask <<= 1;
@@ -776,15 +741,14 @@ IMPL_LINK( SwOutlineSettingsTabPage, StartModified, NumericField *, pFld )
 
 IMPL_LINK( SwOutlineSettingsTabPage, CharFmtHdl, ListBox *, EMPTYARG )
 {
-//	bAutomaticCharStyles = FALSE;
     String sEntry = aCharFmtLB.GetSelectEntry();
-    USHORT nMask = 1;
-    BOOL bFormatNone = sEntry == ViewShell::GetShellRes()->aStrNone;
+    sal_uInt16 nMask = 1;
+    sal_Bool bFormatNone = sEntry == ViewShell::GetShellRes()->aStrNone;
     SwCharFmt* pFmt = 0;
     if(!bFormatNone)
     {
-        USHORT nChCount = pSh->GetCharFmtCount();
-        for(USHORT i = 0; i < nChCount; i++)
+        sal_uInt16 nChCount = pSh->GetCharFmtCount();
+        for(sal_uInt16 i = 0; i < nChCount; i++)
         {
             SwCharFmt& rChFmt = pSh->GetCharFmt(i);
             if(rChFmt.GetName() == sEntry)
@@ -805,7 +769,7 @@ IMPL_LINK( SwOutlineSettingsTabPage, CharFmtHdl, ListBox *, EMPTYARG )
         }
     }
 
-    for(USHORT i = 0; i < MAXLEVEL; i++)
+    for(sal_uInt16 i = 0; i < MAXLEVEL; i++)
     {
         if(nActLevel & nMask)
         {
@@ -832,18 +796,16 @@ void SwOutlineSettingsTabPage::SetWrtShell(SwWrtShell* pShell)
     pNumRule = ((SwOutlineTabDialog*)GetTabDialog())->GetNumRule();
     pCollNames = ((SwOutlineTabDialog*)GetTabDialog())->GetCollNames();
 
-    //pNumRule = new SwNumRule( *rSh.GetOutlineNumRule() );
-
     aPreviewWIN.SetNumRule(pNumRule);
     aPreviewWIN.SetOutlineNames(pCollNames);
     // Startwert setzen - nActLevel muss hier 1 sein
-    USHORT nTmpLevel = lcl_BitToLevel(nActLevel);
+    sal_uInt16 nTmpLevel = lcl_BitToLevel(nActLevel);
     const SwNumFmt& rNumFmt = pNumRule->Get( nTmpLevel );
     aStartEdit.SetValue( rNumFmt.GetStart() );
 
     // Poolformate fuer Ueberschriften anlegen
     String sStr;
-    USHORT i;
+    sal_uInt16 i;
     for( i = 0; i < MAXLEVEL; ++i )
     {
         aCollBox.InsertEntry( SwStyleNameMapper::GetUIName(
@@ -855,7 +817,7 @@ void SwOutlineSettingsTabPage::SetWrtShell(SwWrtShell* pShell)
     aLevelLB.InsertEntry( sStr );
 
     // Erfragen der Gliederungsebenen der Textvorlagen
-    const USHORT nCount = pSh->GetTxtFmtCollCount();
+    const sal_uInt16 nCount = pSh->GetTxtFmtCollCount();
     for( i = 0; i < nCount; ++i )
     {
         SwTxtFmtColl &rTxtColl = pSh->GetTxtFmtColl(i);
@@ -868,11 +830,11 @@ void SwOutlineSettingsTabPage::SetWrtShell(SwWrtShell* pShell)
     }
 
     aNumberBox.SelectNumberingType(rNumFmt.GetNumberingType());
-    USHORT nOutlinePos = pSh->GetOutlinePos(MAXLEVEL);
-    USHORT nTmp = 0;
+    sal_uInt16 nOutlinePos = pSh->GetOutlinePos(MAXLEVEL);
+    sal_uInt16 nTmp = 0;
     if(nOutlinePos != USHRT_MAX)
     {
-        nTmp = static_cast<USHORT>(pSh->getIDocumentOutlineNodesAccess()->getOutlineLevel(nOutlinePos));
+        nTmp = static_cast<sal_uInt16>(pSh->getIDocumentOutlineNodesAccess()->getOutlineLevel(nOutlinePos));
     }
     aLevelLB.SelectEntryPos(nTmp-1);//nTmp);//#outline level,zhaojianwei
 
@@ -902,9 +864,9 @@ int     SwOutlineSettingsTabPage::DeactivatePage(SfxItemSet*)
     return LEAVE_PAGE;
 }
 
-BOOL    SwOutlineSettingsTabPage::FillItemSet( SfxItemSet&  )
+sal_Bool    SwOutlineSettingsTabPage::FillItemSet( SfxItemSet&  )
 {
-    return TRUE;
+    return sal_True;
 }
 
 void 	SwOutlineSettingsTabPage::Reset( const SfxItemSet& rSet )
@@ -920,8 +882,8 @@ SfxTabPage*	SwOutlineSettingsTabPage::Create( Window* pParent,
 
 void SwOutlineSettingsTabPage::CheckForStartValue_Impl(sal_uInt16 nNumberingType)
 {
-    BOOL bIsNull = aStartEdit.GetValue() == 0;
-    BOOL bNoZeroAllowed = nNumberingType < SVX_NUM_ARABIC ||
+    sal_Bool bIsNull = aStartEdit.GetValue() == 0;
+    sal_Bool bNoZeroAllowed = nNumberingType < SVX_NUM_ARABIC ||
                         SVX_NUM_CHARS_UPPER_LETTER_N == nNumberingType ||
                         SVX_NUM_CHARS_LOWER_LETTER_N == nNumberingType;
     aStartEdit.SetMin(bNoZeroAllowed ? 1 : 0);
@@ -929,29 +891,29 @@ void SwOutlineSettingsTabPage::CheckForStartValue_Impl(sal_uInt16 nNumberingType
         aStartEdit.GetModifyHdl().Call(&aStartEdit);
 }
 
-USHORT lcl_DrawBullet(VirtualDevice* pVDev,
-            const SwNumFmt& rFmt, USHORT nXStart,
-            USHORT nYStart, const Size& rSize)
+sal_uInt16 lcl_DrawBullet(VirtualDevice* pVDev,
+            const SwNumFmt& rFmt, sal_uInt16 nXStart,
+            sal_uInt16 nYStart, const Size& rSize)
 {
     Font aTmpFont(pVDev->GetFont());
 
     Font aFont(*rFmt.GetBulletFont());
     aFont.SetSize(rSize);
-    aFont.SetTransparent(TRUE);
+    aFont.SetTransparent(sal_True);
     pVDev->SetFont( aFont );
     String aText(rFmt.GetBulletChar());
     pVDev->DrawText( Point(nXStart, nYStart), aText );
-    USHORT nRet = (USHORT)pVDev->GetTextWidth(aText);
+    sal_uInt16 nRet = (sal_uInt16)pVDev->GetTextWidth(aText);
 
     pVDev->SetFont(aTmpFont);
     return nRet;
 }
 
-USHORT lcl_DrawGraphic(VirtualDevice* pVDev, const SwNumFmt &rFmt, USHORT nXStart,
-                        USHORT nYStart, USHORT nDivision)
+sal_uInt16 lcl_DrawGraphic(VirtualDevice* pVDev, const SwNumFmt &rFmt, sal_uInt16 nXStart,
+                        sal_uInt16 nYStart, sal_uInt16 nDivision)
 {
     const SvxBrushItem* pBrushItem = rFmt.GetBrush();
-    USHORT nRet = 0;
+    sal_uInt16 nRet = 0;
     if(pBrushItem)
     {
         const Graphic* pGrf = pBrushItem->GetGraphic();
@@ -959,7 +921,7 @@ USHORT lcl_DrawGraphic(VirtualDevice* pVDev, const SwNumFmt &rFmt, USHORT nXStar
         {
             Size aGSize( rFmt.GetGraphicSize());
             aGSize.Width() /= nDivision;
-            nRet = (USHORT)aGSize.Width();
+            nRet = (sal_uInt16)aGSize.Width();
             aGSize.Height() /= nDivision;
             pGrf->Draw( pVDev, Point(nXStart,nYStart),
                     pVDev->PixelToLogic( aGSize ) );
@@ -969,7 +931,7 @@ USHORT lcl_DrawGraphic(VirtualDevice* pVDev, const SwNumFmt &rFmt, USHORT nXStar
 
 }
 
-/*-----------------02.12.97 10:34-------------------
+/*--------------------------------------------------
     Vorschau der Numerierung painten
 --------------------------------------------------*/
 void    NumberingPreview::Paint( const Rectangle& /*rRect*/ )
@@ -988,10 +950,10 @@ void    NumberingPreview::Paint( const Rectangle& /*rRect*/ )
 
     if(pActNum)
     {
-        USHORT nWidthRelation;
+        sal_uInt16 nWidthRelation;
         if(nPageWidth)
         {
-            nWidthRelation = USHORT (nPageWidth / aSize.Width());
+            nWidthRelation = sal_uInt16 (nPageWidth / aSize.Width());
             if(bPosition)
                 nWidthRelation = nWidthRelation * 2 / 3;
             else
@@ -1001,29 +963,28 @@ void    NumberingPreview::Paint( const Rectangle& /*rRect*/ )
             nWidthRelation = 30; // Kapiteldialog
 
         //Hoehe pro Ebene
-        USHORT nXStep = USHORT(aSize.Width() / (3 * MAXLEVEL));
+        sal_uInt16 nXStep = sal_uInt16(aSize.Width() / (3 * MAXLEVEL));
         if(MAXLEVEL < 10)
             nXStep /= 2;
-        USHORT nYStart = 4;
-        USHORT nYStep = USHORT((aSize.Height() - 6)/ MAXLEVEL);
+        sal_uInt16 nYStart = 4;
+        sal_uInt16 nYStep = sal_uInt16((aSize.Height() - 6)/ MAXLEVEL);
         aStdFont = OutputDevice::GetDefaultFont(
                                     DEFAULTFONT_UI_SANS, (LanguageType)GetAppLanguage(),
                                     DEFAULTFONT_FLAGS_ONLYONE, this );
         // #101524# OJ
         aStdFont.SetColor( SwViewOption::GetFontColor() );
 
-        //
-        USHORT nFontHeight = nYStep * 6 / 10;
+        sal_uInt16 nFontHeight = nYStep * 6 / 10;
         if(bPosition)
             nFontHeight = nYStep * 15 / 10;
         aStdFont.SetSize(Size( 0, nFontHeight ));
 
-        USHORT nPreNum = pActNum->Get(0).GetStart();
+        sal_uInt16 nPreNum = pActNum->Get(0).GetStart();
 
         if(bPosition)
         {
-            USHORT nLineHeight = nFontHeight * 8 / 7;
-            BYTE nStart = 0;
+            sal_uInt16 nLineHeight = nFontHeight * 8 / 7;
+            sal_uInt8 nStart = 0;
             while( !(nActLevel & (1<<nStart)) )
             {
                 nStart++;
@@ -1032,22 +993,21 @@ void    NumberingPreview::Paint( const Rectangle& /*rRect*/ )
                 nStart--;
 
             SwNumberTree::tNumberVector aNumVector;
-            BYTE nEnd = Min( (BYTE)(nStart + 3), MAXLEVEL );
-            for( BYTE nLevel = nStart; nLevel < nEnd; ++nLevel )
+            sal_uInt8 nEnd = Min( (sal_uInt8)(nStart + 3), MAXLEVEL );
+            for( sal_uInt8 nLevel = nStart; nLevel < nEnd; ++nLevel )
             {
                 const SwNumFmt &rFmt = pActNum->Get(nLevel);
                 aNumVector.push_back(rFmt.GetStart());
 
-                // --> OD 2008-02-01 #newlistlevelattrs#
-                USHORT nXStart( 0 );
+                sal_uInt16 nXStart( 0 );
                 short nTextOffset( 0 );
-                USHORT nNumberXPos( 0 );
+                sal_uInt16 nNumberXPos( 0 );
                 if ( rFmt.GetPositionAndSpaceMode() == SvxNumberFormat::LABEL_WIDTH_AND_POSITION )
                 {
                     nXStart = rFmt.GetAbsLSpace() / nWidthRelation;
                     nTextOffset = rFmt.GetCharTextDistance() / nWidthRelation;
                     nNumberXPos = nXStart;
-                    USHORT nFirstLineOffset = (-rFmt.GetFirstLineOffset()) / nWidthRelation;
+                    sal_uInt16 nFirstLineOffset = (-rFmt.GetFirstLineOffset()) / nWidthRelation;
 
                     if(nFirstLineOffset <= nNumberXPos)
                         nNumberXPos = nNumberXPos - nFirstLineOffset;
@@ -1065,12 +1025,11 @@ void    NumberingPreview::Paint( const Rectangle& /*rRect*/ )
                     }
                     else
                     {
-                        nNumberXPos = static_cast<USHORT>(nTmpNumberXPos);
+                        nNumberXPos = static_cast<sal_uInt16>(nTmpNumberXPos);
                     }
                 }
-                // <--
 
-                USHORT nBulletWidth = 0;
+                sal_uInt16 nBulletWidth = 0;
                 if( SVX_NUM_BITMAP == rFmt.GetNumberingType() )
                 {
                     nBulletWidth = lcl_DrawGraphic(pVDev, rFmt,
@@ -1090,22 +1049,19 @@ void    NumberingPreview::Paint( const Rectangle& /*rRect*/ )
                     String aText(pActNum->MakeNumString( aNumVector ));
                     // <--
                     pVDev->DrawText( Point(nNumberXPos, nYStart), aText );
-                    nBulletWidth = (USHORT)pVDev->GetTextWidth(aText);
+                    nBulletWidth = (sal_uInt16)pVDev->GetTextWidth(aText);
                     nPreNum++;
                 }
-                // --> OD 2008-02-01 #newlistlevelattrs#
                 if ( rFmt.GetPositionAndSpaceMode() == SvxNumberFormat::LABEL_ALIGNMENT &&
                      rFmt.GetLabelFollowedBy() == SvxNumberFormat::SPACE )
                 {
                     pVDev->SetFont(aStdFont);
                     String aText(' ');
                     pVDev->DrawText( Point(nNumberXPos, nYStart), aText );
-                    nBulletWidth = nBulletWidth + (USHORT)pVDev->GetTextWidth(aText);
+                    nBulletWidth = nBulletWidth + (sal_uInt16)pVDev->GetTextWidth(aText);
                 }
-                // <--
 
-                // --> OD 2008-02-01 #newlistlevelattrs#
-                USHORT nTextXPos( 0 );
+                sal_uInt16 nTextXPos( 0 );
                 if ( rFmt.GetPositionAndSpaceMode() == SvxNumberFormat::LABEL_WIDTH_AND_POSITION )
                 {
                     nTextXPos = nXStart;
@@ -1120,7 +1076,7 @@ void    NumberingPreview::Paint( const Rectangle& /*rRect*/ )
                     {
                         case SvxNumberFormat::LISTTAB:
                         {
-                            nTextXPos = static_cast<USHORT>(
+                            nTextXPos = static_cast<sal_uInt16>(
                                             rFmt.GetListtabPos() / nWidthRelation );
                             if ( nTextXPos < nNumberXPos + nBulletWidth )
                             {
@@ -1136,9 +1092,8 @@ void    NumberingPreview::Paint( const Rectangle& /*rRect*/ )
                         break;
                     }
 
-                    nXStart = static_cast<USHORT>( rFmt.GetIndentAt() / nWidthRelation );
+                    nXStart = static_cast<sal_uInt16>( rFmt.GetIndentAt() / nWidthRelation );
                 }
-                // <--
 
 
                 Rectangle aRect1(Point(nTextXPos, nYStart + nFontHeight / 2), Size(aSize.Width() / 2, 2));
@@ -1153,14 +1108,13 @@ void    NumberingPreview::Paint( const Rectangle& /*rRect*/ )
         else
         {
             SwNumberTree::tNumberVector aNumVector;
-            USHORT nLineHeight = nFontHeight * 3 / 2;
-            for( BYTE nLevel = 0; nLevel < MAXLEVEL;
+            sal_uInt16 nLineHeight = nFontHeight * 3 / 2;
+            for( sal_uInt8 nLevel = 0; nLevel < MAXLEVEL;
                             ++nLevel, nYStart = nYStart + nYStep )
             {
                 const SwNumFmt &rFmt = pActNum->Get(nLevel);
                 aNumVector.push_back(rFmt.GetStart());
-                // --> OD 2008-02-01 #newlistlevelattrs#
-                USHORT nXStart( 0 );
+                sal_uInt16 nXStart( 0 );
                 if ( rFmt.GetPositionAndSpaceMode() == SvxNumberFormat::LABEL_WIDTH_AND_POSITION )
                 {
                     nXStart = rFmt.GetAbsLSpace() / nWidthRelation;
@@ -1176,13 +1130,12 @@ void    NumberingPreview::Paint( const Rectangle& /*rRect*/ )
                     }
                     else
                     {
-                        nXStart = static_cast<USHORT>(nTmpXStart);
+                        nXStart = static_cast<sal_uInt16>(nTmpXStart);
                     }
                 }
                 nXStart /= 2;
                 nXStart += 2;
-                // <--
-                USHORT nTextOffset = 2 * nXStep;
+                sal_uInt16 nTextOffset = 2 * nXStep;
                 if( SVX_NUM_BITMAP == rFmt.GetNumberingType() )
                 {
                     lcl_DrawGraphic(pVDev, rFmt, nXStart, nYStart, nWidthRelation);
@@ -1202,7 +1155,7 @@ void    NumberingPreview::Paint( const Rectangle& /*rRect*/ )
                     String aText(pActNum->MakeNumString( aNumVector ));
                     // <--
                     pVDev->DrawText( Point(nXStart, nYStart), aText );
-                    nTextOffset = (USHORT)pVDev->GetTextWidth(aText);
+                    nTextOffset = (sal_uInt16)pVDev->GetTextWidth(aText);
                     nTextOffset = nTextOffset + nXStep;
                     nPreNum++;
                 }
