@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -28,10 +28,17 @@
 
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_toolkit.hxx"
+
+#include <boost/ptr_container/ptr_vector.hpp>
+
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 
-#include <tools/svwin.h>
 #include <stdio.h>
+#ifdef WNT
+#include <prewin.h>
+#include <postwin.h>
+#endif
+#include <com/sun/star/awt/ImageScaleMode.hpp>
 #include <com/sun/star/awt/WindowAttribute.hpp>
 #include <com/sun/star/awt/VclWindowPeerAttribute.hpp>
 #include <com/sun/star/awt/WindowClass.hpp>
@@ -52,11 +59,7 @@
 #include <rtl/uuid.h>
 #include <rtl/process.h>
 
-#ifdef WNT
-#include <tools/prewin.h>
-#include <windows.h>
-#include <tools/postwin.h>
-#elif (defined QUARTZ)
+#ifdef QUARTZ
 #include "premac.h"
 #include <Cocoa/Cocoa.h>
 #include "postmac.h"
@@ -67,16 +70,18 @@
 #include <toolkit/awt/vclxsystemdependentwindow.hxx>
 #include <toolkit/awt/vclxregion.hxx>
 #include <toolkit/awt/vclxtoolkit.hxx>
+#include <toolkit/awt/vclxtabpagecontainer.hxx>
+#include <toolkit/awt/vclxtabpagemodel.hxx>
 
 #include <toolkit/awt/xsimpleanimation.hxx>
 #include <toolkit/awt/xthrobber.hxx>
+#include <toolkit/awt/animatedimagespeer.hxx>
 #include <toolkit/awt/vclxtopwindow.hxx>
 #include <toolkit/awt/vclxwindow.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <toolkit/helper/unowrapper.hxx>
 #include <toolkit/helper/servicenames.hxx>
 
-
 #include <toolkit/helper/macros.hxx>
 #include <toolkit/helper/convert.hxx>
 #include <vcl/unohelp.hxx>
@@ -112,10 +117,12 @@
 #include <vcl/virdev.hxx>
 #include <vcl/window.hxx>
 #include <vcl/wrkwin.hxx>
+#include <vcl/throbber.hxx>
 #include "toolkit/awt/vclxspinbutton.hxx"
 
 #include <tools/debug.hxx>
 #include <comphelper/processfactory.hxx>
+#include "awt/vclxtabcontrol.hxx"
 
 namespace css = ::com::sun::star;
 
@@ -260,7 +267,7 @@ struct ComponentInfo
     WindowType		nWinType;
 };
 
-static ComponentInfo __FAR_DATA aComponentInfos [] =
+static ComponentInfo aComponentInfos [] =
 {
     { "buttondialog", 		WINDOW_BUTTONDIALOG },
     { "cancelbutton",		WINDOW_CANCELBUTTON },
@@ -283,6 +290,7 @@ static ComponentInfo __FAR_DATA aComponentInfos [] =
     { "floatingwindow",		WINDOW_FLOATINGWINDOW },
     { "framewindow",		VCLWINDOW_FRAMEWINDOW },
     { "groupbox",			WINDOW_GROUPBOX },
+    { "frame",			WINDOW_GROUPBOX },
     { "helpbutton",			WINDOW_HELPBUTTON },
     { "imagebutton",		WINDOW_IMAGEBUTTON },
     { "imageradiobutton",	WINDOW_IMAGERADIOBUTTON },
@@ -310,6 +318,7 @@ static ComponentInfo __FAR_DATA aComponentInfos [] =
     { "scrollbar",			WINDOW_SCROLLBAR },
     { "scrollbarbox",		WINDOW_SCROLLBARBOX },
     { "simpleanimation",	WINDOW_CONTROL },
+    { "animatedimages",     WINDOW_CONTROL },
     { "spinbutton",			WINDOW_SPINBUTTON },
     { "spinfield",			WINDOW_SPINFIELD },
     { "throbber",        	WINDOW_CONTROL },
@@ -326,7 +335,9 @@ static ComponentInfo __FAR_DATA aComponentInfos [] =
     { "tristatebox",		WINDOW_TRISTATEBOX },
     { "warningbox",			WINDOW_WARNINGBOX },
     { "window",				WINDOW_WINDOW },
-    { "workwindow",			WINDOW_WORKWINDOW }
+    { "workwindow",			WINDOW_WORKWINDOW },
+    { "tabpagecontainer",	WINDOW_CONTROL },
+    { "tabpagemodel",		WINDOW_TABPAGE }
 };
 
 extern "C"
@@ -381,7 +392,7 @@ sal_uInt16 ImplGetComponentType( const String& rServiceName )
 //	----------------------------------------------------
 
 static sal_Int32							nVCLToolkitInstanceCount = 0;
-static BOOL									bInitedByVCLToolkit = sal_False;
+static sal_Bool									bInitedByVCLToolkit = sal_False;
 //static cppu::OInterfaceContainerHelper *	pToolkits = 0;
 
 static osl::Mutex & getInitMutex()
@@ -623,7 +634,14 @@ Window*	VCLXToolkit::ImplCreateWindow( VCLXWindow** ppNewComp,
 
     Window* pNewWindow = NULL;
     sal_uInt16 nType = ImplGetComponentType( aServiceName );
-
+    bool bFrameControl = false;
+    if ( aServiceName == String( RTL_CONSTASCII_USTRINGPARAM("frame") ) )
+        bFrameControl = true;
+    if ( aServiceName == String( RTL_CONSTASCII_USTRINGPARAM("tabcontrolnotabs") ) )
+    {
+        nWinBits |= WB_NOBORDER;
+        nType = ImplGetComponentType( String( RTL_CONSTASCII_USTRINGPARAM("tabcontrol") ) );
+    }
     if ( !pParent )
     {
         // Wenn die Component einen Parent braucht, dann NULL zurueckgeben,
@@ -677,7 +695,7 @@ Window*	VCLXToolkit::ImplCreateWindow( VCLXWindow** ppNewComp,
             break;
             case WINDOW_CURRENCYFIELD:
                 pNewWindow = new CurrencyField( pParent, nWinBits );
-                static_cast<CurrencyField*>(pNewWindow)->EnableEmptyFieldValue( TRUE );
+                static_cast<CurrencyField*>(pNewWindow)->EnableEmptyFieldValue( sal_True );
                 *ppNewComp = new VCLXNumericField;
                 ((VCLXFormattedSpinField*)*ppNewComp)->SetFormatter( (FormatterBase*)(CurrencyField*)pNewWindow );
             break;
@@ -686,7 +704,7 @@ Window*	VCLXToolkit::ImplCreateWindow( VCLXWindow** ppNewComp,
             break;
             case WINDOW_DATEFIELD:
                 pNewWindow = new DateField( pParent, nWinBits );
-                static_cast<DateField*>(pNewWindow)->EnableEmptyFieldValue( TRUE );
+                static_cast<DateField*>(pNewWindow)->EnableEmptyFieldValue( sal_True );
                 *ppNewComp = new VCLXDateField;
                 ((VCLXFormattedSpinField*)*ppNewComp)->SetFormatter( (FormatterBase*)(DateField*)pNewWindow );
             break;
@@ -720,7 +738,17 @@ Window*	VCLXToolkit::ImplCreateWindow( VCLXWindow** ppNewComp,
                 pNewWindow = new FloatingWindow( pParent, nWinBits );
             break;
             case WINDOW_GROUPBOX:
+                        {
                 pNewWindow = new GroupBox( pParent, nWinBits );
+                                if ( bFrameControl )
+                                {
+                                    GroupBox* pGroupBox =  static_cast< GroupBox* >( pNewWindow );
+                                    *ppNewComp = new VCLXFrame;
+                                    // Frame control needs to recieve
+                                    // Mouse events
+                                    pGroupBox->SetMouseTransparent( sal_False );
+                                }
+                        }
             break;
             case WINDOW_HELPBUTTON:
                 pNewWindow = new HelpButton( pParent, nWinBits );
@@ -791,7 +819,7 @@ Window*	VCLXToolkit::ImplCreateWindow( VCLXWindow** ppNewComp,
             break;
             case WINDOW_NUMERICFIELD:
                 pNewWindow = new NumericField( pParent, nWinBits );
-                static_cast<NumericField*>(pNewWindow)->EnableEmptyFieldValue( TRUE );
+                static_cast<NumericField*>(pNewWindow)->EnableEmptyFieldValue( sal_True );
                 *ppNewComp = new VCLXNumericField;
                 ((VCLXFormattedSpinField*)*ppNewComp)->SetFormatter( (FormatterBase*)(NumericField*)pNewWindow );
             break;
@@ -823,12 +851,12 @@ Window*	VCLXToolkit::ImplCreateWindow( VCLXWindow** ppNewComp,
                 // Since the VCLXRadioButton really cares for it's RadioCheck settings, this is important:
                 // if we enable it, the VCLXRadioButton will use RadioButton::Check instead of RadioButton::SetState
                 // This leads to a strange behaviour if the control is newly created: when settings the initial
-                // state to "checked", the RadioButton::Check (called because RadioCheck=TRUE) will uncheck
+                // state to "checked", the RadioButton::Check (called because RadioCheck=sal_True) will uncheck
                 // _all_other_ radio buttons in the same group. However, at this moment the grouping of the controls
                 // is not really valid: the controls are grouped after they have been created, but we're still in
                 // the creation process, so the RadioButton::Check relies on invalid grouping information.
                 // 07.08.2001 - #87254# - frank.schoenheit@sun.com
-                static_cast<RadioButton*>(pNewWindow)->EnableRadioCheck( FALSE );
+                static_cast<RadioButton*>(pNewWindow)->EnableRadioCheck( sal_False );
             break;
             case WINDOW_SCROLLBAR:
                 pNewWindow = new ScrollBar( pParent, nWinBits );
@@ -860,20 +888,32 @@ Window*	VCLXToolkit::ImplCreateWindow( VCLXWindow** ppNewComp,
             break;
             case WINDOW_TABCONTROL:
                 pNewWindow = new TabControl( pParent, nWinBits );
+                *ppNewComp = new VCLXMultiPage;
             break;
             case WINDOW_TABDIALOG:
                 pNewWindow = new TabDialog( pParent, nWinBits );
             break;
             case WINDOW_TABPAGE:
-                pNewWindow = new TabPage( pParent, nWinBits );
-                *ppNewComp = new VCLXTabPage;
+                /*
+                if ( rDescriptor.WindowServiceName.equalsIgnoreAsciiCase(
+                        ::rtl::OUString::createFromAscii("tabpagemodel") ) )
+                {
+                    pNewWindow = new TabControl( pParent, nWinBits );
+                    *ppNewComp = new VCLXTabPageContainer;
+                }
+                else
+                */
+                {
+                    pNewWindow = new TabPage( pParent, nWinBits );
+                    *ppNewComp = new VCLXTabPage;
+                }
             break;
             case WINDOW_TIMEBOX:
                 pNewWindow = new TimeBox( pParent, nWinBits );
             break;
             case WINDOW_TIMEFIELD:
                 pNewWindow = new TimeField( pParent, nWinBits );
-                static_cast<TimeField*>(pNewWindow)->EnableEmptyFieldValue( TRUE );
+                static_cast<TimeField*>(pNewWindow)->EnableEmptyFieldValue( sal_True );
                 *ppNewComp = new VCLXTimeField;
                 ((VCLXFormattedSpinField*)*ppNewComp)->SetFormatter( (FormatterBase*)(TimeField*)pNewWindow );
             break;
@@ -928,9 +968,9 @@ Window*	VCLXToolkit::ImplCreateWindow( VCLXWindow** ppNewComp,
                                         const css::beans::NamedValue* pProps = aProps.getConstArray();
                                         for( int i = 0; i < nProps; i++ )
                                         {
-                                            if( pProps[i].Name.equalsAscii( "WINDOW" ) )
+                                            if( pProps[i].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "WINDOW" ) ) )
                                                 pProps[i].Value >>= nWindowHandle;
-                                            else if( pProps[i].Name.equalsAscii( "XEMBED" ) )
+                                            else if( pProps[i].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "XEMBED" ) ) )
                                                 pProps[i].Value >>= bXEmbed;
                                         }
                                     }
@@ -981,22 +1021,35 @@ Window*	VCLXToolkit::ImplCreateWindow( VCLXWindow** ppNewComp,
                 }
             break;
             case WINDOW_CONTROL:
-                if ( rDescriptor.WindowServiceName.equalsIgnoreAsciiCase(
-                        ::rtl::OUString::createFromAscii("simpleanimation") ) )
+                if  ( aServiceName.EqualsAscii( "simpleanimation" ) )
                 {
-                    nWinBits |= WB_SCALE;
-                    pNewWindow = new FixedImage( pParent, nWinBits );
+                    pNewWindow = new Throbber( pParent, nWinBits, Throbber::IMAGES_NONE );
+                    ((Throbber*)pNewWindow)->SetScaleMode( css::awt::ImageScaleMode::Anisotropic );
+                        // (compatibility)
                     *ppNewComp = new ::toolkit::XSimpleAnimation;
                 }
-                else if ( rDescriptor.WindowServiceName.equalsIgnoreAsciiCase(
-                        ::rtl::OUString::createFromAscii("throbber") ) )
+                else if ( aServiceName.EqualsAscii( "throbber" ) )
                 {
-                    nWinBits |= WB_SCALE;
-                    pNewWindow = new FixedImage( pParent, nWinBits );
+                    pNewWindow = new Throbber( pParent, nWinBits, Throbber::IMAGES_NONE );
+                    ((Throbber*)pNewWindow)->SetScaleMode( css::awt::ImageScaleMode::Anisotropic );
+                        // (compatibility)
                     *ppNewComp = new ::toolkit::XThrobber;
                 }
+                else if ( rDescriptor.WindowServiceName.equalsIgnoreAsciiCase(
+                        ::rtl::OUString::createFromAscii("tabpagecontainer") ) )
+                {
+                    pNewWindow = new TabControl( pParent, nWinBits );
+                    *ppNewComp = new VCLXTabPageContainer;
+                }
+                else if ( aServiceName.EqualsAscii( "animatedimages" ) )
+                {
+                    pNewWindow = new Throbber( pParent, nWinBits );
+                    *ppNewComp = new ::toolkit::AnimatedImagesPeer;
+                }
             break;
-            default:    DBG_ERRORFILE( "UNO3!" );
+            default:
+                OSL_ENSURE( false, "VCLXToolkit::ImplCreateWindow: unknown window type!" );
+                break;
         }
     }
 
@@ -1040,7 +1093,7 @@ css::uno::Reference< css::awt::XWindowPeer > VCLXToolkit::ImplCreateWindow(
     // try to load the lib
     if ( !fnSvtCreateWindow && !hSvToolsLib )
     {
-        ::rtl::OUString aLibName = ::vcl::unohelper::CreateLibraryName( "svt", TRUE );
+        ::rtl::OUString aLibName = ::vcl::unohelper::CreateLibraryName( "svt", sal_True );
         hSvToolsLib = osl_loadModuleRelative(
             &thisModule, aLibName.pData, SAL_LOADMODULE_DEFAULT );
         if ( hSvToolsLib )
@@ -1087,11 +1140,11 @@ css::uno::Reference< css::awt::XWindowPeer > VCLXToolkit::ImplCreateWindow(
         }
         else
         {
-            pNewComp->SetCreatedWithToolkit( TRUE );
+            pNewComp->SetCreatedWithToolkit( sal_True );
             xRef = pNewComp;
             pNewWindow->SetComponentInterface( xRef );
         }
-        DBG_ASSERT( pNewWindow->GetComponentInterface( FALSE ) == xRef,
+        DBG_ASSERT( pNewWindow->GetComponentInterface( sal_False ) == xRef,
             "VCLXToolkit::createWindow: did #133706# resurge?" );
 
         if ( rDescriptor.WindowAttributes & ::com::sun::star::awt::WindowAttribute::SHOW )
@@ -1141,9 +1194,9 @@ css::uno::Reference< css::awt::XWindowPeer > VCLXToolkit::ImplCreateWindow(
                 const css::beans::NamedValue* pProps = aProps.getConstArray();
                 for( int i = 0; i < nProps; i++ )
                 {
-                    if( pProps[i].Name.equalsAscii( "WINDOW" ) )
+                    if( pProps[i].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "WINDOW" ) ) )
                         pProps[i].Value >>= nWindowHandle;
-                    else if( pProps[i].Name.equalsAscii( "XEMBED" ) )
+                    else if( pProps[i].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "XEMBED" ) ) )
                         pProps[i].Value >>= bXEmbed;
                 }
             }
@@ -1200,12 +1253,12 @@ css::uno::Reference< css::awt::XWindowPeer > VCLXToolkit::ImplCreateWindow(
 }
 
 // ::com::sun::star::awt::XMessageBoxFactory
-::com::sun::star::uno::Reference< ::com::sun::star::awt::XMessageBox > SAL_CALL VCLXToolkit::createMessageBox( 
-    const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindowPeer >& aParent, 
-    const ::com::sun::star::awt::Rectangle& aPosSize, 
-    const ::rtl::OUString& aType, 
-    ::sal_Int32 aButtons, 
-    const ::rtl::OUString& aTitle, 
+::com::sun::star::uno::Reference< ::com::sun::star::awt::XMessageBox > SAL_CALL VCLXToolkit::createMessageBox(
+    const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindowPeer >& aParent,
+    const ::com::sun::star::awt::Rectangle& aPosSize,
+    const ::rtl::OUString& aType,
+    ::sal_Int32 aButtons,
+    const ::rtl::OUString& aTitle,
     const ::rtl::OUString& aMessage ) throw (::com::sun::star::uno::RuntimeException)
 {
     ::com::sun::star::awt::WindowDescriptor aDescriptor;
@@ -1243,7 +1296,7 @@ css::uno::Reference< css::awt::XWindowPeer > VCLXToolkit::ImplCreateWindow(
         nAddWinBits |= WB_ABORT_RETRY_IGNORE;
     if ( sal_Int32( aButtons & 0xffff0000L ) == css::awt::MessageBoxButtons::DEFAULT_BUTTON_IGNORE )
         nAddWinBits |= WB_DEF_IGNORE;
-    
+
     aDescriptor.Type              = css::awt::WindowClass_MODALTOP;
     aDescriptor.WindowServiceName = aType;
     aDescriptor.ParentIndex       = -1;
@@ -1308,14 +1361,14 @@ css::uno::Reference< css::awt::XWindowPeer > VCLXToolkit::ImplCreateWindow(
             {
                 // remember clipboard here
                 mxClipboard = ::com::sun::star::uno::Reference< ::com::sun::star::datatransfer::clipboard::XClipboard > (
-                    xFactory->createInstance( ::rtl::OUString::createFromAscii( "com.sun.star.datatransfer.clipboard.SystemClipboard" ) ), ::com::sun::star::uno::UNO_QUERY );
+                    xFactory->createInstance( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.datatransfer.clipboard.SystemClipboard")) ), ::com::sun::star::uno::UNO_QUERY );
             }
         }
 
         return mxClipboard;
     }
 
-    else if( clipboardName.equals( ::rtl::OUString::createFromAscii("Selection") ) )
+    else if( clipboardName.equals( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Selection")) ) )
     {
         return mxSelection;
     }
@@ -1326,7 +1379,7 @@ css::uno::Reference< css::awt::XWindowPeer > VCLXToolkit::ImplCreateWindow(
 // XServiceInfo
 ::rtl::OUString VCLXToolkit::getImplementationName() throw(::com::sun::star::uno::RuntimeException)
 {
-    return rtl::OUString::createFromAscii( "stardiv.Toolkit.VCLXToolkit" );
+    return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("stardiv.Toolkit.VCLXToolkit"));
 }
 
 sal_Bool VCLXToolkit::supportsService( const ::rtl::OUString& rServiceName ) throw(::com::sun::star::uno::RuntimeException)
@@ -1491,17 +1544,17 @@ void SAL_CALL VCLXToolkit::removeFocusListener(
 }
 
 // virtual
-void SAL_CALL VCLXToolkit::fireFocusGained( 
-    ::com::sun::star::uno::Reference< 
-    ::com::sun::star::uno::XInterface > const &) 
+void SAL_CALL VCLXToolkit::fireFocusGained(
+    ::com::sun::star::uno::Reference<
+    ::com::sun::star::uno::XInterface > const &)
     throw (::com::sun::star::uno::RuntimeException)
 {
 }
-        
-// virtual 
-void SAL_CALL VCLXToolkit::fireFocusLost( 
-    ::com::sun::star::uno::Reference< 
-    ::com::sun::star::uno::XInterface > const &) 
+
+// virtual
+void SAL_CALL VCLXToolkit::fireFocusLost(
+    ::com::sun::star::uno::Reference<
+    ::com::sun::star::uno::XInterface > const &)
     throw (::com::sun::star::uno::RuntimeException)
 {
 }
@@ -1601,11 +1654,11 @@ long VCLXToolkit::callKeyHandlers(::VclSimpleEvent const * pEvent,
 {
     ::css::uno::Sequence< ::css::uno::Reference< ::css::uno::XInterface > >
           aHandlers(m_aKeyHandlers.getElements());
-    
+
     if (aHandlers.hasElements())
     {
         ::Window * pWindow = static_cast< ::VclWindowEvent const * >(pEvent)->GetWindow();
-        
+
         // See implementation in vclxwindow.cxx for mapping between VCL and UNO AWT event
         ::KeyEvent * pKeyEvent = static_cast< ::KeyEvent * >(
             static_cast< ::VclWindowEvent const * >(pEvent)->GetData());
