@@ -58,20 +58,20 @@ class StreamData
 {
 public:
     HFILE   hFile;
-    BOOL    bIsEof;
+    sal_Bool    bIsEof;
 
             StreamData()
             {
                 hFile = 0;
-                bIsEof = TRUE;
+                bIsEof = sal_True;
             }
 };
 
 // -----------------------------------------------------------------------
 
-ULONG GetSvError( APIRET nPMError )
+sal_uIntPtr GetSvError( APIRET nPMError )
 {
-    static struct { APIRET pm; ULONG sv; } errArr[] =
+    static struct { APIRET pm; sal_uIntPtr sv; } errArr[] =
     {
         { ERROR_FILE_NOT_FOUND,         SVSTREAM_FILE_NOT_FOUND },
         { ERROR_PATH_NOT_FOUND,         SVSTREAM_PATH_NOT_FOUND },
@@ -92,7 +92,7 @@ ULONG GetSvError( APIRET nPMError )
         { 0xFFFF, SVSTREAM_GENERALERROR }
     };
 
-    ULONG nRetVal = SVSTREAM_GENERALERROR;    // Standardfehler
+    sal_uIntPtr nRetVal = SVSTREAM_GENERALERROR;    // Standardfehler
     int i=0;
     do
     {
@@ -111,17 +111,13 @@ ULONG GetSvError( APIRET nPMError )
 |*
 |*    SvFileStream::SvFileStream()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 15.06.94
-|*    Letzte Aenderung  OV 15.06.94
-|*
 *************************************************************************/
 
 SvFileStream::SvFileStream( const String& rFileName, StreamMode nOpenMode )
 {
-    bIsOpen             = FALSE;
+    bIsOpen             = sal_False;
     nLockCounter        = 0;
-    bIsWritable         = FALSE;
+    bIsWritable         = sal_False;
     pInstanceData       = new StreamData;
 
     SetBufferSize( 8192 );
@@ -137,17 +133,13 @@ SvFileStream::SvFileStream( const String& rFileName, StreamMode nOpenMode )
 |*
 |*    SvFileStream::SvFileStream()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 22.11.94
-|*    Letzte Aenderung  OV 22.11.94
-|*
 *************************************************************************/
 
 SvFileStream::SvFileStream()
 {
-    bIsOpen             = FALSE;
+    bIsOpen             = sal_False;
     nLockCounter        = 0;
-    bIsWritable         = FALSE;
+    bIsWritable         = sal_False;
     pInstanceData       = new StreamData;
     SetBufferSize( 8192 );
 }
@@ -156,10 +148,6 @@ SvFileStream::SvFileStream()
 |*
 |*    SvFileStream::~SvFileStream()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 14.06.94
-|*    Letzte Aenderung  OV 14.06.94
-|*
 *************************************************************************/
 
 SvFileStream::~SvFileStream()
@@ -173,28 +161,20 @@ SvFileStream::~SvFileStream()
 |*
 |*    SvFileStream::GetFileHandle()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 14.06.94
-|*    Letzte Aenderung  OV 14.06.94
-|*
 *************************************************************************/
 
-ULONG SvFileStream::GetFileHandle() const
+sal_uIntPtr SvFileStream::GetFileHandle() const
 {
-    return (ULONG)pInstanceData->hFile;
+    return (sal_uIntPtr)pInstanceData->hFile;
 }
 
 /*************************************************************************
 |*
 |*    SvFileStream::IsA()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 14.06.94
-|*    Letzte Aenderung  OV 14.06.94
-|*
 *************************************************************************/
 
-USHORT SvFileStream::IsA() const
+sal_uInt16 SvFileStream::IsA() const
 {
     return ID_FILESTREAM;
 }
@@ -204,22 +184,20 @@ USHORT SvFileStream::IsA() const
 |*    SvFileStream::GetData()
 |*
 |*    Beschreibung      STREAM.SDW, Prueft nicht Eof; IsEof danach rufbar
-|*    Ersterstellung    OV 15.06.94
-|*    Letzte Aenderung  OV 15.06.94
 |*
 *************************************************************************/
 
-ULONG SvFileStream::GetData( void* pData, ULONG nSize )
+sal_uIntPtr SvFileStream::GetData( void* pData, sal_uIntPtr nSize )
 {
 #ifdef DBG_UTIL
     ByteString aTraceStr( "SvFileStream::GetData(): " );
     aTraceStr += ByteString::CreateFromInt64(nSize);
     aTraceStr += " Bytes from ";
     aTraceStr += ByteString(aFilename, osl_getThreadTextEncoding());
-    DBG_TRACE( aTraceStr.GetBuffer() );
+    OSL_TRACE( "%s", aTraceStr.GetBuffer() );
 #endif
 
-    ULONG nCount = 0L;
+    sal_uIntPtr nCount = 0L;
     if( IsOpen() )
     {
         APIRET nResult;
@@ -234,23 +212,19 @@ ULONG SvFileStream::GetData( void* pData, ULONG nSize )
 |*
 |*    SvFileStream::PutData()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 15.06.94
-|*    Letzte Aenderung  OV 15.06.94
-|*
 *************************************************************************/
 
-ULONG SvFileStream::PutData( const void* pData, ULONG nSize )
+sal_uIntPtr SvFileStream::PutData( const void* pData, sal_uIntPtr nSize )
 {
 #ifdef DBG_UTIL
     ByteString aTraceStr( "SvFileStrean::PutData: " );
     aTraceStr += ByteString::CreateFromInt64(nSize);
     aTraceStr += " Bytes to ";
     aTraceStr += ByteString(aFilename, osl_getThreadTextEncoding());
-    DBG_TRACE( aTraceStr.GetBuffer() );
+    OSL_TRACE( "%s", aTraceStr.GetBuffer() );
 #endif
 
-    ULONG nCount = 0L;
+    sal_uIntPtr nCount = 0L;
     if( IsOpen() )
     {
         APIRET nResult;
@@ -267,15 +241,11 @@ ULONG SvFileStream::PutData( const void* pData, ULONG nSize )
 |*
 |*    SvFileStream::SeekPos()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 15.06.94
-|*    Letzte Aenderung  OV 15.06.94
-|*
 *************************************************************************/
 
-ULONG SvFileStream::SeekPos( ULONG nPos )
+sal_uIntPtr SvFileStream::SeekPos( sal_uIntPtr nPos )
 {
-    ULONG nNewPos = 0L;
+    sal_uIntPtr nNewPos = 0L;
     if( IsOpen() )
     {
         APIRET nResult;
@@ -299,15 +269,11 @@ ULONG SvFileStream::SeekPos( ULONG nPos )
 |*
 |*    SvFileStream::Tell()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 15.06.94
-|*    Letzte Aenderung  OV 15.06.94
-|*
 *************************************************************************/
 /*
-ULONG SvFileStream::Tell()
+sal_uIntPtr SvFileStream::Tell()
 {
-    ULONG nPos = 0L;
+    sal_uIntPtr nPos = 0L;
 
     if( IsOpen() )
     {
@@ -324,10 +290,6 @@ ULONG SvFileStream::Tell()
 |*
 |*    SvFileStream::FlushData()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 15.06.94
-|*    Letzte Aenderung  OV 15.06.94
-|*
 *************************************************************************/
 
 void SvFileStream::FlushData()
@@ -345,15 +307,11 @@ void SvFileStream::FlushData()
 |*
 |*    SvFileStream::LockRange()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 15.06.94
-|*    Letzte Aenderung  OV 15.06.94
-|*
 *************************************************************************/
 
-sal_Bool SvFileStream::LockRange( ULONG nByteOffset, ULONG nBytes )
+sal_Bool SvFileStream::LockRange( sal_uIntPtr nByteOffset, sal_uIntPtr nBytes )
 {
-    sal_Bool bRetVal = FALSE;
+    sal_Bool bRetVal = sal_False;
     if( IsOpen() )
     {
         APIRET   nResult;
@@ -372,7 +330,7 @@ sal_Bool SvFileStream::LockRange( ULONG nByteOffset, ULONG nBytes )
         if( nResult )
             SetError(::GetSvError(nResult) );
         else
-            bRetVal = TRUE;
+            bRetVal = sal_True;
     }
     return bRetVal;
 }
@@ -381,15 +339,11 @@ sal_Bool SvFileStream::LockRange( ULONG nByteOffset, ULONG nBytes )
 |*
 |*    SvFileStream::UnlockRange()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 15.06.94
-|*    Letzte Aenderung  OV 15.06.94
-|*
 *************************************************************************/
 
-sal_Bool SvFileStream::UnlockRange( ULONG nByteOffset, ULONG nBytes )
+sal_Bool SvFileStream::UnlockRange( sal_uIntPtr nByteOffset, sal_uIntPtr nBytes )
 {
-    sal_Bool bRetVal = FALSE;
+    sal_Bool bRetVal = sal_False;
     if( IsOpen() )
     {
         APIRET   nResult;
@@ -408,7 +362,7 @@ sal_Bool SvFileStream::UnlockRange( ULONG nByteOffset, ULONG nBytes )
         if( nResult )
             SetError(::GetSvError(nResult) );
         else
-            bRetVal = TRUE;
+            bRetVal = sal_True;
     }
     return bRetVal;
 }
@@ -417,27 +371,23 @@ sal_Bool SvFileStream::UnlockRange( ULONG nByteOffset, ULONG nBytes )
 |*
 |*    SvFileStream::LockFile()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 15.06.94
-|*    Letzte Aenderung  OV 15.06.94
-|*
 *************************************************************************/
 
 sal_Bool SvFileStream::LockFile()
 {
-    sal_Bool bRetVal = FALSE;
+    sal_Bool bRetVal = sal_False;
     if( !nLockCounter )
     {
         if( LockRange( 0L, LONG_MAX ) )
         {
             nLockCounter = 1;
-            bRetVal = TRUE;
+            bRetVal = sal_True;
         }
     }
     else
     {
         nLockCounter++;
-        bRetVal = TRUE;
+        bRetVal = sal_True;
     }
     return bRetVal;
 }
@@ -446,15 +396,11 @@ sal_Bool SvFileStream::LockFile()
 |*
 |*    SvFileStream::UnlockFile()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 15.06.94
-|*    Letzte Aenderung  OV 15.06.94
-|*
 *************************************************************************/
 
 sal_Bool SvFileStream::UnlockFile()
 {
-    sal_Bool bRetVal = FALSE;
+    sal_Bool bRetVal = sal_False;
     if( nLockCounter > 0)
     {
         if( nLockCounter == 1)
@@ -462,13 +408,13 @@ sal_Bool SvFileStream::UnlockFile()
             if( UnlockRange( 0L, LONG_MAX ) )
             {
                 nLockCounter = 0;
-                bRetVal = TRUE;
+                bRetVal = sal_True;
             }
         }
         else
         {
             nLockCounter--;
-            bRetVal = TRUE;
+            bRetVal = sal_True;
         }
     }
     return bRetVal;
@@ -478,10 +424,6 @@ sal_Bool SvFileStream::UnlockFile()
 |*
 |*    SvFileStream::Open()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 15.06.94
-|*    Letzte Aenderung  OV 15.06.94
-|*
 *************************************************************************/
 
 void SvFileStream::Open( const String& rFilename, StreamMode nOpenMode )
@@ -495,10 +437,10 @@ void SvFileStream::Open( const String& rFilename, StreamMode nOpenMode )
     Close();
     SvStream::ClearBuffer();
 
-    ULONG   nActionTaken;
-    ULONG   nOpenAction     = 0L;
-    ULONG   nShareBits      = 0L;
-    ULONG   nReadWriteBits  = 0L;
+    sal_uIntPtr   nActionTaken;
+    sal_uIntPtr   nOpenAction     = 0L;
+    sal_uIntPtr   nShareBits      = 0L;
+    sal_uIntPtr   nReadWriteBits  = 0L;
 
     eStreamMode = nOpenMode;
     eStreamMode &= ~STREAM_TRUNC; // beim ReOpen nicht cutten
@@ -556,7 +498,7 @@ void SvFileStream::Open( const String& rFilename, StreamMode nOpenMode )
 #ifdef DBG_UTIL
     ByteString aTraceStr( "SvFileStream::Open(): " );
     aTraceStr +=  aFileNameA;
-    DBG_TRACE( aTraceStr.GetBuffer() );
+    OSL_TRACE( "%s", aTraceStr.GetBuffer() );
 #endif
 
     APIRET nRet = DosOpen( aFileNameA.GetBuffer(), &pInstanceData->hFile,
@@ -566,7 +508,7 @@ void SvFileStream::Open( const String& rFilename, StreamMode nOpenMode )
     if( nRet == ERROR_TOO_MANY_OPEN_FILES )
     {
         long nToAdd = 10;
-        ULONG nCurMaxFH;
+        sal_uIntPtr nCurMaxFH;
         nRet = DosSetRelMaxFH( &nToAdd, &nCurMaxFH );
         nRet = DosOpen( aFileNameA.GetBuffer(), &pInstanceData->hFile,
         &nActionTaken, 0L, FILE_NORMAL, nOpenAction,
@@ -584,15 +526,15 @@ void SvFileStream::Open( const String& rFilename, StreamMode nOpenMode )
 
         if( nRet )
     {
-        bIsOpen = FALSE;
+        bIsOpen = sal_False;
         SetError(::GetSvError(nRet) );
     }
     else
     {
-        bIsOpen     = TRUE;
-        pInstanceData->bIsEof = FALSE;
+        bIsOpen     = sal_True;
+        pInstanceData->bIsEof = sal_False;
         if( nReadWriteBits != OPEN_ACCESS_READONLY )
-            bIsWritable = TRUE;
+            bIsWritable = sal_True;
     }
 }
 
@@ -600,10 +542,6 @@ void SvFileStream::Open( const String& rFilename, StreamMode nOpenMode )
 |*
 |*    SvFileStream::ReOpen()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 15.06.94
-|*    Letzte Aenderung  OV 15.06.94
-|*
 *************************************************************************/
 
 void SvFileStream::ReOpen()
@@ -616,10 +554,6 @@ void SvFileStream::ReOpen()
 |*
 |*    SvFileStream::Close()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 15.06.94
-|*    Letzte Aenderung  OV 15.06.94
-|*
 *************************************************************************/
 
 void SvFileStream::Close()
@@ -629,7 +563,7 @@ void SvFileStream::Close()
 #ifdef DBG_UTIL
         ByteString aTraceStr( "SvFileStream::Close(): " );
         aTraceStr += ByteString(aFilename, osl_getThreadTextEncoding());
-        DBG_TRACE( aTraceStr.GetBuffer() );
+        OSL_TRACE( "%s", aTraceStr.GetBuffer() );
 #endif
 
         if( nLockCounter )
@@ -641,10 +575,10 @@ void SvFileStream::Close()
         DosClose( pInstanceData->hFile );
     }
 
-    bIsOpen     = FALSE;
+    bIsOpen     = sal_False;
     nLockCounter= 0;
-    bIsWritable = FALSE;
-    pInstanceData->bIsEof = TRUE;
+    bIsWritable = sal_False;
+    pInstanceData->bIsEof = sal_True;
     SvStream::ClearBuffer();
     SvStream::ClearError();
 }
@@ -654,8 +588,6 @@ void SvFileStream::Close()
 |*    SvFileStream::ResetError()
 |*
 |*    Beschreibung      STREAM.SDW; Setzt Filepointer auf Dateianfang
-|*    Ersterstellung    OV 15.06.94
-|*    Letzte Aenderung  OV 15.06.94
 |*
 *************************************************************************/
 
@@ -668,13 +600,9 @@ void SvFileStream::ResetError()
 |*
 |*    SvFileStream::SetSize()
 |*
-|*    Beschreibung
-|*    Ersterstellung    OV 19.10.95
-|*    Letzte Aenderung  OV 19.10.95
-|*
 *************************************************************************/
 
-void SvFileStream::SetSize( ULONG nSize )
+void SvFileStream::SetSize( sal_uIntPtr nSize )
 {
     if( IsOpen() )
     {
