@@ -45,7 +45,8 @@ using namespace com::sun::star::ucb;
 using namespace com::sun::star::uno;
 using namespace com::sun::star::util;
 using namespace cppu;
-using namespace rtl;
+
+using ::rtl::OUString;
 
 //--------------------------------------------------------------------------
 //--------------------------------------------------------------------------
@@ -320,13 +321,13 @@ sal_Bool SAL_CALL ContentResultSetWrapper
         }
         aGuard.reacquire();
 
-        rtl::OUString aName = OUString::createFromAscii( "ResultSetType" );
+        OUString aName(RTL_CONSTASCII_USTRINGPARAM("ResultSetType"));
         //find out, if we are ForwardOnly and cache the value:
 
         impl_init_xPropertySetOrigin();
         if( !m_xPropertySetOrigin.is() )
         {
-            OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+            OSL_FAIL( "broadcaster was disposed already" );
             m_nForwardOnly = 0;
             return m_nForwardOnly;
         }
@@ -387,7 +388,7 @@ void SAL_CALL ContentResultSetWrapper
         }
         catch( Exception& )
         {
-            OSL_ENSURE( sal_False, "could not remove PropertyChangeListener" );
+            OSL_FAIL( "could not remove PropertyChangeListener" );
         }
         try
         {
@@ -396,7 +397,7 @@ void SAL_CALL ContentResultSetWrapper
         }
         catch( Exception& )
         {
-            OSL_ENSURE( sal_False, "could not remove VetoableChangeListener" );
+            OSL_FAIL( "could not remove VetoableChangeListener" );
         }
 
         Reference< XComponent > xComponentOrigin( m_xResultSetOrigin, UNO_QUERY );
@@ -544,7 +545,7 @@ void SAL_CALL ContentResultSetWrapper
     impl_init_xPropertySetOrigin();
     if( !m_xPropertySetOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw UnknownPropertyException();
     }
     m_xPropertySetOrigin->setPropertyValue( rPropertyName, rValue );
@@ -562,7 +563,7 @@ Any SAL_CALL ContentResultSetWrapper
     impl_init_xPropertySetOrigin();
     if( !m_xPropertySetOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw UnknownPropertyException();
     }
     return m_xPropertySetOrigin->getPropertyValue( rPropertyName );
@@ -582,7 +583,7 @@ void SAL_CALL ContentResultSetWrapper
 
     if( !getPropertySetInfo().is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw UnknownPropertyException();
     }
 
@@ -603,7 +604,7 @@ void SAL_CALL ContentResultSetWrapper
             osl::Guard< osl::Mutex > aGuard( m_aMutex );
             if( !m_xPropertySetOrigin.is() )
             {
-                OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+                OSL_FAIL( "broadcaster was disposed already" );
                 return;
             }
         }
@@ -634,7 +635,7 @@ void SAL_CALL ContentResultSetWrapper
 
     if( !getPropertySetInfo().is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw UnknownPropertyException();
     }
     if( rPropertyName.getLength() )
@@ -654,7 +655,7 @@ void SAL_CALL ContentResultSetWrapper
             osl::Guard< osl::Mutex > aGuard( m_aMutex );
             if( !m_xPropertySetOrigin.is() )
             {
-                OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+                OSL_FAIL( "broadcaster was disposed already" );
                 return;
             }
         }
@@ -714,7 +715,7 @@ void SAL_CALL ContentResultSetWrapper
             osl::Guard< osl::Mutex > aGuard( m_aMutex );
             if( !m_xPropertySetOrigin.is() )
             {
-                OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+                OSL_FAIL( "broadcaster was disposed already" );
                 return;
             }
         }
@@ -725,7 +726,7 @@ void SAL_CALL ContentResultSetWrapper
         }
         catch( Exception& )
         {
-            OSL_ENSURE( sal_False, "could not remove PropertyChangeListener" );
+            OSL_FAIL( "could not remove PropertyChangeListener" );
         }
     }
 }
@@ -773,7 +774,7 @@ void SAL_CALL ContentResultSetWrapper
             osl::Guard< osl::Mutex > aGuard( m_aMutex );
             if( !m_xPropertySetOrigin.is() )
             {
-                OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+                OSL_FAIL( "broadcaster was disposed already" );
                 return;
             }
         }
@@ -784,7 +785,7 @@ void SAL_CALL ContentResultSetWrapper
         }
         catch( Exception& )
         {
-            OSL_ENSURE( sal_False, "could not remove VetoableChangeListener" );
+            OSL_FAIL( "could not remove VetoableChangeListener" );
         }
     }
 }
@@ -859,7 +860,7 @@ OUString SAL_CALL ContentResultSetWrapper
     impl_init_xContentAccessOrigin();
     if( !m_xContentAccessOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     return m_xContentAccessOrigin->queryContentIdentifierString();
@@ -875,7 +876,7 @@ Reference< XContentIdentifier > SAL_CALL ContentResultSetWrapper
     impl_init_xContentAccessOrigin();
     if( !m_xContentAccessOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     return m_xContentAccessOrigin->queryContentIdentifier();
@@ -891,7 +892,7 @@ Reference< XContent > SAL_CALL ContentResultSetWrapper
     impl_init_xContentAccessOrigin();
     if( !m_xContentAccessOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     return m_xContentAccessOrigin->queryContent();
@@ -911,7 +912,7 @@ sal_Bool SAL_CALL ContentResultSetWrapper
 
     if( !m_xResultSetOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     return m_xResultSetOrigin->next();
@@ -927,7 +928,7 @@ sal_Bool SAL_CALL ContentResultSetWrapper
 
     if( !m_xResultSetOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     return m_xResultSetOrigin->previous();
@@ -943,7 +944,7 @@ sal_Bool SAL_CALL ContentResultSetWrapper
 
     if( !m_xResultSetOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     return m_xResultSetOrigin->absolute( row );
@@ -959,7 +960,7 @@ sal_Bool SAL_CALL ContentResultSetWrapper
 
     if( !m_xResultSetOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     return m_xResultSetOrigin->relative( rows );
@@ -976,7 +977,7 @@ sal_Bool SAL_CALL ContentResultSetWrapper
 
     if( !m_xResultSetOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     return m_xResultSetOrigin->first();
@@ -992,7 +993,7 @@ sal_Bool SAL_CALL ContentResultSetWrapper
 
     if( !m_xResultSetOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     return m_xResultSetOrigin->last();
@@ -1008,7 +1009,7 @@ void SAL_CALL ContentResultSetWrapper
 
     if( !m_xResultSetOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     m_xResultSetOrigin->beforeFirst();
@@ -1024,7 +1025,7 @@ void SAL_CALL ContentResultSetWrapper
 
     if( !m_xResultSetOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     m_xResultSetOrigin->afterLast();
@@ -1040,7 +1041,7 @@ sal_Bool SAL_CALL ContentResultSetWrapper
 
     if( !m_xResultSetOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     return m_xResultSetOrigin->isAfterLast();
@@ -1056,7 +1057,7 @@ sal_Bool SAL_CALL ContentResultSetWrapper
 
     if( !m_xResultSetOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     return m_xResultSetOrigin->isBeforeFirst();
@@ -1072,7 +1073,7 @@ sal_Bool SAL_CALL ContentResultSetWrapper
 
     if( !m_xResultSetOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     return m_xResultSetOrigin->isFirst();
@@ -1088,7 +1089,7 @@ sal_Bool SAL_CALL ContentResultSetWrapper
 
     if( !m_xResultSetOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     return m_xResultSetOrigin->isLast();
@@ -1105,7 +1106,7 @@ sal_Int32 SAL_CALL ContentResultSetWrapper
 
     if( !m_xResultSetOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     return m_xResultSetOrigin->getRow();
@@ -1121,7 +1122,7 @@ void SAL_CALL ContentResultSetWrapper
 
     if( !m_xResultSetOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     m_xResultSetOrigin->refreshRow();
@@ -1137,7 +1138,7 @@ sal_Bool SAL_CALL ContentResultSetWrapper
 
     if( !m_xResultSetOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     return m_xResultSetOrigin->rowUpdated();
@@ -1152,7 +1153,7 @@ sal_Bool SAL_CALL ContentResultSetWrapper
 
     if( !m_xResultSetOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     return m_xResultSetOrigin->rowInserted();
@@ -1168,7 +1169,7 @@ sal_Bool SAL_CALL ContentResultSetWrapper
 
     if( !m_xResultSetOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     return m_xResultSetOrigin->rowDeleted();
@@ -1194,7 +1195,7 @@ impl_EnsureNotDisposed();										\
 impl_init_xRowOrigin();											\
 if( !m_xRowOrigin.is() )										\
 {																\
-    OSL_ENSURE( sal_False, "broadcaster was disposed already" );\
+    OSL_FAIL( "broadcaster was disposed already" );\
     throw RuntimeException();									\
 }																\
 return m_xRowOrigin->getXXX( columnIndex );
@@ -1209,14 +1210,14 @@ sal_Bool SAL_CALL ContentResultSetWrapper
     impl_init_xRowOrigin();
     if( !m_xRowOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     return m_xRowOrigin->wasNull();
 }
 
 //virtual
-rtl::OUString SAL_CALL ContentResultSetWrapper
+OUString SAL_CALL ContentResultSetWrapper
     ::getString( sal_Int32 columnIndex )
     throw( SQLException,
            RuntimeException )
@@ -1358,7 +1359,7 @@ Any SAL_CALL ContentResultSetWrapper
     impl_init_xRowOrigin();
     if( !m_xRowOrigin.is() )
     {
-        OSL_ENSURE( sal_False, "broadcaster was disposed already" );
+        OSL_FAIL( "broadcaster was disposed already" );
         throw RuntimeException();
     }
     return m_xRowOrigin->getObject( columnIndex, typeMap );
