@@ -445,7 +445,7 @@ uno::Sequence< beans::Property > Content::getProperties(
             {
                 bHasCreatableInfos = sal_True;
             }
-            it++;
+            ++it;
         }
     }
 
