@@ -79,9 +79,9 @@ namespace utl
             if ( bValid )
             {
                 Date aDate;
-                aDate.SetDay	( (USHORT)_rStringRep.copy( 0, 2 ).toInt32( ) );
-                aDate.SetMonth	( (USHORT)_rStringRep.copy( 3, 2 ).toInt32( ) );
-                aDate.SetYear	( (USHORT)_rStringRep.copy( 6, 4 ).toInt32( ) );
+                aDate.SetDay	( (sal_uInt16)_rStringRep.copy( 0, 2 ).toInt32( ) );
+                aDate.SetMonth	( (sal_uInt16)_rStringRep.copy( 3, 2 ).toInt32( ) );
+                aDate.SetYear	( (sal_uInt16)_rStringRep.copy( 6, 4 ).toInt32( ) );
                 nDateIntRep = aDate.GetDate();
             }
         }
@@ -139,7 +139,7 @@ namespace utl
     #define DECLARE_STATIC_LAZY_USTRING( name )	\
     static const ::rtl::OUString& lcl_get##name##Name()	\
     {	\
-        static const ::rtl::OUString sName = ::rtl::OUString::createFromAscii( #name );	\
+        static const ::rtl::OUString sName(RTL_CONSTASCII_USTRINGPARAM( #name )); \
         return sName;	\
     }
 
@@ -259,13 +259,13 @@ namespace utl
         // create the config node for all our registration information
         m_aRegistrationNode = OConfigurationTreeRoot::createWithServiceFactory(
             ::comphelper::getProcessServiceFactory(),
-            ::rtl::OUString::createFromAscii( "/org.openoffice.Office.Common/Help/Registration" )
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/org.openoffice.Office.Common/Help/Registration"))
         );
 
         // cache some data
         //the URL to use for online registration
         ::rtl::OUString sStringValue;
-        m_aRegistrationNode.getNodeValue( ::rtl::OUString::createFromAscii( "URL" ) ) >>= sStringValue;
+        m_aRegistrationNode.getNodeValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("URL")) ) >>= sStringValue;
         m_sRegistrationURL = sStringValue;
 
         // the state of the dialog
