@@ -45,7 +45,7 @@ ScVbaLineFormat::ScVbaLineFormat( const uno::Reference< ov::XHelperInterface >&
 }
 
 sal_Int32
-ScVbaLineFormat::calculateArrowheadSize()
+ScVbaLineFormat::calculateArrowheadSize() const
 {
     return 0;
 }
@@ -54,39 +54,39 @@ sal_Int32
 ScVbaLineFormat::convertLineStartEndNameToArrowheadStyle( rtl::OUString sLineName )
 {
     sal_Int32 nLineType = office::MsoArrowheadStyle::msoArrowheadNone;
-    if (sLineName.equals(rtl::OUString::createFromAscii("Small Arrow")) ||
-        sLineName.equals(rtl::OUString::createFromAscii("Arrow")) ||
-        sLineName.equals(rtl::OUString::createFromAscii("msArrowEnd")) ||
-        sLineName.equals(rtl::OUString::createFromAscii("Double Arrow")))
+    if (sLineName.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Small Arrow"))) ||
+        sLineName.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Arrow"))) ||
+        sLineName.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("msArrowEnd"))) ||
+        sLineName.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Double Arrow"))))
     {
         // msoArrowheadTriangle
         nLineType = office::MsoArrowheadStyle::msoArrowheadTriangle;
     }
-    else if (sLineName.equals(rtl::OUString::createFromAscii("Square 45")) ||
-             sLineName.equals(rtl::OUString::createFromAscii("Square")) ||
-             sLineName.equals(rtl::OUString::createFromAscii("msArrowDiamondEnd")))
+    else if (sLineName.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Square 45"))) ||
+             sLineName.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Square"))) ||
+             sLineName.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("msArrowDiamondEnd"))))
     {
         // msoArrowheadDiamond
         nLineType = office::MsoArrowheadStyle::msoArrowheadDiamond;
     }
-    else if (sLineName.equals(rtl::OUString::createFromAscii("Circle")) ||
-             sLineName.equals(rtl::OUString::createFromAscii("msArrowOvalEnd")) ||
-             sLineName.equals(rtl::OUString::createFromAscii("Dimension Lines")) )
+    else if (sLineName.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Circle"))) ||
+             sLineName.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("msArrowOvalEnd"))) ||
+             sLineName.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Dimension Lines"))) )
     {
         // msoArrowheadOval
         nLineType = office::MsoArrowheadStyle::msoArrowheadOval;
     }
-    else if (sLineName.equals(rtl::OUString::createFromAscii("Arrow concave")) ||
-             sLineName.equals(rtl::OUString::createFromAscii("msArrowStealthEnd")))
+    else if (sLineName.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Arrow concave"))) ||
+             sLineName.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("msArrowStealthEnd"))))
     {
         // msoArrowheadStealth
         nLineType = office::MsoArrowheadStyle::msoArrowheadStealth;
     }
-    else if (sLineName.equals(rtl::OUString::createFromAscii("Rounded short Arrow")) ||
-             sLineName.equals(rtl::OUString::createFromAscii("Rounded large Arrow")) ||
-             sLineName.equals(rtl::OUString::createFromAscii("Symmetric Arrow")) ||
-             sLineName.equals(rtl::OUString::createFromAscii("msArrowOpenEnd")) ||
-             sLineName.equals(rtl::OUString::createFromAscii("Line Arrow")))
+    else if (sLineName.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Rounded short Arrow"))) ||
+             sLineName.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Rounded large Arrow"))) ||
+             sLineName.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Symmetric Arrow"))) ||
+             sLineName.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("msArrowOpenEnd"))) ||
+             sLineName.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Line Arrow"))))
     {
         // msoArrowheadOpen
         nLineType = office::MsoArrowheadStyle::msoArrowheadOpen;
@@ -105,19 +105,19 @@ ScVbaLineFormat::convertArrowheadStyleToLineStartEndName( sal_Int32 nArrowheadSt
     switch( nArrowheadStyle )
     {
         case office::MsoArrowheadStyle::msoArrowheadNone:
-            return rtl::OUString(rtl::OUString::createFromAscii( "" ) );
+            return rtl::OUString();
         case office::MsoArrowheadStyle::msoArrowheadStealth:
-            return rtl::OUString::createFromAscii( "Arrow concave" );
+            return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Arrow concave"));
         case office::MsoArrowheadStyle::msoArrowheadOpen:
-            return rtl::OUString::createFromAscii("Line Arrow" );
+            return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Line Arrow"));
         case office::MsoArrowheadStyle::msoArrowheadOval:
-            return  rtl::OUString::createFromAscii("Circle" );
+            return  rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Circle"));
         case office::MsoArrowheadStyle::msoArrowheadDiamond:
-            return rtl::OUString::createFromAscii( "Square 45" );
+            return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Square 45"));
         case office::MsoArrowheadStyle::msoArrowheadTriangle:
-            return rtl::OUString::createFromAscii( "Arrow" );
+            return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Arrow"));
         default:
-            throw uno::RuntimeException( rtl::OUString::createFromAscii("Invalid Arrow Style!"), uno::Reference< uno::XInterface >() );
+            throw uno::RuntimeException( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Invalid Arrow Style!")), uno::Reference< uno::XInterface >() );
     }
 }
 
@@ -127,10 +127,10 @@ ScVbaLineFormat::getBeginArrowheadStyle() throw (uno::RuntimeException)
 {
     sal_Int32 nLineType = office::MsoArrowheadStyle::msoArrowheadNone;
     rtl::OUString sLineName;
-    m_xPropertySet->getPropertyValue( rtl::OUString::createFromAscii( "LineStartName" ) ) >>= sLineName;
-    if( ( sLineName.getLength() > 7 ) && ( sLineName.indexOf( rtl::OUString::createFromAscii( "msArray" ) ) ) != -1 )
+    m_xPropertySet->getPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("LineStartName")) ) >>= sLineName;
+    if( ( sLineName.getLength() > 7 ) && ( sLineName.indexOf( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("msArray")) ) ) != -1 )
     {
-        sal_Int32 nIndex = sLineName.indexOf( rtl::OUString::createFromAscii(" ") );
+        sal_Int32 nIndex = sLineName.indexOf( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(" ")) );
         rtl::OUString sName = sLineName.copy( 0, nIndex );
         //sal_Int32 nSize = sLineName.copy( nIndex + 1 ).toInt32();
         nLineType = convertLineStartEndNameToArrowheadStyle( sName );
@@ -146,31 +146,31 @@ void SAL_CALL
 ScVbaLineFormat::setBeginArrowheadStyle( sal_Int32 _beginarrowheadstyle ) throw (uno::RuntimeException)
 {
     rtl::OUString sArrayName = convertArrowheadStyleToLineStartEndName( _beginarrowheadstyle );
-    m_xPropertySet->setPropertyValue( rtl::OUString::createFromAscii( "LineStartName" ), uno::makeAny( sArrayName ) );
+    m_xPropertySet->setPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("LineStartName")), uno::makeAny( sArrayName ) );
 }
 
 sal_Int32 SAL_CALL 
 ScVbaLineFormat::getBeginArrowheadLength() throw (uno::RuntimeException)
 {
-    throw uno::RuntimeException( rtl::OUString::createFromAscii("Property 'EndArrowheadWidth' is not supported."), uno::Reference< uno::XInterface >() );
+    throw uno::RuntimeException( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Property 'EndArrowheadWidth' is not supported.")), uno::Reference< uno::XInterface >() );
 }
 
 void SAL_CALL 
 ScVbaLineFormat::setBeginArrowheadLength( sal_Int32 /*_beginarrowheadlength*/ ) throw (uno::RuntimeException)
 {
-    throw uno::RuntimeException( rtl::OUString::createFromAscii("Property 'EndArrowheadWidth' is not supported."), uno::Reference< uno::XInterface >() );
+    throw uno::RuntimeException( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Property 'EndArrowheadWidth' is not supported.")), uno::Reference< uno::XInterface >() );
 }
 
 sal_Int32 SAL_CALL 
 ScVbaLineFormat::getBeginArrowheadWidth() throw (uno::RuntimeException)
 {
-    throw uno::RuntimeException( rtl::OUString::createFromAscii("Property 'EndArrowheadWidth' is not supported."), uno::Reference< uno::XInterface >() );
+    throw uno::RuntimeException( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Property 'EndArrowheadWidth' is not supported.")), uno::Reference< uno::XInterface >() );
 }
 
 void SAL_CALL 
 ScVbaLineFormat::setBeginArrowheadWidth( sal_Int32 /*_beginarrowheadwidth*/ ) throw (uno::RuntimeException)
 {
-    throw uno::RuntimeException( rtl::OUString::createFromAscii("Property 'EndArrowheadWidth' is not supported."), uno::Reference< uno::XInterface >() );
+    throw uno::RuntimeException( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Property 'EndArrowheadWidth' is not supported.")), uno::Reference< uno::XInterface >() );
 }
 
 sal_Int32 SAL_CALL 
@@ -187,32 +187,32 @@ ScVbaLineFormat::setEndArrowheadStylel( sal_Int32 /*_endarrowheadstylel*/ ) thro
 sal_Int32 SAL_CALL 
 ScVbaLineFormat::getEndArrowheadLength() throw (uno::RuntimeException)
 {
-    throw uno::RuntimeException( rtl::OUString::createFromAscii("Property 'EndArrowheadWidth' is not supported."), uno::Reference< uno::XInterface >() );
+    throw uno::RuntimeException( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Property 'EndArrowheadWidth' is not supported.")), uno::Reference< uno::XInterface >() );
 }
 
 void SAL_CALL 
 ScVbaLineFormat::setEndArrowheadLength( sal_Int32 /*_endarrowheadlength*/ ) throw (uno::RuntimeException)
 {
-    throw uno::RuntimeException( rtl::OUString::createFromAscii("Property 'EndArrowheadWidth' is not supported."), uno::Reference< uno::XInterface >() );
+    throw uno::RuntimeException( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Property 'EndArrowheadWidth' is not supported.")), uno::Reference< uno::XInterface >() );
 }
 
 sal_Int32 SAL_CALL 
 ScVbaLineFormat::getEndArrowheadWidth() throw (uno::RuntimeException)
 {
-    throw uno::RuntimeException( rtl::OUString::createFromAscii("Property 'EndArrowheadWidth' is not supported."), uno::Reference< uno::XInterface >() );
+    throw uno::RuntimeException( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Property 'EndArrowheadWidth' is not supported.")), uno::Reference< uno::XInterface >() );
 }
 
 void SAL_CALL 
 ScVbaLineFormat::setEndArrowheadWidth( sal_Int32 /*_endarrowheadwidth*/ ) throw (uno::RuntimeException)
 {
-    throw uno::RuntimeException( rtl::OUString::createFromAscii("Property 'EndArrowheadWidth' is not supported."), uno::Reference< uno::XInterface >() );
+    throw uno::RuntimeException( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Property 'EndArrowheadWidth' is not supported.")), uno::Reference< uno::XInterface >() );
 }
 
 double SAL_CALL 
 ScVbaLineFormat::getWeight() throw (uno::RuntimeException)
 {
     sal_Int32 nLineWidth=0;
-    m_xPropertySet->getPropertyValue( rtl::OUString::createFromAscii( "LineWidth") ) >>= nLineWidth;
+    m_xPropertySet->getPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("LineWidth")) ) >>= nLineWidth;
     double dLineWidth = Millimeter::getInPoints( nLineWidth );
     return dLineWidth;
 }
@@ -221,7 +221,7 @@ void SAL_CALL
 ScVbaLineFormat::setWeight( double _weight ) throw (uno::RuntimeException)
 {
     if( _weight < 0 )
-        throw uno::RuntimeException( rtl::OUString::createFromAscii("Parameter: Must be positv."), uno::Reference< uno::XInterface >() );
+        throw uno::RuntimeException( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Parameter: Must be positive.")), uno::Reference< uno::XInterface >() );
     if( _weight == 0 )
         _weight = 0.5;
     m_nLineWeight = _weight;
@@ -229,7 +229,7 @@ ScVbaLineFormat::setWeight( double _weight ) throw (uno::RuntimeException)
     aMillimeter.setInPoints( _weight );
         
     sal_Int32 nLineWidth = static_cast<sal_Int32>( aMillimeter.getInHundredthsOfOneMillimeter() );
-    m_xPropertySet->setPropertyValue( rtl::OUString::createFromAscii( "LineWidth" ), uno::makeAny( nLineWidth ) );
+    m_xPropertySet->setPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("LineWidth")), uno::makeAny( nLineWidth ) );
     setDashStyle( m_nLineDashStyle );
 }
 
@@ -237,7 +237,7 @@ sal_Bool SAL_CALL
 ScVbaLineFormat::getVisible() throw (uno::RuntimeException)
 {
     drawing::LineStyle aLineStyle;
-    m_xPropertySet->getPropertyValue( rtl::OUString::createFromAscii( "LineStyle" ) ) >>= aLineStyle;
+    m_xPropertySet->getPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("LineStyle")) ) >>= aLineStyle;
     if( aLineStyle == drawing::LineStyle_NONE )
     {
         return sal_False;
@@ -249,11 +249,11 @@ void SAL_CALL
 ScVbaLineFormat::setVisible( sal_Bool _visible ) throw (uno::RuntimeException)
 {
     drawing::LineStyle aLineStyle;
-    m_xPropertySet->getPropertyValue( rtl::OUString::createFromAscii( "LineStyle" ) ) >>= aLineStyle;
+    m_xPropertySet->getPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("LineStyle")) ) >>= aLineStyle;
     if( !_visible )
     {
         aLineStyle = drawing::LineStyle_NONE;
-        m_xPropertySet->setPropertyValue( rtl::OUString::createFromAscii( "LineStyle" ), uno::makeAny( aLineStyle ) );
+        m_xPropertySet->setPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("LineStyle")), uno::makeAny( aLineStyle ) );
     }
     else
     {
@@ -268,7 +268,7 @@ double SAL_CALL
 ScVbaLineFormat::getTransparency() throw (uno::RuntimeException)
 {
     sal_Int16 nTransparency = 0;
-    m_xPropertySet->getPropertyValue( rtl::OUString::createFromAscii( "LineTransparence" ) ) >>= nTransparency;
+    m_xPropertySet->getPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("LineTransparence")) ) >>= nTransparency;
     double fTransparency = static_cast<double>( nTransparency );
     return fTransparency / 100;
 }
@@ -277,7 +277,7 @@ void SAL_CALL
 ScVbaLineFormat::setTransparency( double _transparency ) throw (uno::RuntimeException)
 {
     sal_Int16 nTransparency = static_cast<sal_Int16>( _transparency * 100 );
-    m_xPropertySet->setPropertyValue( rtl::OUString::createFromAscii( "LineTransparence" ), uno::makeAny( nTransparency ) );
+    m_xPropertySet->setPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("LineTransparence")), uno::makeAny( nTransparency ) );
 }
 
 sal_Int16 SAL_CALL 
@@ -302,13 +302,13 @@ ScVbaLineFormat::getDashStyle() throw (uno::RuntimeException)
 {
     drawing::LineStyle eLineStyle;
     //LineStyle integer in Xray
-    m_xPropertySet->getPropertyValue( rtl::OUString::createFromAscii( "LineStyle" ) ) >>= eLineStyle;
+    m_xPropertySet->getPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("LineStyle")) ) >>= eLineStyle;
     if( eLineStyle == drawing::LineStyle_SOLID )
         m_nLineDashStyle = office::MsoLineDashStyle::msoLineSolid;
     else
     {
         drawing::LineDash aLineDash;
-        m_xPropertySet->getPropertyValue( rtl::OUString::createFromAscii( "LineDash" ) ) >>= aLineDash;
+        m_xPropertySet->getPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("LineDash")) ) >>= aLineDash;
         if( aLineDash.Dots == 0 )
         {
             //LineDash
@@ -354,11 +354,11 @@ ScVbaLineFormat::setDashStyle( sal_Int32 _dashstyle ) throw (uno::RuntimeExcepti
     m_nLineDashStyle = _dashstyle;
     if( _dashstyle == office::MsoLineDashStyle::msoLineSolid )
     {
-        m_xPropertySet->setPropertyValue( rtl::OUString::createFromAscii( "LineStyle" ), uno::makeAny( drawing::LineStyle_SOLID  ));
+        m_xPropertySet->setPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("LineStyle")), uno::makeAny( drawing::LineStyle_SOLID  ));
     }
     else
     {
-        m_xPropertySet->setPropertyValue( rtl::OUString::createFromAscii( "LineStyle" ), uno::makeAny( drawing::LineStyle_DASH ) );
+        m_xPropertySet->setPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("LineStyle")), uno::makeAny( drawing::LineStyle_DASH ) );
         drawing::LineDash  pLineDash;
         Millimeter aMillimeter( m_nLineWeight );
         sal_Int32 nPixel = static_cast< sal_Int32 >( aMillimeter.getInHundredthsOfOneMillimeter() );
@@ -414,9 +414,9 @@ ScVbaLineFormat::setDashStyle( sal_Int32 _dashstyle ) throw (uno::RuntimeExcepti
             pLineDash.Distance = nPixel;
             break;
         default:
-            throw uno::RuntimeException( rtl::OUString::createFromAscii("this MsoLineDashStyle is not supported."), uno::Reference< uno::XInterface >() );
+            throw uno::RuntimeException( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("this MsoLineDashStyle is not supported.")), uno::Reference< uno::XInterface >() );
         }
-        m_xPropertySet->setPropertyValue( rtl::OUString::createFromAscii( "LineDash" ), uno::makeAny( pLineDash ) );
+        m_xPropertySet->setPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("LineDash")), uno::makeAny( pLineDash ) );
     }
 }
 
