@@ -49,8 +49,9 @@
 #include <Carbon/Carbon.h>
 #include <postmac.h>
 
+#include <salframe.h>
+#include <salframeview.h>
 
-using namespace rtl;
 using namespace cppu;
 using namespace osl;
 using namespace com::sun::star::datatransfer;
@@ -59,8 +60,11 @@ using namespace com::sun::star::datatransfer::dnd::DNDConstants;
 using namespace com::sun::star::datatransfer::clipboard;
 using namespace com::sun::star::lang;
 using namespace com::sun::star::uno;
+using namespace com::sun::star;
 using namespace comphelper;
 
+using ::rtl::OUString;
+
 OUString dropTarget_getImplementationName()
 {
   return OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.datatransfer.dnd.OleDropTarget_V1"));
@@ -125,13 +129,13 @@ namespace /* private */
 }
 
 
--(MacOSBOOL)prepareForDragOperation:(id <NSDraggingInfo>)sender
+-(BOOL)prepareForDragOperation:(id <NSDraggingInfo>)sender
 {
   return mDropTarget->prepareForDragOperation(sender);
 }
 
 
--(MacOSBOOL)performDragOperation:(id <NSDraggingInfo>)sender
+-(BOOL)performDragOperation:(id <NSDraggingInfo>)sender
 {
   return mDropTarget->performDragOperation(sender);
 }
@@ -148,6 +152,8 @@ namespace /* private */
 
 DropTarget::DropTarget() :
   WeakComponentImplHelper5<XInitialization, XDropTarget, XDropTargetDragContext, XDropTargetDropContext, XServiceInfo>(m_aMutex),
+  mView(nil),
+  mpFrame(NULL),
   mDropTargetHelper(nil),
   mbActive(false),
   mDragSourceSupportedActions(DNDConstants::ACTION_NONE),
@@ -160,8 +166,9 @@ DropTarget::DropTarget() :
 
 DropTarget::~DropTarget()
 {
-  [(id <DraggingDestinationHandler>)mView unregisterDraggingDestinationHandler:mDropTargetHelper];
-  [mDropTargetHelper release];
+    if( AquaSalFrame::isAlive( mpFrame ) )
+        [(id <DraggingDestinationHandler>)mView unregisterDraggingDestinationHandler:mDropTargetHelper];
+    [mDropTargetHelper release];
 }
 
 
@@ -242,7 +249,7 @@ NSDragOperation DropTarget::draggingEntered(id sender)
       NSPasteboard* dragPboard = [sender draggingPasteboard];
       mXCurrentDragClipboard = new AquaClipboard(dragPboard, false);
       
-      Reference<XTransferable> xTransferable = DragSource::g_XTransferable.is() ?
+      uno::Reference<XTransferable> xTransferable = DragSource::g_XTransferable.is() ?
         DragSource::g_XTransferable : mXCurrentDragClipboard->getContents();
 
       DropTargetDragEnterEvent dtdee(static_cast<OWeakObject*>(this), 
@@ -320,19 +327,19 @@ NSDragOperation DropTarget::draggingUpdated(id sender)
   }
 
 
-  MacOSBOOL DropTarget::prepareForDragOperation(id sender)
+  BOOL DropTarget::prepareForDragOperation(id sender)
   {
     return 1;
   }
 
 
-MacOSBOOL DropTarget::performDragOperation(id sender)
+BOOL DropTarget::performDragOperation(id sender)
 {
   bool bSuccess = false;
 
   if (mSelectedDropAction != DNDConstants::ACTION_NONE)
     {
-      Reference<XTransferable> xTransferable = DragSource::g_XTransferable;
+        uno::Reference<XTransferable> xTransferable = DragSource::g_XTransferable;
 
       if (!DragSource::g_XTransferable.is())			
         {
@@ -369,7 +376,7 @@ MacOSBOOL DropTarget::performDragOperation(id sender)
   {
     mDragSourceSupportedActions = DNDConstants::ACTION_NONE;
     mSelectedDropAction = DNDConstants::ACTION_NONE;
-    mXCurrentDragClipboard = Reference<XClipboard>();
+    mXCurrentDragClipboard = uno::Reference<XClipboard>();
     SetThemeCursor(kThemeArrowCursor);
   }
 
@@ -395,6 +402,7 @@ MacOSBOOL DropTarget::performDragOperation(id sender)
     sal_uInt64 tmp = 0;
     pNSView >>= tmp;
     mView = (id)tmp;
+    mpFrame = [(SalFrameView*)mView getSalFrame];
 
     mDropTargetHelper = [[DropTargetHelper alloc] initWithDropTarget: this];
     
@@ -414,14 +422,14 @@ MacOSBOOL DropTarget::performDragOperation(id sender)
   }
 
 
-  void SAL_CALL DropTarget::addDropTargetListener(const Reference<XDropTargetListener>& dtl)
+  void SAL_CALL DropTarget::addDropTargetListener(const uno::Reference<XDropTargetListener>& dtl)
     throw(RuntimeException)
   {
     rBHelper.addListener(::getCppuType(&dtl), dtl);
   }
 
 
-  void SAL_CALL DropTarget::removeDropTargetListener(const Reference<XDropTargetListener>& dtl)
+  void SAL_CALL DropTarget::removeDropTargetListener(const uno::Reference<XDropTargetListener>& dtl)
     throw(RuntimeException)
   {
     rBHelper.removeListener(::getCppuType(&dtl), dtl);
@@ -485,7 +493,7 @@ MacOSBOOL DropTarget::performDragOperation(id sender)
   {
     // Reset the internal transferable used as shortcut in case this is 
     // an internal D&D operation
-    DragSource::g_XTransferable = Reference<XTransferable>();
+    DragSource::g_XTransferable = uno::Reference<XTransferable>();
     DragSource::g_DropSuccessSet = true;
     DragSource::g_DropSuccess = success;
   }
@@ -493,13 +501,13 @@ MacOSBOOL DropTarget::performDragOperation(id sender)
 
   void DropTarget::fire_drop( const DropTargetDropEvent& dte)
   {
-    OInterfaceContainerHelper* pContainer= rBHelper.getContainer( getCppuType( (Reference<XDropTargetListener>* )0 ) );
+      OInterfaceContainerHelper* pContainer= rBHelper.getContainer( getCppuType( (uno::Reference<XDropTargetListener>* )0 ) );
     if( pContainer)
       {
         OInterfaceIteratorHelper iter( *pContainer);
         while( iter.hasMoreElements())
           {
-            Reference<XDropTargetListener> listener( static_cast<XDropTargetListener*>( iter.next()));
+              uno::Reference<XDropTargetListener> listener( static_cast<XDropTargetListener*>( iter.next()));
 
             try { listener->drop( dte); }
             catch(RuntimeException&) {}
@@ -510,13 +518,13 @@ MacOSBOOL DropTarget::performDragOperation(id sender)
 
   void DropTarget::fire_dragEnter(const DropTargetDragEnterEvent& e)
   {
-    OInterfaceContainerHelper* pContainer= rBHelper.getContainer( getCppuType( (Reference<XDropTargetListener>* )0 ) );
+      OInterfaceContainerHelper* pContainer= rBHelper.getContainer( getCppuType( (uno::Reference<XDropTargetListener>* )0 ) );
     if( pContainer)
       {
         OInterfaceIteratorHelper iter( *pContainer);
         while( iter.hasMoreElements())
           {
-            Reference<XDropTargetListener> listener( static_cast<XDropTargetListener*>( iter.next()));
+              uno::Reference<XDropTargetListener> listener( static_cast<XDropTargetListener*>( iter.next()));
 
             try { listener->dragEnter( e); }
             catch (RuntimeException&) {}
@@ -527,14 +535,14 @@ MacOSBOOL DropTarget::performDragOperation(id sender)
 
   void DropTarget::fire_dragExit(const DropTargetEvent& dte)
   {
-    OInterfaceContainerHelper* pContainer= rBHelper.getContainer( getCppuType( (Reference<XDropTargetListener>* )0 ) );
+      OInterfaceContainerHelper* pContainer= rBHelper.getContainer( getCppuType( (uno::Reference<XDropTargetListener>* )0 ) );
 
     if( pContainer)
       {
         OInterfaceIteratorHelper iter( *pContainer);
         while( iter.hasMoreElements())
           {
-            Reference<XDropTargetListener> listener( static_cast<XDropTargetListener*>( iter.next()));
+              uno::Reference<XDropTargetListener> listener( static_cast<XDropTargetListener*>( iter.next()));
             
             try { listener->dragExit( dte); }
             catch (RuntimeException&) {}
@@ -545,13 +553,13 @@ MacOSBOOL DropTarget::performDragOperation(id sender)
 
   void DropTarget::fire_dragOver(const DropTargetDragEvent& dtde)
   {
-    OInterfaceContainerHelper* pContainer= rBHelper.getContainer( getCppuType( (Reference<XDropTargetListener>* )0 ) );
+      OInterfaceContainerHelper* pContainer= rBHelper.getContainer( getCppuType( (uno::Reference<XDropTargetListener>* )0 ) );
     if( pContainer)
       {
         OInterfaceIteratorHelper iter( *pContainer );
         while( iter.hasMoreElements())
           {
-            Reference<XDropTargetListener> listener( static_cast<XDropTargetListener*>( iter.next()));
+              uno::Reference<XDropTargetListener> listener( static_cast<XDropTargetListener*>( iter.next()));
 
             try { listener->dragOver( dtde); }
             catch (RuntimeException&) {}
@@ -562,13 +570,13 @@ MacOSBOOL DropTarget::performDragOperation(id sender)
 
   void DropTarget::fire_dropActionChanged(const DropTargetDragEvent& dtde)
   {
-    OInterfaceContainerHelper* pContainer= rBHelper.getContainer( getCppuType( (Reference<XDropTargetListener>* )0 ) );
+      OInterfaceContainerHelper* pContainer= rBHelper.getContainer( getCppuType( (uno::Reference<XDropTargetListener>* )0 ) );
     if( pContainer)
       {
         OInterfaceIteratorHelper iter( *pContainer);
         while( iter.hasMoreElements())
           {
-            Reference<XDropTargetListener> listener( static_cast<XDropTargetListener*>( iter.next()));
+              uno::Reference<XDropTargetListener> listener( static_cast<XDropTargetListener*>( iter.next()));
 
             try { listener->dropActionChanged( dtde); }
             catch (RuntimeException&) {}
