@@ -50,8 +50,8 @@
 #include "com/sun/star/awt/Size.hpp"
 #include "comphelper/processfactory.hxx"
 
-#include <hash_map>
-#include <hash_set>
+#include <boost/unordered_map.hpp>
+#include <boost/unordered_set.hpp>
 
 using namespace com::sun::star;
 using namespace com::sun::star::uno;
@@ -76,13 +76,8 @@ class ImplPageCache
     {
         if( maCacheRanking[0] != nLastHit )
         {
-            bool bMove = false;
             for( sal_Int32 i = nCacheSize-1; i > 0; i-- )
-            {
-                if( maCacheRanking[i] == nLastHit )
-                    bMove = true;
                 maCacheRanking[i] = maCacheRanking[i-1];
-            }
             maCacheRanking[0] = nLastHit;
         }
     }
@@ -149,8 +144,9 @@ public:
         ControlDependency() : mnDependsOnEntry( -1 ) {}
     };
     
-    typedef std::hash_map< rtl::OUString, size_t, rtl::OUStringHash > PropertyToIndexMap;
-    typedef std::hash_map< rtl::OUString, ControlDependency, rtl::OUStringHash > ControlDependencyMap;
+    typedef boost::unordered_map< rtl::OUString, size_t, rtl::OUStringHash > PropertyToIndexMap;
+    typedef boost::unordered_map< rtl::OUString, ControlDependency, rtl::OUStringHash > ControlDependencyMap;
+    typedef boost::unordered_map< rtl::OUString, Sequence< sal_Bool >, rtl::OUStringHash > ChoiceDisableMap;
     
     boost::shared_ptr<Printer>                                  mpPrinter;
     Sequence< PropertyValue >                                   maUIOptions;
@@ -159,6 +155,7 @@ public:
     PropertyToIndexMap                                          maPropertyToIndex;
     Link                                                        maOptionChangeHdl;
     ControlDependencyMap                                        maControlDependencies;
+    ChoiceDisableMap                                            maChoiceDisableMap;
     sal_Bool                                                    mbFirstPage;
     sal_Bool                                                    mbLastPage;
     sal_Bool                                                    mbReversePageOrder;
@@ -187,17 +184,17 @@ public:
     {}
     ~ImplPrinterControllerData() { delete mpProgress; }
     
-    Size getRealPaperSize( const Size& i_rPageSize ) const
+    Size getRealPaperSize( const Size& i_rPageSize, bool bNoNUP ) const
     {
         if( maFixedPageSize.Width() > 0 && maFixedPageSize.Height() > 0 )
             return maFixedPageSize;
-        if( maMultiPage.nRows * maMultiPage.nColumns > 1 )
+        if( maMultiPage.nRows * maMultiPage.nColumns > 1 && ! bNoNUP )
             return maMultiPage.aPaperSize;
         return i_rPageSize;
     }
     bool isFixedPageSize() const
     { return maFixedPageSize.Width() != 0 && maFixedPageSize.Height() != 0; }
-    PrinterController::PageSize modifyJobSetup( const Sequence< PropertyValue >& i_rProps );
+    PrinterController::PageSize modifyJobSetup( const Sequence< PropertyValue >& i_rProps, bool bNoNUP );
 };
 
 PrinterController::PrinterController()
@@ -332,26 +329,13 @@ void Printer::ImplPrintJob( const boost::shared_ptr<PrinterController>& i_pContr
     
     // setup printer
 
-    // if no specific printer is already set, create one
-    
-    // #i108686#
-    // in case of a UI (platform independent or system dialog) print job, make the printer persistent over jobs
-    // however if no printer was already set by the print job's originator,
-    // and this is an API job, then use the system default location (because
-    // this is the only sensible default available if the user has no means of changing
-    // the destination
+    // #i114306# changed behavior back from persistence
+    // if no specific printer is already set, create the default printer
     if( ! pController->getPrinter() )
     {
         rtl::OUString aPrinterName( i_rInitSetup.GetPrinterName() );
-        if( ! aPrinterName.getLength() && pController->isShowDialogs() && ! pController->isDirectPrint() )
-        {
-            // get printer name from configuration
-            SettingsConfigItem* pItem = SettingsConfigItem::get();
-            aPrinterName = pItem->getValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "PrintDialog" ) ),
-                                            rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "LastPrinterUsed" ) ) );
-        }
-
         boost::shared_ptr<Printer> pPrinter( new Printer( aPrinterName ) );
+        pPrinter->SetJobSetup( i_rInitSetup );
         pController->setPrinter( pPrinter );
     }
     
@@ -398,17 +382,25 @@ void Printer::ImplPrintJob( const boost::shared_ptr<PrinterController>& i_pContr
         {
             if( nContent == 0 )
             {
-                sal_Int32 nPages = i_pController->getPageCount();
-                if( nPages > 0 )
+                // do not overwrite PageRange if it is already set
+                beans::PropertyValue* pRangeVal = i_pController->getValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "PageRange" ) ) );
+                rtl::OUString aRange;
+                if( pRangeVal )
+                    pRangeVal->Value >>= aRange;
+                if( aRange.getLength() == 0 )
                 {
-                    rtl::OUStringBuffer aBuf( 32 );
-                    aBuf.appendAscii( "1" );
-                    if( nPages > 1 )
+                    sal_Int32 nPages = i_pController->getPageCount();
+                    if( nPages > 0 )
                     {
-                        aBuf.appendAscii( "-" );
-                        aBuf.append( nPages );
+                        rtl::OUStringBuffer aBuf( 32 );
+                        aBuf.appendAscii( "1" );
+                        if( nPages > 1 )
+                        {
+                            aBuf.appendAscii( "-" );
+                            aBuf.append( nPages );
+                        }
+                        i_pController->setValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "PageRange" ) ), makeAny( aBuf.makeStringAndClear() ) );
                     }
-                    i_pController->setValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "PageRange" ) ), makeAny( aBuf.makeStringAndClear() ) );
                 }
             }
         }
@@ -489,18 +481,18 @@ bool Printer::StartJob( const rtl::OUString& i_rJobName, boost::shared_ptr<vcl::
     mnError = PRINTER_OK;
 
     if ( IsDisplayPrinter() )
-        return FALSE;
+        return sal_False;
 
     if ( IsJobActive() || IsPrinting() )
-        return FALSE;
+        return sal_False;
     
-    ULONG   nCopies = mnCopyCount;
+    sal_uLong   nCopies = mnCopyCount;
     bool    bCollateCopy = mbCollateCopy;
-    bool    bUserCopy = FALSE;
+    bool    bUserCopy = sal_False;
 
     if ( nCopies > 1 )
     {
-        ULONG nDevCopy;
+        sal_uLong nDevCopy;
 
         if ( bCollateCopy )
             nDevCopy = GetCapabilities( PRINTER_CAPABILITIES_COLLATECOPIES );
@@ -510,20 +502,20 @@ bool Printer::StartJob( const rtl::OUString& i_rJobName, boost::shared_ptr<vcl::
         // need to do copies by hand ?
         if ( nCopies > nDevCopy )
         {
-            bUserCopy = TRUE;
+            bUserCopy = sal_True;
             nCopies = 1;
-            bCollateCopy = FALSE;
+            bCollateCopy = sal_False;
         }
     }
     else
-        bCollateCopy = FALSE;
+        bCollateCopy = sal_False;
 
 
     ImplSVData* pSVData = ImplGetSVData();
     mpPrinter = pSVData->mpDefInst->CreatePrinter( mpInfoPrinter );
 
     if ( !mpPrinter )
-        return FALSE;
+        return sal_False;
 
     sal_Bool bSinglePrintJobs = sal_False;
     beans::PropertyValue* pSingleValue = i_pController->getValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "PrintCollateAsSingleJobs" ) ) );
@@ -532,10 +524,6 @@ bool Printer::StartJob( const rtl::OUString& i_rJobName, boost::shared_ptr<vcl::
         pSingleValue->Value >>= bSinglePrintJobs;
     }
     
-    // remark: currently it is still possible to use EnablePrintFile and
-    // SetPrintFileName to redirect printout into file
-    // it can be argued that those methods should be removed in favor
-    // of only using the LocalFileName property
     beans::PropertyValue* pFileValue = i_pController->getValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "LocalFileName" ) ) );
     if( pFileValue )
     {
@@ -543,7 +531,7 @@ bool Printer::StartJob( const rtl::OUString& i_rJobName, boost::shared_ptr<vcl::
         pFileValue->Value >>= aFile;
         if( aFile.getLength() )
         {
-            mbPrintFile = TRUE;
+            mbPrintFile = sal_True;
             maPrintFile = aFile;
             bSinglePrintJobs = sal_False;
         }
@@ -552,14 +540,15 @@ bool Printer::StartJob( const rtl::OUString& i_rJobName, boost::shared_ptr<vcl::
     XubString* pPrintFile = NULL;
     if ( mbPrintFile )
         pPrintFile = &maPrintFile;
-
+    mpPrinterOptions->ReadFromConfig( mbPrintFile );
+    
     maJobName		        = i_rJobName;
     mnCurPage		        = 1;
     mnCurPrintPage	        = 1;
-    mbPrinting		        = TRUE;
-    if( ImplGetSVData()->maGDIData.mbPrinterPullModel )
+    mbPrinting		        = sal_True;
+    if( GetCapabilities( PRINTER_CAPABILITIES_USEPULLMODEL ) )
     {
-        mbJobActive             = TRUE;
+        mbJobActive             = sal_True;
         // sallayer does all necessary page printing
         // and also handles showing a dialog
         // that also means it must call jobStarted when the dialog is finished
@@ -580,7 +569,7 @@ bool Printer::StartJob( const rtl::OUString& i_rJobName, boost::shared_ptr<vcl::
             pSVData->mpDefInst->DestroyPrinter( mpPrinter );
             mnCurPage		    = 0;
             mnCurPrintPage	    = 0;
-            mbPrinting		    = FALSE;
+            mbPrinting		    = sal_False;
             mpPrinter = NULL;
             
             return false;
@@ -621,7 +610,7 @@ bool Printer::StartJob( const rtl::OUString& i_rJobName, boost::shared_ptr<vcl::
                                      i_pController->isDirectPrint(),
                                      maJobSetup.ImplGetConstData() ) )
             {
-                mbJobActive             = TRUE;
+                mbJobActive             = sal_True;
                 i_pController->createProgressDialog();
                 int nPages = i_pController->getFilteredPageCount();
                 for( int nOuterIteration = 0; nOuterIteration < nOuterRepeatCount && ! bAborted; nOuterIteration++ )
@@ -658,7 +647,7 @@ bool Printer::StartJob( const rtl::OUString& i_rJobName, boost::shared_ptr<vcl::
                         maJobName		        = i_rJobName;
                         mnCurPage		        = 1;
                         mnCurPrintPage	        = 1;
-                        mbPrinting		        = TRUE;
+                        mbPrinting		        = sal_True;
                     }
                     else
                         bError = true;
@@ -679,7 +668,7 @@ bool Printer::StartJob( const rtl::OUString& i_rJobName, boost::shared_ptr<vcl::
                     pSVData->mpDefInst->DestroyPrinter( mpPrinter );
                 mnCurPage		    = 0;
                 mnCurPrintPage	    = 0;
-                mbPrinting		    = FALSE;
+                mbPrinting		    = sal_False;
                 mpPrinter = NULL;
                 
                 return false;
@@ -732,6 +721,13 @@ void PrinterController::setPrinter( const boost::shared_ptr<Printer>& i_rPrinter
     mpImplData->mnFixedPaperBin = -1;
 }
 
+void PrinterController:: resetPrinterOptions( bool i_bFileOutput )
+{
+    PrinterOptions aOpt;
+    aOpt.ReadFromConfig( i_bFileOutput );
+    mpImplData->mpPrinter->SetPrinterOptions( aOpt );
+}
+
 bool PrinterController::setupPrinter( Window* i_pParent )
 {
     bool bRet = false;
@@ -740,7 +736,7 @@ bool PrinterController::setupPrinter( Window* i_pParent )
         // get old data
         Size aPaperSize( mpImplData->mpPrinter->PixelToLogic(
             mpImplData->mpPrinter->GetPaperSizePixel(), MapMode( MAP_100TH_MM ) ) );
-        USHORT nPaperBin = mpImplData->mpPrinter->GetPaperBin();
+        sal_uInt16 nPaperBin = mpImplData->mpPrinter->GetPaperBin();
 
         // call driver setup
         bRet = mpImplData->mpPrinter->Setup( i_pParent );
@@ -749,7 +745,7 @@ bool PrinterController::setupPrinter( Window* i_pParent )
             // was papersize or bin  overridden ? if so we need to take action
             Size aNewPaperSize( mpImplData->mpPrinter->PixelToLogic(
                 mpImplData->mpPrinter->GetPaperSizePixel(), MapMode( MAP_100TH_MM ) ) );
-            USHORT nNewPaperBin = mpImplData->mpPrinter->GetPaperBin();
+            sal_uInt16 nNewPaperBin = mpImplData->mpPrinter->GetPaperBin();
             if( aNewPaperSize != aPaperSize || nNewPaperBin != nPaperBin )
             {
                 mpImplData->maFixedPageSize = aNewPaperSize;
@@ -766,7 +762,7 @@ bool PrinterController::setupPrinter( Window* i_pParent )
     return bRet;
 }
 
-PrinterController::PageSize vcl::ImplPrinterControllerData::modifyJobSetup( const Sequence< PropertyValue >& i_rProps )
+PrinterController::PageSize vcl::ImplPrinterControllerData::modifyJobSetup( const Sequence< PropertyValue >& i_rProps, bool bNoNUP )
 {
     PrinterController::PageSize aPageSize;
     aPageSize.aSize = mpPrinter->GetPaperSize();
@@ -774,21 +770,21 @@ PrinterController::PageSize vcl::ImplPrinterControllerData::modifyJobSetup( cons
     sal_Int32 nPaperBin = mnDefaultPaperBin;
     for( sal_Int32 nProperty = 0, nPropertyCount = i_rProps.getLength(); nProperty < nPropertyCount; ++nProperty )
     {
-        if( i_rProps[ nProperty ].Name.equalsAscii( "PreferredPageSize" ) )
+        if( i_rProps[ nProperty ].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "PreferredPageSize" ) ) )
         {
             i_rProps[ nProperty ].Value >>= aSetSize;
         }
-        else if( i_rProps[ nProperty ].Name.equalsAscii( "PageSize" ) )
+        else if( i_rProps[ nProperty ].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "PageSize" ) ) )
         {
             i_rProps[ nProperty ].Value >>= aIsSize;
         }
-        else if( i_rProps[ nProperty ].Name.equalsAscii( "PageIncludesNonprintableArea" ) )
+        else if( i_rProps[ nProperty ].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "PageIncludesNonprintableArea" ) ) )
         {
             sal_Bool bVal = sal_False;
             i_rProps[ nProperty ].Value >>= bVal;
             aPageSize.bFullPaper = static_cast<bool>(bVal);
         }
-        else if( i_rProps[ nProperty ].Name.equalsAscii( "PrinterPaperTray" ) )
+        else if( i_rProps[ nProperty ].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "PrinterPaperTray" ) ) )
         {
             sal_Int32 nBin = -1;
             i_rProps[ nProperty ].Value >>= nBin;
@@ -801,7 +797,7 @@ PrinterController::PageSize vcl::ImplPrinterControllerData::modifyJobSetup( cons
     if( aSetSize.Width && aSetSize.Height )
     {
         Size aSetPaperSize( aSetSize.Width, aSetSize.Height );
-        Size aRealPaperSize( getRealPaperSize( aSetPaperSize ) );
+        Size aRealPaperSize( getRealPaperSize( aSetPaperSize, bNoNUP ) );
         if( aRealPaperSize != aCurSize )
             aIsSize = aSetSize;
     }
@@ -811,7 +807,7 @@ PrinterController::PageSize vcl::ImplPrinterControllerData::modifyJobSetup( cons
         aPageSize.aSize.Width() = aIsSize.Width;
         aPageSize.aSize.Height() = aIsSize.Height;
         
-        Size aRealPaperSize( getRealPaperSize( aPageSize.aSize ) );
+        Size aRealPaperSize( getRealPaperSize( aPageSize.aSize, bNoNUP ) );
         if( aRealPaperSize != aCurSize )
             mpPrinter->SetPaperSizeUser( aRealPaperSize, ! isFixedPageSize() );
     }
@@ -877,15 +873,15 @@ PrinterController::PageSize PrinterController::getPageFile( int i_nUnfilteredPag
     mpImplData->mpPrinter->SetMapMode( aMapMode );
     
     // modify job setup if necessary
-    PrinterController::PageSize aPageSize = mpImplData->modifyJobSetup( aPageParm );
+    PrinterController::PageSize aPageSize = mpImplData->modifyJobSetup( aPageParm, true );
 
     o_rMtf.SetPrefSize( aPageSize.aSize );
     o_rMtf.SetPrefMapMode( aMapMode );
 
-    mpImplData->mpPrinter->EnableOutput( FALSE );
+    mpImplData->mpPrinter->EnableOutput( sal_False );
 
     o_rMtf.Record( mpImplData->mpPrinter.get() );
-
+    
     printPage( i_nUnfilteredPage );
 
     o_rMtf.Stop();
@@ -911,7 +907,7 @@ static void appendSubPage( GDIMetaFile& o_rMtf, const Rectangle& i_rClipRect, GD
     o_rMtf.AddAction( new MetaPushAction( PUSH_ALL ) );
 
     // clip to page rect
-    o_rMtf.AddAction( new MetaClipRegionAction( Region( i_rClipRect ), TRUE ) );
+    o_rMtf.AddAction( new MetaClipRegionAction( Region( i_rClipRect ), sal_True ) );
 
     // append the subpage
     io_rSubPage.WindStart();
@@ -928,8 +924,8 @@ static void appendSubPage( GDIMetaFile& o_rMtf, const Rectangle& i_rClipRect, GD
         o_rMtf.AddAction( new MetaMapModeAction( MapMode( MAP_100TH_MM ) ) );
 
         Rectangle aBorderRect( i_rClipRect );
-        o_rMtf.AddAction( new MetaLineColorAction( Color( COL_BLACK ), TRUE ) );
-        o_rMtf.AddAction( new MetaFillColorAction( Color( COL_TRANSPARENT ), FALSE ) );
+        o_rMtf.AddAction( new MetaLineColorAction( Color( COL_BLACK ), sal_True ) );
+        o_rMtf.AddAction( new MetaFillColorAction( Color( COL_TRANSPARENT ), sal_False ) );
         o_rMtf.AddAction( new MetaRectAction( aBorderRect ) );
 
         // restore gstate
@@ -959,7 +955,7 @@ PrinterController::PageSize PrinterController::getFilteredPageFile( int i_nFilte
         rMPS.nTopMargin == 0 && rMPS.nBottomMargin == 0 )
     {
         PrinterController::PageSize aPageSize = getPageFile( i_nFilteredPage, o_rMtf, i_bMayUseCache );
-        Size aPaperSize = mpImplData->getRealPaperSize( aPageSize.aSize );
+        Size aPaperSize = mpImplData->getRealPaperSize( aPageSize.aSize, true );
         mpImplData->mpPrinter->SetMapMode( MapMode( MAP_100TH_MM ) );
         mpImplData->mpPrinter->SetPaperSizeUser( aPaperSize, ! mpImplData->isFixedPageSize() );
         if( aPaperSize != aPageSize.aSize )
@@ -981,7 +977,7 @@ PrinterController::PageSize PrinterController::getFilteredPageFile( int i_nFilte
     sal_Bool bIsLastPage = mpImplData->mbLastPage;
     mpImplData->mbLastPage = sal_False;
     
-    Size aPaperSize( mpImplData->getRealPaperSize( mpImplData->maMultiPage.aPaperSize ) );
+    Size aPaperSize( mpImplData->getRealPaperSize( mpImplData->maMultiPage.aPaperSize, false ) );
 
     // multi page area: page size minus margins + one time spacing right and down
     // the added spacing is so each subpage can be calculated including its spacing
@@ -1030,6 +1026,14 @@ PrinterController::PageSize PrinterController::getFilteredPageFile( int i_nFilte
                     nCellX = (nSubPage / rMPS.nRows);
                     nCellY = (nSubPage % rMPS.nRows);
                     break;
+                case PrinterController::RLTB:
+                    nCellX = rMPS.nColumns - 1 - (nSubPage % rMPS.nColumns);
+                    nCellY = (nSubPage / rMPS.nColumns);
+                    break;
+                case PrinterController::TBRL:
+                    nCellX = rMPS.nColumns - 1 - (nSubPage / rMPS.nRows);
+                    nCellY = (nSubPage % rMPS.nRows);
+                    break;
                 }
                 // scale the metafile down to a sub page size
                 double fScaleX = double(aSubPageSize.Width())/double(aPageSize.aSize.Width());
@@ -1072,9 +1076,9 @@ int PrinterController::getFilteredPageCount()
     return (getPageCountProtected() * mpImplData->maMultiPage.nRepeat + (nDiv-1)) / nDiv;
 }
 
-ULONG PrinterController::removeTransparencies( GDIMetaFile& i_rIn, GDIMetaFile& o_rOut )
+sal_uLong PrinterController::removeTransparencies( GDIMetaFile& i_rIn, GDIMetaFile& o_rOut )
 {
-    ULONG nRestoreDrawMode = mpImplData->mpPrinter->GetDrawMode();
+    sal_uLong nRestoreDrawMode = mpImplData->mpPrinter->GetDrawMode();
     sal_Int32 nMaxBmpDPIX = mpImplData->mpPrinter->ImplGetDPIX();
     sal_Int32 nMaxBmpDPIY = mpImplData->mpPrinter->ImplGetDPIY();
 
@@ -1172,9 +1176,9 @@ void PrinterController::printFilteredPage( int i_nPage )
     }
     
     GDIMetaFile aCleanedFile;
-    ULONG nRestoreDrawMode = removeTransparencies( aPageFile, aCleanedFile );
+    sal_uLong nRestoreDrawMode = removeTransparencies( aPageFile, aCleanedFile );
     
-    mpImplData->mpPrinter->EnableOutput( TRUE );
+    mpImplData->mpPrinter->EnableOutput( sal_True );
 
     // actually print the page
     mpImplData->mpPrinter->ImplStartPage();
@@ -1226,7 +1230,7 @@ bool PrinterController::getReversePrint() const
 
 Sequence< PropertyValue > PrinterController::getJobProperties( const Sequence< PropertyValue >& i_rMergeList ) const
 {
-    std::hash_set< rtl::OUString, rtl::OUStringHash > aMergeSet;
+    boost::unordered_set< rtl::OUString, rtl::OUStringHash > aMergeSet;
     size_t nResultLen = size_t(i_rMergeList.getLength()) + mpImplData->maUIProperties.size() + 3; 
     for( int i = 0; i < i_rMergeList.getLength(); i++ )
         aMergeSet.insert( i_rMergeList[i].Name );
@@ -1275,14 +1279,14 @@ const Sequence< beans::PropertyValue >& PrinterController::getUIOptions() const
 
 beans::PropertyValue* PrinterController::getValue( const rtl::OUString& i_rProperty )
 {
-    std::hash_map< rtl::OUString, size_t, rtl::OUStringHash >::const_iterator it =
+    boost::unordered_map< rtl::OUString, size_t, rtl::OUStringHash >::const_iterator it =
         mpImplData->maPropertyToIndex.find( i_rProperty );
     return it != mpImplData->maPropertyToIndex.end() ? &mpImplData->maUIProperties[it->second] : NULL;
 }
 
 const beans::PropertyValue* PrinterController::getValue( const rtl::OUString& i_rProperty ) const
 {
-    std::hash_map< rtl::OUString, size_t, rtl::OUStringHash >::const_iterator it =
+    boost::unordered_map< rtl::OUString, size_t, rtl::OUStringHash >::const_iterator it =
         mpImplData->maPropertyToIndex.find( i_rProperty );
     return it != mpImplData->maPropertyToIndex.end() ? &mpImplData->maUIProperties[it->second] : NULL;
 }
@@ -1312,7 +1316,7 @@ void PrinterController::setValue( const rtl::OUString& i_rName, const Any& i_rVa
 
 void PrinterController::setValue( const beans::PropertyValue& i_rValue )
 {
-    std::hash_map< rtl::OUString, size_t, rtl::OUStringHash >::const_iterator it =
+    boost::unordered_map< rtl::OUString, size_t, rtl::OUStringHash >::const_iterator it =
         mpImplData->maPropertyToIndex.find( i_rValue.Name );
     if( it != mpImplData->maPropertyToIndex.end() )
         mpImplData->maUIProperties[ it->second ] = i_rValue;
@@ -1339,10 +1343,11 @@ void PrinterController::setUIOptions( const Sequence< beans::PropertyValue >& i_
         bool bHaveProperty = false;
         rtl::OUString aPropName;
         vcl::ImplPrinterControllerData::ControlDependency aDep;
+        Sequence< sal_Bool > aChoicesDisabled;
         for( int n = 0; n < aOptProp.getLength(); n++ )
         {
             const beans::PropertyValue& rEntry( aOptProp[ n ] );
-            if( rEntry.Name.equalsAscii( "Property" ) )
+            if( rEntry.Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "Property" ) ) )
             {
                 PropertyValue aVal;
                 rEntry.Value >>= aVal;
@@ -1352,20 +1357,24 @@ void PrinterController::setUIOptions( const Sequence< beans::PropertyValue >& i_
                 aPropName = aVal.Name;
                 bHaveProperty = true;
             }
-            else if( rEntry.Name.equalsAscii( "Enabled" ) )
+            else if( rEntry.Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "Enabled" ) ) )
             {
                 sal_Bool bValue = sal_True;
                 rEntry.Value >>= bValue;
                 bIsEnabled = bValue;
             }
-            else if( rEntry.Name.equalsAscii( "DependsOnName" ) )
+            else if( rEntry.Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "DependsOnName" ) ) )
             {
                 rEntry.Value >>= aDep.maDependsOnName;
             }
-            else if( rEntry.Name.equalsAscii( "DependsOnEntry" ) )
+            else if( rEntry.Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "DependsOnEntry" ) ) )
             {
                 rEntry.Value >>= aDep.mnDependsOnEntry;
             }
+            else if( rEntry.Name.equalsAscii( "ChoicesDisabled" ) )
+            {
+                rEntry.Value >>= aChoicesDisabled;
+            }
         }
         if( bHaveProperty )
         {
@@ -1378,13 +1387,15 @@ void PrinterController::setUIOptions( const Sequence< beans::PropertyValue >& i_
             }
             if( aDep.maDependsOnName.getLength() > 0 )
                 mpImplData->maControlDependencies[ aPropName ] = aDep;
+            if( aChoicesDisabled.getLength() > 0 )
+                mpImplData->maChoiceDisableMap[ aPropName ] = aChoicesDisabled;
         }
     }
 }
 
 void PrinterController::enableUIOption( const rtl::OUString& i_rProperty, bool i_bEnable )
 {
-    std::hash_map< rtl::OUString, size_t, rtl::OUStringHash >::const_iterator it =
+    boost::unordered_map< rtl::OUString, size_t, rtl::OUStringHash >::const_iterator it =
         mpImplData->maPropertyToIndex.find( i_rProperty );
     if( it != mpImplData->maPropertyToIndex.end() )
     {
@@ -1402,7 +1413,7 @@ void PrinterController::enableUIOption( const rtl::OUString& i_rProperty, bool i
 bool PrinterController::isUIOptionEnabled( const rtl::OUString& i_rProperty ) const
 {
     bool bEnabled = false;
-    std::hash_map< rtl::OUString, size_t, rtl::OUStringHash >::const_iterator prop_it =
+    boost::unordered_map< rtl::OUString, size_t, rtl::OUStringHash >::const_iterator prop_it =
         mpImplData->maPropertyToIndex.find( i_rProperty );
     if( prop_it != mpImplData->maPropertyToIndex.end() )
     {
@@ -1442,7 +1453,7 @@ bool PrinterController::isUIOptionEnabled( const rtl::OUString& i_rProperty ) co
                         else
                         {
                             // if the type does not match something is awry
-                            OSL_ENSURE( 0, "strange type in control dependency" );
+                            OSL_FAIL( "strange type in control dependency" );
                             bEnabled = false;
                         }
                     }
@@ -1453,6 +1464,20 @@ bool PrinterController::isUIOptionEnabled( const rtl::OUString& i_rProperty ) co
     return bEnabled;
 }
 
+bool PrinterController::isUIChoiceEnabled( const rtl::OUString& i_rProperty, sal_Int32 i_nValue ) const
+{
+    bool bEnabled = true;
+    ImplPrinterControllerData::ChoiceDisableMap::const_iterator it =
+        mpImplData->maChoiceDisableMap.find( i_rProperty );
+    if(it != mpImplData->maChoiceDisableMap.end() )
+    {
+        const Sequence< sal_Bool >& rDisabled( it->second );
+        if( i_nValue >= 0 && i_nValue < rDisabled.getLength() )
+            bEnabled = ! rDisabled[i_nValue];
+    }
+    return bEnabled;
+}
+
 rtl::OUString PrinterController::getDependency( const rtl::OUString& i_rProperty ) const
 {
     rtl::OUString aDependency;
@@ -1496,7 +1521,7 @@ rtl::OUString PrinterController::makeEnabled( const rtl::OUString& i_rProperty )
                else
                {
                    // if the type does not match something is awry
-                   OSL_ENSURE( 0, "strange type in control dependency" );
+                   OSL_FAIL( "strange type in control dependency" );
                }
            }
         }
@@ -1565,7 +1590,7 @@ void PrinterController::pushPropertiesToPrinter()
     pVal = getValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Collate" ) ) );
     if( pVal )
         pVal->Value >>= bCollate;
-    mpImplData->mpPrinter->SetCopyCount( static_cast<USHORT>(nCopyCount), bCollate );
+    mpImplData->mpPrinter->SetCopyCount( static_cast<sal_uInt16>(nCopyCount), bCollate );
 
     // duplex mode
     pVal = getValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "DuplexMode" ) ) );
@@ -1609,7 +1634,7 @@ sal_Bool PrinterController::getBoolProperty( const rtl::OUString& i_rProperty, s
 Any PrinterOptionsHelper::getValue( const rtl::OUString& i_rPropertyName ) const
 {
     Any aRet;
-    std::hash_map< rtl::OUString, Any, rtl::OUStringHash >::const_iterator it =
+    boost::unordered_map< rtl::OUString, Any, rtl::OUStringHash >::const_iterator it =
         m_aPropertyMap.find( i_rPropertyName );
     if( it != m_aPropertyMap.end() )
         aRet = it->second;
@@ -1624,7 +1649,7 @@ void PrinterOptionsHelper::setValue( const rtl::OUString& i_rPropertyName, const
 bool PrinterOptionsHelper::hasProperty( const rtl::OUString& i_rPropertyName ) const
 {
     Any aRet;
-    std::hash_map< rtl::OUString, Any, rtl::OUStringHash >::const_iterator it =
+    boost::unordered_map< rtl::OUString, Any, rtl::OUStringHash >::const_iterator it =
         m_aPropertyMap.find( i_rPropertyName );
     return it != m_aPropertyMap.end();
 }
@@ -1664,7 +1689,7 @@ bool PrinterOptionsHelper::processProperties( const Sequence< PropertyValue >& i
     for( sal_Int32 i = 0; i < nElements; i++ )
     {
         bool bElementChanged = false;
-        std::hash_map< rtl::OUString, Any, rtl::OUStringHash >::iterator it =
+        boost::unordered_map< rtl::OUString, Any, rtl::OUStringHash >::iterator it =
             m_aPropertyMap.find( pVals[ i ].Name );
         if( it != m_aPropertyMap.end() )
         {
@@ -1699,7 +1724,7 @@ void PrinterOptionsHelper::appendPrintUIOptions( uno::Sequence< beans::PropertyV
 }
 
 Any PrinterOptionsHelper::getUIControlOpt( const rtl::OUString& i_rTitle,
-                                           const Sequence< rtl::OUString >& i_rHelpTexts,
+                                           const Sequence< rtl::OUString >& i_rHelpIds,
                                            const rtl::OUString& i_rType,
                                            const PropertyValue* i_pVal,
                                            const PrinterOptionsHelper::UIControlOptions& i_rControlOptions
@@ -1708,7 +1733,7 @@ Any PrinterOptionsHelper::getUIControlOpt( const rtl::OUString& i_rTitle,
     sal_Int32 nElements =
         1                                                               // ControlType
         + (i_rTitle.getLength() ? 1 : 0)                                // Text
-        + (i_rHelpTexts.getLength() ? 1 : 0)                            // HelpText
+        + (i_rHelpIds.getLength() ? 1 : 0)                              // HelpId
         + (i_pVal ? 1 : 0)                                              // Property
         + i_rControlOptions.maAddProps.getLength()                      // additional props
         + (i_rControlOptions.maGroupHint.getLength() ? 1 : 0)           // grouping
@@ -1731,10 +1756,10 @@ Any PrinterOptionsHelper::getUIControlOpt( const rtl::OUString& i_rTitle,
         aCtrl[nUsed  ].Name  = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Text" ) );
         aCtrl[nUsed++].Value = makeAny( i_rTitle );
     }
-    if( i_rHelpTexts.getLength() )
+    if( i_rHelpIds.getLength() )
     {
-        aCtrl[nUsed  ].Name = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "HelpText" ) );
-        aCtrl[nUsed++].Value = makeAny( i_rHelpTexts );
+        aCtrl[nUsed  ].Name = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "HelpId" ) );
+        aCtrl[nUsed++].Value = makeAny( i_rHelpIds );
     }
     aCtrl[nUsed  ].Name  = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ControlType" ) );
     aCtrl[nUsed++].Value = makeAny( i_rType );
@@ -1783,74 +1808,80 @@ Any PrinterOptionsHelper::getUIControlOpt( const rtl::OUString& i_rTitle,
     return makeAny( aCtrl );
 }
 
-Any PrinterOptionsHelper::getGroupControlOpt( const rtl::OUString& i_rTitle, const rtl::OUString& i_rHelpText )
+Any PrinterOptionsHelper::getGroupControlOpt( const rtl::OUString& i_rTitle, const rtl::OUString& i_rHelpId )
 {
-    Sequence< rtl::OUString > aHelpText;
-    if( i_rHelpText.getLength() > 0 )
+    Sequence< rtl::OUString > aHelpId;
+    if( i_rHelpId.getLength() > 0 )
     {
-        aHelpText.realloc( 1 );
-        *aHelpText.getArray() = i_rHelpText;
+        aHelpId.realloc( 1 );
+        *aHelpId.getArray() = i_rHelpId;
     }
-    return getUIControlOpt( i_rTitle, aHelpText, rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Group" ) ) );
+    return getUIControlOpt( i_rTitle, aHelpId, rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Group" ) ) );
 }
 
 Any PrinterOptionsHelper::getSubgroupControlOpt( const rtl::OUString& i_rTitle,
-                                                 const rtl::OUString& i_rHelpText,
+                                                 const rtl::OUString& i_rHelpId,
                                                  const PrinterOptionsHelper::UIControlOptions& i_rControlOptions
                                                  )
 {
-    Sequence< rtl::OUString > aHelpText;
-    if( i_rHelpText.getLength() > 0 )
+    Sequence< rtl::OUString > aHelpId;
+    if( i_rHelpId.getLength() > 0 )
     {
-        aHelpText.realloc( 1 );
-        *aHelpText.getArray() = i_rHelpText;
+        aHelpId.realloc( 1 );
+        *aHelpId.getArray() = i_rHelpId;
     }
-    return getUIControlOpt( i_rTitle, aHelpText, rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Subgroup" ) ),
+    return getUIControlOpt( i_rTitle, aHelpId, rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Subgroup" ) ),
                             NULL, i_rControlOptions );
 }
 
 Any PrinterOptionsHelper::getBoolControlOpt( const rtl::OUString& i_rTitle,
-                                             const rtl::OUString& i_rHelpText,
+                                             const rtl::OUString& i_rHelpId,
                                              const rtl::OUString& i_rProperty,
                                              sal_Bool i_bValue,
                                              const PrinterOptionsHelper::UIControlOptions& i_rControlOptions
                                              )
 {
-    Sequence< rtl::OUString > aHelpText;
-    if( i_rHelpText.getLength() > 0 )
+    Sequence< rtl::OUString > aHelpId;
+    if( i_rHelpId.getLength() > 0 )
     {
-        aHelpText.realloc( 1 );
-        *aHelpText.getArray() = i_rHelpText;
+        aHelpId.realloc( 1 );
+        *aHelpId.getArray() = i_rHelpId;
     }
     PropertyValue aVal;
     aVal.Name = i_rProperty;
     aVal.Value = makeAny( i_bValue );
-    return getUIControlOpt( i_rTitle, aHelpText, rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Bool" ) ), &aVal, i_rControlOptions );
+    return getUIControlOpt( i_rTitle, aHelpId, rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Bool" ) ), &aVal, i_rControlOptions );
 }
 
 Any PrinterOptionsHelper::getChoiceControlOpt( const rtl::OUString& i_rTitle,
-                                               const Sequence< rtl::OUString >& i_rHelpText,
+                                               const Sequence< rtl::OUString >& i_rHelpId,
                                                const rtl::OUString& i_rProperty,
                                                const Sequence< rtl::OUString >& i_rChoices,
                                                sal_Int32 i_nValue,
                                                const rtl::OUString& i_rType,
+                                               const Sequence< sal_Bool >& i_rDisabledChoices,
                                                const PrinterOptionsHelper::UIControlOptions& i_rControlOptions
                                                )
 {
     UIControlOptions aOpt( i_rControlOptions );
     sal_Int32 nUsed = aOpt.maAddProps.getLength();
-    aOpt.maAddProps.realloc( nUsed + 1 );
+    aOpt.maAddProps.realloc( nUsed + 1 + (i_rDisabledChoices.getLength() ? 1 : 0) );
     aOpt.maAddProps[nUsed].Name = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Choices" ) );
     aOpt.maAddProps[nUsed].Value = makeAny( i_rChoices );
+    if( i_rDisabledChoices.getLength() )
+    {
+        aOpt.maAddProps[nUsed+1].Name = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ChoicesDisabled" ) );
+        aOpt.maAddProps[nUsed+1].Value = makeAny( i_rDisabledChoices );
+    }
 
     PropertyValue aVal;
     aVal.Name = i_rProperty;
     aVal.Value = makeAny( i_nValue );
-    return getUIControlOpt( i_rTitle, i_rHelpText, i_rType, &aVal, aOpt );
+    return getUIControlOpt( i_rTitle, i_rHelpId, i_rType, &aVal, aOpt );
 }
 
 Any PrinterOptionsHelper::getRangeControlOpt( const rtl::OUString& i_rTitle,
-                                              const rtl::OUString& i_rHelpText,
+                                              const rtl::OUString& i_rHelpId,
                                               const rtl::OUString& i_rProperty,
                                               sal_Int32 i_nValue,
                                               sal_Int32 i_nMinValue,
@@ -1869,17 +1900,17 @@ Any PrinterOptionsHelper::getRangeControlOpt( const rtl::OUString& i_rTitle,
         aOpt.maAddProps[nUsed++].Value = makeAny( i_nMaxValue );
     }
 
-    Sequence< rtl::OUString > aHelpText;
-    if( i_rHelpText.getLength() > 0 )
+    Sequence< rtl::OUString > aHelpId;
+    if( i_rHelpId.getLength() > 0 )
     {
-        aHelpText.realloc( 1 );
-        *aHelpText.getArray() = i_rHelpText;
+        aHelpId.realloc( 1 );
+        *aHelpId.getArray() = i_rHelpId;
     }
     PropertyValue aVal;
     aVal.Name = i_rProperty;
     aVal.Value = makeAny( i_nValue );
     return getUIControlOpt( i_rTitle,
-                            aHelpText,
+                            aHelpId,
                             rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Range" ) ),
                             &aVal,
                             aOpt
@@ -1887,23 +1918,23 @@ Any PrinterOptionsHelper::getRangeControlOpt( const rtl::OUString& i_rTitle,
 }
 
 Any PrinterOptionsHelper::getEditControlOpt( const rtl::OUString& i_rTitle,
-                                             const rtl::OUString& i_rHelpText,
+                                             const rtl::OUString& i_rHelpId,
                                              const rtl::OUString& i_rProperty,
                                              const rtl::OUString& i_rValue,
                                              const PrinterOptionsHelper::UIControlOptions& i_rControlOptions
                                            )
 {
-    Sequence< rtl::OUString > aHelpText;
-    if( i_rHelpText.getLength() > 0 )
+    Sequence< rtl::OUString > aHelpId;
+    if( i_rHelpId.getLength() > 0 )
     {
-        aHelpText.realloc( 1 );
-        *aHelpText.getArray() = i_rHelpText;
+        aHelpId.realloc( 1 );
+        *aHelpId.getArray() = i_rHelpId;
     }
     PropertyValue aVal;
     aVal.Name = i_rProperty;
     aVal.Value = makeAny( i_rValue );
     return getUIControlOpt( i_rTitle,
-                            aHelpText,
+                            aHelpId,
                             rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Edit" ) ),
                             &aVal,
                             i_rControlOptions
