@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -54,14 +54,11 @@ static void ImplInitMsgBoxImageList()
     {
         ResMgr* pResMgr = ImplGetResMgr();
         pSVData->maWinData.mpMsgBoxImgList = new ImageList(4);
-        pSVData->maWinData.mpMsgBoxHCImgList = new ImageList(4);
         if( pResMgr )
         {
             Color aNonAlphaMask( 0xC0, 0xC0, 0xC0 );
             pSVData->maWinData.mpMsgBoxImgList->InsertFromHorizontalBitmap
                 ( ResId( SV_RESID_BITMAP_MSGBOX, *pResMgr ), 4, &aNonAlphaMask );
-            pSVData->maWinData.mpMsgBoxHCImgList->InsertFromHorizontalBitmap
-                ( ResId( SV_RESID_BITMAP_MSGBOX_HC, *pResMgr ), 4, &aNonAlphaMask );
         }
     }
 }
@@ -73,10 +70,10 @@ void MessBox::ImplInitMessBoxData()
     mpFixedText 		= NULL;
     mpFixedImage		= NULL;
     mnSoundType 		= 0;
-    mbHelpBtn			= FALSE;
-    mbSound 			= TRUE;
+    mbHelpBtn			= sal_False;
+    mbSound 			= sal_True;
     mpCheckBox          = NULL;
-    mbCheck             = FALSE;
+    mbCheck             = sal_False;
 }
 
 // -----------------------------------------------------------------------
@@ -84,11 +81,11 @@ void MessBox::ImplInitMessBoxData()
 void MessBox::ImplInitButtons()
 {
     WinBits nStyle = GetStyle();
-    USHORT	nOKFlags = BUTTONDIALOG_OKBUTTON;
-    USHORT	nCancelFlags = BUTTONDIALOG_CANCELBUTTON;
-    USHORT	nRetryFlags = 0;
-    USHORT	nYesFlags = 0;
-    USHORT	nNoFlags = 0;
+    sal_uInt16	nOKFlags = BUTTONDIALOG_OKBUTTON;
+    sal_uInt16	nCancelFlags = BUTTONDIALOG_CANCELBUTTON;
+    sal_uInt16	nRetryFlags = 0;
+    sal_uInt16	nYesFlags = 0;
+    sal_uInt16	nNoFlags = 0;
 
     if ( nStyle & WB_OK_CANCEL )
     {
@@ -136,8 +133,8 @@ void MessBox::ImplInitButtons()
     }
     else if ( nStyle & WB_ABORT_RETRY_IGNORE )
     {
-        USHORT nAbortFlags = 0;
-        USHORT nIgnoreFlags = 0;
+        sal_uInt16 nAbortFlags = 0;
+        sal_uInt16 nIgnoreFlags = 0;
 
         if ( nStyle & WB_DEF_CANCEL )
             nAbortFlags |= BUTTONDIALOG_DEFBUTTON | BUTTONDIALOG_FOCUSBUTTON;
@@ -189,16 +186,15 @@ MessBox::MessBox( Window* pParent, const ResId& rResId ) :
     ImplInitMessBoxData();
 
     GetRes( rResId.SetRT( RSC_MESSBOX ) );
-    USHORT nHiButtons	= ReadShortRes();
-    USHORT nLoButtons	= ReadShortRes();
-    USHORT nHiDefButton = ReadShortRes();
-    USHORT nLoDefButton = ReadShortRes();
-    USHORT nHiHelpId	= ReadShortRes();
-    USHORT nLoHelpId	= ReadShortRes();
-    /* USHORT bSysModal	= */ ReadShortRes();
-    SetHelpId( ((ULONG)nHiHelpId << 16) + nLoHelpId );
-    WinBits nBits = (((ULONG)nHiButtons << 16) + nLoButtons) |
-                    (((ULONG)nHiDefButton << 16) + nLoDefButton);
+    sal_uInt16 nHiButtons	= ReadShortRes();
+    sal_uInt16 nLoButtons	= ReadShortRes();
+    sal_uInt16 nHiDefButton = ReadShortRes();
+    sal_uInt16 nLoDefButton = ReadShortRes();
+    rtl::OString aHelpId( ReadByteStringRes() );
+    /* sal_uInt16 bSysModal	= */ ReadShortRes();
+    SetHelpId( aHelpId );
+    WinBits nBits = (((sal_uLong)nHiButtons << 16) + nLoButtons) |
+                    (((sal_uLong)nHiDefButton << 16) + nLoDefButton);
     ImplInit( pParent, nBits | WB_MOVEABLE | WB_HORZ | WB_CENTER );
 
     ImplLoadRes( rResId );
@@ -209,7 +205,7 @@ MessBox::MessBox( Window* pParent, const ResId& rResId ) :
 
 void MessBox::ImplLoadRes( const ResId& )
 {
-    SetText( ReadStringRes() );
+    SetText(     ReadStringRes() );
     SetMessText( ReadStringRes() );
     SetHelpText( ReadStringRes() );
 }
@@ -230,12 +226,12 @@ MessBox::~MessBox()
 
 void MessBox::ImplPosControls()
 {
-    if ( GetHelpId() )
+    if ( GetHelpId().getLength() )
     {
         if ( !mbHelpBtn )
         {
             AddButton( BUTTON_HELP, BUTTONID_HELP, BUTTONDIALOG_HELPBUTTON, 3 );
-            mbHelpBtn = TRUE;
+            mbHelpBtn = sal_True;
         }
     }
     else
@@ -243,7 +239,7 @@ void MessBox::ImplPosControls()
         if ( mbHelpBtn )
         {
             RemoveButton( BUTTONID_HELP );
-            mbHelpBtn = FALSE;
+            mbHelpBtn = sal_False;
         }
     }
 
@@ -261,7 +257,7 @@ void MessBox::ImplPosControls()
     long			nMaxLineWidth;
     long			nWidth;
     WinBits 		nWinStyle = WB_LEFT | WB_WORDBREAK | WB_NOLABEL | WB_INFO;
-    USHORT			nTextStyle = TEXT_DRAW_MULTILINE | TEXT_DRAW_TOP | TEXT_DRAW_LEFT;
+    sal_uInt16			nTextStyle = TEXT_DRAW_MULTILINE | TEXT_DRAW_TOP | TEXT_DRAW_LEFT;
 
     if ( mpFixedText )
         delete mpFixedText;
@@ -280,7 +276,7 @@ void MessBox::ImplPosControls()
 
     // Message-Text um Tabs bereinigen
     XubString	aTabStr( RTL_CONSTASCII_USTRINGPARAM( "    " ) );
-    USHORT		nIndex = 0;
+    sal_uInt16		nIndex = 0;
     while ( nIndex != STRING_NOTFOUND )
         nIndex = aMessText.SearchAndReplace( '\t', aTabStr, nIndex );
 
@@ -312,9 +308,6 @@ void MessBox::ImplPosControls()
                                               IMPL_DIALOG_OFFSET-2+IMPL_MSGBOX_OFFSET_EXTRA_Y ),
                                        aImageSize );
         mpFixedImage->SetImage( maImage );
-        // forward the HC image
-        if( !!maImageHC )
-            mpFixedImage->SetModeImage( maImageHC, BMP_COLOR_HIGHCONTRAST );
         mpFixedImage->Show();
         nMaxWidth -= aImageSize.Width()+IMPL_SEP_MSGBOX_IMAGE;
     }
@@ -420,6 +413,8 @@ void MessBox::ImplPosControls()
     }
 
     mpFixedText = new FixedText( this, nWinStyle );
+    if( mpFixedText->GetStyle() & WB_EXTRAOFFSET ) // TODO: use CalcMinimumSize() instead
+        aFixedSize.Width() += 2;
     mpFixedText->SetPosSizePixel( aTextPos, aFixedSize );
     mpFixedText->SetText( aMessText );
     mpFixedText->Show();
@@ -441,14 +436,14 @@ void MessBox::StateChanged( StateChangedType nType )
 
 // -----------------------------------------------------------------------
 
-BOOL MessBox::GetCheckBoxState() const
+sal_Bool MessBox::GetCheckBoxState() const
 {
     return mpCheckBox ? mpCheckBox->IsChecked() : mbCheck;
 }
 
 // -----------------------------------------------------------------------
 
-void MessBox::SetCheckBoxState( BOOL bCheck )
+void MessBox::SetCheckBoxState( sal_Bool bCheck )
 {
     if( mpCheckBox ) mpCheckBox->Check( bCheck );
     mbCheck = bCheck;
@@ -465,38 +460,42 @@ void MessBox::SetDefaultCheckBoxText()
 
 // -----------------------------------------------------------------------
 
-BOOL MessBox::SetModeImage( const Image& rImage, BmpColorMode eMode )
+sal_Bool MessBox::SetModeImage( const Image& rImage )
 {
-    if( eMode == BMP_COLOR_NORMAL )
-        SetImage( rImage );
-    else if( eMode == BMP_COLOR_HIGHCONTRAST )
-        maImageHC = rImage;
-    else
-        return FALSE;
-    return TRUE;
+    SetImage( rImage );
+    return sal_True;
 }
 
 // -----------------------------------------------------------------------
 
-const Image& MessBox::GetModeImage( BmpColorMode eMode ) const
+const Image& MessBox::GetModeImage( ) const
 {
-    if( eMode == BMP_COLOR_HIGHCONTRAST )
-        return maImageHC;
-    else
-        return maImage;
+    return maImage;
 }
 
 // -----------------------------------------------------------------------
 
+Size MessBox::GetOptimalSize(WindowSizeType eType) const
+{
+    switch( eType ) {
+    case WINDOWSIZE_MINIMUM:
+        // FIXME: base me on the font size ?
+        return Size( 250, 100 );
+    default:
+        return Window::GetOptimalSize( eType );
+    }
+}
+
+// ============================================================================
+
 void InfoBox::ImplInitInfoBoxData()
 {
     // Default Text is the display title from the application
     if ( !GetText().Len() )
         SetText( Application::GetDisplayName() );
 
-    SetImage( GetSettings().GetStyleSettings().GetHighContrastMode() ?
-                InfoBox::GetStandardImageHC() : InfoBox::GetStandardImage() );
-    mnSoundType = ((USHORT)SOUND_INFO)+1;
+    SetImage( InfoBox::GetStandardImage() );
+    mnSoundType = ((sal_uInt16)SOUND_INFO)+1;
 }
 
 // -----------------------------------------------------------------------
@@ -523,15 +522,7 @@ Image InfoBox::GetStandardImage()
     return ImplGetSVData()->maWinData.mpMsgBoxImgList->GetImage( 4 );
 }
 
-// -----------------------------------------------------------------------
-
-Image InfoBox::GetStandardImageHC()
-{
-    ImplInitMsgBoxImageList();
-    return ImplGetSVData()->maWinData.mpMsgBoxHCImgList->GetImage( 4 );
-}
-
-// -----------------------------------------------------------------------
+// ============================================================================
 
 void WarningBox::ImplInitWarningBoxData()
 {
@@ -540,7 +531,7 @@ void WarningBox::ImplInitWarningBoxData()
         SetText( Application::GetDisplayName() );
 
     SetImage( WarningBox::GetStandardImage() );
-    mnSoundType = ((USHORT)SOUND_WARNING)+1;
+    mnSoundType = ((sal_uInt16)SOUND_WARNING)+1;
 }
 
 // -----------------------------------------------------------------------
@@ -577,7 +568,7 @@ Image WarningBox::GetStandardImage()
     return ImplGetSVData()->maWinData.mpMsgBoxImgList->GetImage( 3 );
 }
 
-// -----------------------------------------------------------------------
+// ============================================================================
 
 void ErrorBox::ImplInitErrorBoxData()
 {
@@ -585,9 +576,8 @@ void ErrorBox::ImplInitErrorBoxData()
     if ( !GetText().Len() )
         SetText( Application::GetDisplayName() );
 
-    SetImage( GetSettings().GetStyleSettings().GetHighContrastMode() ? 
-        ErrorBox::GetStandardImageHC() : ErrorBox::GetStandardImage() );
-    mnSoundType = ((USHORT)SOUND_ERROR)+1;
+    SetImage( ErrorBox::GetStandardImage() );
+    mnSoundType = ((sal_uInt16)SOUND_ERROR)+1;
 }
 
 // -----------------------------------------------------------------------
@@ -615,15 +605,7 @@ Image ErrorBox::GetStandardImage()
     return ImplGetSVData()->maWinData.mpMsgBoxImgList->GetImage( 1 );
 }
 
-// -----------------------------------------------------------------------
-
-Image ErrorBox::GetStandardImageHC()
-{
-    ImplInitMsgBoxImageList();
-    return ImplGetSVData()->maWinData.mpMsgBoxHCImgList->GetImage( 1 );
-}
-
-// -----------------------------------------------------------------------
+// ============================================================================
 
 void QueryBox::ImplInitQueryBoxData()
 {
@@ -631,9 +613,8 @@ void QueryBox::ImplInitQueryBoxData()
     if ( !GetText().Len() )
         SetText( Application::GetDisplayName() );
 
-    SetImage( GetSettings().GetStyleSettings().GetHighContrastMode() ?
-        QueryBox::GetStandardImageHC() : QueryBox::GetStandardImage() );
-    mnSoundType = ((USHORT)SOUND_QUERY)+1;
+    SetImage( QueryBox::GetStandardImage() );
+    mnSoundType = ((sal_uInt16)SOUND_QUERY)+1;
 }
 
 // -----------------------------------------------------------------------
@@ -669,25 +650,4 @@ Image QueryBox::GetStandardImage()
     return ImplGetSVData()->maWinData.mpMsgBoxImgList->GetImage( 2 );
 }
 
-// -----------------------------------------------------------------------
-
-Image QueryBox::GetStandardImageHC()
-{
-    ImplInitMsgBoxImageList();
-    return ImplGetSVData()->maWinData.mpMsgBoxHCImgList->GetImage( 2 );
-}
-
-// -----------------------------------------------------------------------
-
-Size MessBox::GetOptimalSize(WindowSizeType eType) const
-{
-    switch( eType ) {
-    case WINDOWSIZE_MINIMUM:
-        // FIXME: base me on the font size ?
-        return Size( 250, 100 );
-    default:
-        return Window::GetOptimalSize( eType );
-    }
-}
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
