@@ -3,7 +3,7 @@
 #define vertcurs_mask_height 16
 #define vertcurs_mask_x_hot 8 
 #define vertcurs_mask_y_hot 8
-static char vertcurs_mask_bits[] = {
+static unsigned char vertcurs_mask_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0xe0, 0x07, 0xe0, 0x0f, 0xf0,
    0xff, 0xff, 0xfe, 0x7f, 0xff, 0xff, 0x0f, 0xf0, 0x07, 0xe0, 0x07, 0xe0,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
