@@ -20,9 +20,14 @@
 #include <stdio.h>
 #endif
 
-using namespace rtl;
+#include "dmapperLoggers.hxx"
+
 using namespace com::sun::star;
 
+using ::rtl::OUString;
+using ::rtl::OString;
+using ::rtl::OUStringToOString;
+
 #define MAKE_PROPVAL(NameId, Value) \
     beans::PropertyValue(aPropNameSupplier.GetName(NameId), 0, uno::makeAny(Value), beans::PropertyState_DIRECT_VALUE )
 
@@ -132,7 +137,7 @@ void ListLevel::SetValue( Id nId, sal_Int32 nValue )
             m_nTabstop = nValue;
         break;
         default:
-            OSL_ENSURE( false, "this line should never be reached");
+            OSL_FAIL( "this line should never be reached");
     }
 }
 
@@ -394,7 +399,7 @@ void AbstractListDef::SetValue( sal_uInt32 nSprmId, sal_Int32 nValue )
             m_nUnsigned = nValue;
         break;
         default:
-            OSL_ENSURE( false, "this line should never be reached");
+            OSL_FAIL( "this line should never be reached");
     }
 }
 
@@ -439,7 +444,7 @@ ListDef::~ListDef( )
 
 OUString ListDef::GetStyleName( sal_Int32 nId )
 {
-    OUString sStyleName( OUString::createFromAscii( "WWNum" ) );
+    OUString sStyleName( RTL_CONSTASCII_USTRINGPARAM("WWNum") );
     sStyleName += OUString::valueOf( nId );
 
     return sStyleName;
@@ -476,7 +481,7 @@ uno::Reference< container::XNameContainer > lcl_getUnoNumberingStyles(
     try
     {
         uno::Reference< style::XStyleFamiliesSupplier > xFamilies( xFactory, uno::UNO_QUERY_THROW );
-        uno::Any oFamily = xFamilies->getStyleFamilies( )->getByName( OUString::createFromAscii( "NumberingStyles" ) );
+        uno::Any oFamily = xFamilies->getStyleFamilies( )->getByName( OUString(RTL_CONSTASCII_USTRINGPARAM("NumberingStyles")) );
 
         oFamily >>= xStyles;
     }
@@ -501,7 +506,7 @@ void ListDef::CreateNumberingRules( DomainMapper& rDMapper,
             // Create the numbering style
             uno::Reference< beans::XPropertySet > xStyle (
                 xFactory->createInstance( 
-                    OUString::createFromAscii("com.sun.star.style.NumberingStyle")),
+                    OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.style.NumberingStyle"))),
                 uno::UNO_QUERY_THROW );
 
             rtl::OUString sStyleName = GetStyleName( GetId( ) );
@@ -606,7 +611,7 @@ void ListDef::CreateNumberingRules( DomainMapper& rDMapper,
         }
         catch( const uno::Exception& rEx)
         {
-            OSL_ENSURE( false, "ListTable::CreateNumberingRules");
+            OSL_FAIL( "ListTable::CreateNumberingRules");
         }
     }
 
@@ -615,10 +620,12 @@ void ListDef::CreateNumberingRules( DomainMapper& rDMapper,
 //-------------------------------------  NumberingManager implementation
 
 
-ListsManager::ListsManager( DomainMapper& rDMapper, 
-        const uno::Reference< lang::XMultiServiceFactory > xFactory ) :
-    m_rDMapper( rDMapper ),
-    m_xFactory( xFactory )
+ListsManager::ListsManager(DomainMapper& rDMapper, 
+                           const uno::Reference< lang::XMultiServiceFactory > xFactory) :
+LoggedProperties(dmapper_logger, "ListsManager"),
+LoggedTable(dmapper_logger, "ListsManager"),
+m_rDMapper( rDMapper ),
+m_xFactory( xFactory )
 {
 }
 
@@ -626,7 +633,7 @@ ListsManager::~ListsManager( )
 {
 }
 
-void ListsManager::attribute( Id nName, Value& rVal )
+void ListsManager::lcl_attribute( Id nName, Value& rVal )
 {
     OSL_ENSURE( m_pCurrentDefinition.get(), "current entry has to be set here");
     if(!m_pCurrentDefinition.get())
@@ -636,15 +643,12 @@ void ListsManager::attribute( Id nName, Value& rVal )
     ListLevel::Pointer pCurrentLvl = m_pCurrentDefinition->GetCurrentLevel( );
 
 
-    /* WRITERFILTERSTATUS: table: ListTable_attributedata */
     switch(nName)
     {
-        /* WRITERFILTERSTATUS: done: 50, planned: 0, spent: 0 */
         case NS_rtf::LN_RGBXCHNUMS:
             if(pCurrentLvl.get())
                 pCurrentLvl->AddRGBXchNums( rVal.getString( ) );
         break;
-        /* WRITERFILTERSTATUS: done: 0, planned: 0, spent: 0 */
         case NS_ooxml::LN_CT_LevelText_val:
         {    
             //this strings contains the definition of the level
@@ -656,31 +660,20 @@ void ListsManager::attribute( Id nName, Value& rVal )
                 pCurrentLvl->SetBulletChar( rVal.getString() );
         }
         break;
-//        case NS_rtf::LN_ISTD: break;
-        /* WRITERFILTERSTATUS: done: 75, planned: 0, spent: 0 */
         case NS_rtf::LN_ISTARTAT:
-        /* WRITERFILTERSTATUS: done: 75, planned: 0, spent: 0 */
         case NS_rtf::LN_NFC:
-        /* WRITERFILTERSTATUS: done: 75, planned: 0, spent: 0 */
         case NS_rtf::LN_JC:
-        /* WRITERFILTERSTATUS: done: 75, planned: 0, spent: 0 */
         case NS_rtf::LN_FLEGAL:
-        /* WRITERFILTERSTATUS: done: 75, planned: 0, spent: 0 */
         case NS_rtf::LN_FNORESTART:
-        /* WRITERFILTERSTATUS: done: 75, planned: 0, spent: 0 */
         case NS_rtf::LN_FIDENTSAV:
-        /* WRITERFILTERSTATUS: done: 75, planned: 0, spent: 0 */
         case NS_rtf::LN_FCONVERTED:
 #if 0
-        /* WRITERFILTERSTATUS: done: 75, planned: 0, spent: 0 */
         case NS_rtf::LN_FWORD6:
 #endif
-        /* WRITERFILTERSTATUS: done: 75, planned: 0, spent: 0 */
         case NS_rtf::LN_IXCHFOLLOW:
             if ( pCurrentLvl.get( ) )
                 pCurrentLvl->SetValue( nName, sal_Int32( nIntValue ) );
         break;
-        /* WRITERFILTERSTATUS: done: 75, planned: 0, spent: 0 */
         case NS_rtf::LN_RGISTD:
             m_pCurrentDefinition->AddRGISTD( rVal.getString() );
         break;
@@ -707,7 +700,6 @@ void ListsManager::attribute( Id nName, Value& rVal )
                 pProperties->resolve(*this);
         }
         break;
-        /* WRITERFILTERSTATUS: done: 100, planned: 0, spent: 0 */
         case NS_ooxml::LN_CT_AbstractNum_abstractNumId:
         {   
             // This one corresponds to the AbstractNum Id definition
@@ -717,17 +709,14 @@ void ListsManager::attribute( Id nName, Value& rVal )
         }
         break;
         case NS_ooxml::LN_CT_Ind_left:
-            /* WRITERFILTERSTATUS: done: 100, planned: 0.5, spent: 0 */
             pCurrentLvl->Insert(
                 PROP_INDENT_AT, true, uno::makeAny( ConversionHelper::convertTwipToMM100( nIntValue ) ));
             break;
         case NS_ooxml::LN_CT_Ind_hanging:
-            /* WRITERFILTERSTATUS: done: 100, planned: 0.5, spent: 0 */
             pCurrentLvl->Insert(
                 PROP_FIRST_LINE_INDENT, true, uno::makeAny( - ConversionHelper::convertTwipToMM100( nIntValue ) ));
         break;
         case NS_ooxml::LN_CT_Ind_firstLine:
-            /* WRITERFILTERSTATUS: done: 100, planned: 0.5, spent: 0 */
             pCurrentLvl->Insert(
                 PROP_FIRST_LINE_INDENT, true, uno::makeAny( ConversionHelper::convertTwipToMM100( nIntValue ) ));
         break;
@@ -759,13 +748,13 @@ void ListsManager::attribute( Id nName, Value& rVal )
             sMessage += ::rtl::OString::valueOf( sal_Int32( nIntValue ), 10 );
             sMessage += ::rtl::OString(" / 0x");
             sMessage += ::rtl::OString::valueOf( sal_Int32( nIntValue ), 16 );
-            OSL_ENSURE( false, sMessage.getStr()); //
+            OSL_FAIL( sMessage.getStr()); //
 #endif
         }
     }
 }
 
-void ListsManager::sprm( Sprm& rSprm )
+void ListsManager::lcl_sprm( Sprm& rSprm )
 {
     //fill the attributes of the style sheet
     sal_uInt32 nSprmId = rSprm.getId();
@@ -774,10 +763,8 @@ void ListsManager::sprm( Sprm& rSprm )
         nSprmId == NS_ooxml::LN_CT_Numbering_num )
     {
         sal_Int32 nIntValue = rSprm.getValue()->getInt();
-        /* WRITERFILTERSTATUS: table: ListTable_sprm */
         switch( nSprmId )
         {
-            /* WRITERFILTERSTATUS: done: 100, planned: 0, spent: 0 */
             case NS_ooxml::LN_CT_Numbering_abstractNum:
             {
                 writerfilter::Reference<Properties>::Pointer_t pProperties = rSprm.getProps();
@@ -793,7 +780,6 @@ void ListsManager::sprm( Sprm& rSprm )
                 }
             }
             break;
-            /* WRITERFILTERSTATUS: done: 50, planned: 0, spent: 0 */
             case NS_ooxml::LN_CT_Numbering_num:
             {
                 writerfilter::Reference<Properties>::Pointer_t pProperties = rSprm.getProps();
@@ -823,14 +809,11 @@ void ListsManager::sprm( Sprm& rSprm )
                 }
             }
             break;
-            /* WRITERFILTERSTATUS: done: 0, planned: 0, spent: 0 */
             case NS_ooxml::LN_CT_AbstractNum_multiLevelType:
             break;
-            /* WRITERFILTERSTATUS: done: 50, planned: 0, spent: 0 */
             case NS_rtf::LN_TPLC:
                 m_pCurrentDefinition->SetValue( nSprmId, nIntValue );
             break;
-            /* WRITERFILTERSTATUS: done: 100, planned: 0, spent: 0 */
             case NS_ooxml::LN_CT_AbstractNum_lvl:
             {
                 m_pCurrentDefinition->AddLevel();
@@ -839,27 +822,17 @@ void ListsManager::sprm( Sprm& rSprm )
                     pProperties->resolve(*this);
                 }
             break;
-            /* WRITERFILTERSTATUS: done: 0, planned: 0, spent: 0 */
             case NS_rtf::LN_RGBXCHNUMS: break;
-            /* WRITERFILTERSTATUS: done: 75, planned: 0, spent: 0 */
             case NS_rtf::LN_ISTARTAT:
-            /* WRITERFILTERSTATUS: done: 75, planned: 0, spent: 0 */
             case NS_rtf::LN_NFC:
-            /* WRITERFILTERSTATUS: done: 75, planned: 0, spent: 0 */
             case NS_rtf::LN_JC:
-            /* WRITERFILTERSTATUS: done: 75, planned: 0, spent: 0 */
             case NS_rtf::LN_FLEGAL:
-            /* WRITERFILTERSTATUS: done: 75, planned: 0, spent: 0 */
             case NS_rtf::LN_FNORESTART:
-            /* WRITERFILTERSTATUS: done: 75, planned: 0, spent: 0 */
             case NS_rtf::LN_FIDENTSAV:
-            /* WRITERFILTERSTATUS: done: 75, planned: 0, spent: 0 */
             case NS_rtf::LN_FCONVERTED:
 #if 0
-            /* WRITERFILTERSTATUS: done: 75, planned: 0, spent: 0 */
             case NS_rtf::LN_FWORD6:
 #endif
-            /* WRITERFILTERSTATUS: done: 75, planned: 0, spent: 0 */
             case NS_rtf::LN_IXCHFOLLOW:
                 m_pCurrentDefinition->GetCurrentLevel( )->SetValue( nSprmId, nIntValue );
             break;
@@ -940,8 +913,8 @@ void ListsManager::sprm( Sprm& rSprm )
     }
 }
 
-void ListsManager::entry( int /* pos */, 
-        writerfilter::Reference<Properties>::Pointer_t ref )
+void ListsManager::lcl_entry( int /* pos */, 
+                          writerfilter::Reference<Properties>::Pointer_t ref )
 {
     if( m_rDMapper.IsOOXMLImport() )
     {
@@ -1009,7 +982,7 @@ void ListsManager::CreateNumberingRules( )
 {
     // Loop over the definitions
     std::vector< ListDef::Pointer >::iterator listIt = m_aLists.begin( );
-    for ( ; listIt != m_aLists.end( ); listIt++ )
+    for ( ; listIt != m_aLists.end( ); ++listIt )
     {
         (*listIt)->CreateNumberingRules( m_rDMapper, m_xFactory );
     }
