@@ -64,7 +64,7 @@
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/drawing/XCustomShapeEngine.hpp>
 
-#include "xmlnmspe.hxx"
+#include "xmloff/xmlnmspe.hxx"
 
 using ::rtl::OUString;
 using ::rtl::OUStringBuffer;
@@ -81,7 +81,7 @@ XMLShapeExport::XMLShapeExport(SvXMLExport& rExp,
     maShapesInfos(),
     maCurrentShapesIter(maShapesInfos.end()),
     mbExportLayer( sal_False ),
-    // #88546# init to FALSE
+    // #88546# init to sal_False
     mbHandleProgressBar( sal_False ),
     msZIndex( RTL_CONSTASCII_USTRINGPARAM("ZOrder") ),
     msPrintable( RTL_CONSTASCII_USTRINGPARAM("Printable") ),
@@ -164,19 +164,15 @@ uno::Reference< drawing::XShape > XMLShapeExport::checkForCustomShapeReplacement
                     aEngine = OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.drawing.EnhancedCustomShapeEngine" ) );
 
                 uno::Reference< lang::XMultiServiceFactory > xFactory( ::comphelper::getProcessServiceFactory() );
-        /*
-                uno::Reference< drawing::XShape > aXShape = GetXShapeForSdrObject( (SdrObjCustomShape*)pCustomShape );
-                if ( !aXShape.is() )
-                    aXShape = new SvxCustomShape( (SdrObjCustomShape*)pCustomShape );
-        */
+
                 if ( aEngine.getLength() && xFactory.is() )
                 {
                     uno::Sequence< uno::Any > aArgument( 1 );
                     uno::Sequence< beans::PropertyValue > aPropValues( 2 );
-                    aPropValues[ 0 ].Name = rtl::OUString::createFromAscii( "CustomShape" );
+                    aPropValues[ 0 ].Name = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "CustomShape" ));
                     aPropValues[ 0 ].Value <<= xShape;
                     sal_Bool bForceGroupWithText = sal_True;
-                    aPropValues[ 1 ].Name = rtl::OUString::createFromAscii( "ForceGroupWithText" );
+                    aPropValues[ 1 ].Name = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "ForceGroupWithText" ));
                     aPropValues[ 1 ].Value <<= bForceGroupWithText;
                     aArgument[ 0 ] <<= aPropValues;
                     uno::Reference< uno::XInterface > xInterface( xFactory->createInstanceWithArguments( aEngine, aArgument ) );
@@ -199,7 +195,7 @@ void XMLShapeExport::collectShapeAutoStyles(const uno::Reference< drawing::XShap
 {
     if( maCurrentShapesIter == maShapesInfos.end() )
     {
-        DBG_ERROR( "XMLShapeExport::collectShapeAutoStyles(): no call to seekShapes()!" );
+        OSL_FAIL( "XMLShapeExport::collectShapeAutoStyles(): no call to seekShapes()!" );
         return;
     }
     sal_Int32 nZIndex = 0;
@@ -211,7 +207,7 @@ void XMLShapeExport::collectShapeAutoStyles(const uno::Reference< drawing::XShap
 
     if( (sal_Int32)aShapeInfoVector.size() <= nZIndex )
     {
-        DBG_ERROR( "XMLShapeExport::collectShapeAutoStyles(): no shape info allocated for a given shape" );
+        OSL_FAIL( "XMLShapeExport::collectShapeAutoStyles(): no shape info allocated for a given shape" );
         return;
     }
 
@@ -227,7 +223,6 @@ void XMLShapeExport::collectShapeAutoStyles(const uno::Reference< drawing::XShap
     ImpCalcShapeType(xShape, aShapeInfo.meShapeType);
 
     const bool bObjSupportsText =
-//		aShapeInfo.meShapeType != XmlShapeTypeDrawControlShape &&
         aShapeInfo.meShapeType != XmlShapeTypeDrawChartShape &&
         aShapeInfo.meShapeType != XmlShapeTypePresChartShape &&
         aShapeInfo.meShapeType != XmlShapeTypeDrawOLE2Shape &&
@@ -360,7 +355,7 @@ void XMLShapeExport::collectShapeAutoStyles(const uno::Reference< drawing::XShap
             {
                 if( aIter->mnIndex != -1 )
                     nCount++;
-                aIter++;
+                ++aIter;
             }
         }
 
@@ -402,7 +397,6 @@ void XMLShapeExport::collectShapeAutoStyles(const uno::Reference< drawing::XShap
                     // * defaults for style properties are not written, but we need to write the "left",
                     //   because we need to distiguish this "left" from the case where not align attribute
                     //   is present which means "void"
-                    // 102407 - 2002-11-01 - fs@openoffice.org
                     static const ::rtl::OUString s_sParaAdjustPropertyName( RTL_CONSTASCII_USTRINGPARAM( "ParaAdjust" ) );
                     if  (   xPropSetInfo->hasPropertyByName( s_sParaAdjustPropertyName )
                         &&  ( beans::PropertyState_DEFAULT_VALUE == xPropState->getPropertyState( s_sParaAdjustPropertyName ) )
@@ -429,7 +423,7 @@ void XMLShapeExport::collectShapeAutoStyles(const uno::Reference< drawing::XShap
             {
                 if( aIter->mnIndex != -1 )
                     nCount++;
-                aIter++;
+                ++aIter;
             }
 
             if( nCount )
@@ -479,7 +473,7 @@ void XMLShapeExport::collectShapeAutoStyles(const uno::Reference< drawing::XShap
             }
             catch( uno::Exception& )
             {
-                DBG_ERROR( "XMLShapeExport::collectShapeAutoStyles(): exception caught while collection auto styles for a table!" );
+                OSL_FAIL( "XMLShapeExport::collectShapeAutoStyles(): exception caught while collection auto styles for a table!" );
             }
             break;
         }
@@ -507,7 +501,6 @@ void XMLShapeExport::collectShapeAutoStyles(const uno::Reference< drawing::XShap
 
 ///////////////////////////////////////////////////////////////////////
 
-// --> OD 2008-05-08 #refactorlists#
 namespace
 {
     class NewTextListsHelper
@@ -536,7 +529,7 @@ void XMLShapeExport::exportShape(const uno::Reference< drawing::XShape >& xShape
 {
     if( maCurrentShapesIter == maShapesInfos.end() )
     {
-        DBG_ERROR( "XMLShapeExport::exportShape(): no auto styles where collected before export" );
+        OSL_FAIL( "XMLShapeExport::exportShape(): no auto styles where collected before export" );
         return;
     }
     sal_Int32 nZIndex = 0;
@@ -569,7 +562,7 @@ void XMLShapeExport::exportShape(const uno::Reference< drawing::XShape >& xShape
     }
     catch( uno::Exception& )
     {
-        DBG_ERROR("XMLShapeExport::exportShape(): exception during hyperlink export");
+        OSL_FAIL("XMLShapeExport::exportShape(): exception during hyperlink export");
     }
 
 
@@ -580,13 +573,11 @@ void XMLShapeExport::exportShape(const uno::Reference< drawing::XShape >& xShape
 
     if( (sal_Int32)aShapeInfoVector.size() <= nZIndex )
     {
-        DBG_ERROR( "XMLShapeExport::exportShape(): no shape info collected for a given shape" );
+        OSL_FAIL( "XMLShapeExport::exportShape(): no shape info collected for a given shape" );
         return;
     }
 
-    // --> OD 2008-05-08 #refactorlists#
     NewTextListsHelper aNewTextListsHelper( mrExport );
-    // <--
 
     const ImplXMLShapeExportInfo& aShapeInfo = aShapeInfoVector[nZIndex];
 
@@ -619,16 +610,13 @@ void XMLShapeExport::exportShape(const uno::Reference< drawing::XShape >& xShape
     if( mxAnimationsExporter.is() )
         mxAnimationsExporter->collect( xShape, mrExport );
 
-    // -------------------------------
-    // export shapes name if he has one
-    // --> OD 2006-03-13 #i51726#
-    // Export of the shape name for text documents only if the OpenDocument
-    // file format is written - exceptions are group shapes.
-    // Note: Writer documents in OpenOffice.org file format doesn't contain
-    //       any names for shapes, except for group shapes.
-    // -------------------------------
+    /* Export shapes name if he has one (#i51726#)
+       Export of the shape name for text documents only if the OpenDocument
+       file format is written - exceptions are group shapes.
+       Note: Writer documents in OpenOffice.org file format doesn't contain
+             any names for shapes, except for group shapes.
+    */
     {
-        // --> OD 2006-03-10 #i51726#
         if ( ( GetExport().GetModelType() != SvtModuleOptions::E_WRITER &&
                GetExport().GetModelType() != SvtModuleOptions::E_WRITERWEB &&
                GetExport().GetModelType() != SvtModuleOptions::E_WRITERGLOBAL ) ||
@@ -645,7 +633,6 @@ void XMLShapeExport::exportShape(const uno::Reference< drawing::XShape >& xShape
                     mrExport.AddAttribute(XML_NAMESPACE_DRAW, XML_NAME, aName );
             }
         }
-        // <--
     }
 
     // ------------------
@@ -692,13 +679,13 @@ void XMLShapeExport::exportShape(const uno::Reference< drawing::XShape >& xShape
             {
                 uno::Reference< beans::XPropertySet > xProps( xShape, uno::UNO_QUERY );
                 OUString aLayerName;
-                xProps->getPropertyValue( OUString::createFromAscii( "LayerName" ) ) >>= aLayerName;
+                xProps->getPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM( "LayerName" )) ) >>= aLayerName;
                 mrExport.AddAttribute(XML_NAMESPACE_DRAW, XML_LAYER, aLayerName );
 
             }
             catch( uno::Exception e )
             {
-                DBG_ERROR( "could not export layer name for shape!" );
+                OSL_FAIL( "could not export layer name for shape!" );
             }
         }
     }
@@ -707,7 +694,7 @@ void XMLShapeExport::exportShape(const uno::Reference< drawing::XShape >& xShape
     if( xSet.is() && ( mrExport.getDefaultVersion() > SvtSaveOptions::ODFVER_012 ) )
     {
         if( aShapeInfo.meShapeType != XmlShapeTypeDrawPageShape && aShapeInfo.meShapeType != XmlShapeTypePresPageShape &&
-            aShapeInfo.meShapeType != XmlShapeTypeHandoutShape )
+            aShapeInfo.meShapeType != XmlShapeTypeHandoutShape && aShapeInfo.meShapeType != XmlShapeTypeDrawChartShape )
             
         try
         {
@@ -732,7 +719,7 @@ void XMLShapeExport::exportShape(const uno::Reference< drawing::XShape >& xShape
         }
         catch( uno::Exception& )
         {
-            DBG_ERROR( "XMLShapeExport::exportShape(), exception caught!" );
+            OSL_FAIL( "XMLShapeExport::exportShape(), exception caught!" );
         }
     }
 
@@ -912,7 +899,7 @@ void XMLShapeExport::exportShape(const uno::Reference< drawing::XShape >& xShape
         default:
         {
             // this should never happen and is an error
-            DBG_ERROR("XMLEXP: WriteShape: unknown or unexpected type of shape in export!");
+            OSL_FAIL("XMLEXP: WriteShape: unknown or unexpected type of shape in export!");
             break;
         }
     }
@@ -1009,7 +996,6 @@ void XMLShapeExport::exportAutoStyles()
     // export all autostyle infos
 
     // ...for graphic
-//	if(IsFamilyGraphicUsed())
     {
         GetExport().GetAutoStylePool()->exportXML(
             XML_STYLE_FAMILY_SD_GRAPHICS_ID
@@ -1020,7 +1006,6 @@ void XMLShapeExport::exportAutoStyles()
     }
 
     // ...for presentation
-//	if(IsFamilyPresentationUsed())
     {
         GetExport().GetAutoStylePool()->exportXML(
             XML_STYLE_FAMILY_SD_PRESENTATION_ID
@@ -1173,7 +1158,7 @@ void XMLShapeExport::ImpCalcShapeType(const uno::Reference< drawing::XShape >& x
                     }
                     catch( uno::Exception& )
                     {
-                        DBG_ERROR( "XMLShapeExport::ImpCalcShapeType(), expected ole shape to have the CLSID property?" );
+                        OSL_FAIL( "XMLShapeExport::ImpCalcShapeType(), expected ole shape to have the CLSID property?" );
                     }
                 }
                 else if(aType.EqualsAscii("Chart", 26, 5)) { eShapeType = XmlShapeTypePresChartShape;  }
@@ -1272,7 +1257,7 @@ void XMLShapeExport::ExportGraphicDefaults()
                 aStEx.exportDefaultStyle( xDefaults, OUString(RTL_CONSTASCII_USTRINGPARAM(XML_STYLE_FAMILY_SD_GRAPHICS_NAME)), xPropertySetMapper );
 
                 // write graphic family styles
-                aStEx.exportStyleFamily("graphics", OUString(RTL_CONSTASCII_USTRINGPARAM(XML_STYLE_FAMILY_SD_GRAPHICS_NAME)), xPropertySetMapper, FALSE, XML_STYLE_FAMILY_SD_GRAPHICS_ID);
+                aStEx.exportStyleFamily("graphics", OUString(RTL_CONSTASCII_USTRINGPARAM(XML_STYLE_FAMILY_SD_GRAPHICS_NAME)), xPropertySetMapper, sal_False, XML_STYLE_FAMILY_SD_GRAPHICS_ID);
             }
         }
         catch( lang::ServiceNotRegisteredException& )
