@@ -35,7 +35,7 @@
 #include <osl/diagnose.h>
 #include <comphelper/extract.hxx>
 #include "callbacks.hxx"
-#include "xmlnmspe.hxx"
+#include "xmloff/xmlnmspe.hxx"
 #include <tools/date.hxx>
 #include <tools/time.hxx>
 #include <tools/datetime.hxx>
@@ -162,7 +162,7 @@ Any PropertyConversion::convertString( SvXMLImport& _rImporter, const ::com::sun
         break;
         case TypeClass_HYPER:
         {
-            OSL_ENSURE(sal_False, "PropertyConversion::convertString: 64-bit integers not implemented yet!");
+            OSL_FAIL("PropertyConversion::convertString: 64-bit integers not implemented yet!");
         }
         break;
         case TypeClass_DOUBLE:
@@ -241,11 +241,11 @@ Any PropertyConversion::convertString( SvXMLImport& _rImporter, const ::com::sun
                 }
             }
             else
-                OSL_ENSURE(sal_False, "PropertyConversion::convertString: unsupported property type!");
+                OSL_FAIL("PropertyConversion::convertString: unsupported property type!");
         }
         break;
         default:
-            OSL_ENSURE(sal_False, "PropertyConversion::convertString: invalid type class!");
+            OSL_FAIL("PropertyConversion::convertString: invalid type class!");
     }
 
     return aReturn;
@@ -296,8 +296,7 @@ SvXMLImportContext* OPropertyImport::CreateChildContext(sal_uInt16 _nPrefix, con
     }
     else
     {
-        OSL_ENSURE(sal_False,
-                ::rtl::OString("OPropertyImport::CreateChildContext: unknown sub element (only \"properties\" is recognized, but it is ")
+        OSL_FAIL(::rtl::OString("OPropertyImport::CreateChildContext: unknown sub element (only \"properties\" is recognized, but it is ")
             +=	::rtl::OString(_rLocalName.getStr(), _rLocalName.getLength(), RTL_TEXTENCODING_ASCII_US)
             +=	::rtl::OString(")!"));
         return SvXMLImportContext::CreateChildContext(_nPrefix, _rLocalName, _rxAttrList);
@@ -350,7 +349,7 @@ _rChars
 }
 
 //---------------------------------------------------------------------
-void OPropertyImport::handleAttribute(sal_uInt16 /*_nNamespaceKey*/, const ::rtl::OUString& _rLocalName, const ::rtl::OUString& _rValue)
+bool OPropertyImport::handleAttribute(sal_uInt16 /*_nNamespaceKey*/, const ::rtl::OUString& _rLocalName, const ::rtl::OUString& _rValue)
 {
     const OAttribute2Property::AttributeAssignment* pProperty = m_rContext.getAttributeMap().getAttributeTranslation(_rLocalName);
     if (pProperty)
@@ -362,18 +361,21 @@ void OPropertyImport::handleAttribute(sal_uInt16 /*_nNamespaceKey*/, const ::rtl
         // convert the value string into the target type
         aNewValue.Value = PropertyConversion::convertString(m_rContext.getGlobalContext(), pProperty->aPropertyType, _rValue, pProperty->pEnumMap, pProperty->bInverseSemantics);
         implPushBackPropertyValue( aNewValue );
+        return true;
     }
-#if OSL_DEBUG_LEVEL > 0
-    else if (!token::IsXMLToken(_rLocalName, token::XML_TYPE))  // xlink:type is valid but ignored for <form:form>
+    if (!token::IsXMLToken(_rLocalName, token::XML_TYPE))  // xlink:type is valid but ignored for <form:form>
     {
+#if OSL_DEBUG_LEVEL > 0
         ::rtl::OString sMessage( "OPropertyImport::handleAttribute: Can't handle the following:\n" );
         sMessage += ::rtl::OString( "  Attribute name: " );
         sMessage += ::rtl::OString( _rLocalName.getStr(), _rLocalName.getLength(), osl_getThreadTextEncoding() );
         sMessage += ::rtl::OString( "\n  value: " );
         sMessage += ::rtl::OString( _rValue.getStr(), _rValue.getLength(), osl_getThreadTextEncoding() );
-        OSL_ENSURE( sal_False, sMessage.getStr() );
-    }
+        OSL_FAIL( sMessage.getStr() );
 #endif
+        return false;
+    }
+    return true;
 }
 
 //=====================================================================
@@ -401,8 +403,7 @@ SvXMLImportContext* OPropertyElementsContext::CreateChildContext(sal_uInt16 _nPr
     }
     else
     {
-        OSL_ENSURE(sal_False,
-                ::rtl::OString("OPropertyElementsContext::CreateChildContext: unknown child element (\"")
+        OSL_FAIL(::rtl::OString("OPropertyElementsContext::CreateChildContext: unknown child element (\"")
             +=	::rtl::OString(_rLocalName.getStr(), _rLocalName.getLength(), RTL_TEXTENCODING_ASCII_US)
             +=	::rtl::OString("\")!"));
         return new SvXMLImportContext(GetImport(), _nPrefix, _rLocalName);
@@ -441,8 +442,7 @@ OSinglePropertyContext::OSinglePropertyContext(SvXMLImport& _rImport, sal_uInt16
 SvXMLImportContext* OSinglePropertyContext::CreateChildContext(sal_uInt16 _nPrefix, const ::rtl::OUString& _rLocalName,
         const Reference< sax::XAttributeList >&)
 {
-    OSL_ENSURE(sal_False,
-            ::rtl::OString("OSinglePropertyContext::CreateChildContext: unknown child element (\"")
+    OSL_FAIL(::rtl::OString("OSinglePropertyContext::CreateChildContext: unknown child element (\"")
         +=	::rtl::OString(_rLocalName.getStr(), _rLocalName.getLength(), RTL_TEXTENCODING_ASCII_US)
         +=	::rtl::OString("\")!"));
     return new SvXMLImportContext(GetImport(), _nPrefix, _rLocalName);
@@ -460,7 +460,6 @@ void OSinglePropertyContext::StartElement(const Reference< sax::XAttributeList >
     for( sal_Int16 i=0; i < nAttrCount; i++ )
     {
         const ::rtl::OUString& rAttrName = _rxAttrList->getNameByIndex( i );
-        //const ::rtl::OUString& rValue = _rxAttrList->getValueByIndex( i );
 
         ::rtl::OUString aLocalName;
         sal_uInt16 nPrefix =
@@ -543,8 +542,7 @@ void OListPropertyContext::StartElement( const Reference< sax::XAttributeList >&
         }
         else
         {
-            OSL_ENSURE( false,
-                    ::rtl::OString( "OListPropertyContext::StartElement: unknown child element (\"")
+            OSL_FAIL( ::rtl::OString( "OListPropertyContext::StartElement: unknown child element (\"")
                 +=	::rtl::OString( sAttributeName.getStr(), sAttributeName.getLength(), RTL_TEXTENCODING_ASCII_US )
                 +=	::rtl::OString( "\")!" ) );
         }
@@ -588,8 +586,7 @@ SvXMLImportContext* OListPropertyContext::CreateChildContext( sal_uInt16 _nPrefi
     }
     else
     {
-        OSL_ENSURE( sal_False,
-                ::rtl::OString("OListPropertyContext::CreateChildContext: unknown child element (\"")
+        OSL_FAIL( ::rtl::OString("OListPropertyContext::CreateChildContext: unknown child element (\"")
             +=	::rtl::OString(_rLocalName.getStr(), _rLocalName.getLength(), RTL_TEXTENCODING_ASCII_US)
             +=	::rtl::OString("\")!"));
         return new SvXMLImportContext( GetImport(), _nPrefix, _rLocalName );
@@ -629,8 +626,7 @@ void OListValueContext::StartElement( const Reference< sax::XAttributeList >& _r
             }
         }
 
-        OSL_ENSURE( false,
-                ::rtl::OString( "OListValueContext::StartElement: unknown child element (\"")
+        OSL_FAIL( ::rtl::OString( "OListValueContext::StartElement: unknown child element (\"")
             +=	::rtl::OString( sAttributeName.getStr(), sAttributeName.getLength(), RTL_TEXTENCODING_ASCII_US )
             +=	::rtl::OString( "\")!" ) );
     }
