@@ -41,10 +41,10 @@
 #include <xmloff/xmlimppr.hxx>
 #include <xmloff/xmlimp.hxx>
 
-#include "unoatrcn.hxx"
-#include "xmlnmspe.hxx"
+#include "xmloff/unoatrcn.hxx"
+#include "xmloff/xmlnmspe.hxx"
 #include <xmloff/xmltoken.hxx>
-#include "xmlerror.hxx"
+#include "xmloff/xmlerror.hxx"
 #include <tools/debug.hxx>
 
 #include "xmloff/contextid.hxx"
@@ -137,7 +137,7 @@ void SvXMLImportPropertyMapper::importXML(
         sal_Int32 nStartIdx,
         sal_Int32 nEndIdx ) const
 {
-    INT16 nAttr = xAttrList->getLength();
+    sal_Int16 nAttr = xAttrList->getLength();
 
     Reference< XNameContainer > xAttrContainer;
 
@@ -145,11 +145,11 @@ void SvXMLImportPropertyMapper::importXML(
         nStartIdx = 0;
     if( -1 == nEndIdx )
         nEndIdx = maPropMapper->GetEntryCount();
-    for( INT16 i=0; i < nAttr; i++ )
+    for( sal_Int16 i=0; i < nAttr; i++ )
     {
         const OUString& rAttrName = xAttrList->getNameByIndex( i );
         OUString aLocalName, aPrefix, aNamespace;
-        USHORT nPrefix = rNamespaceMap.GetKeyByAttrName( rAttrName, &aPrefix,
+        sal_uInt16 nPrefix = rNamespaceMap.GetKeyByAttrName( rAttrName, &aPrefix,
                                                     &aLocalName, &aNamespace );
 
         if( XML_NAMESPACE_XMLNS == nPrefix )
@@ -344,16 +344,6 @@ void SvXMLImportPropertyMapper::importXML(
     }
 
     finished( rProperties, nStartIdx, nEndIdx );
-
-    // Have to do if we change from a vector to a list or something like that
-    /*std::vector <XMLPropertyState>::iterator aItr = rProperties.begin();
-    while (aItr != rProperties.end())
-    {
-        if (aItr->mnIndex == -1)
-            aItr = rProperties.erase(aItr);
-        else
-            aItr++;
-    }*/
 }
 
 /** this method is called for every item that has the MID_FLAG_SPECIAL_ITEM_IMPORT flag set */
@@ -369,7 +359,7 @@ bool SvXMLImportPropertyMapper::handleSpecialItem(
         return mxNextMapper->handleSpecialItem( rProperty, rProperties, rValue,
                                                rUnitConverter, rNamespaceMap );
     else
-        return FALSE;
+        return sal_False;
 }
 
 void SvXMLImportPropertyMapper::FillPropertySequence(
