@@ -44,13 +44,10 @@
 #include <com/sun/star/lang/Locale.hpp>
 #include <rtl/ustrbuf.hxx>
 
-// #110680#
-//#include <comphelper/processfactory.hxx>
-
 #include <com/sun/star/i18n/NativeNumberXmlAttributes.hpp>
 
 #include <xmloff/xmlnumfe.hxx>
-#include "xmlnmspe.hxx"
+#include "xmloff/xmlnmspe.hxx"
 #include <xmloff/xmluconv.hxx>
 #include <xmloff/attrlist.hxx>
 #include <xmloff/nmspmap.hxx>
@@ -74,8 +71,6 @@ using namespace ::svt;
 
 //-------------------------------------------------------------------------
 
-//	4th condition for text formats doesn't work
-//#define XMLNUM_MAX_PARTS	4
 #define XMLNUM_MAX_PARTS	3
 
 //-------------------------------------------------------------------------
@@ -161,25 +156,25 @@ void SvXMLNumUsedList_Impl::SetUsed( sal_uInt32 nKey )
 
 sal_Bool SvXMLNumUsedList_Impl::IsUsed( sal_uInt32 nKey ) const
 {
-    SvXMLuInt32Set::iterator aItr = aUsed.find(nKey);
+    SvXMLuInt32Set::const_iterator aItr = aUsed.find(nKey);
     return (aItr != aUsed.end());
 }
 
 sal_Bool SvXMLNumUsedList_Impl::IsWasUsed( sal_uInt32 nKey ) const
 {
-    SvXMLuInt32Set::iterator aItr = aWasUsed.find(nKey);
+    SvXMLuInt32Set::const_iterator aItr = aWasUsed.find(nKey);
     return (aItr != aWasUsed.end());
 }
 
 void SvXMLNumUsedList_Impl::Export()
 {
-    SvXMLuInt32Set::iterator aItr = aUsed.begin();
+    SvXMLuInt32Set::const_iterator aItr = aUsed.begin();
     while (aItr != aUsed.end())
     {
-        std::pair<SvXMLuInt32Set::iterator, bool> aPair = aWasUsed.insert( *aItr );
+        std::pair<SvXMLuInt32Set::const_iterator, bool> aPair = aWasUsed.insert( *aItr );
         if (aPair.second)
             nWasUsedCount++;
-        aItr++;
+        ++aItr;
     }
     aUsed.clear();
     nUsedCount = 0;
@@ -203,7 +198,7 @@ sal_Bool SvXMLNumUsedList_Impl::GetNextUsed(sal_uInt32& nKey)
     sal_Bool bRet(sal_False);
     if (aCurrentUsedPos != aUsed.end())
     {
-        aCurrentUsedPos++;
+        ++aCurrentUsedPos;
         if (aCurrentUsedPos != aUsed.end())
         {
             nKey = *aCurrentUsedPos;
@@ -219,12 +214,12 @@ void SvXMLNumUsedList_Impl::GetWasUsed(uno::Sequence<sal_Int32>& rWasUsed)
     sal_Int32* pWasUsed = rWasUsed.getArray();
     if (pWasUsed)
     {
-        SvXMLuInt32Set::iterator aItr = aWasUsed.begin();
+        SvXMLuInt32Set::const_iterator aItr = aWasUsed.begin();
         while (aItr != aWasUsed.end())
         {
             *pWasUsed = *aItr;
-            aItr++;
-            pWasUsed++;
+            ++aItr;
+            ++pWasUsed;
         }
     }
 }
@@ -236,7 +231,7 @@ void SvXMLNumUsedList_Impl::SetWasUsed(const uno::Sequence<sal_Int32>& rWasUsed)
     const sal_Int32* pWasUsed = rWasUsed.getConstArray();
     for (sal_uInt16 i = 0; i < nCount; i++, pWasUsed++)
     {
-        std::pair<SvXMLuInt32Set::iterator, bool> aPair = aWasUsed.insert( *pWasUsed );
+        std::pair<SvXMLuInt32Set::const_iterator, bool> aPair = aWasUsed.insert( *pWasUsed );
         if (aPair.second)
             nWasUsedCount++;
     }
@@ -248,7 +243,7 @@ SvXMLNumFmtExport::SvXMLNumFmtExport(
             SvXMLExport& rExp,
             const uno::Reference< util::XNumberFormatsSupplier >& rSupp ) :
     rExport( rExp ),
-    sPrefix( OUString::createFromAscii( "N" ) ),
+    sPrefix( OUString(RTL_CONSTASCII_USTRINGPARAM("N")) ),
     pFormatter( NULL ),
     pCharClass( NULL ),
     pLocaleData( NULL )
@@ -270,9 +265,6 @@ SvXMLNumFmtExport::SvXMLNumFmtExport(
     {
         lang::Locale aLocale( MsLangId::convertLanguageToLocale( MsLangId::getSystemLanguage() ) );
 
-        // #110680#
-        // pCharClass = new CharClass( ::comphelper::getProcessServiceFactory(), aLocale );
-        // pLocaleData = new LocaleDataWrapper( ::comphelper::getProcessServiceFactory(), aLocale );
         pCharClass = new CharClass( rExport.getServiceFactory(), aLocale );
         pLocaleData = new LocaleDataWrapper( rExport.getServiceFactory(), aLocale );
     }
@@ -308,9 +300,6 @@ SvXMLNumFmtExport::SvXMLNumFmtExport(
     {
         lang::Locale aLocale( MsLangId::convertLanguageToLocale( MsLangId::getSystemLanguage() ) );
 
-        // #110680#
-        // pCharClass = new CharClass( ::comphelper::getProcessServiceFactory(), aLocale );
-        // pLocaleData = new LocaleDataWrapper( ::comphelper::getProcessServiceFactory(), aLocale );
         pCharClass = new CharClass( rExport.getServiceFactory(), aLocale );
         pLocaleData = new LocaleDataWrapper( rExport.getServiceFactory(), aLocale );
     }
@@ -754,7 +743,7 @@ void SvXMLNumFmtExport::WriteMapElement_Impl( sal_Int32 nOp, double fLimit,
             case NUMBERFORMAT_OP_GT: aCondStr.append( (sal_Unicode) '>' );	break;
             case NUMBERFORMAT_OP_GE: aCondStr.appendAscii( ">=" );			break;
             default:
-                DBG_ERROR("unknown operator");
+                OSL_FAIL("unknown operator");
         }
         ::rtl::math::doubleToUStringBuffer( aCondStr, fLimit,
                 rtl_math_StringFormat_Automatic, rtl_math_DecimalPlaces_Max,
@@ -811,13 +800,10 @@ xub_StrLen lcl_FindSymbol( const String& sUpperStr, const String& sCurString )
 sal_Bool SvXMLNumFmtExport::WriteTextWithCurrency_Impl( const OUString& rString,
                             const ::com::sun::star::lang::Locale& rLocale )
 {
-    //	returns TRUE if currency element was written
+    //	returns sal_True if currency element was written
 
     sal_Bool bRet = sal_False;
 
-//	pLocaleData->setLocale( rLocale );
-//	String sCurString = pLocaleData->getCurrSymbol();
-
     LanguageType nLang = MsLangId::convertLocaleToLanguage( rLocale );
     pFormatter->ChangeIntl( nLang );
     String sCurString, sDummy;
@@ -848,7 +834,7 @@ sal_Bool SvXMLNumFmtExport::WriteTextWithCurrency_Impl( const OUString& rString,
     else
         AddToTextElement_Impl( rString );		// simple text
 
-    return bRet;		// TRUE: currency element written
+    return bRet;		// sal_True: currency element written
 }
 
 //-------------------------------------------------------------------------
@@ -890,7 +876,7 @@ sal_Bool lcl_IsInEmbedded( const SvXMLEmbeddedTextEntryArr& rEmbeddedEntries, sa
     return sal_False;		// not found
 }
 
-BOOL lcl_IsDefaultDateFormat( const SvNumberformat& rFormat, sal_Bool bSystemDate, NfIndexTableOffset eBuiltIn )
+sal_Bool lcl_IsDefaultDateFormat( const SvNumberformat& rFormat, sal_Bool bSystemDate, NfIndexTableOffset eBuiltIn )
 {
     //	make an extra loop to collect date elements, to check if it is a default format
     //	before adding the automatic-order attribute
@@ -951,7 +937,7 @@ BOOL lcl_IsDefaultDateFormat( const SvNumberformat& rFormat, sal_Bool bSystemDat
     }
 
     if ( bDateNoDefault )
-        return FALSE;						// additional elements
+        return sal_False;						// additional elements
     else
     {
         NfIndexTableOffset eFound = (NfIndexTableOffset) SvXMLNumFmtDefaults::GetDefaultDateFormat(
@@ -977,7 +963,7 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
     NfIndexTableOffset eBuiltIn = pFormatter->GetIndexTableOffset( nKey );
 
     short nFmtType = 0;
-    BOOL bThousand = sal_False;
+    sal_Bool bThousand = sal_False;
     sal_uInt16 nPrecision = 0;
     sal_uInt16 nLeading = 0;
     rFormat.GetNumForInfo( nPart, nFmtType, bThousand, nPrecision, nLeading);
@@ -1060,7 +1046,7 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
 
     //	automatic ordering for currency and date formats
     //	only used for some built-in formats
-    BOOL bAutoOrder = ( eBuiltIn == NF_CURRENCY_1000INT     || eBuiltIn == NF_CURRENCY_1000DEC2 ||
+    sal_Bool bAutoOrder = ( eBuiltIn == NF_CURRENCY_1000INT     || eBuiltIn == NF_CURRENCY_1000DEC2 ||
                         eBuiltIn == NF_CURRENCY_1000INT_RED || eBuiltIn == NF_CURRENCY_1000DEC2_RED ||
                         eBuiltIn == NF_CURRENCY_1000DEC2_DASHED ||
                         eBuiltIn == NF_DATE_SYSTEM_SHORT	|| eBuiltIn == NF_DATE_SYSTEM_LONG ||
@@ -1073,16 +1059,16 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
 
     //	format source (for date and time formats)
     //	only used for some built-in formats
-    BOOL bSystemDate = ( eBuiltIn == NF_DATE_SYSTEM_SHORT ||
+    sal_Bool bSystemDate = ( eBuiltIn == NF_DATE_SYSTEM_SHORT ||
                          eBuiltIn == NF_DATE_SYSTEM_LONG  ||
                          eBuiltIn == NF_DATETIME_SYSTEM_SHORT_HHMM );
-    BOOL bLongSysDate = ( eBuiltIn == NF_DATE_SYSTEM_LONG );
+    sal_Bool bLongSysDate = ( eBuiltIn == NF_DATE_SYSTEM_LONG );
 
     // check if the format definition matches the key
     if ( bAutoOrder && ( nFmtType == NUMBERFORMAT_DATE || nFmtType == NUMBERFORMAT_DATETIME ) &&
             !lcl_IsDefaultDateFormat( rFormat, bSystemDate, eBuiltIn ) )
     {
-        bAutoOrder = bSystemDate = bLongSysDate = FALSE;		// don't write automatic-order attribute then
+        bAutoOrder = bSystemDate = bLongSysDate = sal_False;		// don't write automatic-order attribute then
     }
 
     if ( bAutoOrder &&
@@ -1197,7 +1183,7 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
                     if ( bExpFound && pElemStr )
                         nExpDigits += pElemStr->Len();
                     else if ( !bDecDashes && pElemStr && pElemStr->GetChar(0) == '-' )
-                        bDecDashes = TRUE;
+                        bDecDashes = sal_True;
                     else if ( !bVarDecimals && !bInInteger && pElemStr && pElemStr->GetChar(0) == '#' )
                     {
                         //	If the decimal digits string starts with a '#', variable
@@ -1220,7 +1206,7 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
                     bInInteger = sal_False;
                     break;
                 case NF_SYMBOLTYPE_CURRENCY:
-                    bCurrFound = TRUE;
+                    bCurrFound = sal_True;
                     break;
                 case NF_SYMBOLTYPE_CURREXT:
                     if (pElemStr)
@@ -1746,7 +1732,7 @@ OUString SvXMLNumFmtExport::GetStyleName( sal_uInt32 nKey )
         return lcl_CreateStyleName( nKey, 0, sal_True, sPrefix );
     else
     {
-        DBG_ERROR("There is no written Data-Style");
+        OSL_FAIL("There is no written Data-Style");
         return rtl::OUString();
     }
 }
@@ -1760,7 +1746,7 @@ void SvXMLNumFmtExport::SetUsed( sal_uInt32 nKey )
     if (pFormatter->GetEntry(nKey))
         pUsedList->SetUsed( nKey );
     else {
-        DBG_ERROR("no existing Numberformat found with this key");
+        OSL_FAIL("no existing Numberformat found with this key");
     }
 }
 
