@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -47,6 +47,8 @@
 #include <com/sun/star/awt/PushButtonType.hpp>
 #include <com/sun/star/awt/VisualEffect.hpp>
 
+#include <com/sun/star/io/XPersistObject.hpp>
+
 #include <com/sun/star/script/XScriptEventsSupplier.hpp>
 #include <com/sun/star/script/ScriptEventDescriptor.hpp>
 
@@ -58,6 +60,17 @@
 
 #include <com/sun/star/view/SelectionType.hpp>
 
+#include <com/sun/star/form/binding/XListEntrySink.hpp>
+#include <com/sun/star/form/binding/XBindableValue.hpp>
+#include <com/sun/star/form/binding/XValueBinding.hpp>
+#include <com/sun/star/table/CellAddress.hpp>
+#include <com/sun/star/table/CellRangeAddress.hpp>
+#include <com/sun/star/lang/XServiceInfo.hpp>
+#include <com/sun/star/document/XStorageBasedDocument.hpp>
+#include <com/sun/star/document/XGraphicObjectResolver.hpp>
+
+#include <comphelper/componentcontext.hxx>
+#include <comphelper/processfactory.hxx>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
@@ -147,7 +160,7 @@ Reference< xml::sax::XAttributeList > Style::createElement()
             break;
         }
         default:
-            OSL_ENSURE( 0, "### unexpected border value!" );
+            OSL_FAIL( "### unexpected border value!" );
             break;
         }
     }
@@ -170,7 +183,7 @@ Reference< xml::sax::XAttributeList > Style::createElement()
                                   OUSTR("simple") );
             break;
         default:
-            OSL_ENSURE( 0, "### unexpected visual effect value!" );
+            OSL_FAIL( "### unexpected visual effect value!" );
             break;
         }
     }
@@ -234,7 +247,7 @@ Reference< xml::sax::XAttributeList > Style::createElement()
                                       OUString( RTL_CONSTASCII_USTRINGPARAM("system") ) );
                 break;
             default:
-                OSL_ENSURE( 0, "### unexpected font-family!" );
+                OSL_FAIL( "### unexpected font-family!" );
                 break;
             }
         }
@@ -284,7 +297,7 @@ Reference< xml::sax::XAttributeList > Style::createElement()
                                       OUString( RTL_CONSTASCII_USTRINGPARAM("symbol") ) );
                 break;
             default:
-                OSL_ENSURE( 0, "### unexpected font-charset!" );
+                OSL_FAIL( "### unexpected font-charset!" );
                 break;
             }
         }
@@ -302,7 +315,7 @@ Reference< xml::sax::XAttributeList > Style::createElement()
                                       OUString( RTL_CONSTASCII_USTRINGPARAM("variable") ) );
                 break;
             default:
-                OSL_ENSURE( 0, "### unexpected font-pitch!" );
+                OSL_FAIL( "### unexpected font-pitch!" );
                 break;
             }
         }
@@ -340,7 +353,7 @@ Reference< xml::sax::XAttributeList > Style::createElement()
                                       OUString( RTL_CONSTASCII_USTRINGPARAM("reverse_italic") ) );
                 break;
             default:
-                OSL_ENSURE( 0, "### unexpected font-slant!" );
+                OSL_FAIL( "### unexpected font-slant!" );
                 break;
             }
         }
@@ -418,7 +431,7 @@ Reference< xml::sax::XAttributeList > Style::createElement()
                                       OUString( RTL_CONSTASCII_USTRINGPARAM("boldwave") ) );
                 break;
             default:
-                OSL_ENSURE( 0, "### unexpected font-underline!" );
+                OSL_FAIL( "### unexpected font-underline!" );
                 break;
             }
         }
@@ -448,7 +461,7 @@ Reference< xml::sax::XAttributeList > Style::createElement()
                                       OUString( RTL_CONSTASCII_USTRINGPARAM("x") ) );
                 break;
             default:
-                OSL_ENSURE( 0, "### unexpected font-strikeout!" );
+                OSL_FAIL( "### unexpected font-strikeout!" );
                 break;
             }
         }
@@ -488,7 +501,7 @@ Reference< xml::sax::XAttributeList > Style::createElement()
                                       OUString( RTL_CONSTASCII_USTRINGPARAM("scalable") ) );
                 break;
             default:
-                OSL_ENSURE( 0, "### unexpected font-type!" );
+                OSL_FAIL( "### unexpected font-type!" );
                 break;
             }
         }
@@ -510,7 +523,7 @@ Reference< xml::sax::XAttributeList > Style::createElement()
                 OUString( RTL_CONSTASCII_USTRINGPARAM("engraved") ) );
             break;
         default:
-            OSL_ENSURE( 0, "### unexpected font-relief!" );
+            OSL_FAIL( "### unexpected font-relief!" );
             break;
         }
         // dialog:font-emphasismark (none|dot|circle|disc|accent|above|below) #IMPLIED
@@ -549,7 +562,7 @@ Reference< xml::sax::XAttributeList > Style::createElement()
                 OUString( RTL_CONSTASCII_USTRINGPARAM("below") ) );
             break;
         default:
-            OSL_ENSURE( 0, "### unexpected font-emphasismark!" );
+            OSL_FAIL( "### unexpected font-emphasismark!" );
             break;
         }
     }
@@ -613,7 +626,7 @@ void ElementDescriptor::readStringAttr(
         if (a >>= v)
             addAttribute( rAttrName, v );
         else
-            OSL_ENSURE( 0, "### unexpected property type!" );
+            OSL_FAIL( "### unexpected property type!" );
     }
 }
 
@@ -681,7 +694,7 @@ void ElementDescriptor::readDateFormatAttr( OUString const & rPropName, OUString
                 addAttribute( rAttrName, OUString( RTL_CONSTASCII_USTRINGPARAM("short_YYYYMMDD_DIN5008") ) );
                 break;
             default:
-                OSL_ENSURE( 0, "### unexpected date format!" );
+                OSL_FAIL( "### unexpected date format!" );
                 break;
             }
         }
@@ -716,7 +729,7 @@ void ElementDescriptor::readTimeFormatAttr( OUString const & rPropName, OUString
                 addAttribute( rAttrName, OUString( RTL_CONSTASCII_USTRINGPARAM("Duration_long") ) );
                 break;
             default:
-                OSL_ENSURE( 0, "### unexpected time format!" );
+                OSL_FAIL( "### unexpected time format!" );
                 break;
             }
         }
@@ -742,7 +755,7 @@ void ElementDescriptor::readAlignAttr( OUString const & rPropName, OUString cons
                 addAttribute( rAttrName, OUString( RTL_CONSTASCII_USTRINGPARAM("right") ) );
                 break;
             default:
-                OSL_ENSURE( 0, "### illegal alignment value!" );
+                OSL_FAIL( "### illegal alignment value!" );
                 break;
             }
         }
@@ -770,13 +783,40 @@ void ElementDescriptor::readVerticalAlignAttr( OUString const & rPropName, OUStr
                 addAttribute( rAttrName, OUString( RTL_CONSTASCII_USTRINGPARAM("bottom") ) );
                 break;
             default:
-                OSL_ENSURE( 0, "### illegal vertical alignment value!" );
+                OSL_FAIL( "### illegal vertical alignment value!" );
                 break;
             }
         }
     }
 }
 //__________________________________________________________________________________________________
+void ElementDescriptor::readImageURLAttr( OUString const & rPropName, OUString const & rAttrName )
+{
+    if (beans::PropertyState_DEFAULT_VALUE != _xPropState->getPropertyState( rPropName ))
+    {
+        rtl::OUString sURL;
+        _xProps->getPropertyValue( rPropName ) >>= sURL;
+
+        if ( sURL.getLength() && sURL.compareToAscii( XMLSCRIPT_GRAPHOBJ_URLPREFIX, RTL_CONSTASCII_LENGTH( XMLSCRIPT_GRAPHOBJ_URLPREFIX ) ) == 0 )
+        {
+            Reference< document::XStorageBasedDocument > xDocStorage( _xDocument, UNO_QUERY );
+            if ( xDocStorage.is() )
+            {
+                uno::Sequence< Any > aArgs( 1 );
+                aArgs[ 0 ] <<= xDocStorage->getDocumentStorage();
+
+                ::comphelper::ComponentContext aContext( ::comphelper::getProcessServiceFactory() );
+                uno::Reference< document::XGraphicObjectResolver > xGraphicResolver;
+                aContext.createComponentWithArguments( OUSTR( "com.sun.star.comp.Svx.GraphicExportHelper" ), aArgs, xGraphicResolver );
+                if ( xGraphicResolver.is() )
+                    sURL = xGraphicResolver->resolveGraphicObjectURL( sURL );
+            }
+        }
+        if ( sURL.getLength() )
+                addAttribute( rAttrName, sURL );
+    }
+}
+//__________________________________________________________________________________________________
 void ElementDescriptor::readImageAlignAttr( OUString const & rPropName, OUString const & rAttrName )
 {
     if (beans::PropertyState_DEFAULT_VALUE != _xPropState->getPropertyState( rPropName ))
@@ -799,7 +839,7 @@ void ElementDescriptor::readImageAlignAttr( OUString const & rPropName, OUString
                 addAttribute( rAttrName, OUString( RTL_CONSTASCII_USTRINGPARAM("bottom") ) );
                 break;
             default:
-                OSL_ENSURE( 0, "### illegal image alignment value!" );
+                OSL_FAIL( "### illegal image alignment value!" );
                 break;
             }
         }
@@ -855,7 +895,7 @@ void ElementDescriptor::readImagePositionAttr( OUString const & rPropName, OUStr
                 addAttribute( rAttrName, OUString( RTL_CONSTASCII_USTRINGPARAM("center") ) );
                 break;
             default:
-                OSL_ENSURE( 0, "### illegal image position value!" );
+                OSL_FAIL( "### illegal image position value!" );
                 break;
             }
         }
@@ -884,7 +924,7 @@ void ElementDescriptor::readButtonTypeAttr( OUString const & rPropName, OUString
                 addAttribute( rAttrName, OUString( RTL_CONSTASCII_USTRINGPARAM("help") ) );
                 break;
             default:
-                OSL_ENSURE( 0, "### illegal button-type value!" );
+                OSL_FAIL( "### illegal button-type value!" );
                 break;
             }
         }
@@ -907,7 +947,7 @@ void ElementDescriptor::readOrientationAttr( OUString const & rPropName, OUStrin
                 addAttribute( rAttrName, OUString( RTL_CONSTASCII_USTRINGPARAM("vertical") ) );
                 break;
             default:
-                OSL_ENSURE( 0, "### illegal orientation value!" );
+                OSL_FAIL( "### illegal orientation value!" );
                 break;
             }
         }
@@ -933,19 +973,79 @@ void ElementDescriptor::readLineEndFormatAttr( OUString const & rPropName, OUStr
                 addAttribute( rAttrName, OUString( RTL_CONSTASCII_USTRINGPARAM("carriage-return-line-feed") ) );
                 break;
             default:
-                OSL_ENSURE( 0, "### illegal line end format value!" );
+                OSL_FAIL( "### illegal line end format value!" );
                 break;
             }
         }
     }
 }
 //__________________________________________________________________________________________________
+void ElementDescriptor::readDataAwareAttr( OUString const & rAttrName )
+{
+    Reference< lang::XMultiServiceFactory > xFac;
+    if ( _xDocument.is() )
+        xFac.set( _xDocument, uno::UNO_QUERY );
+
+    Reference< form::binding::XBindableValue > xBinding( _xProps, UNO_QUERY );
+
+    if ( xFac.is() && xBinding.is() && rAttrName.equals( OUSTR(XMLNS_DIALOGS_PREFIX ":linked-cell") ) )
+    {
+        try
+        {
+            Reference< beans::XPropertySet > xConvertor( xFac->createInstance( OUSTR( "com.sun.star.table.CellAddressConversion" )), uno::UNO_QUERY );
+        Reference< beans::XPropertySet > xBindable( xBinding->getValueBinding(), UNO_QUERY );
+            if ( xBindable.is() )
+            {
+                table::CellAddress aAddress;
+                xBindable->getPropertyValue( OUSTR("BoundCell") ) >>= aAddress;
+                xConvertor->setPropertyValue( OUSTR("Address"), makeAny( aAddress ) );
+                rtl::OUString sAddress;
+                xConvertor->getPropertyValue( OUSTR("PersistentRepresentation") ) >>= sAddress;
+                if ( sAddress.getLength() > 0 )
+                    addAttribute( rAttrName, sAddress );
+
+                OSL_TRACE( "*** Bindable value %s", rtl::OUStringToOString( sAddress, RTL_TEXTENCODING_UTF8 ).getStr() );
+
+            }
+        }
+        catch( uno::Exception& )
+        {
+        }
+    }
+    Reference< form::binding::XListEntrySink > xEntrySink( _xProps, UNO_QUERY );
+    if ( xEntrySink.is() && rAttrName.equals( OUSTR( XMLNS_DIALOGS_PREFIX ":source-cell-range") ) )
+    {
+        Reference< beans::XPropertySet > xListSource( xEntrySink->getListEntrySource(), UNO_QUERY );
+        if ( xListSource.is() )
+        {
+            try
+            {
+                Reference< beans::XPropertySet > xConvertor( xFac->createInstance( OUSTR( "com.sun.star.table.CellRangeAddressConversion" )), uno::UNO_QUERY );
+
+                table::CellRangeAddress aAddress;
+                xListSource->getPropertyValue( OUSTR( "CellRange" ) ) >>= aAddress;
+
+                rtl::OUString sAddress;
+                xConvertor->setPropertyValue( OUSTR("Address"), makeAny( aAddress ) );
+                xConvertor->getPropertyValue( OUSTR("PersistentRepresentation") ) >>= sAddress;
+                OSL_TRACE("**** cell range source list %s",
+                    rtl::OUStringToOString( sAddress, RTL_TEXTENCODING_UTF8 ).getStr() );
+                if ( sAddress.getLength() > 0 )
+                    addAttribute( rAttrName, sAddress );
+            }
+            catch( uno::Exception& )
+            {
+            }
+        }
+    }
+}
+//__________________________________________________________________________________________________
 void ElementDescriptor::readSelectionTypeAttr( OUString const & rPropName, OUString const & rAttrName )
 {
     if (beans::PropertyState_DEFAULT_VALUE != _xPropState->getPropertyState( rPropName ))
     {
         Any aSelectionType ( _xProps->getPropertyValue( rPropName ) );
-        
+
         if (aSelectionType.getValueTypeClass() == TypeClass_ENUM && aSelectionType.getValueType() == ::getCppuType( (::view::SelectionType*)0 ))
         {
             ::view::SelectionType eSelectionType;
@@ -966,7 +1066,7 @@ void ElementDescriptor::readSelectionTypeAttr( OUString const & rPropName, OUStr
                     addAttribute( rAttrName, OUString( RTL_CONSTASCII_USTRINGPARAM("range") ) );
                     break;
                 default:
-                    OSL_ENSURE( 0, "### illegal selection type value!" );
+                    OSL_FAIL( "### illegal selection type value!" );
                     break;
             }
         }
@@ -976,11 +1076,33 @@ void ElementDescriptor::readSelectionTypeAttr( OUString const & rPropName, OUStr
 void ElementDescriptor::readDefaults( bool supportPrintable, bool supportVisible )
 {
     Any a( _xProps->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM("Name") ) ) );
+
+    // The following is a hack to allow 'form' controls to override the default
+    // control supported by dialogs. This should work well for both vba support and
+    // normal openoffice ( when normal 'Dialogs' decide to support form control models )
+    // In the future VBA support might require custom models ( and not the just the form
+    // variant of a control that we currently use ) In this case the door is still open,
+    // we just need to define a new way for the 'ServiceName' to be extracted from the
+    // incomming model. E.g. the use of supporting service
+    // "com.sun.star.form.FormComponent", 'ServiceName' and XPersistObject
+    // is only an implementation detail here, in the future some other
+    // method ( perhaps a custom prop ) could be used instead.
+    Reference< lang::XServiceInfo > xSrvInfo( _xProps, UNO_QUERY );
+    if ( xSrvInfo.is() && xSrvInfo->supportsService( OUSTR("com.sun.star.form.FormComponent" ) ) )
+    {
+        Reference< io::XPersistObject > xPersist( _xProps, UNO_QUERY );
+        if ( xPersist.is() )
+        {
+            OUString sCtrlName = xPersist->getServiceName();
+            if ( sCtrlName.getLength() )
+                    addAttribute( OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":control-implementation") ), sCtrlName );
+        }
+    }
     addAttribute( OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":id") ),
              * reinterpret_cast< const OUString * >( a.getValue() ) );
     readShortAttr( OUString( RTL_CONSTASCII_USTRINGPARAM("TabIndex") ),
                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":tab-index") ) );
-    
+
     sal_Bool bEnabled = sal_False;
     if (_xProps->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM("Enabled") ) ) >>= bEnabled)
     {
@@ -992,7 +1114,7 @@ void ElementDescriptor::readDefaults( bool supportPrintable, bool supportVisible
     }
     else
     {
-        OSL_ENSURE( 0, "unexpected property type for \"Enabled\": not bool!" );
+        OSL_FAIL( "unexpected property type for \"Enabled\": not bool!" );
     }
     
     sal_Bool bVisible = sal_True;
@@ -1111,16 +1233,16 @@ void ElementDescriptor::readEvents()
                             ++p;
                         }
                     }
-                    
+
                     ElementDescriptor * pElem;
                     Reference< xml::sax::XAttributeList > xElem;
-                    
+
                     if (aEventName.getLength()) // script:event
-                    {    
+                    {
                         pElem = new ElementDescriptor(
                             OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_SCRIPT_PREFIX ":event") ) );
                         xElem = pElem;
-                        
+
                         pElem->addAttribute(
                             OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_SCRIPT_PREFIX ":event-name") ),
                             aEventName );
@@ -1181,7 +1303,7 @@ void ElementDescriptor::readEvents()
                 }
                 else
                 {
-                    OSL_ENSURE( 0, "### unexpected event type in container!" );
+                    OSL_FAIL( "### unexpected event type in container!" );
                 }
             }
         }
@@ -1331,265 +1453,29 @@ void SAL_CALL exportDialogModel(
     SAL_THROW( (Exception) )
 {
     StyleBag all_styles;
-    ::std::vector< Reference< xml::sax::XAttributeList > > all_elements;
-    
-    // read out all props
-
-    Sequence< OUString > aElements( xDialogModel->getElementNames() );
-    OUString const * pElements = aElements.getConstArray();
-    
-    ElementDescriptor * pRadioGroup = 0;
-    
-    sal_Int32 nPos;
-    for ( nPos = 0; nPos < aElements.getLength(); ++nPos )
-    {
-        Any aControlModel( xDialogModel->getByName( pElements[ nPos ] ) );
-        Reference< beans::XPropertySet > xProps;
-        OSL_VERIFY( aControlModel >>= xProps );
-        if (! xProps.is())
-            continue;
-        Reference< beans::XPropertyState > xPropState( xProps, UNO_QUERY );
-        OSL_ENSURE( xPropState.is(), "no XPropertyState!" );
-        if (! xPropState.is())
-            continue;
-        Reference< lang::XServiceInfo > xServiceInfo( xProps, UNO_QUERY );
-        OSL_ENSURE( xServiceInfo.is(), "no XServiceInfo!" );
-        if (! xServiceInfo.is())
-            continue;
-
-        ElementDescriptor * pElem = 0;
-        Reference< xml::sax::XAttributeList > xElem;
-        
-        // group up radio buttons
-        if ( xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlRadioButtonModel") ) ) )
-        {
-            if (! pRadioGroup) // open radiogroup
-            {
-                pRadioGroup = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":radiogroup") ) );
-                all_elements.push_back( pRadioGroup );
-            }
-            
-            pElem = new ElementDescriptor(
-                xProps, xPropState,
-                OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":radio") ) );
-            xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-            pElem->readRadioButtonModel( &all_styles, xDocument  );
-            pRadioGroup->addSubElement( xElem );
-        }
-        else // no radio
-        {
-            pRadioGroup = 0; // close radiogroup
-            
-            if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlButtonModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":button") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readButtonModel( &all_styles );
-            }
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlCheckBoxModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":checkbox") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readCheckBoxModel( &all_styles );
-            }
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlComboBoxModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":combobox") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readComboBoxModel( &all_styles, xDocument );
-            }
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlListBoxModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":menulist") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readListBoxModel( &all_styles, xDocument );
-            }
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlGroupBoxModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":titledbox") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readGroupBoxModel( &all_styles );
-            }
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoMultiPageModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":multipage") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readMultiPageModel( &all_styles );
-            }
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlFixedTextModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":text") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readFixedTextModel( &all_styles );
-            }
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlEditModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":textfield") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readEditModel( &all_styles );
-            }
-            // FixedHyperLink
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlFixedHyperlinkModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":linklabel") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readFixedHyperLinkModel( &all_styles );
-            }
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlImageControlModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":img") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readImageControlModel( &all_styles, xDocument );
-            }
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlFileControlModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":filecontrol") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readFileControlModel( &all_styles );
-            }
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.tree.TreeControlModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":treecontrol") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readTreeControlModel( &all_styles );
-            }
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlCurrencyFieldModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":currencyfield") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readCurrencyFieldModel( &all_styles );
-            }
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlDateFieldModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":datefield") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readDateFieldModel( &all_styles );
-            }
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlNumericFieldModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":numericfield") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readNumericFieldModel( &all_styles );
-            }           
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlTimeFieldModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":timefield") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readTimeFieldModel( &all_styles );
-            }
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlPatternFieldModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":patternfield") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readPatternFieldModel( &all_styles );
-            }
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlFormattedFieldModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":formattedfield") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readFormattedFieldModel( &all_styles );
-            }
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlFixedLineModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":fixedline") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readFixedLineModel( &all_styles );
-            }
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlScrollBarModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":scrollbar") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readScrollBarModel( &all_styles, xDocument );
-            }
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlSpinButtonModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":spinbutton") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readSpinButtonModel( &all_styles, xDocument );
-            }
-            else if (xServiceInfo->supportsService( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.UnoControlProgressBarModel") ) ) )
-            {
-                pElem = new ElementDescriptor(
-                    xProps, xPropState,
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":progressmeter") ) );
-                xElem = static_cast< xml::sax::XAttributeList * >( pElem );
-                pElem->readProgressBarModel( &all_styles );
-            }
-            //
-            
-            OSL_ASSERT( xElem.is() );
-            if (xElem.is())
-            {
-                all_elements.push_back( xElem );
-            }
-            else
-            {
-                OSL_ENSURE( sal_False, "unknown control type!" );
-                continue;
-            }
-        }
-    }
-    
-    xOut->startDocument();
-    
-    OUString aDocTypeStr( RTL_CONSTASCII_USTRINGPARAM(
-        "<!DOCTYPE dlg:window PUBLIC \"-//OpenOffice.org//DTD OfficeDocument 1.0//EN\""
-        " \"dialog.dtd\">" ) );
-    xOut->unknown( aDocTypeStr );
-    xOut->ignorableWhitespace( OUString() );
-    
     // window
     Reference< beans::XPropertySet > xProps( xDialogModel, UNO_QUERY );
     OSL_ASSERT( xProps.is() );
     Reference< beans::XPropertyState > xPropState( xProps, UNO_QUERY );
     OSL_ASSERT( xPropState.is() );
-    
+
+    ElementDescriptor * pElem = new ElementDescriptor(
+                    xProps, xPropState,
+                    OUString( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":bulletinboard") ), xDocument );
+    Reference< xml::sax::XAttributeList > xElem( pElem );
+    pElem->readBullitinBoard( &all_styles );
+
+    xOut->startDocument();
+
+    OUString aDocTypeStr( RTL_CONSTASCII_USTRINGPARAM(
+        "<!DOCTYPE dlg:window PUBLIC \"-//OpenOffice.org//DTD OfficeDocument 1.0//EN\""
+        " \"dialog.dtd\">" ) );
+    xOut->unknown( aDocTypeStr );
+    xOut->ignorableWhitespace( OUString() );
+
+
     OUString aWindowName( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":window") );
-    ElementDescriptor * pWindow = new ElementDescriptor( xProps, xPropState, aWindowName );
+    ElementDescriptor * pWindow = new ElementDescriptor( xProps, xPropState, aWindowName, xDocument );
     Reference< xml::sax::XAttributeList > xWindow( pWindow );
     pWindow->readDialogModel( &all_styles );
     xOut->ignorableWhitespace( OUString() );
@@ -1598,30 +1484,24 @@ void SAL_CALL exportDialogModel(
     pWindow->dumpSubElements( xOut.get() );
     // dump out stylebag
     all_styles.dump( xOut );
-    
-    if (! all_elements.empty())
-    {   
+
+    if ( xDialogModel->getElementNames().getLength() )
+    {
         // open up bulletinboard
         OUString aBBoardName( RTL_CONSTASCII_USTRINGPARAM(XMLNS_DIALOGS_PREFIX ":bulletinboard") );
         xOut->ignorableWhitespace( OUString() );
-        xOut->startElement( aBBoardName, Reference< xml::sax::XAttributeList >() );
-        
-        // export control elements
-        for ( std::size_t n = 0; n < all_elements.size(); ++n )
-        {
-            ElementDescriptor * pElem = static_cast< ElementDescriptor * >( all_elements[ n ].get() );
-            pElem->dump( xOut.get() );
-        }
-        
+        xOut->startElement( aBBoardName, xElem );
+
+        pElem->dumpSubElements( xOut.get() );
         // end bulletinboard
         xOut->ignorableWhitespace( OUString() );
         xOut->endElement( aBBoardName );
     }
-    
+
     // end window
     xOut->ignorableWhitespace( OUString() );
     xOut->endElement( aWindowName );
-    
+
     xOut->endDocument();
 }
 
